package BondLib "Modelica library for Bond Graph modeling" 
  extends Modelica.Icons.Library;
  
  annotation (
    Coordsys(
      extent=[0, 0; 402, 261],
      grid=[2, 2],
      component=[20, 20]),
    Window(
      x=0.01,
      y=0.55,
      width=0.4,
      height=0.4,
      library=1,
      autolayout=1),
    Documentation(info="<html>
The <b>BondLib</b> library is designed as a graphical library for modeling physical systems using the bond graph metaphor.  This library has been created by Prof. Fran&ccedil;ois Cellier and his students.<p>

When modeling systems in this fashion, it is common to hide many connections behind the bondgraphic connectors.  To this end, one first places neighboring connected elements next to each other <br>
<img src=\"../Images/BG_Fig1.gif\"> <br>
making the connection between the connectors.  The two models are then shifted together, until the two connectors are in the same position on the screen <br>
<img src=\"../Images/BG_Fig2.gif\"> <br>
thereby hiding the connection from view. <p>

Bond graphs are described in terms of four basic variables: <p>

<ol>
<li> efforts (<b>e</b>), <br>
<li> flows (<b>f</b>), <br>
<li> generalized momentums (<b>p</b>), and <br>
<li> generalized positions (<b>q</b>).
</ol> <p>

The four variables are related to each other in the following fashion: <br>
<img src=\"../Images/BG_Fig3.gif\"> <p>

Power is always the product of effort and flow: <br>
<b>P = e*f</b> <p>

The three basic OnePort elements of the bond graph methodology are: <p>

<ol>
<li> resistors (<b>R</b>): <b>e = R(f)</b>, <br>
<li> capacitors (<b>C</b>): <b>e = C(q)</b>, and <br>
<li> inductors (<b>I</b>): <b>f = I(p)</b>,
</ol> <p>

where <b>R</b>, <b>C</b>, and <b>I</b> can be arbitrarily non-linear functions operating in the first and third quadrants only. <p>

Bond graphs are domain independent.  The four basic variables of a number of physical domains are summarized below: <br>
<img src=\"../Images/BG_Fig4.gif\"> <p>

<hr>

<b>References:</b> <p>

<ol>
<li> Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York, ISBN: 0-387-97502-0, 755p.
<li> Cellier, F.E. (1992), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/HierarchBG.pdf\">Hierarchical Non-linear
     Bond Graphs: A Unified Methodology for Modeling Complex Physical Systems</a>,\" <i>Simulation</i>, <b>58</b>(4),
     pp. 230-248.
<li> Cellier, F.E. (1995), \"Bond Graphs: The Right Choice for Educating Students in Modeling Continuous-time Physical
     Systems,\" <i>Simulation</i>, <b>64</b>(3), pp. 154-159.
<li> Cellier, F.E. and R.T. McBride (2003), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/icbgm03_bglib.pdf\">Object-oriented
     Modeling of Complex Physical Systems Using the Dymola Bond-graph Library</a>,\" <i>Proc. ICBGM'03,
     6<sup>th</sup> SCS Intl. Conf. on Bond Graph Modeling and Simulation</i>, Orlando, Florida, pp. 157-162.
<li> Cellier, F.E. and A. Nebot (2005), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/modelica2005_cellier.pdf\">The
     Modelica Bond Graph Library</a>,\" <i>Proc. 4<sup>th</sup> Modelica Conference</i>, Hamburg, Germany.
</ol> <p>

<hr>

<b>Main Author:</b> <p>

Prof. Dr. Fran&ccedil;ois E. Cellier <br>
Institut f&uuml;r Computational Science <br>
ETH Z&uuml;rich <br>
ETH Zentrum HRS H28 <br>
CH-8092 Z&uuml;rich <br>
Switzerland <p>

Phone: +41(1)632-7474 <br>
Fax: +41(1)632-1374 <br>
Email: <a href=\"mailto:FCellier@Inf.ETHZ.CH\"> FCellier@Inf.ETHZ.CH</a> <br>
URL: <a href=\"http://www.inf.ethz.ch/~fcellier/\"> http://www.inf.ethz.ch/~fcellier/</a> <p>

<hr>

<b>Release Notes:</b> <p>

<ul>
<li><i>February 10, 2005</i>
       by <a href=\"http://www.inf.ethz.ch/~fcellier/\">Fran&ccedil;ois E. Cellier</a>:<br>
       released.</li>
</ul> <p>

<hr>

<b>Copyright (C) 2005, Fran&ccedil;ois E. Cellier.</b> <p>

<i>The ModelicaAdditions.BondLib package is <b>free</b> software;
it can be redistributed and/or modified
under the terms of the <b>Modelica license</b>, see the license conditions
and the accompanying <b>disclaimer</b> in the documentation of package
Modelica in file \"Modelica/package.mo\".</i>
</html>
"), Diagram(
      Rectangle(extent=[-104, 98; 92, -92], style(
          color=0,
          thickness=2,
          fillColor=9)),
      Text(
        extent=[-64, 66; 48, 44],
        style(
          color=0,
          thickness=2,
          fillColor=9,
          fillPattern=1),
        string="The bond graph"),
      Text(
        extent=[-77.9, 13.05; 64, -16],
        style(
          color=0,
          thickness=2,
          fillColor=9,
          fillPattern=1),
        string="domain independent"),
      Text(
        extent=[-59.8, 32.1; 50, 2],
        style(
          color=0,
          thickness=2,
          fillColor=9,
          fillPattern=1),
        string="offers a uniform, "),
      Text(
        extent=[-51.7, -10.85; 34, -28],
        style(
          color=0,
          thickness=2,
          fillColor=9,
          fillPattern=1),
        string="interface to"),
      Text(
        extent=[-83.6, -21.8; 78, -52],
        style(
          color=0,
          thickness=2,
          fillColor=9,
          fillPattern=1),
        string="physical system modeling."),
      Text(
        extent=[-49.9, 49.05; 36, 22],
        style(
          color=0,
          thickness=2,
          fillColor=9,
          fillPattern=1),
        string="methodology")),
    uses(Modelica(version="2.1")),
    version="1",
    conversion(from(version="", script="ConvertFromBondLib_.mos")));
  
  package UsersGuide "User's Guide" 
    annotation (DocumentationClass=true, Documentation(info="<html>
<h3><font color=\"#008000\" size=5>Users Guide of package BondLib</font></h3>
<p>
Library <b>BondLib</b> is a <b>free</b> Modelica package providing components to model multi-energy physical systems in a convenient domain-independent format. This package contains the <b>users guide</b> to the library, and has the following content:
</p>
<ol>
<li><a href=\"Modelica://BondLib.UsersGuide.Overview\">Overview of library</a>
       gives an overview of the library.
</ol>
</html>
"));
    package Overview "Overview of Library" 
      annotation (Documentation(info="<html>
This overview contains the following sections: <p>

<ol>
<li><a href=\"Modelica://BondLib.UsersGuide.Overview.Introduction\">An introduction to bond graph modeling</a>
<li><a href=\"Modelica://BondLib.UsersGuide.Overview.Connectors\">Bond graph connectors</a>
<li><a href=\"Modelica://BondLib.UsersGuide.Overview.Bonds\">Causal and a-causal bonds</a>
<li><a href=\"Modelica://BondLib.UsersGuide.Overview.Basic\">Basic bond graph elements</a>
<li><a href=\"Modelica://BondLib.UsersGuide.Overview.Advanced\">Advanced bond graph elements</a>
<li><a href=\"Modelica://BondLib.UsersGuide.Overview.Wrapping\">Wrapping bond graphs</a>
<li><a href=\"Modelica://BondLib.UsersGuide.Overview.Electrical\">The electrical library</a>
<li><a href=\"Modelica://BondLib.UsersGuide.Overview.Encapsulating\">Encapsulating bond graphs</a>
<li><a href=\"Modelica://BondLib.UsersGuide.Overview.Hydraulic\">The hydraulic library</a>
<li><a href=\"Modelica://BondLib.UsersGuide.Overview.Examples\">Examples</a>
<li><a href=\"Modelica://BondLib.UsersGuide.Overview.Literature\">Literature</a>
</ol>
</html>
"));
      class Introduction "An introduction to bond graph modeling" 
        annotation (Documentation(info="<html>
Bond graphs offer a generic domain-independent means to graphically modeling physical systems in an object-oriented fashion. <p>

All physical systems are characterized by the fact that they observe a number of conservation principles.  Prime among those is the conservation of energy.  When modeling a physical system, it is important for the modeler to be aware of these conservation principles, and ensure that the models constructed adhere to them. <p>

Yet, if the modeling formalism doesn't guarantee that the conservation principles are being observed, i.e., if it is up to the modeler to verify that his or her models adhere to them, these principles can get easily violated, because modelers (just like all other people) are constantly under time pressure, and usually won't take the time to validate their models, once they have been constructed and compile/simulate without generating error messages. <p>

It may therefore be a good idea to embrace a modeling formalism that checks the conservation principles implicitly for the modeler.  For example, if a modeler wishes to model an electrical capacitor, he or she knows that: <p>

<b>i = C*<font color=red>der</font>(u)</b> <p>

Yet, this model may fail, when the capacitance <b>C</b> happens to be a function of time.  It is better to ask oneself, what happens physically in the capacitor. <p>

We know that the capacitor stores <i>electrical charge</i>, <b>Q</b>.  The electrical charge is the integral of the current.  Thus, when current flows into the capacitor, electrical charge builds up.  The charge is a physical quantity having mass.  It thus needs to be conserved.  Thus, the charge, <b>Q</b>, rather than the voltage, <b>u</b>, is a much better choice for a state variable, since voltage doesn't need to be conserved. <p>

The voltage across the capacitor is proportional to the charge stored in the capacitor: <p>

<b>u = C*Q</b> <p>

What happens to the energy?  The power, <b>P</b>, flowing into the capacitor is the product of current and voltage: <p>

<b>P = u*i</b> <p>

The energy, <b>E</b>, stored in the capacitor is the integral of the power.  It also needs to be conserved.  Yet, we only need one state variable, thus energy doesn't get conserved automatically.  We must ensure explicitly that this happens. <p>

Bond graphs ensure that no energy is ever lost or (worse!) generated out of thin air in interconnections between models.  They do this by explicitly modeling the power flow through a physical system. <p>

Power, in all physical systems, can always be expressed as a product of two adjugate variables, or possibly in the most complex cases, as the sum of products of adjugate variables. <p>

Bond graphs work with these adjugate variables as the basic modeling variables: the <i>effort</i>, <b>e</b>, and the <i>flow</i>, <b>f</b>. Power is always the product of effort and flow: <p>

<b>P = e*f</b> <p>

What these adjugate variables represent, depends on the physical nature of the model.  For example in electrical systems, the effort would be the <i>voltage</i>, whereas the flow would be the <i>current</i>.  In mechanical translational systems, the effort would be the <i>force</i>, whereas the flow would be the <i>velocity</i>. <p>

A power flow is represented by a harpoon, with which the two adjugate variables are being associated.  The hook of the harpoon points always to the \"left\" (relative to the direction, in which the harpoon points), and the effort variable is written on the side of the harpoon, whereas the flow variable is written on the opposite side: <p>

<img src=\"../Images/BG_Fig5.gif\"> <p>

The direction of the harpoon is the direction of positive power flow. <p>

Evidently, since <i>efforts</i> and <i>flows</i> can represent different physical properties, no strong type checking is possible in bond graph modeling.  All variables need to be declared as <b><font color=red>Real</font></b> rather than <b><font color=red>Modelica.SIunits.Voltage</font></b>, for example.  This is a price that the modeler must be willing to pay, if he or she wishes to use bond graphs. <p>

Sometimes, as in the case of the capacitor, it is useful to also consider the integrals of the two adjugate variables, as these are in fact natural state variables.  Since bond graphs were invented by a mechanical engineer, the integral of the effort is called the <i>generalized momentum</i>, <b>p</b>, whereas the integral of the flow is called the <i>generalized position</i>, <b>q</b>, since the integral of <i>force</i> is a <i>momentum</i>, whereas the integral of <i>velocity</i> is a position. <p>

The below table lists the four basic bond graph variables, <b>e</b>, <b>f</b>, <b>p</b>, and <b>q</b>, for a number of different energy domains: <p>

<img src=\"../Images/BG_Fig4.gif\"> <p>

The bond graph model of a non-linear capacitor would thus take the form: <p>

<img src=\"../Images/BG_Fig6.gif\"> <p>

where <b><font color=red>ModPassiveOnePort</font></b> is one of the standard bond graph interfaces offered in the <b><font color=\"#008000\">Interfaces</font</b> sub-library of the bond graph library.  It represents a modulated one-port, where the modulation signal (a real-valued input) is given the name <b>s</b>.  The variables <b>e</b> and <b>f</b> don't need to be declared either, as they are already declared inside the (partial) interface model.
</html>
"));
      end Introduction;
      
      class Connectors "Bond graph connectors" 
        annotation (Documentation(info="<html>
As bonds carry two physical variables, the <i>effort</i>, <b>e</b> and the <i>flow</i>, <b>f</i>, the bond graph connectors need to carry at least these two variables.  Yet, also the direction of positive power flow is explicitly encoded in the bond models, and thereby also in the connectors.  To this end, a (non-physical) directional variable, <b>d</b>, is associated with each bond: <p>

<img src=\"../Images/BG_Fig7.gif\"> <p>

<b>d</b> assumes a value of <b>-1</b> at the connector, from which the bond emanates, and a value of <b>+1</b> at the  connector, where it ends. <p>

All bond graph variables are declared as <i>potential variables</i>, i.e., rather than making use of the <i>flow variables</i> of Modelica, the bond graph library encodes the direction of flow explicitly using the <b>d</b> variable. <p>

The bond graph connector is a grey dot.  Its definition is given as follows: <p>

<img src=\"../Images/BG_Fig8.gif\"> <p>

The corresponding bond model has been encoded as: <p>

<img src=\"../Images/BG_Fig9.gif\"> <p>

It passes the physical variables along, like an electrical wire, and it defines the directional variable, <b>d</b>, at the two ends. <p>

In the bond graph methodology, there are two types of nodes, called <i>junctions</i>, the <b>0-junction</b>, which corresponds to a regular Modelica node, and the <b>1-junction</b>, which offers the dual functionality. <p>

<img src=\"../Images/BG_Fig10.gif\"> <p>

The flows into a 0-junction add up to zero, whereas the efforts around a 0-junction are the same.  Correspondingly, the efforts into a 1-junction add up to zero, whereas the flows around it are the same.  This, by the way, is the reason, why the bond graph library doesn't make use of the Modelica flow variables, since Modelica offers only one type of nodes. <p>

For example, the 1-junction with three bond connectors is defined as: <p>

<img src=\"../Images/BG_Fig11.gif\"> <p>

It inherits the effort and flow vectors from the (partial) <b><font color=red>ThreePortOne</font></b> interface model: <p>

<img src=\"../Images/BG_Fig12.gif\"> <p>

which makes use of the directional <b>d</b> variables to decide on the sign in summing the efforts (or flows) into the junction.
</html>
"));
      end Connectors;
      
      class Bonds "Causal and a-causal bonds" 
        annotation (Documentation(info="<html>
Modelica is perfectly capable of deciding on its own the computational causality of all equations.  Thus, models can be generated in the form of implicitly defined differential and algebraic equation (DAE) systems.  If we use the a-causal bonds, as presented so far, this is precisely, what we get. <p>

However, it may be useful to write models in their causal form, as the computational causality information may offer additional insight into the system. <p>

Since bonds carry two physical variables, we need to generate two equations to compute their values.  It turns out that, in every case, one of the two variables is computed at each end of the bond.  We can denote the side, where the flow variable is computed, by marking it with a vertical stroke, the so-called <i>causality stroke</i>. <p>

To this end, the bond graph library offers two additional types of bonds: <p>

<img src=\"../Images/BG_Fig13.gif\"> <p>

In this case, the equations can be read out of the bond graph in their causal forms: <p>

<b>B1.e = B2.e</b> <br>
<b>B3.e = B2.e</b> <br>
<b>B2.f = B1.f - B3.f</b> <p>

for the 0-junction, and: <p>

<b>B4.f = B5.f</b> <br>
<b>B6.f = B5.f</b> <br>
<b>B5.e = B4.e - B6.e</b> <p>

for the 1-junction, respectively.  Since the 0-junction has only one flow equation, there must be exactly one causality stroke at the junction.  Similarly, since the 1-junction has only one effort equation, there must be exactly one causality stroke away from the junction. <p>

Causal and a-causal bonds can be arbitrarily mixed.  We recommend to use causal bonds as much as possible.
</html>
"));
      end Bonds;
      
      class Basic "Basic bond graph elements" 
        annotation (Documentation(info="<html>
The four basic bond graph variables can be related in the following way: <p>

<img src=\"../Images/BG_Fig3.gif\"> <p>

<i>Resistors</i> relate efforts and flows to each other in a static fashion, i.e.: <p>

<b>e = R(f)</b> <p>

Similarly, <i>capacitors</i> relate efforts and generalized positions to each other, i.e.: <p>

<b>e = C(q)</b> <p>

Finally, <i>inductors</i> relate flows and generalized momentums to each other, i.e.: <p>

<b>f = I(p)</b> <p>

All of these relationships must be defined in the first and thrid quadrants only for the element to be physical. There cannot exist any other relationships in physics; thus, all bond graphs can be written in terms of the three variables <b>R</b>, <b>C</b>, and <b>I</b>. <p>

In addition, energy can be transformed, either from one domain to another, or within a domain.  The transformation of free energy can follow two different patterns: <p>

<b>e1 = m*e2</b> <br>
<b>e1*f1 = e2*f2</b> <p>

or: <p>

<b>e1 = r*f2</b> <br>
<b>e1*f1 = e2*f2</b> <p>

We call the former relationship a <i>transformer</i>, <b>TF</b>, whereas the latter relationship is called a <i>gyrator</i>, <b>GY</i>.  The second equation in both cases ensures that no power is either lost or generated by the transformation. <p>

In their causal forms, transformers and gyrators can be written as follows: <p>

<img src=\"../Images/BG_Fig14.gif\"> <p>

Thus, both the transformers and the gyrators have two possible causalities.  <i>Transformers</i> have always one causality stroke at the transformer and the other away from it, whereas <i>gyrators</i> have either both causality strokes at the gyrator, or both away from it. <p>

Finally, we need two types of sources, the effort source, <b>Se</b>, and the flow source, <b>Sf</b>: <p>

<img src=\"../Images/BG_Fig15.gif\"> <p>

The causality strokes of the two sources are fixed. <p>

As we haven't discussed the causality strokes for the three basic modeling elements yet, let us cover that topic now: <p>

<img src=\"../Images/BG_Fig16.gif\"> <p>

Both capacitors and inductors have <i>preferred causalities</i>, so-called <i>integral causalities</i>, whereas the causality of the resistors is free. <p>

That is all there is.  These elements exhaust all of physics, and puritans among the bond graph practitioners would argue that no other elements should be offered. <p>

If the preferred causality of a bond graph can be assigned in a unique way, the bond graph has neither algebraic loops nor structural singularities, i.e., can be described by an index-0 ordinary differential equation (ODE) system.  If the modeler has free choice in assigning causality strokes, the model contains one or several algebraic loops.  If a conflict exists on either capacitors or inductors, the model consists of a higher-index DAE system.
</html>
"));
      end Basic;
      
      class Advanced "Advanced bond graph elements" 
        annotation (Documentation(info="<html>
For practical purposes, it makes sense to add more elements to the list. <p>

On the one hand, we may wish to offer different types of sources, such as sinusoidal and trapezoidal sources, to make the tool more practical for simulation.  Similarly, we may wish to offer different types of non-linear resistors, e.g. for hydraulic systems or thermal systems.  These are not really new elements, only specializations of the elements introduced previously. <p>

It may also make sense to offer sensor (detector) elements.  We may wish to sense any one of the four basic variables.  An effort detector, <b>De</b>, receives the effort from the model.  It computes the flow, by setting it to zero.  Thus, an effort sensor is in fact the same as a zero flow source: <p>

<img src=\"../Images/BG_Fig17.gif\"> <p>

with the model: <p>

<img src=\"../Images/BG_Fig18.gif\"> <p>

A position sensor: <p>

<img src=\"../Images/BG_Fig19.gif\"> <p>

on the other hand, has the model: <p>

<img src=\"../Images/BG_Fig20.gif\"> <p>

i.e., a position sensor is a macro element that is itself described by a bond graph.  A position sensor is a flow sensor followed by an integrator. <p>

Finally, we ought to discuss the switching elements.  The bond graph switch: <p>

<img src=\"../Images/BG_Fig21.gif\"> <p>

has a Boolean input signal using the convention that, if the input signal has a value of <i>true</i>, the switch is <i>open</i>, i.e., there is zero flow.  On the other hand, if the Boolean input signal assumes a value of <i>false</i>, the switch is <i>closed</i>, i.e., there is zero effort. <p>

Switch elements are strange, because they change the location of their causality stroke as a function of the value of the Boolean input signal.  Thus, switch elements must always be attached to a-causal bonds. <p>

Furthermore, if the causality of the bond connecting to the switch is fixed from the outside, an ideal switch will lead to a division by zero in one of the two switch positions.  Thus, ideal switch elements must always be placed inside algebraic loops. <p>

To avoid this pitfall, the library offers also a leaking switch element, <b>Sw2</i>, that contains a parasitic resistor in the closed state, and a parasitic conductance in the open state. <p>

The library also offers special switching elements, such as electrical diodes.
</html>
"));
      end Advanced;
      
      class Wrapping "Wrapping bond graphs" 
        annotation (Documentation(info="<html>
Although bond graphs can be used to describe arbitrarily complex physical systems, they offer a fairly low-level interface and are therefore not always easily readable.  Furthermore, different modelers may prefer different modeling mechanisms, because they are more familiar with them. <p>

Since bond graphs offer a low-level interface, it is always possible to wrap bond graphs inside other modeling metaphors.  For example, the electrical resistor model: <p>

<img src=\"../Images/BG_Fig22.gif\"> <p>

can easily be reimplemented as follows: <p>

<img src=\"../Images/BG_Fig23.gif\"> <p>

The <b>El2BG</b> and <b>BG2El</b> blocks are wrappers that transform the electrical connectors to bond graph connectors, and vice versa.
</html>
"));
      end Wrapping;
      
      class Electrical "The electrical library" 
        annotation (Documentation(info="<html>
We made use of the wrapping technique to re-implement large portions of the standard electrical analog library of Modelica using bond graph technology.  These models have the same touch and feel as the models contained in the standard library.  They are interchangeable and combinable in an arbitrary fashion. <p>

The new electrical analog library is a subset of the standard library, because not all elements have been recoded yet.  However, it is also a superset, because additional elements have been provided in some places. <p>

Especially, the new library contains Spice-style implementations of the four classes of bipolar transistors, the laterally and vertically diffused NPN and PNP transistors with all of the technological parameters that Spice offers.
</html>
"));
      end Electrical;
      
      class Encapsulating "Encapsulating bond graphs" 
        annotation (Documentation(info="<html>
<i>Encapsulation</i> of bond graph models is a technique similar to <i>wrapping</i>, however, it doesn't require special wrapping models.  The bond graph methodology already offers standard interfaces to mathematical signals.  On the one hand, there are the modulated sources, <b>mSe</b> and <b>mSf</b>, which convert input signals to bond graph signals.  On the other hand, there are the four detector elements, <b>De</b>, <b>Df</b>, <b>Dp</b>, and <b>Dq</b>, that offer the inverse functionality by converting bond graph signals to mathematical signals. <p>

These elements can be used to encapsulate bond graphs inside block diagrams, which is particularly useful for the description of control systems, the individual components of which may still be composed using bond graph technology.
</html>"));
      end Encapsulating;
      
      class Hydraulic "The hydraulic library" 
        annotation (Documentation(info="<html>
The hydraulic library contains a few bond graph models of hydraulic systems, such as a hydraulic motor with a servo valve. <p>

This library was built using the encapsulation technique discussed earlier.  The hydraulic motor is described by a bond graph with two bond graph connectors at the input, and one signal connector at the output: <p>

<img src=\"../Images/BG_Fig24.gif\"> <p>

The servo valve, on the other hand, is described by another bond graph with one signal connector at the input, and two bond graph connectors at the output: <p>

<img src=\"../Images/BG_Fig25.gif\"> <p>

In this way, the two components can be connected in the form of a block diagram: <p>

<img src=\"../Images/BG_Fig26.gif\"> <p>

where they can then be used as part of a control loop: <p>

<img src=\"../Images/BG_Fig27.gif\">
</html>
"));
      end Hydraulic;
      
      class Examples "Examples" 
        annotation (Documentation(info="<html>
The library contains a small but interesting example section: <p>

<ol>
<li> <b>SimpleBondGraph</b> describes a simple bond graph of a small electrical circuit.  The development of this bond graph was explained in [3].
<li> <b>ElectricalCircuit</b> contains a model of the same circuit, this time using the wrapping technology and components of the new electrical analog library contained as part of the bond graph library.
<li><b>OperationalAmplifierCircuit</b> describes a commercial hifi operational amplifier built in bipolar technology with six NPN and six PNP transistors [1].
<li><b>HydraulicControl</b> contains a hydraulic motor control problem, also explained in [2,3], that explains the encapsulation technique.
<li><b>SolarHouse</b> shows the use of bond graphs for thermodynamic modeling.  The example contains a fairly elaborate model of a passive solar heating system implemented in an experimental house in Tucson [5,6].
<li><b>Biosphere </b> shows another example of thermodynamic modeling, describing a model of the thermodynamic budget of the Biosphere 2 structure, located outside Tucson, without air conditioning [3,4].
</ol> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York, ISBN: 0-387-97502-0, 755p.
<li> Cellier, F.E. and R.T. McBride (2003), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/icbgm03_bglib.pdf\">Object-oriented
     Modeling of Complex Physical Systems Using the Dymola Bond-graph Library</a>,\" <i>Proc. ICBGM'03,
     6<sup>th</sup> SCS Intl. Conf. on Bond Graph Modeling and Simulation</i>, Orlando, Florida, pp. 157-162.
<li> Cellier, F.E. and A. Nebot (2005), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/modelica2005_cellier.pdf\">The
     Modelica Bond Graph Library</a>,\" <i>Proc. 4<sup>th</sup> Modelica Conference</i>, Hamburg, Germany.
<li> Nebot, A., F.E. Cellier, and F. Mugica (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/ecoeng_bio2.pdf\">Simulation
     of Heat and Humidity Budget of Biosphere 2 without its Air Conditioning</a>,\" <i>Ecological Engineering</i>,
     <b>13</b>, pp. 333-356.
<li> Weiner, M. (1992), <i>Bond Graph Model of a Passive Solar Heating System</i>, MS Thesis, Dept. of Electr. &amp;
     Comp. Engr., University of Arizona, Tucson, Arizona.
<li> Weiner, M., and F.E. Cellier (1993), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/weiner.pdf\">Modeling
     and Simulation of a Solar Energy System by Use of Bond Graphs</a>,\" <i>Proc. 1<sup>st</sup> SCS Intl. Conf. on Bond Graph
     Modeling</i>, San Diego, California, pp.301-306.
</ol>
</html>
"));
      end Examples;
      
      class Literature "Literature" 
        annotation (Documentation(info="<html>
We offer a fairly substantial bibliography of bond graph modeling in the \"<a href=\"http://www.inf.ethz.ch/~fcellier/BondGraphs/bg.html\">Bond Graph Compendium</a>.\"
</html>
"));
      end Literature;
    end Overview;
  end UsersGuide;
  
  package Interfaces 
    "Connectors and partial models for Modelica bond graph library" 
    annotation (
      Coordsys(
        extent=[0, 0; 504, 364],
        grid=[2, 2],
        component=[20, 20]),
      Icon(
        Rectangle(extent=[-100, -100; 80, 50], style(
            color=58,
            fillColor=30,
            fillPattern=1)),
        Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50], style(
            color=58,
            fillColor=30,
            fillPattern=1)),
        Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70], style(
            color=58,
            fillColor=30,
            fillPattern=1)),
        Text(
          extent=[-85, 35; 65, -85],
          string="Library",
          style(color=58)),
        Text(
          extent=[-120, 122; 120, 73],
          string="%name",
          style(color=1))),
      Window(
        x=0.02,
        y=0.53,
        width=0.4,
        height=0.4,
        library=1,
        autolayout=1),
      Documentation(info="<html>
This package contains the three basic bond graph connectors as well as some partial models that invoke them. <p>

The <b>BondCon</b> connector is the basic bi-directional bondgraphic connector that is used always.  The <b>eBondCon</b> and <b>fBondCon</b> connectors are uni-directional connectors that are only used in the definitions of the two causal bonds.
</html>
"));
    connector BondCon "Bi-directional bondgraphic connector" 
      Real e "Bondgraphic effort variable";
      Real f "Bondgraphic flow variable";
      Real d "Directional variable";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Ellipse(extent=[-60, 60; 60, -60], style(color=8, fillColor=8))),
        Icon(Ellipse(extent=[-60, 60; 60, -60], style(color=8, fillColor=8))),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.49),
        Documentation(info="<html>
This is the basic bi-directional bondgraphic connector that is used everywhere, except in the definitions of the two causal bonds. <p>

The bondgraphic connector references three variables, two of which are physical variables, whereas the third one is a topological variable.  All three are defined as potential variables. <p>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable

 d:  Directional variable indicating the direction of positive power flow
</pre>
</html>
"));
    end BondCon;
    
    connector eBondCon "Uni-directional bondgraphic connector" 
      input Real e "Bondgraphic effort variable";
      output Real f "Bondgraphic flow variable";
      output Real d "Direction variable";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Ellipse(extent=[-60, 60; 60, -60], style(color=8, fillColor=8)),
              Text(
            extent=[-34, 34; 38, -28],
            string="e",
            style(color=41, fillColor=41))),
        Icon(Ellipse(extent=[-60, 60; 60, -60], style(color=8, fillColor=8)),
            Text(
            extent=[-34, 34; 38, -28],
            string="e",
            style(color=41, fillColor=41))),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.49),
        Documentation(info="<html>
This is one of two uni-directional bondgraphic connectors used in the definitions of the two causal bonds. <p>

The bondgraphic connectors reference three variables, two of which are physical variables, whereas the third one is a topological variable.  All three are defined as potential variables. <p>

<pre>
Potential variables:

 e:  Bondgraphic effort variable (input)

 f:  Bondgraphic flow variable (output)

 d:  Directional variable indicating the direction of positive power flow (output)
</pre>
</html>
"));
    end eBondCon;
    
    connector fBondCon "Uni-directional bondgraphic connector" 
      output Real e "Bondgraphic effort variable";
      input Real f "Bondgraphic flow variable";
      output Real d "Direction variable";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Ellipse(extent=[-60, 60; 60, -60], style(color=8, fillColor=8)),
              Text(
            extent=[-36, 38; 36, -34],
            string="f",
            style(color=41, fillColor=41))),
        Icon(Ellipse(extent=[-60, 60; 60, -60], style(color=8, fillColor=8)),
            Text(
            extent=[-36, 38; 36, -34],
            string="f",
            style(color=41, fillColor=41))),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.49),
        Documentation(info="<html>
This is one of two uni-directional bondgraphic connectors used in the definitions of the two causal bonds. <p>

The bondgraphic connectors reference three variables, two of which are physical variables, whereas the third one is a topological variable.  All three are defined as potential variables. <p>

<pre>
Potential variables:

 e:  Bondgraphic effort variable (output)

 f:  Bondgraphic flow variable (input)

 d:  Directional variable indicating the direction of positive power flow (output)
</pre>
</html>
"));
    end fBondCon;
    
    partial model PassiveOnePort 
      "Partial model invoking one bondgraphic connector" 
      Real e "Bondgraphic effort";
      Real f "Bondgraphic flow";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram,
        Icon,
        Documentation(info="<html>
This is a partial model invoking a single bondgraphic connector.  It is used to describe passive OnePort elements.<p>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model
</pre>
</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
    equation 
      e = BondCon1.e;
      f = BondCon1.d*BondCon1.f;
    end PassiveOnePort;
    
    partial model ModPassiveOnePort 
      "Partial model invoking one bondgraphic connector and one signal connector" 
      
      Real e "Bondgraphic effort";
      Real f "Bondgraphic flow";
      Real s "Signal input";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.49),
        Documentation(info="<html>
This is a partial model invoking a single bondgraphic connector and a signal connector.  It is used to describe passive modulated OnePort elements.<p>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model

 s:  Real-valued signal input used for modulation
</pre>
</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      Modelica.Blocks.Interfaces.RealInput InPort1 
                                                annotation (extent=[100, -10;
            80, 10]);
    equation 
      e = BondCon1.e;
      f = BondCon1.d*BondCon1.f;
      s =InPort1;
    end ModPassiveOnePort;
    
    partial model ActiveOnePort 
      "Partial model invoking one bondgraphic connector" 
      Real e "Bondgraphic effort";
      Real f "Bondgraphic flow";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram,
        Icon,
        Documentation(info="<html>
This is a partial model invoking a single bondgraphic connector.  It is used to describe active OnePort elements.<p>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows out of the model
</pre>
</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
    equation 
      e = BondCon1.e;
      f = -BondCon1.d*BondCon1.f;
    end ActiveOnePort;
    
    partial model ModActiveOnePort 
      Real e "Bondgraphic effort";
      Real f "Bondgraphic flow";
      Real s "Signal input";
      annotation (Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]), Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.49));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      Modelica.Blocks.Interfaces.RealInput InPort1 
                                                annotation (extent=[100, -10;
            80, 10]);
    equation 
      e = BondCon1.e;
      f = -BondCon1.d*BondCon1.f;
      s =InPort1;
    end ModActiveOnePort;
    
    partial model TwoPort "Partial model invoking two bondgraphic connectors" 
      Real e1 "Bondgraphic primary effort";
      Real f1 "Bondgraphic primary flow";
      Real e2 "Bondgraphic secondary effort";
      Real f2 "Bondgraphic secondary flow";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram,
        Icon(Line(points=[42, -44; 68, -50; 42, -56], style(color=0)), Line(
              points=[-70, -50; 68, -50], style(color=0))),
        Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors.  It is used to describe directed TwoPort elements.  Positive flow is from inflow to outflow.  The direction of positive flow is indicated by an arrow. <p>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model
</pre>

</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
    equation 
      e1 = BondCon1.e;
      f1 = BondCon1.d*BondCon1.f;
      e2 = BondCon2.e;
      f2 = -BondCon2.d*BondCon2.f;
    end TwoPort;
    
    partial model TwoPort2 "Partial model invoking two bondgraphic connectors" 
      Real e1 "Bondgraphic primary effort";
      Real f1 "Bondgraphic primary flow";
      Real e2 "Bondgraphic secondary effort";
      Real f2 "Bondgraphic secondary flow";
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
    equation 
      e1 = BondCon1.e;
      f1 = BondCon1.d*BondCon1.f;
      e2 = BondCon2.e;
      f2 = BondCon2.d*BondCon2.f;
      annotation (Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors.  It is used to describe symmetric TwoPort elements.  Both inflow and outflow are assumed positive into the model. <p>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows into the model
</pre>

</html>
"));
    end TwoPort2;
    
    partial model TwoPortZero 
      "Partial model invoking two bondgraphic connectors" 
      Real e1 "Bondgraphic primary effort";
      Real f1 "Bondgraphic primary flow";
      Real e2 "Bondgraphic secondary effort";
      Real f2 "Bondgraphic secondary flow";
      annotation (Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]), Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors.  It is used only for the description of the TwoPort 0-junction. <p>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of first connector

 f1:  Bondgraphic flow variable of first connector, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of second connector

 f2:  Bondgraphic flow variable of second connector, normalized positive for flows into the model
</pre>

</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
    equation 
      e1 = BondCon1.e;
      f1 = BondCon1.d*BondCon1.f;
      e2 = BondCon2.e;
      f2 = BondCon2.d*BondCon2.f;
    end TwoPortZero;
    
    partial model TwoPortOne 
      "Partial model invoking two bondgraphic connectors" 
      Real e1 "Bondgraphic primary effort";
      Real f1 "Bondgraphic primary flow";
      Real e2 "Bondgraphic secondary effort";
      Real f2 "Bondgraphic secondary flow";
      annotation (Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]), Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors.  It is used only for the description of the TwoPort 1-junction. <p>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of first connector, normalized positive for flows into the model

 f1:  Bondgraphic flow variable of first connector

 e2:  Bondgraphic effort variable of second connector, normalized positive for flows into the model

 f2:  Bondgraphic flow variable of second connector
</pre>

</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
    equation 
      e1 = BondCon1.d*BondCon1.e;
      f1 = BondCon1.f;
      e2 = BondCon2.d*BondCon2.e;
      f2 = BondCon2.f;
    end TwoPortOne;
    
    partial model ModTwoPort 
      "Partial model invoking two bondgraphic connectors and one signal connector" 
      
      Real e1 "Bondgraphic primary effort";
      Real f1 "Bondgraphic primary flow";
      Real e2 "Bondgraphic secondary effort";
      Real f2 "Bondgraphic secondary flow";
      Real s "Signal input";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.49),
        Diagram,
        Icon(Line(points=[-70, -50; 68, -50], style(color=0)), Line(points=[42,
                  -44; 68, -50; 42, -56], style(color=0))),
        Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors and a signal connector.  It is used to describe modulated directed TwoPort elements.  Positive flow is from inflow to outflow.  The direction of positive flow is indicated by an arrow. <p>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 s:   Real-valued signal input used for modulation
</pre>

</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
      Modelica.Blocks.Interfaces.RealInput InPort1 
                                                annotation (extent=[10, -100; -
            10, -80], rotation=90);
    equation 
      e1 = BondCon1.e;
      f1 = BondCon1.d*BondCon1.f;
      e2 = BondCon2.e;
      f2 = -BondCon2.d*BondCon2.f;
      s =InPort1;
    end ModTwoPort;
    
    partial model ThreePortZero 
      "Partial model invoking three bondgraphic connectors" 
      Real e[3] "Bondgraphic effort vector";
      Real f[3] "Bondgraphic flow vector";
      annotation (Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]), Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors.  It is used only for the description of the ThreePort 0-junction. <p>

<pre>
Potential variables:

 e[3]:  Vector of bondgraphic effort variables of connectors

 f[3]:  Vector of bondgraphic flow variables of connectors, normalized positive for flows into the model
</pre>

</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
      BondLib.Interfaces.BondCon BondCon3 annotation (extent=[-10, -110; 10, -
            90]);
    equation 
      e[1] = BondCon1.e;
      f[1] = BondCon1.d*BondCon1.f;
      e[2] = BondCon2.e;
      f[2] = BondCon2.d*BondCon2.f;
      e[3] = BondCon3.e;
      f[3] = BondCon3.d*BondCon3.f;
    end ThreePortZero;
    
    partial model ThreePortOne 
      "Partial model invoking three bondgraphic connectors" 
      Real e[3] "Bondgraphic effort vector";
      Real f[3] "Bondgraphic flow vector";
      annotation (Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]), Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors.  It is used only for the description of the ThreePort 1-junction. <p>

<pre>
Potential variables:

 e[3]:  Vector of bondgraphic effort variables of connectors, normalized positive for flows into the model

 f[3]:  Vector of bondgraphic flow variables of connectors
</pre>

</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
      BondLib.Interfaces.BondCon BondCon3 annotation (extent=[-10, -110; 10, -
            90]);
    equation 
      e[1] = BondCon1.d*BondCon1.e;
      f[1] = BondCon1.f;
      e[2] = BondCon2.d*BondCon2.e;
      f[2] = BondCon2.f;
      e[3] = BondCon3.d*BondCon3.e;
      f[3] = BondCon3.f;
    end ThreePortOne;
    
    partial model FourPortZero 
      "Partial model invoking four bondgraphic connectors" 
      Real e[4] "Bondgraphic effort vector";
      Real f[4] "Bondgraphic flow vector";
      annotation (Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]), Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors.  It is used only for the description of the FourPort 0-junction. <p>

<pre>
Potential variables:

 e[4]:  Vector of bondgraphic effort variables of connectors

 f[4]:  Vector of bondgraphic flow variables of connectors, normalized positive for flows into the model
</pre>

</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
      BondLib.Interfaces.BondCon BondCon3 annotation (extent=[-10, -110; 10, -
            90]);
      BondLib.Interfaces.BondCon BondCon4 annotation (extent=[-10, 90; 10, 110]);
    equation 
      e[1] = BondCon1.e;
      f[1] = BondCon1.d*BondCon1.f;
      e[2] = BondCon2.e;
      f[2] = BondCon2.d*BondCon2.f;
      e[3] = BondCon3.e;
      f[3] = BondCon3.d*BondCon3.f;
      e[4] = BondCon4.e;
      f[4] = BondCon4.d*BondCon4.f;
    end FourPortZero;
    
    partial model FourPortOne 
      "Partial model invoking four bondgraphic connectors" 
      Real e[4] "Bondgraphic effort vector";
      Real f[4] "Bondgraphic flow vector";
      annotation (Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]), Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors.  It is used only for the description of the FourPort 1-junction. <p>

<pre>
Potential variables:

 e[4]:  Vector of bondgraphic effort variables of connectors, normalized positive for flows into the model

 f[4]:  Vector of bondgraphic flow variables of connectors
</pre>

</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
      BondLib.Interfaces.BondCon BondCon3 annotation (extent=[-10, -110; 10, -
            90]);
      BondLib.Interfaces.BondCon BondCon4 annotation (extent=[-10, 90; 10, 110]);
    equation 
      e[1] = BondCon1.d*BondCon1.e;
      f[1] = BondCon1.f;
      e[2] = BondCon2.d*BondCon2.e;
      f[2] = BondCon2.f;
      e[3] = BondCon3.d*BondCon3.e;
      f[3] = BondCon3.f;
      e[4] = BondCon4.d*BondCon4.e;
      f[4] = BondCon4.f;
    end FourPortOne;
    
    partial model FivePortZero 
      "Partial model invoking five bondgraphic connectors" 
      Real e[5] "Bondgraphic effort vector";
      Real f[5] "Bondgraphic flow vector";
      annotation (Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]), Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors.  It is used only for the description of the FivePort 0-junction. <p>

<pre>
Potential variables:

 e[5]:  Vector of bondgraphic effort variables of connectors

 f[5]:  Vector of bondgraphic flow variables of connectors, normalized positive for flows into the model
</pre>

</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
      BondLib.Interfaces.BondCon BondCon3 annotation (extent=[-50, -110; -30, -
            90]);
      BondLib.Interfaces.BondCon BondCon4 annotation (extent=[30, -110; 50, -90]);
      BondLib.Interfaces.BondCon BondCon5 annotation (extent=[-10, 90; 10, 110]);
    equation 
      e[1] = BondCon1.e;
      f[1] = BondCon1.d*BondCon1.f;
      e[2] = BondCon2.e;
      f[2] = BondCon2.d*BondCon2.f;
      e[3] = BondCon3.e;
      f[3] = BondCon3.d*BondCon3.f;
      e[4] = BondCon4.e;
      f[4] = BondCon4.d*BondCon4.f;
      e[5] = BondCon5.e;
      f[5] = BondCon5.d*BondCon5.f;
    end FivePortZero;
    
    partial model FivePortOne 
      "Partial model invoking five bondgraphic connectors" 
      Real e[5] "Bondgraphic effort vector";
      Real f[5] "Bondgraphic flow vector";
      annotation (Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]), Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors.  It is used only for the description of the FivePort 1-junction. <p>

<pre>
Potential variables:

 e[5]:  Vector of bondgraphic effort variables of connectors, normalized positive for flows into the model

 f[5]:  Vector of bondgraphic flow variables of connectors
</pre>

</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
      BondLib.Interfaces.BondCon BondCon3 annotation (extent=[-50, -110; -30, -
            90]);
      BondLib.Interfaces.BondCon BondCon4 annotation (extent=[30, -110; 50, -90]);
      BondLib.Interfaces.BondCon BondCon5 annotation (extent=[-10, 90; 10, 110]);
    equation 
      e[1] = BondCon1.d*BondCon1.e;
      f[1] = BondCon1.f;
      e[2] = BondCon2.d*BondCon2.e;
      f[2] = BondCon2.f;
      e[3] = BondCon3.d*BondCon3.e;
      f[3] = BondCon3.f;
      e[4] = BondCon4.d*BondCon4.e;
      f[4] = BondCon4.f;
      e[5] = BondCon5.d*BondCon5.e;
      f[5] = BondCon5.f;
    end FivePortOne;
    
    partial model SixPortZero 
      "Partial model invoking six bondgraphic connectors" 
      Real e[6] "Bondgraphic effort vector";
      Real f[6] "Bondgraphic flow vector";
      annotation (Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]), Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors.  It is used only for the description of the SixPort 0-junction. <p>

<pre>
Potential variables:

 e[6]:  Vector of bondgraphic effort variables of connectors

 f[6]:  Vector of bondgraphic flow variables of connectors, normalized positive for flows into the model
</pre>

</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
      BondLib.Interfaces.BondCon BondCon3 annotation (extent=[-50, -110; -30, -
            90]);
      BondLib.Interfaces.BondCon BondCon4 annotation (extent=[30, -110; 50, -90]);
      BondLib.Interfaces.BondCon BondCon5 annotation (extent=[-50, 90; -30, 110]);
      BondLib.Interfaces.BondCon BondCon6 annotation (extent=[30, 90; 50, 110]);
    equation 
      e[1] = BondCon1.e;
      f[1] = BondCon1.d*BondCon1.f;
      e[2] = BondCon2.e;
      f[2] = BondCon2.d*BondCon2.f;
      e[3] = BondCon3.e;
      f[3] = BondCon3.d*BondCon3.f;
      e[4] = BondCon4.e;
      f[4] = BondCon4.d*BondCon4.f;
      e[5] = BondCon5.e;
      f[5] = BondCon5.d*BondCon5.f;
      e[6] = BondCon6.e;
      f[6] = BondCon6.d*BondCon6.f;
    end SixPortZero;
    
    partial model SixPortOne 
      "Partial model invoking six bondgraphic connectors" 
      Real e[6] "Bondgraphic effort vector";
      Real f[6] "Bondgraphic flow vector";
      annotation (Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]), Documentation(info="<html>
This is a partial model invoking two bondgraphic connectors.  It is used only for the description of the SixPort 1-junction. <p>

<pre>
Potential variables:

 e[6]:  Vector of bondgraphic effort variables of connectors, normalized positive for flows into the model

 f[6]:  Vector of bondgraphic flow variables of connectors
</pre>

</html>
"));
      BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -90,
            10]);
      BondLib.Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
      BondLib.Interfaces.BondCon BondCon3 annotation (extent=[-50, -110; -30, -
            90]);
      BondLib.Interfaces.BondCon BondCon4 annotation (extent=[30, -110; 50, -90]);
      BondLib.Interfaces.BondCon BondCon5 annotation (extent=[-50, 90; -30, 110]);
      BondLib.Interfaces.BondCon BondCon6 annotation (extent=[30, 90; 50, 110]);
    equation 
      e[1] = BondCon1.d*BondCon1.e;
      f[1] = BondCon1.f;
      e[2] = BondCon2.d*BondCon2.e;
      f[2] = BondCon2.f;
      e[3] = BondCon3.d*BondCon3.e;
      f[3] = BondCon3.f;
      e[4] = BondCon4.d*BondCon4.e;
      f[4] = BondCon4.f;
      e[5] = BondCon5.d*BondCon5.e;
      f[5] = BondCon5.f;
      e[6] = BondCon6.d*BondCon6.e;
      f[6] = BondCon6.f;
    end SixPortOne;
  end Interfaces;
  
  package Bonds "Bonds of Modelica bond graph library" 
    annotation (
      Coordsys(
        extent=[0, 0; 442, 394],
        grid=[2, 2],
        component=[20, 20]),
      Icon(
        Rectangle(extent=[-100, -100; 80, 50], style(fillColor=30, fillPattern=
                1)),
        Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50], style(
              fillColor=30, fillPattern=1)),
        Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70], style(
              fillColor=30, fillPattern=1)),
        Text(
          extent=[-85, 35; 65, -85],
          string="Library",
          style(color=3)),
        Text(
          extent=[-120, 122; 120, 73],
          string="%name",
          style(color=1))),
      Window(
        x=0.55,
        y=0.46,
        width=0.35,
        height=0.49,
        library=1,
        autolayout=1),
      Documentation(info="<html>
This package contains models of the three bonds of the Modelica bond graph library.  The <b>Bond</b> model describes the a-causal bonds, whereas the <b>eBond</b> and <b>fBond</b> blocks describe the two causal bonds. <p>

Although it is possible to work with a-causal bonds throughout, it is recommended to use causal bonds whenever possible. <p>

Bonds must be connected to either elements or junctions.  It is illegal to connect two bonds in series.
</html>
"));
    model Bond "The a-causal bond model of the bond graph library" 
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(
          Line(points=[-80, 0; 80, 0], style(color=0, thickness=2)),
          Line(points=[80, 0; 40, 40], style(color=0, thickness=2)),
          Text(
            extent=[-40, -8; 20, -40],
            string="f",
            style(color=0)),
          Text(
            extent=[-40, 40; 18, 10],
            string="e",
            style(color=0))),
        Icon(
          Line(points=[-80, 0; 80, 0], style(color=0, thickness=2)),
          Line(points=[80, 0; 40, 40], style(color=0, thickness=2)),
          Text(
            extent=[-70, -4; 72, -42],
            string="%name",
            style(color=0))),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.49),
        Documentation(info="<html>
This is the model of the general a-causal bond of the Modelica bond graph library. <p>

The model invokes two general bond connectors.  It does so directly, i.e., without inheriting them from one of the TwoPort partial models. <p>

The Model passes the effort and flow variables from the inflow to the outflow, and it sets the directional variable <b>d</b> to <b>-1</b> at the inflow, and to <b>+1</b> at the outflow.
</html>
"));
      Interfaces.BondCon BondCon1 annotation (extent=[-108, -10; -88, 10]);
      Interfaces.BondCon BondCon2 annotation (extent=[90, -10; 110, 10]);
    equation 
      BondCon2.e = BondCon1.e;
      BondCon2.f = BondCon1.f;
      BondCon1.d = -1;
      BondCon2.d = +1;
    end Bond;
    
    block eBond "One of two causal bond models of the bond graph library" 
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Icon(
          Line(points=[-80, 0; 80, 0], style(color=0, thickness=2)),
          Line(points=[80, 0; 40, 40], style(color=0, thickness=2)),
          Line(points=[-80, 40; -80, -40], style(color=0, thickness=2)),
          Text(
            extent=[-68, -4; 64, -42],
            string="%name",
            style(color=0))),
        Diagram(
          Line(points=[-80, 0; 80, 0], style(color=0, thickness=2)),
          Line(points=[80, 0; 40, 40], style(color=0, thickness=2)),
          Line(points=[-80, 40; -80, -40], style(color=0, thickness=2)),
          Text(
            extent=[-38, 42; 20, 12],
            string="e",
            style(color=0)),
          Text(
            extent=[-40, -8; 20, -40],
            string="f",
            style(color=0)),
          Line(points=[4, -24; 34, -24], style(
              color=0,
              thickness=2,
              arrow=1)),
          Line(points=[-24, 24; -56, 24], style(
              color=0,
              thickness=2,
              arrow=1))),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.49),
        Documentation(info="<html>
This is the model of one of two causal bonds of the Modelica bond graph library. <p>

The model invokes one <b>fBond</b> and one <b>eBond</b> connector.  The <b>fBond</b> connector is used at the inflow, i.e., where the flow variable is being computed, whereas the <b>eBond</b> connector is used at the outflow, i.e., where the effort variable is being computed. Thus, the causality stroke of this causal bond is at the inflow. <p>

The model passes the effort and flow variables from the inflow to the outflow, and it sets the directional variable <b>d</b> to <b>-1</b> at the inflow, and to <b>+1</b> at the outflow.
</html>
"));
      Interfaces.fBondCon fBondCon1 annotation (extent=[-110, -10; -90, 10]);
      Interfaces.eBondCon eBondCon1 annotation (extent=[90, -10; 110, 10]);
    equation 
      fBondCon1.e = eBondCon1.e;
      eBondCon1.f = fBondCon1.f;
      fBondCon1.d = -1;
      eBondCon1.d = +1;
    end eBond;
    
    block fBond "One of two causal bond models of the bond graph library" 
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(
          Line(points=[-80, 0; 80, 0], style(color=0, thickness=2)),
          Text(
            extent=[-40, -8; 20, -40],
            string="f",
            style(color=0)),
          Text(
            extent=[-38, 42; 20, 12],
            string="e",
            style(color=0)),
          Line(points=[80, 0; 40, 40], style(color=0, thickness=2)),
          Line(points=[80, 40; 80, -40], style(color=0, thickness=2)),
          Line(points=[-22, -24; -54, -24], style(
              color=0,
              thickness=2,
              arrow=1)),
          Line(points=[2, 26; 32, 26], style(
              color=0,
              thickness=2,
              arrow=1))),
        Icon(
          Line(points=[-80, 0; 80, 0], style(color=0, thickness=2)),
          Line(points=[80, 0; 40, 40], style(color=0, thickness=2)),
          Line(points=[80, 40; 80, -40], style(color=0, thickness=2)),
          Text(
            extent=[-66, -4; 62, -44],
            string="%name",
            style(color=0))),
        Window(
          x=0.52,
          y=0.42,
          width=0.35,
          height=0.49),
        Documentation(info="<html>
This is the model of one of two causal bonds of the Modelica bond graph library. <p>

The model invokes one <b>eBond</b> and one <b>fBond</b> connector.  The <b>eBond</b> connector is used at the inflow, i.e., where the effort variable is being computed, whereas the <b>fBond</b> connector is used at the outflow, i.e., where the flow variable is being computed. Thus, the causality stroke of this causal bond is at the outflow. <p>

The model passes the effort and flow variables from the inflow to the outflow, and it sets the directional variable <b>d</b> to <b>-1</b> at the inflow, and to <b>+1</b> at the outflow.
</html>
"));
      Interfaces.eBondCon eBondCon1 annotation (extent=[-110, -10; -90, 10]);
      Interfaces.fBondCon fBondCon1 annotation (extent=[90, -10; 110, 10]);
    equation 
      fBondCon1.e = eBondCon1.e;
      eBondCon1.f = fBondCon1.f;
      eBondCon1.d = -1;
      fBondCon1.d = +1;
    end fBond;
  end Bonds;
  
  package Junctions "Junctions of Modelica bond graph library" 
    annotation (
      Coordsys(
        extent=[0, 0; 440, 456],
        grid=[2, 2],
        component=[20, 20]),
      Icon(
        Rectangle(extent=[-100, -100; 80, 50], style(fillColor=30, fillPattern=
                1)),
        Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50], style(
              fillColor=30, fillPattern=1)),
        Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70], style(
              fillColor=30, fillPattern=1)),
        Text(
          extent=[-85, 35; 65, -85],
          string="Library",
          style(color=3)),
        Text(
          extent=[-120, 122; 120, 73],
          string="%name",
          style(color=1))),
      Window(
        x=0.49,
        y=0.48,
        width=0.35,
        height=0.49,
        library=1,
        autolayout=1),
      Documentation(info="<html>
This package contains models of the different junctions of the Modelica bond graph library.  The library distinguishes explicitly between junctions with 2, 3, 4, 5, and 6 connectors.  If more than 6 connectors are needed, the junction needs to be split.  Since neighboring same-sex junctions can always be treated logically like a single junction, it is possible to construct junctions with arbitrarily many connectors.<p>

Junctions must be connected to bonds.  It is illegal to connect junctions to either modeling elements or other junctions directly.  If junctions are being split, a bond must be placed between them.
</html>
"));
    model J0p2 "Model of TwoPort 0-junction" 
      extends Interfaces.TwoPortZero;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="0",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="0",
            style(color=0))),
        Documentation(info="<html>
This is the model of the TwoPort 0-junction.  It has one causality stroke.
</html>
"));
    equation 
      e2 = e1;
      f1 + f2 = 0;
    end J0p2;
    
    model J0p3 "Model of ThreePort 0-junction" 
      extends Interfaces.ThreePortZero;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="0",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="0",
            style(color=0))),
        Documentation(info="<html>
This is the model of the ThreePort 0-junction.  It has one causality stroke.
</html>
"));
    equation 
      e[2:3] = e[1:2];
      sum(f) = 0;
    end J0p3;
    
    model J0p4 "Model of FourPort 0-junction" 
      extends Interfaces.FourPortZero;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="0",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="0",
            style(color=0))),
        Documentation(info="<html>
This is the model of the FourPort 0-junction.  It has one causality stroke.
</html>
"));
    equation 
      e[2:4] = e[1:3];
      sum(f) = 0;
    end J0p4;
    
    model J0p5 "Model of FivePort 0-junction" 
      extends Interfaces.FivePortZero;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="0",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="0",
            style(color=0))),
        Documentation(info="<html>
This is the model of the FivePort 0-junction.  It has one causality stroke.
</html>
"));
    equation 
      e[2:5] = e[1:4];
      sum(f) = 0;
    end J0p5;
    
    model J0p6 "Model of SixPort 0-junction" 
      extends Interfaces.SixPortZero;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="0",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="0",
            style(color=0))),
        Documentation(info="<html>
This is the model of the SixPort 0-junction.  It has one causality stroke.
</html>
"));
    equation 
      e[2:6] = e[1:5];
      sum(f) = 0;
    end J0p6;
    
    model J1p2 "Model of TwoPort 1-junction" 
      extends Interfaces.TwoPortOne;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="1",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="1",
            style(color=0))),
        Documentation(info="<html>
This is the model of the TwoPort 1-junction.  It has one causality stroke.
</html>
"));
    equation 
      f2 = f1;
      e1 + e2 = 0;
    end J1p2;
    
    model J1p3 "Model of ThreePort 1-junction" 
      extends Interfaces.ThreePortOne;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="1",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="1",
            style(color=0))),
        Documentation(info="<html>
This is the model of the ThreePort 1-junction.  It has two causality strokes.
</html>
"));
    equation 
      f[2:3] = f[1:2];
      sum(e) = 0;
    end J1p3;
    
    model J1p4 "Model of FourPort 1-junction" 
      extends Interfaces.FourPortOne;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="1",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="1",
            style(color=0))),
        Documentation(info="<html>
This is the model of the FourPort 1-junction.  It has three causality strokes.
</html>
"));
    equation 
      f[2:4] = f[1:3];
      sum(e) = 0;
    end J1p4;
    
    model J1p5 "Model of FivePort 1-junction" 
      extends Interfaces.FivePortOne;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="1",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="1",
            style(color=0))),
        Documentation(info="<html>
This is the model of the FivePort 1-junction.  It has four causality strokes.
</html>
"));
    equation 
      f[2:5] = f[1:4];
      sum(e) = 0;
    end J1p5;
    
    model J1p6 "Model of SixPort 1-junction" 
      extends Interfaces.SixPortOne;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="1",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="1",
            style(color=0))),
        Documentation(info="<html>
This is the model of the SixPort 1-junction.  It has two causality strokes.
</html>
"));
    equation 
      f[2:6] = f[1:5];
      sum(e) = 0;
    end J1p6;
  end Junctions;
  
  package Passive "Passive elements of Modelica bond graph library" 
    annotation (
      Coordsys(
        extent=[0, 0; 440, 456],
        grid=[2, 2],
        component=[20, 20]),
      Icon(
        Rectangle(extent=[-100, -100; 80, 50], style(fillColor=30, fillPattern=
                1)),
        Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50], style(
              fillColor=30, fillPattern=1)),
        Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70], style(
              fillColor=30, fillPattern=1)),
        Text(
          extent=[-85, 35; 65, -85],
          string="Library",
          style(color=3)),
        Text(
          extent=[-120, 122; 120, 73],
          string="%name",
          style(color=1))),
      Window(
        x=0.48,
        y=0.48,
        width=0.35,
        height=0.49,
        library=1,
        autolayout=1),
      Documentation(info="<html>
The basic passive modeling elements used in the bond graph methodology are: <p>

<ul>
<li> the resistors (<b>R</b>),
<li> the capacitors (<b>C</b>),
<li> the inductors (<b>I</b>),
<li> the transformers (<b>TF</b>), and
<li> the gyrators (<b>GY</b>).
</ul> <p>

These elements are collected here.
</html>

"));
    model R "The bondgraphic linear resistor element" 
      extends Interfaces.PassiveOnePort;
      parameter Real R=1 "Bondgraphic Resistance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="R",
            style(color=0, fillColor=0))),
        Icon(
          Text(extent=[-70, -50; 70, -90], string="R=%R"),
          Text(
            extent=[-60, 80; 60, -80],
            string="R",
            style(color=0, fillColor=0)),
          Text(extent=[-70, 90; 70, 50], string="%name")),
        Documentation(info="<html>
The bondgraphic linear resistor is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The resistance is modeled as a parameter. <p>

The causality of the resistor is free. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model


Parameters:

 R:  Resistance (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = R*f</b>
</html>
"));
    equation 
      e = R*f;
    end R;
    
    model mR "The bondgraphic modulated resistor element" 
      extends Interfaces.ModPassiveOnePort;
      Real R "Bondgraphic Resistance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="mR",
            style(color=0))),
        Icon(Text(
            extent=[-58,80; 62,-80],
            string="mR",
            style(color=0)), Text(extent=[-70, 80; 70, 40], string="%name")),
        Documentation(info="<html>
The bondgraphic modulated resistor is a modulated passive OnePort element.  It inherits the effort and flow variables as well as the modulating signal from the modulated passive OnePort.  The resistance is modeled as a real-valued variable. <p>

The causality of the resistor is free. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model

 R:  Resistance (modulated input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = R*f</b>
</html>
"));
    equation 
      R = s;
      e = R*f;
    end mR;
    
    model HydroR "The bondgraphic hydraulic resistor element" 
      extends Interfaces.PassiveOnePort;
      parameter Real k=1 "Hydraulic Valve Constant";
      Real sf "Sign of f";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="R",
            style(color=0, fillColor=0)), Text(
            extent=[14, 10; 122, -12],
            string="Hydro",
            style(color=0))),
        Icon(
          Text(
            extent=[-60, 80; 60, -80],
            string="R",
            style(color=0, fillColor=0)),
          Text(
            extent=[14, 10; 122, -12],
            string="Hydro",
            style(color=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(extent=[-70, -50; 70, -90], string="k=%k")),
        Documentation(info="<html>
The bondgraphic hydraulic resistor is a passive OnePort element.  It models the turbulent flow through a hydraulic valve.  The model inherits the effort and flow variables from the passive OnePort.  The valve constant is modeled as a parameter. <p>

This non-linear model is formulated in resistive causality.  There exists a second model, <b>HydroG</b>, that models the same device in conductive causality.  It is useful to make use of the model in its correct causality, as Modelica may be unable to automatically turn the causality of this non-linear equation around. <p>

The hydraulic resistor model has a preferred causality away from the element. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model


Parameters:

 k:  Valve constant (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = sign(f)*f<sup>2</sup>/k</b>
</html>
"));
    equation 
      sf = noEvent(if f > 0 then 1 else -1);
      e = sf*f*f/k;
    end HydroR;
    
    model HydromR "The bondgraphic hydraulic modulated resistor element" 
      extends Interfaces.ModPassiveOnePort;
      Real k "Hydraulic Valve Constant";
      Real sf "Sign of f";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="mR",
            style(color=0)), Text(
            extent=[-48, -26; 60, -48],
            string="Hydro",
            style(color=0))),
        Icon(
          Text(
            extent=[-60, 80; 60, -80],
            string="mR",
            style(color=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(
            extent=[-48, -26; 60, -48],
            string="Hydro",
            style(color=0))),
        Window(
          x=0.45,
          y=0.01,
          width=0.44,
          height=0.65),
        Documentation(info="<html>
The bondgraphic hydraulic modulated resistor is a modulated passive OnePort element.  It models the turbulent flow through a hydraulic valve.  The model inherits the effort and flow variables as well as the modulation signal from the modulated passive OnePort.  The valve constant is modeled as a real-valued variable. <p>

This non-linear model is formulated in resistive causality.  There exists a second model, <b>HydromG</b>, that models the same device in conductive causality.  It is useful to make use of the model in its correct causality, as Modelica may be unable to automatically turn the causality of this non-linear equation around. <p>

The hydraulic resistor model has a preferred causality away from the element. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model

 k:  Valve constant (modulated input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = sign(f)*f<sup>2</sup>/k</b>
</html>
"));
    equation 
      sf = noEvent(if f > 0 then 1 else -1);
      k = s;
      e = sf*f*f/k;
    end HydromR;
    
    model RF "The bondgraphic linear TwoPort resistive field element" 
      extends Interfaces.TwoPort2;
      parameter Real R1=1 "Primary Resistance";
      parameter Real R2=1 "Secondary Resistance";
      parameter Real R12=0 "Coupling Resistance";
      annotation (
        Icon(Text(
            extent=[-62, 80; 58, -80],
            style(color=0),
            string="RF"), Text(extent=[-68, 90; 72, 50], string="%name")),
        Diagram(Text(
            extent=[-62, 80; 58, -80],
            style(color=0),
            string="RF")),
        Documentation(info="<html>
The bondgraphic TwoPort resistive field is a symmetric TwoPort element.  It inherits the effort and flow variables from the symmetric TwoPort.  The resistance values are modeled as a set of three parameters. <p>

The TwoPort resistive field has free causality. <p>

<hr>

<pre>
Potential variables:

 e1:   Bondgraphic effort variable of inflow

 f1:   Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:   Bondgraphic effort variable of outflow

 f2:   Bondgraphic flow variable of outflow, normalized positive for flows into the model


Parameters:

 R1:   Primary resistance (default value = 1)

 R2:   Secondary resistance (default value = 1)

 R12:  Coupling resistance (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e1 = R1*f1 + R12*f2</b> <br>
<b>e2 = R12*f1 + R2*f2</b>
</html>
"));
    equation 
      e1 = R1*f1 + R12*f2;
      e2 = R12*f1 + R2*f2;
    end RF;
    
    model G "The bondgraphic linear conductor element" 
      extends Interfaces.PassiveOnePort;
      parameter Real G=1 "Bondgraphic Conductance";
      annotation (
        Icon(
          Text(extent=[-68,-52; 72,-92], string="G=%G"),
          Text(
            extent=[-58,78; 62,-82],
            style(color=0, fillColor=0),
            string="G"),
          Text(extent=[-68,88; 72,48],   string="%name")),
        Diagram(
          Text(
            extent=[-58,78; 62,-82],
            style(color=0, fillColor=0),
            string="G")),
        Documentation(info="<html>
The bondgraphic linear conductor is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The conductance is modeled as a parameter. <p>

The causality of the conductor is free. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model


Parameters:

 G:  Conductance (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = G*e</b>
</html>"));
    equation 
      f = G*e;
    end G;
    
    model mG "The bondgraphic modulated rconductor element" 
      extends Interfaces.ModPassiveOnePort;
      Real G "Bondgraphic Conductance";
      annotation (
        Icon(Text(
            extent=[-62,78; 58,-82],
            style(color=0),
            string="mG"),    Text(extent=[-70,80; 70,40],   string="%name")),
        Diagram(
             Text(
            extent=[-62,78; 58,-82],
            style(color=0),
            string="mG")),
        Documentation(info="<html>
The bondgraphic modulated conductor is a modulated passive OnePort element.  It inherits the effort and flow variables as well as the modulating signal from the modulated passive OnePort.  The conductance is modeled as a real-valued variable. <p>

The causality of the conductor is free. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model

 G:  Conductance (modulated input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = G*e</b>
</html>"));
    equation 
      G = s;
      f = G*e;
    end mG;
    
    model HydroG "The bondgraphic hydraulic conductor element" 
      extends Interfaces.PassiveOnePort;
      parameter Real k=1 "Hydraulic Valve Constant";
      Real se "Sign of e";
      Real ae "Absolute value of e";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="G",
            style(color=0, fillColor=0)), Text(
            extent=[16, 10; 124, -12],
            string="Hydro",
            style(color=0))),
        Icon(
          Text(
            extent=[16, 10; 124, -12],
            string="Hydro",
            style(color=0)),
          Text(
            extent=[-60, 80; 60, -80],
            string="G",
            style(color=0, fillColor=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(extent=[-70, -50; 70, -90], string="k=%k")),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.49),
        Documentation(info="<html>
The bondgraphic hydraulic conductor is a passive OnePort element.  It models the turbulent flow through a hydraulic valve.  The model inherits the effort and flow variables from the passive OnePort.  The valve constant is modeled as a parameter. <p>

This non-linear model is formulated in conductive causality.  There exists a second model, <b>HydroR</b>, that models the same device in resistive causality.  It is useful to make use of the model in its correct causality, as Modelica may be unable to automatically turn the causality of this non-linear equation around. <p>

The hydraulic conductor model has a preferred causality at the element. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model


Parameters:

 k:  Valve constant (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = k*sign(e)*sqrt(abs(e))</b>
</html>
"));
    equation 
      se = noEvent(if e > 0 then 1 else -1);
      ae = noEvent(if e > 0 then e else -e);
      f = k*se*sqrt(ae);
    end HydroG;
    
    model HydromG "The bondgraphic hydraulic modulated conductor element" 
      extends Interfaces.ModPassiveOnePort;
      Real k "Hydraulic Valve Constant";
      Real se "Sign of e";
      Real ae "Absolute value of e";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="mG",
            style(color=0)), Text(
            extent=[-48, -26; 60, -48],
            string="Hydro",
            style(color=0))),
        Icon(
          Text(
            extent=[-60, 80; 60, -80],
            string="mG",
            style(color=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(
            extent=[-48, -26; 60, -48],
            string="Hydro",
            style(color=0))),
        Window(
          x=0.45,
          y=0.01,
          width=0.44,
          height=0.65),
        Documentation(info="<html>
The bondgraphic hydraulic modulated conductor is a modulated passive OnePort element.  It models the turbulent flow through a hydraulic valve.  The model inherits the effort and flow variables as well as the modulation signal from the modulated passive OnePort.  The valve constant is modeled as a real-valued variable. <p>

This non-linear model is formulated in conductive causality.  There exists a second model, <b>HydromR</b>, that models the same device in resistive causality.  It is useful to make use of the model in its correct causality, as Modelica may be unable to automatically turn the causality of this non-linear equation around. <p>

The hydraulic conductor model has a preferred causality at the element. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model

 k:  Valve constant (modulated input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = k*sign(e)*sqrt(abs(e))</b>
</html>
"));
    equation 
      se = noEvent(if e > 0 then 1 else -1);
      ae = noEvent(if e > 0 then e else -e);
      k = s;
      f = k*se*sqrt(ae);
    end HydromG;
    
    model GF "The bondgraphic linear TwoPort conductive field element" 
      extends Interfaces.TwoPort2;
      parameter Real G1=1 "Primary Conductance";
      parameter Real G2=1 "Secondary Conductance";
      parameter Real G12=0 "Coupling Conductance";
      annotation (
        Icon(Text(
            extent=[-60, 78; 60, -82],
            style(color=0),
            string="GF"), Text(extent=[-66, 86; 74, 46], string="%name")),
        Diagram(Text(
            extent=[-60, 78; 60, -82],
            style(color=0),
            string="GF")),
        Documentation(info="<html>
The bondgraphic TwoPort conductive field is a symmetric TwoPort element.  It inherits the effort and flow variables from the symmetric TwoPort.  The conductance values are modeled as a set of three parameters. <p>

The TwoPort conductive field has free causality. <p>

<hr>

<pre>
Potential variables:

 e1:   Bondgraphic effort variable of inflow

 f1:   Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:   Bondgraphic effort variable of outflow

 f2:   Bondgraphic flow variable of outflow, normalized positive for flows into the model


Parameters:

 G1:   Primary conductance (default value = 1)

 G2:   Secondary conductance (default value = 1)

 G12:  Coupling conductance (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f1 = G1*e1 + G12*e2</b> <br>
<b>f2 = G12*e1 + G2*e2</b>
</html>
"));
    equation 
      f1 = G1*e1 + G12*e2;
      f2 = G12*e1 + G2*e2;
    end GF;
    
    model C "The bondgraphic linear capacitor element" 
      extends Interfaces.PassiveOnePort;
      parameter Real C=1 "Bondgraphic Capacitance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="C",
            style(color=0, fillColor=0))),
        Icon(
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(
            extent=[-60, 80; 60, -80],
            string="C",
            style(color=0, fillColor=0)),
          Text(extent=[-70, -50; 70, -90], string="C=%C")),
        Documentation(info="<html>
The bondgraphic linear capacitor is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The capacitance is modeled as a parameter. <p>

The capacitor model has a preferred causality away from the element. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model


Parameters:

 C:  Capacitance (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = C*der(e)</b>
</html>
"));
    equation 
      f = C*der(e);
    end C;
    
    model mC "The bondgraphic modulated capacitor element" 
      extends Interfaces.ModPassiveOnePort;
      Real C "Bondgraphic Capacitance";
      Real q "Bondgraphic generalized position";
      annotation (
        Icon(Text(
            extent=[-64,78; 56,-82],
            style(color=0),
            string="mC"),    Text(extent=[-70,80; 70,40],   string="%name")),
        Diagram(
             Text(
            extent=[-64,78; 56,-82],
            style(color=0),
            string="mC")),
        Documentation(info="<html>
The bondgraphic modulated capacitor is a modulated passive OnePort element.  It inherits the effort and flow variables as well as the modulating signal from the modulated passive OnePort.  The capacitance is modeled as a real-valued variable. <p>

The capacitor has a preferred causality at the element. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model

 q:  Bondgraphic generalized position variable

 C:  Capacitance (modulated input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>q = C*e</b> <br>
<b>f = der(q)</b>
</html>"));
    equation 
      C = s;
      q = C*e;
      f = der(q);
    end mC;
    
    model CF "The bondgraphic linear TwoPort capacitive field element" 
      extends Interfaces.TwoPort2;
      parameter Real C1=1 "Primary Capacitance";
      parameter Real C2=1 "Secondary Capacitance";
      parameter Real C12=0 "Coupling Capacitance";
      parameter Real Det=C1*C2 - C12^2;
      parameter Real Cinv1=C2/Det;
      parameter Real Cinv2=C1/Det;
      parameter Real Cinv12=-C12/Det;
      annotation (
        Icon(Text(
            extent=[-60, 78; 60, -82],
            style(color=0),
            string="CF"), Text(extent=[-66, 88; 74, 48], string="%name")),
        Diagram(Text(
            extent=[-60, 78; 60, -82],
            style(color=0),
            string="CF")),
        Documentation(info="<html>
The bondgraphic TwoPort capacitive field is a symmetric TwoPort element.  It inherits the effort and flow variables from the symmetric TwoPort.  The capacitance values are modeled as a set of three parameters.  The symmetric capacitance matrix is manually inverted to speed up the compilation. <p>

The TwoPort capacitive field has preferred causalities at the <b>CF</b> element. <p>

<hr>

<pre>
Potential variables:

 e1:   Bondgraphic effort variable of inflow

 f1:   Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:   Bondgraphic effort variable of outflow

 f2:   Bondgraphic flow variable of outflow, normalized positive for flows into the model


Parameters:

 C1:   Primary capacitance (default value = 1)

 C2:   Secondary capacitance (default value = 1)

 C12:  Coupling capacitance (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>Det = C1*C2 - C12^2</b> <br>
<b>Cinv1 = C2/Det</b> <br>
<b>Cinv2 = C1/Det</b> <br>
<b>Cinv12 = -C12/Det</b> <p>
<b>der(e1) = Cinv1*f1 + Cinv12*f2</b> <br>
<b>der(e2) = Cinv12*f1 + Cinv2*f2</b>
</html>
"));
    equation 
      der(e1) = Cinv1*f1 + Cinv12*f2;
      der(e2) = Cinv12*f1 + Cinv2*f2;
    end CF;
    
    model I "The bondgraphic linear inductor element" 
      extends Interfaces.PassiveOnePort;
      parameter Real I=1 "Bondgraphic Inductance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="I",
            style(color=0, fillColor=0))),
        Icon(
          Text(
            extent=[-60, 80; 60, -80],
            string="I",
            style(color=0, fillColor=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(extent=[-70, -50; 70, -90], string="I=%I")),
        Documentation(info="<html>
The bondgraphic linear inductor is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The inductance is modeled as a parameter. <p>

The inductor model has a preferred causality at the element. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model


Parameters:

 I:  Inductance (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = I*der(f)</b>
</html>
"));
    equation 
      e = I*der(f);
    end I;
    
    model mI "The bondgraphic modulated inductor element" 
      extends Interfaces.ModPassiveOnePort;
      Real I "Bondgraphic Inductance";
      Real p "Bondgraphic generalized momentum";
      annotation (
        Icon(Text(
            extent=[-50,48; 48,-50],
            style(color=0),
            string="mI"),    Text(extent=[-70,80; 70,40],   string="%name")),
        Diagram(
             Text(
            extent=[-50,48; 48,-50],
            style(color=0),
            string="mI")),
        Documentation(info="<html>
The bondgraphic modulated inductor is a modulated passive OnePort element.  It inherits the effort and flow variables as well as the modulating signal from the modulated passive OnePort.  The inductance is modeled as a real-valued variable. <p>

The inductor has a preferred causality away from the element. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model

 p:  Bondgraphic generalized momentum variable

 I:  inductance (modulated input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>p = I*f</b> <br>
<b>e = der(p)</b>
</html>"));
    equation 
      I = s;
      p = I*f;
      e = der(p);
    end mI;
    
    model IF "The bondgraphic linear TwoPort inductive field element" 
      extends Interfaces.TwoPort2;
      parameter Real I1=1 "Primary Inductance";
      parameter Real I2=1 "Secondary Inductance";
      parameter Real I12=0 "Coupling Inductance";
      parameter Real Det=I1*I2 - I12^2;
      parameter Real Iinv1=I2/Det;
      parameter Real Iinv2=I1/Det;
      parameter Real Iinv12=-I12/Det;
      annotation (
        Icon(Text(extent=[-68, 88; 72, 48], string="%name"), Text(
            extent=[-48, 72; 44, -74],
            style(color=0),
            string="IF")),
        Diagram(Text(
            extent=[-48, 72; 44, -74],
            style(color=0),
            string="IF")),
        Documentation(info="<html>
The bondgraphic TwoPort inductive field is a symmetric TwoPort element.  It inherits the effort and flow variables from the symmetric TwoPort.  The inductance values are modeled as a set of three parameters.  The symmetric inductance matrix is manually inverted to speed up the compilation. <p>

The TwoPort inductive field has preferred causalities away from the <b>IF</b> element. <p>

<hr>

<pre>
Potential variables:

 e1:   Bondgraphic effort variable of inflow

 f1:   Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:   Bondgraphic effort variable of outflow

 f2:   Bondgraphic flow variable of outflow, normalized positive for flows into the model


Parameters:

 I1:   Primary inductance (default value = 1)

 I2:   Secondary inductance (default value = 1)

 I12:  Coupling inductance (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>Det = I1*I2 - I12^2</b> <br>
<b>Iinv1 = I2/Det</b> <br>
<b>Iinv2 = I1/Det</b> <br>
<b>Iinv12 = -I12/Det</b> <p>
<b>der(f1) = Iinv1*e1 + Iinv12*e2</b> <br>
<b>der(f2) = Iinv12*e1 + Iinv2*e2</b>
</html>
"));
    equation 
      der(f1) = Iinv1*e1 + Iinv12*e2;
      der(f2) = Iinv12*e1 + Iinv2*e2;
    end IF;
    
    model TF "The bondgraphic linear transformer element" 
      extends Interfaces.TwoPort;
      parameter Real m=1 "Bondgraphic Transformation Constant";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="TF",
            style(color=0))),
        Icon(
          Text(
            extent=[-60, 80; 60, -80],
            string="TF",
            style(color=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(extent=[-70, -50; 70, -90], string="m=%m")),
        Window(
          x=0.45,
          y=0.01,
          width=0.44,
          height=0.65),
        Documentation(info="<html>
The bondgraphic linear transformer is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The transformation constant is modeled as a parameter. <p>

The bond graph literature is not consistent in the definition of the transformation constant.  In this library, the constant is defined as the amplification of <b>flow</b> from the inflow to the outflow.  Some other bond graph references define the transformation constant as the amplification of <b>effort</b> from the inflow to the outflow. <p>

The transformer model has one causality stroke. <p>

<hr>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model


Parameters:

 m:   Transformation constant (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f2 = m*f1</b> <br>
<b>e1 = m*e2</b>
</html>
"));
    equation 
      e1 = m*e2;
      f2 = m*f1;
    end TF;
    
    model mTF "The bondgraphic modulated transformer element" 
      extends Interfaces.ModTwoPort;
      Real m "Bondgraphic Transformation Constant";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="mTF",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="mTF",
            style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
        Window(
          x=0.45,
          y=0.01,
          width=0.44,
          height=0.65),
        Documentation(info="<html>
The bondgraphic modulated transformer is a modulated directed TwoPort element.  It inherits the effort and flow variables from the modulated directed TwoPort.  The transformation constant is modeled as a real-valued variable. <p>

The bond graph literature is not consistent in the definition of the transformation constant.  In this library, the constant is defined as the amplification of <b>flow</b> from the inflow to the outflow.  Some other bond graph references define the transformation constant as the amplification of <b>effort</b> from the inflow to the outflow. <p>

The transformer model has one causality stroke. <p>

<hr>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 m:   Transformation constant (modulation input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f2 = m*f1</b> <br>
<b>e1 = m*e2</b>
</html>
"));
    equation 
      m = s;
      e2 = m*e1;
      f1 = m*f2;
    end mTF;
    
    model GY "The bondgraphic linear gyrator element" 
      extends Interfaces.TwoPort;
      parameter Real r=1 "Bondgraphic Gyration Constant";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="GY",
            style(color=0))),
        Icon(
          Text(
            extent=[-60, 80; 60, -80],
            string="GY",
            style(color=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(extent=[-70, -50; 70, -90], string="r=%r")),
        Window(
          x=0.45,
          y=0.01,
          width=0.44,
          height=0.65),
        Documentation(info="<html>
The bondgraphic linear gyrator is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The gyration constant is modeled as a parameter. <p>

The bond graph literature is not consistent in the definition of the gyration constant.  In this library, the constant is defined as the amplification of <b>flow</b> at the inflow to <b>effort</b> at the outflow.  Some other bond graph references define the gyration constant as the amplification of <b>effort</b> at the inflow to <b>flow</b> at the outflow. <p>

The gyrator model has either zero or two causality strokes. <p>

<hr>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model


Parameters:

 r:   Gyration constant (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e2 = r*f1</b> <br>
<b>e1 = r*f2</b>
</html>
"));
    equation 
      e1 = r*f2;
      e2 = r*f1;
    end GY;
    
    model mGY "The bondgraphic modulated gyrator element" 
      extends Interfaces.ModTwoPort;
      Real r "Bondgraphic Gyration Constant";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="mGY",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="mGY",
            style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
        Window(
          x=0.45,
          y=0.01,
          width=0.44,
          height=0.65),
        Documentation(info="<html>
The bondgraphic modulated gyrator is a modulated directed TwoPort element.  It inherits the effort and flow variables from the modulated directed TwoPort.  The gyration constant is modeled as a real-valued variable. <p>

The bond graph literature is not consistent in the definition of the gyration constant.  In this library, the constant is defined as the amplification of <b>flow</b> at the inflow to <b>effort</b> at the outflow.  Some other bond graph references define the gyration constant as the amplification of <b>effort</b> at the inflow to <b>flow</b> at the outflow. <p>

The gyrator model has either zero or two causality strokes. <p>

<hr>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 r:   Gyration constant (modulation input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e2 = r*f1</b> <br>
<b>e1 = r*f2</b>
</html>
"));
    equation 
      r = s;
      e1 = r*f2;
      e2 = r*f1;
    end mGY;
  end Passive;
  
  package Semiconductors "Bondgraphic description of semiconductor elements" 
    annotation (Icon(
        Rectangle(extent=[-100,-100; 80,50],   style(fillColor=30, fillPattern=
                1)),
        Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50],      style(
              fillColor=30, fillPattern=1)),
        Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70],      style(
              fillColor=30, fillPattern=1)),
        Text(
          extent=[-85,35; 65,-85],
          string="Library",
          style(color=3)),
        Text(
          extent=[-120,122; 120,73],
          string="%name",
          style(color=1))), Documentation(info="<html>
This package contains bond graph models of electronic semiconductors using the standard bond graph interface.
</html>
"));
    model Dreal "Electrical real diode of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      parameter Modelica.SIunits.Current Ids=1.e-6 "Saturation current";
      parameter Modelica.SIunits.Voltage Vt=0.04 
        "Voltage equivalent of temperature (kT/qn)";
      parameter Real Maxexp(final min=Modelica.Constants.small) = 15 
        "Max. exponent for linear continuation";
      parameter Modelica.SIunits.Resistance R=1.e8 "Parallel Ohmic resistance";
      annotation (
        Icon(
          Text(
            extent=[-88,68; 74,-76],
            string="D",
            style(color=0)),
          Text(
            extent=[26,-18; 88,-52],
            style(color=0, pattern=0),
            string="real"),
          Text(extent=[-76,92; 64,52],   string="%name")),
        Diagram(
          Line(points=[-80,0; 80,0],   style(color=10)),
          Polygon(points=[70,4; 80,0; 70,-4; 70,4],     style(color=10,
                fillColor=10)),
          Line(points=[0,80; 0,-80],   style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[-4,70; 0,80; 4,70; -4,70],     style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[4,82; 14,72],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Text(
            extent=[70,-4; 80,-14],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e"),
          Line(points=[-80,-4; -28,-4; -6,-2; 0,0],         style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[-66,-6; -36,-14],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="blocking"),
          Text(
            extent=[16,50; 48,42],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="conducting"),
          Line(points=[0,0; 6,10; 12,28; 16,66],            style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1))),
        Documentation(info="<html>
The real diode element is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  Real diodes are a special class of non-linear resistors. <p>

The real diode model consists of the diode itself and an parallel Ohmic resistance <b>R</b>. The diode formula essentially is: <p>

<b>f = Ids*(exp(e/Vt) - 1)</b> <p>

However, if the exponent <b>e/Vt</b> reaches the limit <b>Maxexp</b>, the diode characterisic is linearly continued to avoid overflow. <p>

The causality of the real diode element is free. <p>

<hr>

<pre>
Potential variables:

 e:       Bondgraphic effort variable

 f:       Bondgraphic flow variable, normalized positive for flows into the model


Parameters:

 Ids:     Saturation current (default value = 1e-6 Amp)

 Vt:      Thermal voltage (default value = 0.04 Volt)

 Maxexp:  Maximum exponent (default value = 15)

 R:       Parallel Ohmic leakage resistance (default value = 1e8 Ohm)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = if (e/Vt &gt; Maxexp) then Ids*(exp(Maxexp)*(1 + e/Vt - Maxexp) - 1) + e/R else Ids*(exp(e/Vt) - 1) + e/R</b>
</html>
"));
    equation 
      f = if (e/Vt > Maxexp) then Ids*(exp(Maxexp)*(1 + e/Vt - Maxexp) - 1) +
        e/R else Ids*(exp(e/Vt) - 1) + e/R;
    end Dreal;
    
    model NPN "NPN transistor of the Modelica bond graph library" 
      parameter Real Bf=50 "Forward beta coefficient";
      parameter Real Br=0.1 "Reverse beta coefficient";
      parameter Modelica.SIunits.Current Is=1.e-16 
        "Transport saturation current";
      parameter Modelica.SIunits.InversePotential Vak=0.02 
        "Inverse early voltage";
      parameter Modelica.SIunits.Time Tauf=0.12e-9 "Ideal forward transit time";
      parameter Modelica.SIunits.Time Taur=5e-9 "Ideal reverse transit time";
      parameter Modelica.SIunits.Capacitance Ccs=1e-12 
        "Collector-substrate capacitance";
      parameter Modelica.SIunits.Capacitance Cje=0.4e-12 
        "Base-emitter zero bias depletion capacitance";
      parameter Modelica.SIunits.Capacitance Cjc=0.5e-12 
        "Base-collector zero bias depletion capacitance";
      parameter Modelica.SIunits.Voltage Phie=0.8 
        "Base-emitter diffusion voltage";
      parameter Real Me=0.4 "Base-emitter gradation exponent";
      parameter Modelica.SIunits.Voltage Phic=0.8 
        "Base-collector diffusion voltage";
      parameter Real Mc=0.333 "Base-collector gradation exponent";
      parameter Modelica.SIunits.Conductance Gbc=1e-15 
        "Base-collector leakage conductance";
      parameter Modelica.SIunits.Conductance Gbe=1e-15 
        "Base-emitter leakage conductance";
      parameter Modelica.SIunits.Voltage Vt=0.02585 "Thermal voltage";
      parameter Real EMin=-100 "if x < EMin, the exp(x) function is linearized";
      parameter Real EMax=40 "if x > EMax, the exp(x) function is linearized";
      Interfaces.BondCon B annotation (extent=[-110,-10; -90,10]);
      Interfaces.BondCon C annotation (extent=[-10,90; 10,110]);
      Interfaces.BondCon E annotation (extent=[-10,-110; 10,-90]);
      annotation (
        Diagram(
          Text(
            extent=[6,-90; 26,-110],
            style(color=9, rgbcolor={149,164,171}),
            string="E"),
          Text(
            extent=[-108,28; -88,8],
            string="B",
            style(color=9, rgbcolor={149,164,171})),
          Text(
            extent=[6,110; 26,90],
            style(color=9, rgbcolor={149,164,171}),
            string="C"),
          Ellipse(extent=[-112,42; -108,38], style(
              color=9,
              rgbcolor={149,164,171},
              fillColor=74,
              rgbfillColor={0,0,185})),
          Ellipse(extent=[-122,-42; -118,-38], style(
              color=9,
              rgbcolor={149,164,171},
              fillColor=74,
              rgbfillColor={0,0,185})),
          Text(
            extent=[-98,48; -88,40],
            string="ibc",
            style(color=9, rgbcolor={149,164,171})),
          Text(
            extent=[-96,-66; -86,-74],
            string="ibc",
            style(color=9, rgbcolor={149,164,171})),
          Text(
            extent=[78,72; 88,64],
            string="ibc",
            style(color=9, rgbcolor={149,164,171})),
          Text(
            extent=[54,72; 64,64],
            style(color=9, rgbcolor={149,164,171}),
            string="ibe"),
          Text(
            extent=[-96,-86; -86,-94],
            style(color=9, rgbcolor={149,164,171}),
            string="ibe"),
          Text(
            extent=[-100,-32; -90,-40],
            style(color=9, rgbcolor={149,164,171}),
            string="ibe"),
          Text(
            extent=[-36,-12; -26,-20],
            style(color=9, rgbcolor={149,164,171}),
            string="vbc"),
          Text(
            extent=[48,58; 58,50],
            style(color=9, rgbcolor={149,164,171}),
            string="vbc"),
          Text(
            extent=[78,8; 88,0],
            style(color=9, rgbcolor={149,164,171}),
            string="IC0"),
          Text(
            extent=[-38,-90; -28,-98],
            style(color=9, rgbcolor={149,164,171}),
            string="IB0")),
        Icon(
          Text(
            extent=[-82,82; 86,-86],
            style(color=0),
            string="NPN"),
          Text(
            extent=[-108,28; -88,8],
            string="B",
            style(color=9, rgbcolor={149,164,171})),
          Text(
            extent=[6,110; 26,90],
            style(color=9, rgbcolor={149,164,171}),
            string="C"),
          Text(
            extent=[6,-90; 26,-110],
            style(color=9, rgbcolor={149,164,171}),
            string="E"),
          Line(points=[0,80; 0,-80], style(
              color=9,
              rgbcolor={149,164,171},
              thickness=2,
              fillColor=74,
              rgbfillColor={0,0,185},
              fillPattern=1)),
          Line(points=[-20,-60; 0,-80], style(
              color=9,
              rgbcolor={149,164,171},
              thickness=2,
              fillColor=74,
              rgbfillColor={0,0,185},
              fillPattern=1)),
          Line(points=[0,-80; 20,-60], style(
              color=9,
              rgbcolor={149,164,171},
              thickness=2,
              fillColor=74,
              rgbfillColor={0,0,185},
              fillPattern=1))),
        Documentation(info="<html>
The NPN element of the bond graph library implements the Ebers-Moll model of a NPN bipolar transistor.  The substrate is not shown on the icon layer, as it is assumed grounded. The transistor is assumed to be vertically diffused, as the substrate is connected to the collector, rather than to the base. <p>

The NPN bipolar transistor is a directed ThreePort.  The direction of positive power flow is assumed into the model at the base, <b>B</b>, and at the collector, <b>C</b>, whereas it is assumed out of the model at the emitter, <b>E</b>. <p>

The causality of the NPN model is relatively free.  However, if there is a causality stroke placed at the collector from the outside, the substrate capacitor will assume differential causality. <p>

<hr>

<pre>
Parameters:

 Bf:    Forward beta coefficient (default value = 50)

 Br:    Reverse beta coefficient (default value = 0.1)

 Is:    Transport saturation current (default value = 1e-16 Amp)

 Vak:   Inverse early voltage (default value = 0.02 /Volt)

 Tauf:  Ideal forward transit time (default value = 0.12e-9 sec)

 Taur:  Ideal reverse transit time (default value = 5e-9 sec)

 Ccs:   Collector-substrate capacitance (default value = 1e-12 F)

 Cje:   Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 Cjc:   Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 Phie:  Base-emitter diffusion voltage (default value = 0.8 Volt)

 Me:    Base-emitter gradation exponent (default value = 0.4)

 Phic:  Base-collector diffusion voltage (default value = 0.8 Volt)

 Mc:    Base-collector gradation exponent (default value = 0.333)

 Gbc:   Base-collector leakage conductance (default value = 1e-15 Mho)

 Gbe:   Base-emitter leakage conductance (default value = 1e-15 Mho)

 Vt:    Thermal voltage (default value = 0.02585 Volt)

 EMin:  Minimum exponent (default value = -100)

 EMax:  Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

References: <p>

Vlach, J. and K. Singal (1983), <I>Computer methods for circuit analysis and design</I>, Van Nostrand Reinhold, New York,
on page 317 ff.
</html>
"));
      Junctions.J0p3 J0p3_1 annotation (extent=[-10,-10; 10,10], rotation=-90);
      Bonds.Bond B1 annotation (extent=[-10,50; 10,70], rotation=90);
      Bonds.Bond B2 annotation (extent=[-10,10; 10,30], rotation=90);
      Bonds.Bond B3 annotation (extent=[-10,-30; 10,-10], rotation=-90);
      Bonds.Bond B4 annotation (extent=[-10,-70; 10,-50], rotation=-90);
      Junctions.J1p3 J1p3_1 annotation (extent=[-10,30; 10,50], rotation=-90);
      Junctions.J0p4 J0p4_1 annotation (extent=[-10,70; 10,90]);
      Junctions.J1p3 J1p3_2 annotation (extent=[-10,-50; 10,-30], rotation=-90);
      Junctions.J0p3 J0p3_2 annotation (extent=[10,-90; -10,-70], rotation=-90);
      Junctions.J1p3 J1p3_3 annotation (extent=[40,-10; 20,10], rotation=-90);
      Bonds.Bond B5 annotation (extent=[20,10; 40,30], rotation=-90);
      Bonds.Bond B6 annotation (extent=[20,-30; 40,-10], rotation=-90);
      Bonds.Bond B7 annotation (extent=[-30,70; -10,90], rotation=180);
      Passive.C C1(C=Ccs) annotation (extent=[-30,70; -50,90]);
      Bonds.eBond B8 annotation (extent=[40,-10; 60,10], rotation=180);
      Sources.mSf Ic0 annotation (extent=[60,-10; 80,10]);
      Junctions.J0p3 J0p3_3 annotation (extent=[-50,50; -30,30], rotation=-180);
      Bonds.eBond B9 annotation (extent=[-30,30; -10,50], rotation=180);
      Bonds.fBond B10 annotation (extent=[-50,10; -30,30], rotation=-90);
      Sensors.De Vbc annotation (extent=[-50,-10; -30,10], rotation=-90);
      Bonds.eBond B11 annotation (extent=[-70,30; -50,50], rotation=180);
      Utilities.Cj Cbc(
        Is=Is,
        Tau=Taur,
        Cj=Cjc,
        Phi=Phic,
        M=Mc,
        Gb=Gbc,
        Vt=Vt,
        EMin=EMin,
        EMax=EMax) annotation (extent=[-70,30; -90,50]);
      Bonds.eBond B12 annotation (extent=[-30,-50; -10,-30], rotation=180);
      Junctions.J0p3 J0p3_4 
        annotation (extent=[-50,-30; -30,-50], rotation=-180);
      Bonds.eBond B13 annotation (extent=[-50,-70; -30,-50], rotation=90);
      Sources.mSf Ib0 annotation (extent=[-50,-90; -30,-70], rotation=-90);
      Bonds.eBond B14 annotation (extent=[-70,-50; -50,-30], rotation=180);
      Utilities.Cj Cbe(
        Is=Is,
        Vt=Vt,
        EMin=EMin,
        EMax=EMax,
        Tau=Tauf,
        Cj=Cje,
        Phi=Phie,
        M=Me,
        Gb=Gbe) annotation (extent=[-70,-50; -90,-30]);
      Utilities.IC0 IC0_1(
        Bf=Bf,
        Br=Br,
        Vak=Vak) annotation (extent=[60,40; 80,60], rotation=-90);
      Utilities.IB0 IB0_1(Bf=Bf, Br=Br) annotation (extent=[-80,-90; -60,-70]);
    equation 
      connect(J0p3_1.BondCon1, B2.BondCon1) annotation (points=[-6.12303e-016,
            10; -6.00057e-016,10; -6.00057e-016,10.2], style(color=8, rgbcolor=
              {192,192,192}));
      connect(J1p3_1.BondCon2, B2.BondCon2) annotation (points=[6.12303e-016,30; 
            6.12303e-016,30], style(color=8, rgbcolor={192,192,192}));
      connect(B1.BondCon1, J1p3_1.BondCon1) annotation (points=[-6.00057e-016,
            50.2; -6.00057e-016,56.1; -6.12303e-016,56.1; -6.12303e-016,50],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p4_1.BondCon3, B1.BondCon2) annotation (points=[0,70; 
            6.12303e-016,70], style(color=8, rgbcolor={192,192,192}));
      connect(J0p4_1.BondCon4, C) annotation (points=[0,90; 0,100], style(color=
             8, rgbcolor={192,192,192}));
      connect(J0p3_1.BondCon2, B3.BondCon1) annotation (points=[6.12303e-016,
            -10; -6.00057e-016,-10; -6.00057e-016,-10.2], style(color=8,
            rgbcolor={192,192,192}));
      connect(J1p3_2.BondCon1, B3.BondCon2) annotation (points=[-6.12303e-016,
            -30; 6.12303e-016,-30], style(color=8, rgbcolor={192,192,192}));
      connect(B4.BondCon1, J1p3_2.BondCon2) annotation (points=[-6.00057e-016,
            -50.2; -6.00057e-016,-55.1; 6.12303e-016,-55.1; 6.12303e-016,-50],
          style(color=8, rgbcolor={192,192,192}));
      connect(B4.BondCon2, J0p3_2.BondCon1) annotation (points=[6.12303e-016,
            -70; 6.12303e-016,-70], style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_2.BondCon2, E) annotation (points=[-6.12303e-016,-90; 0,-90; 
            0,-100], style(color=8, rgbcolor={192,192,192}));
      connect(B5.BondCon2, J1p3_3.BondCon1) annotation (points=[30,10; 30,10],
          style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_3.BondCon2, B6.BondCon1) annotation (points=[30,-10; 30,
            -10.2], style(color=8, rgbcolor={192,192,192}));
      connect(J0p4_1.BondCon2, B5.BondCon1) annotation (points=[10,80; 30,80;
            30,29.8], style(color=8, rgbcolor={192,192,192}));
      connect(B6.BondCon2, J0p3_2.BondCon3) annotation (points=[30,-30; 30,-80;
            10,-80], style(color=8, rgbcolor={192,192,192}));
      connect(B7.BondCon1, J0p4_1.BondCon1) annotation (points=[-10.2,80; -10,
            80], style(color=8, rgbcolor={192,192,192}));
      connect(C1.BondCon1, B7.BondCon2) annotation (points=[-30,80; -30,80],
          style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_3.BondCon3, B8.eBondCon1) annotation (points=[40,
            -6.12303e-016; 44,-6.12303e-016; 44,1.22461e-015; 40,1.22461e-015],
          style(color=8, rgbcolor={192,192,192}));
      connect(Ic0.BondCon1, B8.fBondCon1) annotation (points=[60,0; 64,0; 64,
            -1.22461e-015; 60,-1.22461e-015], style(color=8, rgbcolor={192,192,
              192}));
      connect(B9.fBondCon1, J1p3_1.BondCon3) annotation (points=[-10,40; -10,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_3.BondCon1, B9.eBondCon1) annotation (points=[-30,40; -30,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_3.BondCon3, B10.eBondCon1) annotation (points=[-40,30; -40,
            30], style(color=8, rgbcolor={192,192,192}));
      connect(Vbc.BondCon1, B10.fBondCon1) annotation (points=[-40,10; -40,10],
          style(color=8, rgbcolor={192,192,192}));
      connect(B11.fBondCon1, J0p3_3.BondCon2) annotation (points=[-50,40; -50,
            40], style(color=8, rgbcolor={192,192,192}));
      connect(Cbc.BondCon1, B11.eBondCon1) annotation (points=[-70,40; -70,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(B12.fBondCon1, J1p3_2.BondCon3) annotation (points=[-10,-40; -10,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_4.BondCon1, B12.eBondCon1) annotation (points=[-30,-40; -30,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(B13.eBondCon1, J0p3_4.BondCon3) annotation (points=[-40,-50; -40,
            -50], style(color=8, rgbcolor={192,192,192}));
      connect(Ib0.BondCon1, B13.fBondCon1) annotation (points=[-40,-70; -40,-70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B14.fBondCon1, J0p3_4.BondCon2) annotation (points=[-50,-40; -50,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(Cbe.BondCon1, B14.eBondCon1) annotation (points=[-70,-40; -70,-40],
          style(color=8, rgbcolor={192,192,192}));
      connect(IC0_1.y, Ic0.InPort1) annotation (points=[70,39; 70,30; 90,30; 90,
            0; 79,0], style(color=74, rgbcolor={0,0,127}));
      connect(Vbc.OutPort1, IC0_1.u3) annotation (points=[-40,-11; -40,-20; -20,
            -20; -20,34; 50,34; 50,50; 60,50], style(color=74, rgbcolor={0,0,
              127}));
      connect(Cbc.y, IC0_1.u1) annotation (points=[-90,40; -110,40; -110,112;
            76,112; 76,62], style(color=74, rgbcolor={0,0,127}));
      connect(IB0_1.y, Ib0.InPort1) annotation (points=[-59,-80; -52,-80; -52,
            -96; -40,-96; -40,-89], style(color=74, rgbcolor={0,0,127}));
      connect(Cbc.y, IB0_1.u1) annotation (points=[-90,40; -110,40; -110,-74;
            -82,-74], style(color=74, rgbcolor={0,0,127}));
      connect(Cbe.y, IB0_1.u2) annotation (points=[-90,-40; -120,-40; -120,-86;
            -82,-86], style(color=74, rgbcolor={0,0,127}));
      connect(Cbe.y, IC0_1.u2) annotation (points=[-90,-40; -120,-40; -120,122;
            64,122; 64,62], style(color=74, rgbcolor={0,0,127}));
      connect(J0p3_1.BondCon3, B) annotation (points=[-10,-6.12303e-016; -52,
            -6.12303e-016; -52,0; -100,0], style(
          color=8,
          rgbcolor={192,192,192},
          fillColor=74,
          rgbfillColor={0,0,185},
          fillPattern=1));
    end NPN;
    
    model PNP "PNP transistor of the Modelica bond graph library" 
      parameter Real Bf=50 "Forward beta coefficient";
      parameter Real Br=0.1 "Reverse beta coefficient";
      parameter Modelica.SIunits.Current Is=1.e-16 
        "Transport saturation current";
      parameter Modelica.SIunits.InversePotential Vak=0.02 
        "Inverse early voltage";
      parameter Modelica.SIunits.Time Tauf=0.12e-9 "Ideal forward transit time";
      parameter Modelica.SIunits.Time Taur=5e-9 "Ideal reverse transit time";
      parameter Modelica.SIunits.Capacitance Ccs=1e-12 
        "Collector-substrate capacitance";
      parameter Modelica.SIunits.Capacitance Cje=0.4e-12 
        "Base-emitter zero bias depletion capacitance";
      parameter Modelica.SIunits.Capacitance Cjc=0.5e-12 
        "Base-collector zero bias depletion capacitance";
      parameter Modelica.SIunits.Voltage Phie=0.8 
        "Base-emitter diffusion voltage";
      parameter Real Me=0.4 "Base-emitter gradation exponent";
      parameter Modelica.SIunits.Voltage Phic=0.8 
        "Base-collector diffusion voltage";
      parameter Real Mc=0.333 "Base-collector gradation exponent";
      parameter Modelica.SIunits.Conductance Gbc=1e-15 
        "Base-collector leakage conductance";
      parameter Modelica.SIunits.Conductance Gbe=1e-15 
        "Base-emitter leakage conductance";
      parameter Modelica.SIunits.Voltage Vt=0.02585 "Thermal voltage";
      parameter Real EMin=-100 "if x < EMin, the exp(x) function is linearized";
      parameter Real EMax=40 "if x > EMax, the exp(x) function is linearized";
      annotation (
        Icon(
          Text(
            extent=[-80,82; 88,-86],
            style(color=0),
            string="PNP"),
          Text(
            extent=[-108,28; -88,8],
            string="B",
            style(color=9, rgbcolor={149,164,171})),
          Text(
            extent=[6,110; 26,90],
            style(color=9, rgbcolor={149,164,171}),
            string="C"),
          Text(
            extent=[6,-90; 26,-110],
            style(color=9, rgbcolor={149,164,171}),
            string="E"),
          Line(points=[0,80; 0,-80], style(
              color=9,
              rgbcolor={149,164,171},
              thickness=2,
              fillColor=74,
              rgbfillColor={0,0,185},
              fillPattern=1)),
          Line(points=[0,80; 20,60],    style(
              color=9,
              rgbcolor={149,164,171},
              thickness=2,
              fillColor=74,
              rgbfillColor={0,0,185},
              fillPattern=1)),
          Line(points=[-20,60; 0,80],  style(
              color=9,
              rgbcolor={149,164,171},
              thickness=2,
              fillColor=74,
              rgbfillColor={0,0,185},
              fillPattern=1))),
        Diagram(
          Text(
            extent=[6,-90; 26,-110],
            style(color=9, rgbcolor={149,164,171}),
            string="E"),
          Text(
            extent=[-108,28; -88,8],
            string="B",
            style(color=9, rgbcolor={149,164,171})),
          Text(
            extent=[6,110; 26,90],
            style(color=9, rgbcolor={149,164,171}),
            string="C"),
          Ellipse(extent=[-112,42; -108,38], style(
              color=9,
              rgbcolor={149,164,171},
              fillColor=74,
              rgbfillColor={0,0,185})),
          Ellipse(extent=[-122,-42; -118,-38], style(
              color=9,
              rgbcolor={149,164,171},
              fillColor=74,
              rgbfillColor={0,0,185})),
          Text(
            extent=[-98,48; -88,40],
            style(color=9, rgbcolor={149,164,171}),
            string="icb"),
          Text(
            extent=[-96,-66; -86,-74],
            style(color=9, rgbcolor={149,164,171}),
            string="icb"),
          Text(
            extent=[78,72; 88,64],
            style(color=9, rgbcolor={149,164,171}),
            string="icb"),
          Text(
            extent=[54,72; 64,64],
            style(color=9, rgbcolor={149,164,171}),
            string="ieb"),
          Text(
            extent=[-96,-86; -86,-94],
            style(color=9, rgbcolor={149,164,171}),
            string="ieb"),
          Text(
            extent=[-100,-32; -90,-40],
            style(color=9, rgbcolor={149,164,171}),
            string="ieb"),
          Text(
            extent=[-36,-12; -26,-20],
            style(color=9, rgbcolor={149,164,171}),
            string="vcb"),
          Text(
            extent=[48,58; 58,50],
            style(color=9, rgbcolor={149,164,171}),
            string="vcb"),
          Text(
            extent=[78,8; 88,0],
            style(color=9, rgbcolor={149,164,171}),
            string="IC0"),
          Text(
            extent=[-38,-90; -28,-98],
            style(color=9, rgbcolor={149,164,171}),
            string="IB0")),
        Documentation(info="<html>
The PNP element of the bond graph library implements the Ebers-Moll model of a PNP bipolar transistor.  The substrate is not shown on the icon layer, as it is assumed grounded. The transistor is assumed to be vertically diffused, as the substrate is connected to the collector, rather than to the base. <p>

The PNP bipolar transistor is a directed ThreePort.  The direction of positive power flow is assumed out of the model at the base, <b>B</b>, and at the collector, <b>C</b>, whereas it is assumed into the model at the emitter, <b>E</b>. <p>

The causality of the PNP model is relatively free.  However, if there is a causality stroke placed at the collector from the outside, the substrate capacitor will assume differential causality. <p>

<hr>

<pre>
Parameters:

 Bf:    Forward beta coefficient (default value = 50)

 Br:    Reverse beta coefficient (default value = 0.1)

 Is:    Transport saturation current (default value = 1e-16 Amp)

 Vak:   Inverse early voltage (default value = 0.02 /Volt)

 Tauf:  Ideal forward transit time (default value = 0.12e-9 sec)

 Taur:  Ideal reverse transit time (default value = 5e-9 sec)

 Ccs:   Collector-substrate capacitance (default value = 1e-12 F)

 Cje:   Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 Cjc:   Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 Phie:  Base-emitter diffusion voltage (default value = 0.8 Volt)

 Me:    Base-emitter gradation exponent (default value = 0.4)

 Phic:  Base-collector diffusion voltage (default value = 0.8 Volt)

 Mc:    Base-collector gradation exponent (default value = 0.333)

 Gbc:   Base-collector leakage conductance (default value = 1e-15 Mho)

 Gbe:   Base-emitter leakage conductance (default value = 1e-15 Mho)

 Vt:    Thermal voltage (default value = 0.02585 Volt)

 EMin:  Minimum exponent (default value = -100)

 EMax:  Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

References: <p>

Vlach, J. and K. Singal (1983), <I>Computer methods for circuit analysis and design</I>, Van Nostrand Reinhold, New York,
on page 317 ff.
</html>
"));
      Interfaces.BondCon B annotation (extent=[-110,-10; -90,10]);
      Interfaces.BondCon C annotation (extent=[-10,90; 10,110]);
      Interfaces.BondCon E annotation (extent=[-10,-110; 10,-90]);
      Junctions.J0p3 J0p3_1 annotation (extent=[-10,-10; 10,10], rotation=-90);
      Bonds.Bond B1 annotation (extent=[-10,50; 10,70], rotation=270);
      Bonds.Bond B2 annotation (extent=[-10,10; 10,30], rotation=270);
      Bonds.Bond B3 annotation (extent=[-10,-30; 10,-10], rotation=90);
      Bonds.Bond B4 annotation (extent=[-10,-70; 10,-50], rotation=90);
      Junctions.J1p3 J1p3_1 annotation (extent=[-10,30; 10,50], rotation=-90);
      Junctions.J0p4 J0p4_1 annotation (extent=[-10,70; 10,90]);
      Junctions.J1p3 J1p3_2 annotation (extent=[-10,-50; 10,-30], rotation=-90);
      Junctions.J0p3 J0p3_2 annotation (extent=[10,-90; -10,-70], rotation=-90);
      Junctions.J1p3 J1p3_3 annotation (extent=[40,-10; 20,10], rotation=-90);
      Bonds.Bond B5 annotation (extent=[20,10; 40,30], rotation=90);
      Bonds.Bond B6 annotation (extent=[20,-30; 40,-10], rotation=90);
      Bonds.Bond B7 annotation (extent=[-30,70; -10,90], rotation=180);
      Passive.C C1(C=Ccs) annotation (extent=[-30,70; -50,90]);
      Bonds.eBond B8 annotation (extent=[40,-10; 60,10], rotation=180);
      Sources.mSf Ic0 annotation (extent=[60,-10; 80,10]);
      Junctions.J0p3 J0p3_3 annotation (extent=[-50,50; -30,30], rotation=-180);
      Bonds.eBond B9 annotation (extent=[-30,30; -10,50], rotation=180);
      Bonds.fBond B10 annotation (extent=[-50,10; -30,30], rotation=-90);
      Sensors.De Vcb annotation (extent=[-50,-10; -30,10], rotation=-90);
      Bonds.eBond B11 annotation (extent=[-70,30; -50,50], rotation=180);
      Utilities.Cj Ccb(
        Is=Is,
        Tau=Taur,
        Cj=Cjc,
        Phi=Phic,
        M=Mc,
        Gb=Gbc,
        Vt=Vt,
        EMin=EMin,
        EMax=EMax) annotation (extent=[-70,30; -90,50]);
      Bonds.eBond B12 annotation (extent=[-30,-50; -10,-30], rotation=180);
      Junctions.J0p3 J0p3_4 
        annotation (extent=[-50,-30; -30,-50], rotation=-180);
      Bonds.eBond B13 annotation (extent=[-50,-70; -30,-50], rotation=90);
      Sources.mSf Ib0 annotation (extent=[-50,-90; -30,-70], rotation=-90);
      Bonds.eBond B14 annotation (extent=[-70,-50; -50,-30], rotation=180);
      Utilities.Cj Ceb(
        Is=Is,
        Vt=Vt,
        EMin=EMin,
        EMax=EMax,
        Tau=Tauf,
        Cj=Cje,
        Phi=Phie,
        M=Me,
        Gb=Gbe) annotation (extent=[-70,-50; -90,-30]);
      Utilities.IC0 IC0_1(
        Bf=Bf,
        Br=Br,
        Vak=Vak) annotation (extent=[60,40; 80,60], rotation=-90);
      Utilities.IB0 IB0_1(Bf=Bf, Br=Br) annotation (extent=[-80,-90; -60,-70]);
    equation 
      connect(J0p4_1.BondCon4,C)  annotation (points=[0,90; 0,100], style(color=
             8, rgbcolor={192,192,192}));
      connect(J0p3_2.BondCon2,E)  annotation (points=[-6.12303e-016,-90; 0,-90; 
            0,-100], style(color=8, rgbcolor={192,192,192}));
      connect(B7.BondCon1,J0p4_1. BondCon1) annotation (points=[-10.2,80; -10,
            80], style(color=8, rgbcolor={192,192,192}));
      connect(C1.BondCon1,B7. BondCon2) annotation (points=[-30,80; -30,80],
          style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_3.BondCon3,B8. eBondCon1) annotation (points=[40,
            -6.12303e-016; 44,-6.12303e-016; 44,1.22461e-015; 40,1.22461e-015],
          style(color=8, rgbcolor={192,192,192}));
      connect(Ic0.BondCon1,B8. fBondCon1) annotation (points=[60,0; 64,0; 64,
            -1.22461e-015; 60,-1.22461e-015], style(color=8, rgbcolor={192,192,
              192}));
      connect(B9.fBondCon1,J1p3_1. BondCon3) annotation (points=[-10,40; -10,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_3.BondCon1,B9. eBondCon1) annotation (points=[-30,40; -30,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_3.BondCon3,B10. eBondCon1) annotation (points=[-40,30; -40,
            30], style(color=8, rgbcolor={192,192,192}));
      connect(Vcb.BondCon1,B10. fBondCon1) annotation (points=[-40,10; -40,10],
          style(color=8, rgbcolor={192,192,192}));
      connect(B11.fBondCon1,J0p3_3. BondCon2) annotation (points=[-50,40; -50,
            40], style(color=8, rgbcolor={192,192,192}));
      connect(Ccb.BondCon1,B11. eBondCon1) annotation (points=[-70,40; -70,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(B12.fBondCon1,J1p3_2. BondCon3) annotation (points=[-10,-40; -10,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_4.BondCon1,B12. eBondCon1) annotation (points=[-30,-40; -30,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(B13.eBondCon1,J0p3_4. BondCon3) annotation (points=[-40,-50; -40,
            -50], style(color=8, rgbcolor={192,192,192}));
      connect(Ib0.BondCon1,B13. fBondCon1) annotation (points=[-40,-70; -40,-70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B14.fBondCon1,J0p3_4. BondCon2) annotation (points=[-50,-40; -50,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(Ceb.BondCon1,B14. eBondCon1) annotation (points=[-70,-40; -70,-40],
          style(color=8, rgbcolor={192,192,192}));
      connect(IC0_1.y,Ic0. InPort1) annotation (points=[70,39; 70,30; 90,30; 90,
            0; 79,0], style(color=74, rgbcolor={0,0,127}));
      connect(Vcb.OutPort1,IC0_1. u3) annotation (points=[-40,-11; -40,-20; -20,
            -20; -20,34; 50,34; 50,50; 60,50], style(color=74, rgbcolor={0,0,
              127}));
      connect(Ccb.y,IC0_1. u1) annotation (points=[-90,40; -110,40; -110,112;
            76,112; 76,62], style(color=74, rgbcolor={0,0,127}));
      connect(IB0_1.y,Ib0. InPort1) annotation (points=[-59,-80; -52,-80; -52,
            -96; -40,-96; -40,-89], style(color=74, rgbcolor={0,0,127}));
      connect(Ccb.y,IB0_1. u1) annotation (points=[-90,40; -110,40; -110,-74;
            -82,-74], style(color=74, rgbcolor={0,0,127}));
      connect(Ceb.y,IB0_1. u2) annotation (points=[-90,-40; -120,-40; -120,-86;
            -82,-86], style(color=74, rgbcolor={0,0,127}));
      connect(Ceb.y,IC0_1. u2) annotation (points=[-90,-40; -120,-40; -120,122;
            64,122; 64,62], style(color=74, rgbcolor={0,0,127}));
      connect(J0p3_1.BondCon3,B)  annotation (points=[-10,-6.12303e-016; -52,
            -6.12303e-016; -52,0; -100,0], style(
          color=8,
          rgbcolor={192,192,192},
          fillColor=74,
          rgbfillColor={0,0,185},
          fillPattern=1));
      connect(J1p3_1.BondCon1, B1.BondCon2) annotation (points=[-6.12303e-016,
            50; -1.83691e-015,50], style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_1.BondCon1, B2.BondCon2) annotation (points=[-6.12303e-016,
            10; -1.83691e-015,10], style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_1.BondCon2, B3.BondCon2) annotation (points=[6.12303e-016,
            -10; 6.12303e-016,-10], style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_2.BondCon2, B4.BondCon2) annotation (points=[6.12303e-016,
            -50; 6.12303e-016,-50], style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_3.BondCon1, B5.BondCon1) annotation (points=[30,10; 30,10.2],
          style(color=8, rgbcolor={192,192,192}));
      connect(B5.BondCon2, J0p4_1.BondCon2) annotation (points=[30,30; 30,80;
            10,80], style(color=8, rgbcolor={192,192,192}));
      connect(B6.BondCon2, J1p3_3.BondCon2) annotation (points=[30,-10; 30,-10],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_2.BondCon3, B6.BondCon1) annotation (points=[10,-80; 30,-80;
            30,-29.8], style(color=8, rgbcolor={192,192,192}));
      connect(B1.BondCon1, J0p4_1.BondCon3) annotation (points=[1.80017e-015,
            69.8; 1.80017e-015,65.9; 0,65.9; 0,70], style(color=8, rgbcolor={
              192,192,192}));
      connect(B2.BondCon1, J1p3_1.BondCon2) annotation (points=[1.80017e-015,
            29.8; 1.80017e-015,27.9; 6.12303e-016,27.9; 6.12303e-016,30], style(
            color=8, rgbcolor={192,192,192}));
      connect(J1p3_2.BondCon1, B3.BondCon1) annotation (points=[-6.12303e-016,
            -30; -6.00057e-016,-30; -6.00057e-016,-29.8], style(color=8,
            rgbcolor={192,192,192}));
      connect(J0p3_2.BondCon1, B4.BondCon1) annotation (points=[6.12303e-016,
            -70; -6.00057e-016,-70; -6.00057e-016,-69.8], style(color=8,
            rgbcolor={192,192,192}));
    end PNP;
    
    package Utilities "Utility models for bond graph semiconductor package" 
      annotation (Icon(
          Rectangle(extent=[-100,-100; 80,50], style(
              color=42,
              rgbcolor={127,0,0},
              fillColor=30,
              rgbfillColor={235,235,235},
              fillPattern=1)),
          Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50], style(
              color=42,
              rgbcolor={127,0,0},
              fillColor=30,
              rgbfillColor={235,235,235},
              fillPattern=1)),
          Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70], style(
              color=42,
              rgbcolor={127,0,0},
              fillColor=30,
              rgbfillColor={235,235,235},
              fillPattern=1)),
          Text(
            extent=[-85,35; 65,-85],
            string="Library",
            style(color=42, rgbcolor={127,0,0})),
          Text(
            extent=[-120,122; 120,73],
            string="%name",
            style(color=1))), Documentation(info="<html>
This package contains some utility models used inside some of the semiconductor bond graph models.
</html>
"));
      block nlC "Non-linear capacitance computation of Ebers-Moll BJT" 
        extends Modelica.Blocks.Interfaces.SISO;
        parameter Modelica.SIunits.Current Is=1.e-16 
          "Transport saturation current";
        parameter Modelica.SIunits.Time Tau=5e-9 "Ideal transit time";
        parameter Modelica.SIunits.Voltage Phi=0.8 "Diffusion voltage";
        parameter Modelica.SIunits.Capacitance Cj=0.5e-12 
          "Zero bias depletion capacitance";
        parameter Real M=0.333 "Gradation exponent";
        parameter Modelica.SIunits.Voltage Vt=0.02585 "Thermal voltage";
        parameter Real EMin=-100 
          "if x < EMin, the exp(x) function is linearized";
        parameter Real EMax=40 "if x > EMax, the exp(x) function is linearized";
        output Modelica.SIunits.Voltage v 
          "Voltage across the junction capacitance";
        output Modelica.SIunits.Capacitance C 
          "Non-linear junction capacitance value";
        
      protected 
        Modelica.SIunits.Capacitance Cjunc "Junction capacitance";
        Modelica.SIunits.Capacitance Cdepl "Depletion capacitance";
        Real ExMin;
        Real ExMax;
        
        function pow "Just a helper function for x^y" 
          input Real x;
          input Real y;
          output Real z;
        algorithm 
          z:=x^y;
        end pow;
        annotation (
          Icon(Text(
              extent=[-76,64; 78,-64],
              string="nl C",
              style(color=0, rgbcolor={0,0,0})), Text(
              extent=[-80,-52; 84,-76],
              style(color=0, rgbcolor={0,0,0}),
              string="Ebers-Moll BJT")),
          Diagram(Text(
              extent=[-76,64; 78,-64],
              string="nl C",
              style(color=0, rgbcolor={0,0,0})), Text(
              extent=[-80,-52; 84,-76],
              style(color=0, rgbcolor={0,0,0}),
              string="Ebers-Moll BJT")),
          Documentation(info="<html>
This block computes the junction capacitance value of a junction capacitance in accordance with the Ebers-Moll junction diode model.
</html>
"));
      equation 
        ExMin = exp(EMin);
        ExMax = exp(EMax);
        v = u;
        Cjunc = if (v/Vt < EMin) then Tau*Is/Vt*ExMin*(v/Vt - EMin + 1) else 
                if (v/Vt > EMax) then Tau*Is/Vt*ExMax*(v/Vt - EMax + 1) else Tau*Is/Vt*exp(v/Vt);
        Cdepl = if (v/Phi > 0) then Cj*(1 + M*v/Phi) else Cj*pow(1 - v/Phi, -M);
        C = Cjunc + Cdepl;
        y = C;
      end nlC;
      
      block IB0 "Non-linear base-emitter current source of the Ebers-Moll BJT" 
        extends Modelica.Blocks.Interfaces.SI2SO;
        parameter Real Bf=50 "Forward beta coefficient";
        parameter Real Br=0.1 "Reverse beta coefficient";
        output Modelica.SIunits.Current ibc "Base-collector diode current";
        output Modelica.SIunits.Current ibe "Base-emitter diode current";
        output Modelica.SIunits.Current IB0 "Injected base current";
        annotation (
          Icon(Text(
              extent=[-72,62; 82,-66],
              style(color=0, rgbcolor={0,0,0}),
              string="IB 0"), Text(
              extent=[-76,-54; 88,-78],
              style(color=0, rgbcolor={0,0,0}),
              string="Ebers-Moll BJT"),
            Text(
              extent=[-96,68; -76,52],
              style(color=3, rgbcolor={0,0,255}),
              string="ibc"),
            Text(
              extent=[-96,-52; -76,-68],
              style(color=3, rgbcolor={0,0,255}),
              string="ibe")),
          Diagram(Text(
              extent=[-72,62; 82,-66],
              style(color=0, rgbcolor={0,0,0}),
              string="IB 0"), Text(
              extent=[-76,-54; 88,-78],
              style(color=0, rgbcolor={0,0,0}),
              string="Ebers-Moll BJT"),
            Text(
              extent=[-96,68; -76,52],
              style(color=3, rgbcolor={0,0,255}),
              string="ibc"),
            Text(
              extent=[-96,-52; -76,-68],
              style(color=3, rgbcolor={0,0,255}),
              string="ibe")),
          Documentation(info="<html>
This block computes the injected base current of a BJT in accordance with the Ebers-Moll model. <p>

<pre>
Parameters:

 Bf:   Forward beta coefficient (default value = 50)

 Br:   Reverse beta coefficient (default value = 0.1)
</pre>
</html>
"));
      equation 
        ibc = u1;
        ibe = u2;
        IB0 = ibe/Bf + ibc/Br;
        y = IB0;
      end IB0;
      
      block IC0 
        "Non-linear collector-emitter current source of the Ebers-Moll BJT" 
        extends Modelica.Blocks.Interfaces.SI2SO;
        parameter Real Bf=50 "Forward beta coefficient";
        parameter Real Br=0.1 "Reverse beta coefficient";
        parameter Modelica.SIunits.InversePotential Vak=0.02 
          "Inverse early voltage";
        output Modelica.SIunits.Current ibc "Base-collector diode current";
        output Modelica.SIunits.Current ibe "Base-emitter diode current";
        output Modelica.SIunits.Voltage vbc "Base-collector voltage";
        output Modelica.SIunits.Current IC0 "Injected collector current";
        
      protected 
        Real qbk "Inverse base charge";
        annotation (
          Icon(Text(
              extent=[-72,62; 82,-66],
              style(color=0, rgbcolor={0,0,0}),
              string="IC 0"), Text(
              extent=[-76,-54; 88,-78],
              style(color=0, rgbcolor={0,0,0}),
              string="Ebers-Moll BJT"),
            Text(
              extent=[-96,-52; -76,-68],
              style(color=3, rgbcolor={0,0,255}),
              string="ibe"),
            Text(
              extent=[-96,68; -76,52],
              style(color=3, rgbcolor={0,0,255}),
              string="ibc"),
            Text(
              extent=[10,-82; 32,-98],
              style(color=3, rgbcolor={0,0,255}),
              string="vbc")),
          Diagram(Text(
              extent=[-72,62; 82,-66],
              style(color=0, rgbcolor={0,0,0}),
              string="IC 0"), Text(
              extent=[-76,-54; 88,-78],
              style(color=0, rgbcolor={0,0,0}),
              string="Ebers-Moll BJT"),
            Text(
              extent=[-96,-52; -76,-68],
              style(color=3, rgbcolor={0,0,255}),
              string="ibe"),
            Text(
              extent=[-96,68; -76,52],
              style(color=3, rgbcolor={0,0,255}),
              string="ibc"),
            Text(
              extent=[10,-82; 32,-98],
              style(color=3, rgbcolor={0,0,255}),
              string="vbc")),
          Documentation(info="<html>
This block computes the injected collector current of a BJT in accordance with the Ebers-Moll model. <p>

<pre>
Parameters:

 Bf:   Forward beta coefficient (default value = 50)

 Br:   Reverse beta coefficient (default value = 0.1)

 Vak:  Inverse early voltage (default value = 0.02 /Volt)
</pre>
</html>
"));
      public 
        Modelica.Blocks.Interfaces.RealInput u3 
          annotation (extent=[-20,-120; 20,-80], rotation=90);
      equation 
        ibc = u1;
        ibe = u2;
        vbc = u3;
        qbk = 1 - vbc*Vak;
        IC0 = (ibe - ibc)*qbk - ibc/Br;
        y = IC0;
      end IC0;
      
      model mC2 "Bondgraphic modulated capacitor element" 
        extends Interfaces.ModPassiveOnePort;
        Real C "Bondgraphic Capacitance";
        annotation (
          Icon(Text(
              extent=[-66,78; 54,-82],
              style(color=0),
              string="mC"),    Text(extent=[-72,80; 68,40],   string="%name"),
               Text(
              extent=[50,-2; 80,-54],
              style(color=0),
              string="2")),
          Diagram(
               Text(
              extent=[50,-2; 80,-54],
              style(color=0),
              string="2"),
               Text(
              extent=[-66,78; 54,-82],
              style(color=0),
              string="mC")),
          Documentation(info="<html>
This is an alternative model to the <b>mC</b> modulated capacitance model of the bond graph library.  This model is physically dubious.  Modelers are advised to always use the <b>mC</b> model, never the <b>mC2</b> model.  However, since this is the model that is being used in the Ebers-Moll description of bipolar transistors, it is being reproduced here.  However, it is hidden under utilities to discourage modelers from using it. <p>

 <hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model

 C:  Capacitance (modulated input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = C*der(e)</b>
</html>
"));
      equation 
        C = s;
        f = C*der(e);
      end mC2;
      
      model Cj "Junction capacitance model of Ebers-Moll BJT" 
        extends Interfaces.PassiveOnePort;
        parameter Modelica.SIunits.Current Is=1.e-16 
          "Transport saturation current";
        parameter Modelica.SIunits.Time Tau=5e-9 "Ideal transit time";
        parameter Modelica.SIunits.Capacitance Cj=0.5e-12 
          "Zero bias depletion capacitance";
        parameter Modelica.SIunits.Voltage Phi=0.8 "Diffusion voltage";
        parameter Real M=0.333 "Gradation exponent";
        parameter Modelica.SIunits.Conductance Gb=1e-15 "Leakage conductance";
        parameter Modelica.SIunits.Voltage Vt=0.02585 "Thermal voltage";
        parameter Real EMin=-100 
          "if x < EMin, the exp(x) function is linearized";
        parameter Real EMax=40 "if x > EMax, the exp(x) function is linearized";
        Modelica.Blocks.Interfaces.RealOutput y 
          annotation (extent=[90,-10; 110,10]);
        annotation (
          Icon(Text(
              extent=[2,-6; 92,-72],
              style(color=0),
              string="Junction"),
               Text(
              extent=[-74,62; 12,-70],
              style(color=0),
              string="C"),     Text(extent=[-70,94; 70,54],   string="%name")),
          Diagram,
          Documentation(info="<html>
The junction capacitance element is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  Junction capacitances are used in semiconductor technology to model the charge accumulated in the vicinity of a pn-junction. <p>

The junction capacitance element has its preferred causality away from the element. <p>

The model also computes the diodic current through the junction and puts it out as an output signal. <p>

<hr>

<pre>
Potential variables:

 e:     Bondgraphic effort variable

 f:     Bondgraphic flow variable, normalized positive for flows into the model

 id:    Diodic current through the junction (output variable)


Parameters:

 Is:    Transport saturation current (default value = 1e-16 Amp)

 Tau:   Ideal transit time (default value = 5e-9 sec)

 Cj:    Zero bias depletion capacitance (default value = 0.5e-12 F)

 Phi:   Diffusion voltage (default value = 0.8 Volt)

 M:     Gradation exponent (default value = 0.333)

 Gb:    Leakage conductance (default value = 1e-15 Mho)

 Vt:    Thermal voltage (default value = 0.02585 Volt)

 EMin:  Minimum exponent (default value = -100)

 EMax:  Maximum exponent (default value = 40)
</pre>
</html>
"));
        Junctions.J0p3 J0p3_1 annotation (extent=[-90,10; -70,-10]);
        Bonds.fBond B1 annotation (extent=[-70,-10; -50,10]);
        Sensors.De vbi annotation (extent=[-50,-10; -30,10]);
        Bonds.eBond B2 annotation (extent=[-90,10; -70,30], rotation=90);
        mC2 Cj1 annotation (extent=[-90,30; -70,50], rotation=90);
        Sources.mSe Vbi annotation (extent=[0,-10; -20,10]);
        Bonds.fBond B3 annotation (extent=[0,-10; 20,10]);
        Junctions.J1p3 J1p3_1 annotation (extent=[20,-10; 40,10]);
        Bonds.eBond B4 annotation (extent=[40,-10; 60,10], rotation=0);
        Sensors.Df id annotation (extent=[60,-10; 80,10]);
        Bonds.fBond B5 annotation (extent=[20,-30; 40,-10], rotation=270);
        Junctions.J0p3 J0p3_2 annotation (extent=[20,-30; 40,-50]);
        Bonds.fBond B6 annotation (extent=[40,-50; 60,-30], rotation=0);
        Bonds.fBond B7 annotation (extent=[0,-50; 20,-30], rotation=180);
        Passive.G G1(G=Gb) annotation (extent=[60,-50; 80,-30]);
        nlC nlC1(
          Is=Is,
          Tau=Tau,
          Phi=Phi,
          Cj=Cj,
          M=M,
          Vt=Vt,
          EMin=EMin,
          EMax=EMax) annotation (extent=[-40,50; -60,70]);
        Dj Dbi(
          Is=Is,
          Vt=Vt,
          EMin=EMin,
          EMax=EMax) annotation (extent=[0,-50; -20,-30]);
      equation 
        connect(J0p3_1.BondCon1, BondCon1) annotation (points=[-90,0; -100,0], style(
              color=8, rgbcolor={192,192,192}));
        connect(J0p3_1.BondCon2, B1.eBondCon1) annotation (points=[-70,0; -70,0],
            style(color=8, rgbcolor={192,192,192}));
        connect(B1.fBondCon1, vbi.BondCon1) annotation (points=[-50,0; -50,0],
            style(color=8, rgbcolor={192,192,192}));
        connect(J0p3_1.BondCon3, B2.fBondCon1) annotation (points=[-80,10; -80,
              10], style(color=8, rgbcolor={192,192,192}));
        connect(B2.eBondCon1, Cj1.BondCon1) annotation (points=[-80,30; -80,30],
            style(color=8, rgbcolor={192,192,192}));
        connect(vbi.OutPort1, Vbi.InPort1) annotation (points=[-29,0; -19,0],
            style(color=74, rgbcolor={0,0,127}));
        connect(Vbi.BondCon1, B3.eBondCon1) annotation (points=[0,0; 0,0],
            style(color=8, rgbcolor={192,192,192}));
        connect(B3.fBondCon1, J1p3_1.BondCon1) annotation (points=[20,0; 20,0],
            style(color=8, rgbcolor={192,192,192}));
        connect(J1p3_1.BondCon2, B4.fBondCon1) annotation (points=[40,0; 40,0],
            style(color=8, rgbcolor={192,192,192}));
        connect(B4.eBondCon1, id.BondCon1) annotation (points=[60,0; 60,0],
            style(color=8, rgbcolor={192,192,192}));
        connect(id.OutPort1, y) annotation (points=[81,0; 100,0], style(color=
                74, rgbcolor={0,0,127}));
        connect(J0p3_2.BondCon2, B6.eBondCon1) annotation (points=[40,-40; 40,
              -40], style(color=8, rgbcolor={192,192,192}));
        connect(B7.eBondCon1, J0p3_2.BondCon1) annotation (points=[20,-40; 20,
              -40], style(color=8, rgbcolor={192,192,192}));
        connect(B6.fBondCon1, G1.BondCon1) annotation (points=[60,-40; 60,-40],
            style(color=8, rgbcolor={192,192,192}));
        connect(J1p3_1.BondCon3, B5.eBondCon1) annotation (points=[30,-10; 30,
              -10], style(color=8, rgbcolor={192,192,192}));
        connect(B5.fBondCon1, J0p3_2.BondCon3) annotation (points=[30,-30; 30,
              -30], style(color=8, rgbcolor={192,192,192}));
        connect(vbi.OutPort1, nlC1.u) annotation (points=[-29,0; -24,0; -24,60;
              -38,60], style(color=74, rgbcolor={0,0,127}));
        connect(nlC1.y, Cj1.InPort1) annotation (points=[-61,60; -80,60; -80,49],
            style(color=74, rgbcolor={0,0,127}));
        connect(Dbi.BondCon1, B7.fBondCon1) annotation (points=[0,-40; 0,-40],
            style(color=8, rgbcolor={192,192,192}));
      end Cj;
      
      model Dj "Junction diode model of Ebers-Moll BJT" 
        extends Interfaces.PassiveOnePort;
        parameter Modelica.SIunits.Current Is=1.e-16 
          "Transport saturation current";
        parameter Modelica.SIunits.Voltage Vt=0.02585 
          "Voltage equivalent of temperature (kT/qn)";
        parameter Real EMin=-100 
          "if x < EMin, the exp(x) function is linearized";
        parameter Real EMax=40 "if x > EMax, the exp(x) function is linearized";
        
      protected 
        Real ExMin;
        Real ExMax;
        annotation (
          Icon(Text(
              extent=[-76,64; 10,-68],
              style(color=0),
              string="D"),
               Text(
              extent=[-4,-4; 86,-70],
              style(color=0),
              string="Junction"),
                               Text(extent=[-70,96; 70,56],   string="%name")),
          Diagram(
            Line(points=[-80,0; 80,0],   style(color=10)),
            Polygon(points=[70,4; 80,0; 70,-4; 70,4],     style(color=10,
                  fillColor=10)),
            Line(points=[0,80; 0,-80],   style(
                color=10,
                fillColor=10,
                fillPattern=1)),
            Polygon(points=[-4,70; 0,80; 4,70; -4,70],     style(
                color=10,
                fillColor=10,
                fillPattern=1)),
            Text(
              extent=[4,82; 14,72],
              style(
                color=10,
                fillColor=10,
                fillPattern=1),
              string="f"),
            Text(
              extent=[70,-4; 80,-14],
              style(
                color=10,
                fillColor=10,
                fillPattern=1),
              string="e"),
            Line(points=[-80,-4; -28,-4; -6,-2; 0,0],         style(
                color=0,
                thickness=2,
                fillColor=10,
                fillPattern=1)),
            Text(
              extent=[-66,-6; -36,-14],
              style(
                color=10,
                pattern=3,
                fillColor=10,
                fillPattern=1),
              string="blocking"),
            Text(
              extent=[16,50; 48,42],
              style(
                color=10,
                pattern=3,
                fillColor=10,
                fillPattern=1),
              string="conducting"),
            Line(points=[0,0; 6,10; 12,28; 16,66],            style(
                color=0,
                thickness=2,
                fillColor=10,
                fillPattern=1))),
          Documentation(info="<html>
The junction diode element is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  Junction diodes are a special class of non-linear resistors. <p>

The junction diode model is a simple diode with an exponential characteristic. The diode formula essentially is: <p>

<b>f = Is*(exp(e/Vt) - 1)</b> <p>

However, if the exponent <b>e/Vt</b> reaches either an upper limit <b>EMax</b> or a lower limit <b>Emin</b>, the diode characterisic is linearly continued to avoid overflow or underflow, respectively. <p>

The causality of the junction diode element is free. <p>

<hr>

<pre>
Potential variables:

 e:     Bondgraphic effort variable

 f:     Bondgraphic flow variable, normalized positive for flows into the model


Parameters:

 Is:    Transport saturation current (default value = 1e-16 Amp)

 Vt:    Thermal voltage (default value = 0.02585 Volt)

 EMin:  Minimum exponent (default value = -100)

 EMax:  Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

Equations: <p>

<b>ExMin = exp(EMin)</b> <br>
<b>ExMax = exp(EMax)</b> <br>
<b>f = if (e/Vt &lt; EMin) then Is*(ExMin*(e/Vt - EMin + 1) - 1) else 
       if (e/Vt &gt; EMax) then Is*(ExMax*(e/Vt - EMax + 1) - 1) else Is*(exp(e/Vt) - 1)</b>
</html>
"));
      equation 
        ExMin = exp(EMin);
        ExMax = exp(EMax);
        f = if (e/Vt < EMin) then Is*(ExMin*(e/Vt - EMin + 1) - 1) else 
            if (e/Vt > EMax) then Is*(ExMax*(e/Vt - EMax + 1) - 1) else Is*(exp(e/Vt) - 1);
      end Dj;
    end Utilities;
  end Semiconductors;
  
  package Sensors "Sensors (detectors) of Modelica bond graph library" 
    annotation (
      Coordsys(
        extent=[0, 0; 402, 261],
        grid=[2, 2],
        component=[20, 20]),
      Icon(
        Rectangle(extent=[-100, -100; 80, 50], style(fillColor=30, fillPattern=
                1)),
        Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50], style(
              fillColor=30, fillPattern=1)),
        Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70], style(
              fillColor=30, fillPattern=1)),
        Text(
          extent=[-85, 35; 65, -85],
          string="Library",
          style(color=3)),
        Text(
          extent=[-120, 122; 120, 73],
          string="%name",
          style(color=1))),
      Window(
        x=0,
        y=0.6,
        width=0.4,
        height=0.4,
        library=1,
        autolayout=1),
      Documentation(info="<html>
Sensors (detectors) are not among the standard bond graph elements advertized regularly in the bond graph literature.  Yet, they are very useful elements indeed, as they enable the modeler to convert bond graph variables to signal variables.  This is useful for modeling blocks of block diagrams internally by bond graphs.  It is also useful for extracting bond graph variables needed for the modeling of so-called \"activated bonds,\" bond graph elements that are internally modulated by variables extracted elsewhere in the bond graph. <p>

This package contains four types of detectors: <p>

<ol>
<li> effort detectors (<b>De</b>), <br>
<li> flow detectors (<b>Df</b>), <br>
<li> detectors of generalized momentums (<b>Dp</b>), and <br>
<li> detectors of generalized positions (<b>Dq</b>).
</ol> <p>
</html>
"));
    model De "Effort sensor of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="De",
            style(color=0, fillColor=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="De",
            style(color=0, fillColor=0)), Text(extent=[-70, 90; 70, 50], string=
               "%name")),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.63),
        Documentation(info="<html>
The effort sensor (detector) senses the common effort of a 0-junction.  Thus, effort sensors must always be connected to 0-junctions via a bond. <p>

An effort sensor does not affect the behavior of the system at all.  This is accomplished by setting the flow into the sensor equal to zero.  Thus, an effort sensor is in its effects identical with a flow source of zero flow. <p>

The effort sensor is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The effort sensor has an additional output signal, through which it transmits the effort value. <p>

Since the effort sensor computes the flow (by setting it equal to zero), it has a causality stroke at the sensor element.

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = 0</b>
</html>
"));
      Modelica.Blocks.Interfaces.RealOutput OutPort1 
                                                  annotation (extent=[100, -10;
              120, 10], layer="icon");
    equation 
      OutPort1 = e;
      f = 0;
    end De;
    
    model Df "Flow sensor of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="Df",
            style(color=0, fillColor=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="Df",
            style(color=0, fillColor=0)), Text(extent=[-70, 90; 70, 50], string=
               "%name")),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.63),
        Documentation(info="<html>
The flow sensor (detector) senses the common flow of a 1-junction.  Thus, flow sensors must always be connected to 1-junctions via a bond. <p>

A flow sensor does not affect the behavior of the system at all.  This is accomplished by setting the effort at the sensor equal to zero.  Thus, a flow sensor is in its effects identical with an effort source of zero effort. <p>

The flow sensor is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The flow sensor has an additional output signal, through which it transmits the flow value. <p>

Since the flow sensor computes the effort (by setting it equal to zero), it has a causality stroke away from the sensor element.

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = 0</b>
</html>
"));
      Modelica.Blocks.Interfaces.RealOutput OutPort1 
                                                  annotation (extent=[100, -10;
              120, 10]);
    equation 
      OutPort1 = f;
      e = 0;
    end Df;
    
    model Dp "Generalized momentum sensor of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Icon(Text(
            extent=[-58, 80; 62, -80],
            string="Dp",
            style(color=0, fillColor=0)), Text(extent=[-68, 90; 72, 50], string=
               "%name")),
        Diagram,
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.63),
        Documentation(info="<html>
The sensor (detector) of generalized momentum senses the common effort of a 0-junction, then integrates it.  Thus, momentum sensors must always be connected to 0-junctions via a bond. <p>

A momentum sensor does not affect the behavior of the system at all.  This is accomplished by setting the flow into the sensor equal to zero.  Thus, a momentum sensor is in its effects similar to a flow source of zero flow. <p>

The momentum sensor is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The momentum sensor has an additional output signal, through which it transmits the generalized momentum value. <p>

Since the momentum sensor computes the flow (by setting it equal to zero), it has a causality stroke at the sensor element.

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model

 p:  Generalized momentum
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = 0</b> <br>
<b>der(p) = e</b>
</html>
"));
      Modelica.Blocks.Interfaces.RealOutput OutPort1 
                                                  annotation (extent=[100, -10;
              120, 10], layer="icon");
      Modelica.Blocks.Continuous.Integrator Integrator1 annotation (extent=[50,
              -20; 90, 20]);
      De De1 annotation (extent=[-10, -20; 30, 20]);
      Junctions.J0p2 J0p2_1 annotation (extent=[-90, -20; -50, 20]);
      Bonds.fBond B1 annotation (extent=[-50, -20; -10, 20]);
    equation 
      connect(Integrator1.y,       OutPort1) annotation (points=[92,0; 110,0],
            style(color=3));
      connect(De1.OutPort1,Integrator1.u)       annotation (points=[32, 0; 46,
            0], style(color=3));
      connect(BondCon1, J0p2_1.BondCon1) annotation (points=[-100,0; -90,0],
          style(color=8));
      connect(J0p2_1.BondCon2, B1.eBondCon1) annotation (points=[-50, 0; -50, 0],
               style(color=8));
      connect(B1.fBondCon1, De1.BondCon1) annotation (points=[-10, 0; -10, 0],
          style(color=8));
    end Dp;
    
    model Dq "Generalized position sensor of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Icon(Text(
            extent=[-58, 80; 62, -80],
            string="Dq",
            style(color=0, fillColor=0)), Text(extent=[-68, 90; 72, 50], string=
               "%name")),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.63),
        Documentation(info="<html>
The sensor (detector) of generalized position senses the common flow of a 1-junction, then integrates it.  Thus, position sensors must always be connected to 1-junctions via a bond. <p>

A position sensor does not affect the behavior of the system at all.  This is accomplished by setting the effort at the sensor equal to zero.  Thus, a position sensor is in its effects similar to an effort source of zero effort. <p>

The position sensor is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The position sensor has an additional output signal, through which it transmits the generalized position value. <p>

Since the position sensor computes the effort (by setting it equal to zero), it has a causality stroke away from the sensor element.

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model

 q:  Generalized position
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = 0</b> <br>
<b>der(q) = f</b>
</html>
"));
      Modelica.Blocks.Interfaces.RealOutput OutPort1 
                                                  annotation (extent=[100, -10;
              120, 10], layer="icon");
      Modelica.Blocks.Continuous.Integrator Integrator1 annotation (extent=[50,
              -20; 90, 20]);
      Df Df1 annotation (extent=[-10, -20; 30, 20]);
      Bonds.eBond B1 annotation (extent=[-50, -20; -10, 20]);
      Junctions.J1p2 J1p2_1 annotation (extent=[-90, -20; -50, 20]);
    equation 
      connect(Integrator1.y,       OutPort1) annotation (points=[92,0; 110,0],
            style(color=3));
      connect(Df1.OutPort1,Integrator1.u)       annotation (points=[32, 0; 46,
            0], style(color=3));
      connect(B1.eBondCon1, Df1.BondCon1) annotation (points=[-10, 0; -10, 0],
          style(color=8));
      connect(J1p2_1.BondCon2, B1.fBondCon1) annotation (points=[-50, 0; -50, 0],
               style(color=8));
      connect(BondCon1, J1p2_1.BondCon1) annotation (points=[-100,0; -90,0],
          style(color=8));
    end Dq;
  end Sensors;
  
  package Sources "Sources of Modelica bond graph library" 
    annotation (
      Coordsys(
        extent=[0, 0; 350, 330],
        grid=[2, 2],
        component=[20, 20]),
      Icon(
        Rectangle(extent=[-100, -100; 80, 50], style(fillColor=30, fillPattern=
                1)),
        Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50], style(
              fillColor=30, fillPattern=1)),
        Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70], style(
              fillColor=30, fillPattern=1)),
        Text(
          extent=[-85, 35; 65, -85],
          string="Library",
          style(color=3)),
        Text(
          extent=[-120, 122; 120, 73],
          string="%name",
          style(color=1))),
      Window(
        x=0.04,
        y=0.26,
        width=0.35,
        height=0.49,
        library=1,
        autolayout=1),
      Documentation(info="<html>
This package contains a collection of effort sources (<b>Se</b>) and flow sources (<b>Sf</b>). <p>

As of now, only the most common types of sources are being provided.  These are: <p>

<ol>
<li> constant sources, <br>
<li> modulated sources, and <br>
<li> sinusoidal sources.
</ol><p>

Other types of sources, such as rectangular sources can easily be constructed using the electrical library as a model.
</html>

"));
    model Se "Constant effort source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real e0=1 "Bondgraphic Effort Source";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="Se",
            style(color=0))),
        Icon(
          Text(
            extent=[-60, 80; 60, -80],
            string="Se",
            style(color=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(extent=[-70, -50; 70, -90], string="e0=%e0")),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.63),
        Documentation(info="<html>
The constant effort source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The constant effort to be generated is modeled as a parameter. <p>

The effort source has its causality stroke away from the source. <p>

<hr>

<pre>
Potential variables:

 e:   Bondgraphic effort variable

 f:   Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 e0:  Constant effort to be generated (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = e0</b>
</html>
"));
    equation 
      e = e0;
    end Se;
    
    model mSe "Modulated effort source of the Modelica bond graph library" 
      extends Interfaces.ModActiveOnePort;
      Real e0 "Bondgraphic Effort Source";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="mSe",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="mSe",
            style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.63),
        Documentation(info="<html>
The modulated effort source is a modulated active OnePort element.  It inherits the effort and flow variables from the modulated active OnePort.  The modulated effort to be generated is modeled as a real-valued variable. <p>

Modulated sources are commonly used to model actuators of control systems.  They are the most common and convenient way for converting signal variables to bondgraphic variables, thereby allowing individual blocks of a block diagram, e.g. describing a control system, to be modeled internally using bond graphs. <p>

The effort source has its causality stroke away from the source. <p>

<hr>

<pre>
Potential variables:

 e:   Bondgraphic effort variable

 f:   Bondgraphic flow variable, normalized positive for flows out of the model

 e0:  Effort to be generated (modulated input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = e0</b>
</html>
"));
    equation 
      e0 = s;
      e = e0;
    end mSe;
    
    model sinSe "Sinusoidal effort source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real e0=1 "Amplitude of sine wave";
      parameter Modelica.SIunits.Angle phase=0 "Phase of sine wave";
      parameter Modelica.SIunits.Frequency freqHz=1 "Frequency of sine wave";
      parameter Real offset=0 "Offset of sine wave";
      parameter Real startTime=0 "Start time of sine wave";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(
          Line(points=[-80, -90; -80, 84], style(color=8)),
          Polygon(points=[-80, 100; -86, 84; -74, 84; -80, 100], style(color=8,
                  fillColor=8)),
          Line(points=[-99, -40; 85, -40], style(color=8)),
          Polygon(points=[101, -40; 85, -34; 85, -46; 101, -40], style(color=8,
                  fillColor=8)),
          Line(points=[-40, 0; -31.6, 34.2; -26.1, 53.1; -21.3, 66.4; -17.1,
                74.6; -12.9, 79.1; -8.64, 79.8; -4.42, 76.6; -0.201, 69.7; 4.02,
                  59.4; 8.84, 44.1; 14.9, 21.2; 27.5, -30.8; 33, -50.2; 37.8, -
                64.2; 42, -73.1; 46.2, -78.4; 50.5, -80; 54.7, -77.6; 58.9, -
                71.5; 63.1, -61.9; 67.9, -47.2; 74, -24.8; 80, 0], style(color=
                  0, thickness=2)),
          Line(points=[-41, -2; -80, -2], style(color=0, thickness=2)),
          Text(
            extent=[-106, -11; -60, -29],
            string="offset",
            style(color=9)),
          Line(points=[-41, -2; -41, -40], style(color=8, pattern=2)),
          Text(
            extent=[-60, -43; -14, -61],
            string="startTime",
            style(color=9)),
          Text(
            extent=[84, -52; 108, -72],
            string="time",
            style(color=9)),
          Line(points=[-9, 79; 43, 79], style(color=8, pattern=2)),
          Line(points=[-42, -1; 50, 0], style(color=8, pattern=2)),
          Polygon(points=[33, 80; 30, 67; 37, 67; 33, 80], style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[33, 1; 30, 14; 36, 14; 33, 1; 33, 1], style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[33, 79; 33, 0], style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Text(
            extent=[-88, 100; -44, 80],
            string="e",
            style(color=9, fillColor=8)),
          Text(
            extent=[32, 52; 72, 34],
            string="e0",
            style(color=9))),
        Icon(
          Text(
            extent=[-60, 80; 60, -80],
            string="Se",
            style(color=0)),
          Line(points=[-70, 0; -60.2, 29.9; -53.8, 46.5; -48.2, 58.1; -43.3,
                65.2; -38.3, 69.2; -33.4, 69.8; -28.5, 67; -23.6, 61; -18.6, 52;
                  -13, 38.6; -5.98, 18.6; 8.79, -26.9; 15.1, -44; 20.8, -56.2;
                25.7, -64; 30.6, -68.6; 35.5, -70; 40.5, -67.9; 45.4, -62.5;
                50.3, -54.1; 55.9, -41.3; 63, -21.7; 70, 0], style(color=8)),
          Text(extent=[-70, 90; 70, 50], string="%name")),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.63),
        Documentation(info="<html>
The sinusoidal effort source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The sinusoidal effort to be generated is modeled as a set of five parameters. <p>

The effort source has its causality stroke away from the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 e0:         Amplitude of sine wave to be generated (default value = 1)

 phase:      Phase of sine wave to be generated (default value = 0)

 freqHz:     Frequency of sine wave to be generated (default value = 1)

 offset:     Offset of sine wave to be generated (default value = 0)

 startTime:  Start time of sine wave to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = offset + e0*sin(2*pi*freqHz*(time - startTime))</b>
</html>
"));
      Modelica.Blocks.Sources.Sine Sine1(
        amplitude=e0,
        freqHz=freqHz,
        offset=offset,
        phase=phase,
        startTime=startTime)   annotation (extent=[70, 66; 90, 86]);
    equation 
      e = Sine1.y;
    end sinSe;
    
    model stepSe "Step effort source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real e0=1 "Height of step";
      parameter Real offset=0 "Offset of step";
      parameter Real startTime=0 "Start time of step";
      annotation (
        Icon(
          Text(
            extent=[-62,78; 58,-82],
            string="Se",
            style(color=0)),
          Text(extent=[-72,100; 68,60],  string="%name"),
             Line(points=[-70,-80; 0,-80; 0,60; 69,60],     style(color=8))),
        Diagram(
          Polygon(points=[-80,90; -88,68; -72,68; -80,90],     style(color=8,
                fillColor=8)),
          Line(points=[-80,68; -80,-80],   style(color=8)),
          Line(points=[-80,-18; 0,-18; 0,50; 80,50],     style(color=0, thickness=
                 2)),
          Line(points=[-90,-70; 82,-70],   style(color=8)),
          Polygon(points=[90,-70; 68,-62; 68,-78; 90,-70],     style(color=8,
                fillColor=8)),
          Text(
            extent=[70,-80; 94,-100],
            string="time",
            style(color=9)),
          Text(
            extent=[-21,-72; 25,-90],
            string="startTime",
            style(color=9)),
          Line(points=[0,-17; 0,-71],   style(color=8, pattern=2)),
          Text(
            extent=[-68,-36; -22,-54],
            string="offset",
            style(color=9)),
          Line(points=[-13,50; -13,-17],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[2,50; -19,50; 2,50],    style(color=8, pattern=2)),
          Polygon(points=[-13,-17; -16,-4; -10,-4; -13,-17; -13,-17],      style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-13,50; -16,37; -9,37; -13,50],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-50,26; -4,8],
            style(color=9),
            string="e0"),
          Polygon(points=[-13,-69; -16,-56; -10,-56; -13,-69; -13,-69],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-13,-18; -13,-70],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-13,-18; -16,-31; -9,-31; -13,-18],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-91,93; -32,70],
            style(color=9),
            string="e")),
        Documentation(info="<html>
The step effort source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The step effort to be generated is modeled as a set of three parameters. <p>

The effort source has its causality stroke away from the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 e0:         Height of step to be generated (default value = 1)

 offset:     Offset of step to be generated (default value = 0)

 startTime:  Start time of step to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = offset + (if time &lt; startTime then 0 else e0)</b>
</html>
"));
      Modelica.Blocks.Sources.Step Step1(
        offset=offset,
        startTime=startTime,
        height=e0) annotation (extent=[70,68; 90,88]);
    equation 
      e = Step1.y;
    end stepSe;
    
    model rampSe "Ramp effort source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real e0=1 "Height of ramp";
      parameter Real duration=2 "Duration of ramp";
      parameter Real offset=0 "Offset of ramp";
      parameter Real startTime=0 "Start time of ramp";
      annotation (
        Icon(
          Text(
            extent=[-60,70; 60,-90],
            string="Se",
            style(color=0)),
          Text(extent=[-70,100; 70,60],  string="%name"),
             Line(points=[-80,-70; -50,-70; 50,50; 80,50],     style(color=8))),
        Diagram(
          Polygon(points=[-80,80; -88,58; -72,58; -80,80],     style(color=8,
                fillColor=8)),
          Line(points=[-80,-30; -20,-30; 50,40],    style(color=0, thickness=2)),
          Line(points=[-90,-80; 82,-80],   style(color=8)),
          Polygon(points=[90,-80; 68,-72; 68,-88; 90,-80],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-40,-30; -42,-40; -37,-40; -40,-30],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-40,-30; -40,-80],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-40,-80; -43,-70; -38,-70; -40,-80; -40,-80],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-80,-43; -41,-59],
            string="offset",
            style(color=9)),
          Text(
            extent=[-40,-80; 6,-98],
            string="startTime",
            style(color=9)),
          Text(
            extent=[-83,83; -38,58],
            style(color=9),
            string="e"),
          Text(
            extent=[70,-86; 94,-106],
            string="time",
            style(color=9)),
          Line(points=[-20,-30; -20,-80],   style(color=8, pattern=2)),
          Line(points=[-19,-30; 50,-30],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Line(points=[50,40; 101,40],   style(color=0, thickness=2)),
          Line(points=[50,40; 50,-30],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[50,-30; 42,-28; 42,-32; 50,-30],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-20,-30; -11,-28; -11,-32; -20,-30],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[50,40; 48,30; 53,30; 50,40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[50,-30; 47,-20; 52,-20; 50,-30; 50,-30],      style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[53,15; 82,-3],
            style(color=9),
            string="e0"),
          Text(
            extent=[0,-27; 35,-47],
            string="duration",
            style(color=9))),
        Documentation(info="<html>
The ramp effort source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The ramp effort to be generated is modeled as a set of four parameters. <p>

The effort source has its causality stroke away from the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 e0:         Height of ramp to be generated (default value = 1)

 duration:   Duration of ramp to be generated (default value = 2)

 offset:     Offset of ramp to be generated (default value = 0)

 startTime:  Start time of ramp to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = offset + (if time &lt; startTime then 0 else if time &lt; (startTime + duration)
                 then (time - startTime)*e0/duration else e0);</b>
</html>
"));
      Modelica.Blocks.Sources.Ramp Ramp1(
        height=e0,
        duration=duration,
        offset=offset,
        startTime=startTime) annotation (extent=[68,66; 90,88]);
    equation 
      e = Ramp1.y;
    end rampSe;
    
    model expsinSe 
      "Damped sinusoidal effort source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real e0=1 "Amplitude of sine wave";
      parameter Real phase=0 "Phase of sine wave";
      parameter Real freqHz=2 "Frequency of sine wave";
      parameter Real damping=1 "Damping coefficient of sine wave";
      parameter Real offset=0 "Offset of sine wave";
      parameter Real startTime=0 "Start time of sine wave";
      annotation (
        Icon(
          Text(
            extent=[-60,80; 60,-80],
            string="Se",
            style(color=0)),
          Text(extent=[-64,98; 76,58],   string="%name"),
             Line(points=[-70,-4; -65.2,28.3; -62,46.3; -58.7,60.5; -55.5,70.2;
                -52.3,75.3; -49.1,75.6; -45.9,71.3; -42.7,63.1; -38.6,48.2; -33,
                21.8; -25,-17.9; -20.2,-37.7; -16.1,-49.9; -12.1,-57.2; -8.1,
                -59.3; -4.1,-56.5; -0.1,-49.3; 4.77,-36.1; 18.44,9.7; 23.3,22.4;
                28.1,30.8; 32.1,34; 36.9,33.2; 41.8,27.8; 48.2,15.4; 61.1,-14.5;
                67.5,-25.2; 73.1,-29.9; 78.7,-29.9; 85.2,-24.5; 90,-17.8],
                                               style(color=8))),
        Diagram(
          Line(points=[-86,-94; -86,80],   style(color=8)),
          Polygon(points=[-86,96; -92,80; -80,80; -86,96],       style(color=8,
                fillColor=8)),
          Line(points=[-105,-44; 79,-44],  style(color=8)),
          Polygon(points=[95,-44; 79,-38; 79,-50; 95,-44],       style(color=8,
                fillColor=8)),
          Line(points=[-56,-4; -52.1,24.2; -49.5,40; -46.9,52.4; -44.2,60.9;
                -41.6,65.4; -39,65.6; -36.4,61.9; -33.8,54.7; -30.5,41.7; -25.9,
                18.5; -19.4,-16.2; -15.5,-33.5; -12.23,-44.1; -8.96,-50.5;
                -5.698,-52.4; -2.43,-49.9; 0.83,-43.6; 4.8,-32.1; 15.9,8; 19.8,
                19.1; 23.7,26.5; 27,29.3; 30.9,28.5; 34.8,23.8; 40,12.9; 50.5,
                -13.2; 55.7,-22.6; 60.3,-26.7; 64.9,-26.6; 70.1,-22; 74,-16.1],
                                style(color=0, thickness=2)),
          Text(
            extent=[-84,-3; -61,-23],
            string="offset",
            style(color=9)),
          Text(
            extent=[-78,-40; -32,-58],
            string="startTime",
            style(color=9)),
          Text(
            extent=[78,-56; 102,-76],
            string="time",
            style(color=9)),
          Line(points=[-56,-4; 12,-4], style(color=8, pattern=2)),
          Line(points=[-56,-4; -87,-4], style(color=0, thickness=2)),
          Line(points=[-56,73; -56,-4],  style(color=8, pattern=2)),
          Line(points=[12,-5; 12,72],   style(color=8, pattern=2)),
          Line(points=[12,69; -56,69],   style(color=8)),
          Text(
            extent=[-48,84; 3,70],
            string="1/freqHz",
            style(color=9)),
          Polygon(points=[-55,69; -46,71; -46,67; -55,69],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[12,69; 4,71; 4,67; 12,69],       style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-56,-65; -25,-65],   style(color=8)),
          Polygon(points=[-24,-65; -32,-63; -32,-67; -24,-65],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-57,-67; -33,-79],
            string="t",
            style(color=9)),
          Text(
            extent=[-88,-71; 102,-100],
            style(color=9),
            string="e0*exp(-damping*t)*sin(2*pi*freqHz*t+phase)"),
          Line(points=[-56,-4; -56,-44],  style(color=8, pattern=2)),
          Line(points=[-56,-58; -56,-76],   style(color=8, pattern=2)),
          Line(points=[12,-80; -7,-52],   style(color=8, pattern=2)),
          Text(
            extent=[-91,101; -52,82],
            style(color=9),
            string="e")),
        Documentation(info="<html>
The damped sinusoidal effort source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The damped sinusoidal effort to be generated is modeled as a set of six parameters. <p>

The effort source has its causality stroke away from the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 e0:         Amplitude of damped sine wave to be generated (default value = 1)

 phase:      Phase of damped sine wave to be generated (default value = 0)

 freqHz:     Frequency of damped sine wave to be generated (default value = 2)

 damping:    Damping coefficient of damped sine wave to be generated (default value = 1)

 offset:     Offset of damped sine wave to be generated (default value = 0)

 startTime:  Start time of damped sine wave to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e = offset + (if time &lt; startTime then 0 else e0*exp(-(time
       - startTime)*damping)*sin(2*pi*freqHz*(time - startTime) + phase))</b>
</html>
"));
      Modelica.Blocks.Sources.ExpSine ExpSine1(
        amplitude=e0,
        freqHz=freqHz,
        phase=phase,
        damping=damping,
        offset=offset,
        startTime=startTime) annotation (extent=[68,66; 90,88]);
    equation 
      e = ExpSine1.y;
    end expsinSe;
    
    model expSe 
      "Step response effort source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real e0=1 "Height of step response after infinite time";
      parameter Real riseTime(min=0) = 0.5 "Rise time";
      parameter Real riseTimeConst(min=Modelica.Constants.small) = 0.1 
        "Rise time constant";
      parameter Real fallTimeConst(min=Modelica.Constants.small) = riseTimeConst 
        "Fall time constant";
      parameter Real offset=0 "Offset of step response";
      parameter Real startTime=0 "Start time of step response";
      annotation (
        Icon(
          Text(
            extent=[-60,78; 60,-82],
            string="Se",
            style(color=0)),
          Text(extent=[-68,98; 72,58],   string="%name"),
             Line(points=[-70,-69; -67.2,-54.3; -64.3,-41.1; -60.8,-26.6; -57.3,
                -14; -53.7,-3.08; -49.5,8.18; -45.3,17.7; -40.3,27; -34.6,35.5;
                -28.3,43.1; -21.2,49.6; -12.7,55.3; -2.1,60.2; 0,61; 2.12,48.5;
                4.95,33.7; 7.78,20.8; 10.606,9.45; 14.14,-2.7; 17.68,-13; 21.9,
                -23.2; 26.2,-31.6; 31.1,-39.5; 36.8,-46.4; 43.1,-52.3; 50.9,
                -57.5; 60.8,-61.8; 70,-64.4],                            style(
                color=8))),
        Diagram(
          Line(points=[-100,-80; 84,-80],   style(color=8)),
          Polygon(points=[100,-80; 84,-74; 84,-86; 100,-80],     style(color=8,
                fillColor=8)),
          Line(points=[-40,-40; -37.2,-25.3; -34.3,-12.1; -30.8,2.4; -27.3,15;
                -23.7,25.92; -19.5,37.18; -15.3,46.7; -10.3,56; -4.6,64.5; 1.7,
                72.1; 8.8,78.6; 17.3,84.3; 27.9,89.2; 30,90; 32.12,77.5; 34.95,
                62.7; 37.78,49.8; 40.606,38.45; 44.14,26.3; 47.68,16; 51.9,5.8;
                56.2,-2.6; 61.1,-10.5; 66.8,-17.4; 73.1,-23.3; 80.9,-28.5; 90.8,
                -32.8; 100,-35.4],                              style(color=0,
                thickness=2)),
          Polygon(points=[-80,80; -88,58; -72,58; -80,80],     style(color=8,
                fillColor=8)),
          Line(points=[-80,58; -80,-90],   style(color=8)),
          Text(
            extent=[-78,-53; -46,-66],
            string="offset",
            style(color=9)),
          Polygon(points=[-40,-80; -43,-70; -38,-70; -40,-80; -40,-80],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-40,-39; -40,-70],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-40,-40; -42,-50; -37,-50; -40,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-39,-40; -80,-40],   style(color=0, thickness=2)),
          Text(
            extent=[-59,-81; -13,-99],
            string="startTime",
            style(color=9)),
          Polygon(points=[-41,-40; -32,-38; -32,-42; -41,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-40,-40; 29,-40],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[29,-40; 21,-38; 21,-42; 29,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-26,-22; 19,-38],
            string="riseTime",
            style(color=9)),
          Text(
            extent=[78,-86; 102,-106],
            string="time",
            style(color=9)),
          Line(points=[-100,-80; 84,-80],   style(color=8)),
          Polygon(points=[100,-80; 84,-74; 84,-86; 100,-80],     style(color=8,
                fillColor=8)),
          Line(points=[-40,-40; -37.2,-25.3; -34.3,-12.1; -30.8,2.4; -27.3,15;
                -23.7,25.92; -19.5,37.18; -15.3,46.7; -10.3,56; -4.6,64.5; 1.7,
                72.1; 8.8,78.6; 17.3,84.3; 27.9,89.2; 30,90; 32.12,77.5; 34.95,
                62.7; 37.78,49.8; 40.606,38.45; 44.14,26.3; 47.68,16; 51.9,5.8;
                56.2,-2.6; 61.1,-10.5; 66.8,-17.4; 73.1,-23.3; 80.9,-28.5; 90.8,
                -32.8; 100,-35.4],                              style(color=0,
                thickness=2)),
          Polygon(points=[-80,80; -88,58; -72,58; -80,80],     style(color=8,
                fillColor=8)),
          Line(points=[-80,58; -80,-90],   style(color=8)),
          Text(
            extent=[-82,81; -41,61],
            style(color=9),
            string="e"),
          Text(
            extent=[-78,-53; -46,-66],
            string="offset",
            style(color=9)),
          Polygon(points=[-40,-80; -43,-70; -38,-70; -40,-80; -40,-80],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-40,-39; -40,-70],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-40,-40; -42,-50; -37,-50; -40,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-39,-40; -80,-40],   style(color=0, thickness=2)),
          Text(
            extent=[-59,-81; -13,-99],
            string="startTime",
            style(color=9)),
          Polygon(points=[-41,-40; -32,-38; -32,-42; -41,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-40,-40; 29,-40],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[29,-40; 21,-38; 21,-42; 29,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-26,-22; 19,-38],
            string="riseTime",
            style(color=9)),
          Text(
            extent=[78,-86; 102,-106],
            string="time",
            style(color=9)),
          Line(points=[30,90; 30,-44],    style(color=8, pattern=2))),
        Documentation(info="<html>
The step response effort source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The step response effort to be generated is modeled as a set of six parameters. <p>

The effort source has its causality stroke away from the source. <p>

<hr>

<pre>
Potential variables:

 e:              Bondgraphic effort variable

 f:              Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 e0:             Height of step response after infinite time (default value = 1)

 riseTime:       Rise time of step response to be generated (default value = 0.5)

 riseTimeConst:  Rise time constant of step response to be generated (default value = 0.1)

 fallTimeConst:  Fall time constant of step response to be generated (default value = riseTimeConst)

 offset:         Offset of step response to be generated (default value = 0)

 startTime:      Start time of step response to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e_riseTime = e0*(1 - exp(-riseTime/riseTimeConst))</b> <br>
<b>e = offset + (if (time &lt; startTime) then 0 else if (time &lt; (startTime
     + riseTime)) then e0*(1 - exp(-(time - startTime)/riseTimeConst)) else 
          e_riseTime*exp(-(time - startTime - riseTime)/fallTimeConst));</b>
</html>
"));
      Modelica.Blocks.Sources.Exponentials Exponentials1(
        outMax=e0,
        riseTime=riseTime,
        riseTimeConst=riseTimeConst,
        fallTimeConst=fallTimeConst,
        offset=offset,
        startTime=startTime) annotation (extent=[68,66; 90,88]);
    equation 
      e = Exponentials1.y;
    end expSe;
    
    model pulseSe "Pulse effort source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real e0=1 "Amplitude of pulse";
      parameter Real width(
        final min=Modelica.Constants.small,
        final max=100) = 50 "Width of pulse in % of period";
      parameter Real period(final min=Modelica.Constants.small) = 1 
        "Time for one period";
      parameter Real offset=0 "Offset of pulse";
      parameter Real startTime=0 "Start time of pulse";
      annotation (
        Icon(
          Text(
            extent=[-62,70; 58,-90],
            string="Se",
            style(color=0)),
          Text(extent=[-70,100; 70,60],  string="%name"),
             Line(points=[-76,-80; -46,-80; -46,60; -6,60; -6,-80; 34,-80; 35,
                60; 74,60],    style(color=8))),
        Diagram(
          Polygon(points=[-80,86; -88,64; -72,64; -80,86],     style(color=8,
                fillColor=8)),
          Line(points=[-80,64; -80,-84],   style(color=8)),
          Line(points=[-90,-74; 82,-74],   style(color=8)),
          Polygon(points=[90,-74; 68,-66; 68,-82; 90,-74],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-34,-3; -37,-16; -30,-16; -34,-3],   style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-34,-5; -34,-74],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-33,-74; -36,-61; -30,-61; -33,-74; -33,-74],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-78,-28; -35,-40],
            string="offset",
            style(color=9)),
          Text(
            extent=[-39,-73; 7,-91],
            string="startTime",
            style(color=9)),
          Text(
            extent=[70,-84; 94,-104],
            string="time",
            style(color=9)),
          Line(points=[-18,-4; -18,-74],  style(color=8, pattern=2)),
          Line(points=[-80,-4; -20,-4; -20,46; 20,46; 20,-4; 40,-4; 40,46; 80,
                46],   style(color=0, thickness=2)),
          Line(points=[-19,84; -19,45],   style(color=8, pattern=2)),
          Line(points=[21,70; 21,46],   style(color=9, pattern=2)),
          Line(points=[41,84; 41,46],   style(color=8, pattern=2)),
          Line(points=[-19,79; 42,79],   style(color=8)),
          Line(points=[-19,65; 21,65],   style(color=8)),
          Text(
            extent=[-9,93; 37,81],
            string="period",
            style(color=9)),
          Text(
            extent=[-18,77; 21,65],
            string="width",
            style(color=9)),
          Line(points=[-52,46; -19,46],   style(color=8, pattern=2)),
          Line(points=[-34,46; -34,-3],  style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Text(
            extent=[-66,28; -25,14],
            style(color=9),
            string="e0"),
          Polygon(points=[-34,45; -37,32; -30,32; -34,45],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-34,-3; -37,10; -31,10; -34,-3; -34,-3],   style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[80,46; 80,-4; 92,-4],   style(color=0, thickness=2)),
          Polygon(points=[-19,65; -10,67; -10,63; -19,65],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[21,65; 13,67; 13,63; 21,65],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-19,79; -10,81; -10,77; -19,79],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[41,79; 33,81; 33,77; 41,79],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-70,87; -52,68],
            style(color=9),
            string="e")),
        Documentation(info="<html>
The pulse effort source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The pulse effort to be generated is modeled as a set of five parameters. <p>

The effort source has its causality stroke away from the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 e0:         Amplitude of pulse to be generated (default value = 1)

 width:      Percentage of period in on state (default value = 50)

 period:     Length of period of pulse to be generated (default value = 1)

 offset:     Offset of pulse to be generated (default value = 0)

 startTime:  Start time of pulse to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>when sample(startTime, period) then</b> <br>
<b>T0 = time</b> <br>
<b>end when</b> <br>
<b>e = offset + (if time &lt; startTime or time &gt;= T0 + T_width then 0 else e0)</b>
</html>
"));
      Modelica.Blocks.Sources.Pulse Pulse1(
        amplitude=e0,
        width=width,
        period=period,
        offset=offset,
        startTime=startTime) annotation (extent=[68,66; 90,88]);
    equation 
      e = Pulse1.y;
    end pulseSe;
    
    model sawSe "Saw tooth effort source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real e0=1 "Amplitude of saw tooth";
      parameter Real period(final min=Modelica.Constants.small) = 1 
        "Time for one period";
      parameter Real offset=0 "Offset of saw tooth";
      parameter Real startTime=0 "Start time of saw tooth";
      annotation (
        Icon(
          Text(
            extent=[-66,68; 54,-92],
            string="Se",
            style(color=0)),
          Text(extent=[-68,104; 72,64],  string="%name"),
             Line(points=[-78,-79; -58,-79; 2,62; 2,-79; 62,62; 62,-79],
              style(color=8))),
        Diagram(
          Polygon(points=[-80,80; -88,58; -72,58; -80,80],     style(color=8,
                fillColor=8)),
          Line(points=[-80,58; -80,-90],   style(color=8)),
          Line(points=[-90,-80; 82,-80],   style(color=8)),
          Polygon(points=[90,-80; 68,-72; 68,-88; 90,-80],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-34,-29; -37,-42; -30,-42; -34,-29],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-34,-30; -34,-80],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-34,-80; -37,-67; -31,-67; -34,-80; -34,-80],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-78,-34; -35,-46],
            string="offset",
            style(color=9)),
          Text(
            extent=[-31,-79; 15,-97],
            string="startTime",
            style(color=9)),
          Text(
            extent=[74,-84; 98,-104],
            string="time",
            style(color=9)),
          Line(points=[-10,-30; -10,-80],   style(color=8, pattern=2)),
          Line(points=[-10,78; -10,-30],   style(color=8, pattern=2)),
          Line(points=[30,78; 30,49],   style(color=8, pattern=2)),
          Line(points=[-10,73; 30,73],   style(color=8)),
          Text(
            extent=[-12,87; 34,75],
            string="period",
            style(color=9)),
          Line(points=[-44,50; 30,50],   style(color=8, pattern=2)),
          Line(points=[-34,37; -34,-17],  style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Text(
            extent=[-66,18; -25,4],
            style(color=9),
            string="e0"),
          Polygon(points=[-34,50; -37,37; -30,37; -34,50],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-34,-30; -37,-17; -31,-17; -34,-30; -34,-30],    style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-10,73; -1,75; -1,71; -10,73],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[30,73; 22,75; 22,71; 30,73],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-80,-30; -10,-30; 30,50; 30,-30; 72,50; 72,-30],
              style(color=0, thickness=2)),
          Text(
            extent=[-69,82; -50,62],
            style(color=9),
            string="e")),
        Documentation(info="<html>
The saw tooth effort source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The saw tooth effort to be generated is modeled as a set of four parameters. <p>

The effort source has its causality stroke away from the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 e0:         Amplitude of saw tooth to be generated (default value = 1)

 period:     Length of period of saw tooth to be generated (default value = 1)

 offset:     Offset of saw tooth to be generated (default value = 0)

 startTime:  Start time of saw tooth to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>when sample(startTime, period) then</b> <br>
<b>T0 = time</b> <br>
<b>end when</b> <br>
<b>e = offset + (if time &lt; startTime then 0 else (e0/period)*(time - T0))</b>
</html>
"));
      Modelica.Blocks.Sources.SawTooth SawTooth1(
        amplitude=e0,
        period=period,
        offset=offset,
        startTime=startTime) annotation (extent=[68,66; 90,88]);
    equation 
      e = SawTooth1.y;
    end sawSe;
    
    model trapSe "Trapezoidal effort source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real e0=1 "Amplitude of trapezoidal function";
      parameter Real rising(final min=0) = 0 "Rising duration of trapezoid";
      parameter Real width(final min=0) = 0.5 "Width duration of trapezoid";
      parameter Real falling(final min=0) = 0 "Falling duration of trapezoid";
      parameter Real period(final min=Modelica.Constants.small) = 1 
        "Time for one period";
      parameter Integer nperiod=-1 
        "Number of periods (< 0 means infinite number of periods)";
      parameter Real offset=0 "Offset of saw tooth";
      parameter Real startTime=0 "Start time of saw tooth";
      annotation (
        Icon(
          Text(
            extent=[-56,78; 64,-82],
            string="Se",
            style(color=0)),
          Text(extent=[-64,104; 76,64],  string="%name"),
             Line(points=[-79,-78; -58,-78; -28,62; 3,62; 32,-78; 53,-78; 82,62],
                         style(color=8))),
        Diagram(
          Polygon(points=[-80,80; -88,58; -72,58; -80,80],     style(color=8,
                fillColor=8)),
          Line(points=[-80,58; -80,-90],   style(color=8)),
          Line(points=[-90,-80; 82,-80],   style(color=8)),
          Polygon(points=[90,-80; 68,-72; 68,-88; 90,-80],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-45,-40; -47,-51; -43,-51; -45,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-45,-41; -45,-80],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-45,-80; -47,-70; -43,-70; -45,-80; -45,-80],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-86,-53; -43,-65],
            string="offset",
            style(color=9)),
          Text(
            extent=[-47,-79; -1,-97],
            string="startTime",
            style(color=9)),
          Text(
            extent=[76,-84; 100,-104],
            string="time",
            style(color=9)),
          Line(points=[-30,71; -30,-80],   style(color=8, pattern=2)),
          Line(points=[-10,49; -10,30],   style(color=8, pattern=2)),
          Line(points=[20,49; 20,29],   style(color=9, pattern=2)),
          Line(points=[40,49; 40,-40],   style(color=8, pattern=2)),
          Line(points=[-29,46; 40,46],   style(color=8)),
          Text(
            extent=[-8,60; 21,50],
            string="width",
            style(color=9)),
          Line(points=[-42,30; -10,30],   style(color=8, pattern=2)),
          Line(points=[-39,30; -39,-29],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Text(
            extent=[-67,6; -30,-8],
            style(color=9),
            string="e0"),
          Polygon(points=[-29,46; -22,48; -22,44; -29,46],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-10,46; -17,48; -17,44; -10,46],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-80,-40; -30,-40; -9,36; 21,36; 40,-40; 60,-40; 80,36;
                100,36],      style(color=0, thickness=2)),
          Polygon(points=[-39,30; -41,19; -37,19; -39,30],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-39,-39; -41,-29; -37,-29; -39,-39; -39,-39],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[60,71; 60,-40],   style(color=8, pattern=2)),
          Polygon(points=[39,46; 32,48; 32,44; 39,46],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[20,46; 27,48; 27,44; 20,46],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[20,46; 13,48; 13,44; 20,46],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-12,46; -5,48; -5,44; -12,46],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-34,60; -5,50],
            string="rising",
            style(color=9)),
          Text(
            extent=[16,60; 45,50],
            string="falling",
            style(color=9)),
          Text(
            extent=[-75,85; -46,62],
            style(color=9),
            string="e"),
          Line(points=[-20,66; 61,66],   style(color=8)),
          Polygon(points=[-29,66; -20,68; -20,64; -29,66],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[61,66; 53,68; 53,64; 61,66],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-2,76; 25,67],
            string="period",
            style(color=9))),
        Documentation(info="<html>
The trapezoidal effort source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The trapezoidal effort to be generated is modeled as a set of eight parameters. <p>

The effort source has its causality stroke away from the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 e0:         Amplitude of trapezoid to be generated (default value = 1)

 rising:     Length of rising time of trapezoid to be generated (default value = 0)

 width :     Length of on state of trapezoid to be generated (default value = 0.5)

 falling:    Length of falling time of trapezoid to be generated (default value = 0)

 period:     Length of period of trapezoid to be generated (default value = 1)

 nperiod:    Number of periods of trapezoid to be generated
             an infinite number of periods is being generated if nperiod &lt; 0 (default value = -1)

 offset:     Offset of trapezoid to be generated (default value = 0)

 startTime:  Start time of trapezoid to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>when pre(counter2) &lt;&gt; 0 and sample(startTime, period) then</b> <br>
<b>T0 = time</b> <br>
<b>counter2 = pre(counter)</b> <br>
<b>counter = pre(counter) - (if pre(counter) &gt; 0 then 1 else 0)</b> <br>
<b>end when</b> <br>
<b>e = offset + (if (time &lt; startTime or counter2 == 0 or time &gt;= T0 +
    T_falling) then 0 else if (time &lt; T0 + T_rising) then (time - T0)*e0/T_rising
    else if (time &lt; T0 + T_width) then e0 else 
    (T0 + T_falling - time)*e0/(T_falling - T_width))</b>
</html>
"));
      Modelica.Blocks.Sources.Trapezoid Trapezoid1(
        amplitude=e0,
        rising=rising,
        width=width,
        falling=falling,
        period=period,
        nperiod=nperiod,
        offset=offset,
        startTime=startTime) annotation (extent=[68,66; 90,88]);
    equation 
      e = Trapezoid1.y;
    end trapSe;
    
    model tableSe "Tabular effort source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real table[:, :]=[0, 0; 1, 1; 2, 4] 
        "Table matrix (time = first column, voltage = second column)";
      parameter Real offset=0 "Offset of saw tooth";
      parameter Real startTime=0 "Start time of saw tooth";
      annotation (
        Icon(
          Text(
            extent=[-58,78; 62,-82],
            string="Se",
            style(color=0)),
          Text(extent=[-66,104; 74,64],  string="%name"),
             Line(points=[-64,-62; -64,58; 36,58; 36,-62; -64,-62; -64,-32; 36,
                -32; 36,-2; -64,-2; -64,28; 36,28; 36,58; -14,58; -14,-63],
                     style(color=8))),
        Diagram(
          Polygon(points=[-80,80; -88,58; -72,58; -80,80],     style(color=8,
                fillColor=8)),
          Line(points=[-80,58; -80,-90],   style(color=8)),
          Line(points=[-90,-80; 82,-80],   style(color=8)),
          Polygon(points=[90,-80; 68,-72; 68,-88; 90,-80],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Rectangle(extent=[-20,80; 30,-40],   style(
              color=7,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-20,-40; -20,80; 80,80; 80,-40; -20,-40; -20,-10; 80,-10;
                80,20; -20,20; -20,50; 80,50; 80,80; 30,80; 30,-41],
              style(color=0)),
          Text(
            extent=[-77,-52; -38,-68],
            string="offset",
            style(color=9)),
          Polygon(points=[-31,-40; -33,-50; -28,-50; -31,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-30,-80; -33,-70; -28,-70; -30,-80; -30,-80],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-31,-41; -31,-80],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Line(points=[-20,-42; -20,-80],   style(color=8, pattern=2)),
          Text(
            extent=[-38,-80; 8,-98],
            string="startTime",
            style(color=9)),
          Line(points=[-20,-40; -80,-40],   style(color=8, pattern=2)),
          Text(
            extent=[72,-87; 97,-99],
            string="time",
            style(color=9)),
          Text(
            extent=[-15,73; 24,58],
            string="time",
            style(color=0)),
          Text(
            extent=[33,73; 76,57],
            string="v",
            style(color=0)),
          Text(
            extent=[-73,84; -50,62],
            style(color=9),
            string="e")),
        Documentation(info="<html>
The tabular effort source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The tabular effort to be generated is modeled as a two-dimensional parameter table plus a set of two scalar parameters. <p>

The effort source has its causality stroke away from the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 table:      Two-dimensional table with supporting values (default value = [0, 0; 1, 1; 2, 4])

 offset:     Offset of time function to be generated (default value = 0)

 startTime:  Start time of time function to be generated (default value = 0)
</pre> <p>

<hr> <p>

The model generates an effort source by <b>linear interpolation</b> in
a table. The time points and effort values are stored in a matrix
<b>table[i,j]</b>, where the first column table[:,1] contains the
time points, and the second column contains the effort to be interpolated.
The table interpolation has the following proporties: <p>

<ul>
<li>The time points need to be <b>monotonically increasing</b>.
<li><b>Discontinuities</b> are allowed, by providing the same
    time point twice in the table.
<li>Values <b>outside</b> of the table range, are computed by
    <b>extrapolation</b> through the last or first two points of the
    table.
<li>If the table has only <b>one row</b>, no interpolation is performed and
    the voltage value is just returned independantly of the
    actual time instant, i.e., this is a constant voltage source.
<li>Via parameters <b>startTime</b> and <b>offset</b> the curve defined
    by the table can be shifted both in time and in the voltage.
<li>The table is implemented in a numerically sound way by
    generating <b>time events</b> at interval boundaries,
    in order to not integrate over a discontinuous or not differentiable
    points.
</ul> <p>

<hr> <p>

<b>Example:</b> <p>

<pre>
   table = [0  0
            1  0
            1  1
            2  4
            3  9
            4 16]
If, e.g., time = 1.0, the effort e =  0.0 (before event), 1.0 (after event)
    e.g., time = 1.5, the effort e =  2.5,
    e.g., time = 2.0, the effort e =  4.0,
    e.g., time = 5.0, the effort e = 23.0 (i.e. extrapolation).
</pre>
</html>
"));
      Modelica.Blocks.Sources.TimeTable TimeTable1(
        table=table,
        offset=offset,
        startTime=startTime) annotation (extent=[68,68; 90,90]);
    equation 
      e = TimeTable1.y;
    end tableSe;
    
    model mSe_int "Internal modulated effort source of the bond graph library" 
      extends Interfaces.ModTwoPort;
      Real e0 "Bondgraphic Effort Source";
      annotation (
        Diagram(Text(
            extent=[-60,80; 60,-80],
            string="mSe",
            style(color=0))),
        Icon(   Text(
            extent=[-60,80; 60,-80],
            string="mSe",
            style(color=0)), Text(extent=[-70,90; 70,50],   string="%name")),
        Documentation(info="<html>
The modulated internal effort source is a modulated directed TwoPort element.  It inherits the effort and flow variables from the modulated directed TwoPort.  The modulated effort to be generated is modeled as a real-valued variable. <p>

The modulated internal effort source is a modulated effort source on its secondary side.  The primary side provides the power needed by the effort source.  This element can e.g. be used to model a DC power supply together with the power cable that draws the required energy from the grid. <p>

The effort source has its secondary causality stroke away from the source.  Its primary causality stroke is free. <p>

<hr>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 e0:  Effort to be generated (modulated input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e2 = e0</b> <br>
<b>e1*f1 = e2*f2</b>
</html>
"));
    equation 
      e0 = s;
      e2 = e0;
      e1*f1 = e2*f2;
    end mSe_int;
    
    model Sf "Constant flow source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real f0=1 "Bondgraphic Flow Source";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="Sf",
            style(color=0))),
        Icon(
          Text(
            extent=[-60, 80; 60, -80],
            string="Sf",
            style(color=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(extent=[-70, -50; 70, -90], string="f0=%f0")),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.63),
        Documentation(info="<html>
The constant flow source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The constant flow to be generated is modeled as a parameter. <p>

The flow source has its causality stroke at the source. <p>

<hr>

<pre>
Potential variables:

 e:   Bondgraphic effort variable

 f:   Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 f0:  Constant flow to be generated (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = f0</b>
</html>
"));
    equation 
      f = f0;
    end Sf;
    
    model mSf "Modulated flow source of the Modelica bond graph library" 
      extends Interfaces.ModActiveOnePort;
      Real f0 "Bondgraphic Effort Source";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="mSf",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="mSf",
            style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.63),
        Documentation(info="<html>
The modulated flow source is a modulated active OnePort element.  It inherits the effort and flow variables from the modulated active OnePort.  The modulated flow to be generated is modeled as a real-valued variable. <p>

Modulated sources are commonly used to model actuators of control systems.  They are the most common and convenient way for converting signal variables to bondgraphic variables, thereby allowing individual blocks of a block diagram, e.g. describing a control system, to be modeled internally using bond graphs. <p>

The flow source has its causality stroke at the source. <p>

<hr>

<pre>
Potential variables:

 e:   Bondgraphic effort variable

 f:   Bondgraphic flow variable, normalized positive for flows out of the model

 f0:  Flow to be generated (modulated input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = f0</b>
</html>
"));
    equation 
      f0 = s;
      f = f0;
    end mSf;
    
    model sinSf "Sinusoidal flow source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real f0=1 "Amplitude of sine wave";
      parameter Modelica.SIunits.Angle phase=0 "Phase of sine wave";
      parameter Modelica.SIunits.Frequency freqHz=1 "Frequency of sine wave";
      parameter Real offset=0 "Offset of sine wave";
      parameter Real startTime=0 "Start time of sine wave";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(
          Line(points=[-80, -90; -80, 84], style(color=8)),
          Polygon(points=[-80, 100; -86, 84; -74, 84; -80, 100], style(color=8,
                  fillColor=8)),
          Line(points=[-99, -40; 85, -40], style(color=8)),
          Polygon(points=[101, -40; 85, -34; 85, -46; 101, -40], style(color=8,
                  fillColor=8)),
          Line(points=[-40, 0; -31.6, 34.2; -26.1, 53.1; -21.3, 66.4; -17.1,
                74.6; -12.9, 79.1; -8.64, 79.8; -4.42, 76.6; -0.201, 69.7; 4.02,
                  59.4; 8.84, 44.1; 14.9, 21.2; 27.5, -30.8; 33, -50.2; 37.8, -
                64.2; 42, -73.1; 46.2, -78.4; 50.5, -80; 54.7, -77.6; 58.9, -
                71.5; 63.1, -61.9; 67.9, -47.2; 74, -24.8; 80, 0], style(color=
                  0, thickness=2)),
          Line(points=[-41, -2; -80, -2], style(color=0, thickness=2)),
          Text(
            extent=[-106, -11; -60, -29],
            string="offset",
            style(color=9)),
          Line(points=[-41, -2; -41, -40], style(color=8, pattern=2)),
          Text(
            extent=[-60, -43; -14, -61],
            string="startTime",
            style(color=9)),
          Text(
            extent=[84, -52; 108, -72],
            string="time",
            style(color=9)),
          Line(points=[-9, 79; 43, 79], style(color=8, pattern=2)),
          Line(points=[-42, -1; 50, 0], style(color=8, pattern=2)),
          Polygon(points=[33, 80; 30, 67; 37, 67; 33, 80], style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[33, 1; 30, 14; 36, 14; 33, 1; 33, 1], style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[33, 79; 33, 0], style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Text(
            extent=[32, 52; 72, 34],
            string="f0",
            style(color=9)),
          Text(
            extent=[-86, 96; -44, 78],
            string="f",
            style(color=9))),
        Icon(
          Text(
            extent=[-60, 80; 60, -80],
            string="Sf",
            style(color=0)),
          Line(points=[-70, 0; -60.2, 29.9; -53.8, 46.5; -48.2, 58.1; -43.3,
                65.2; -38.3, 69.2; -33.4, 69.8; -28.5, 67; -23.6, 61; -18.6, 52;
                  -13, 38.6; -5.98, 18.6; 8.79, -26.9; 15.1, -44; 20.8, -56.2;
                25.7, -64; 30.6, -68.6; 35.5, -70; 40.5, -67.9; 45.4, -62.5;
                50.3, -54.1; 55.9, -41.3; 63, -21.7; 70, 0], style(color=8)),
          Text(extent=[-70, 90; 70, 50], string="%name")),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.63),
        Documentation(info="<html>
The sinusoidal flow source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The sinusoidal flow to be generated is modeled as a set of five parameters. <p>

The flow source has its causality stroke at the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 f0:         Amplitude of sine wave to be generated (default value = 1)

 phase:      Phase of sine wave to be generated (default value = 0)

 freqHz:     Frequency of sine wave to be generated (default value = 1)

 offset:     Offset of sine wave to be generated (default value = 0)

 startTime:  Start time of sine wave to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = offset + f0*sin(2*pi*freqHz*(time - startTime))</b>
</html>
"));
      Modelica.Blocks.Sources.Sine Sine1(
        amplitude=f0,
        freqHz=freqHz,
        offset=offset,
        phase=phase,
        startTime=startTime)   annotation (extent=[70, 66; 90, 86]);
    equation 
      f = Sine1.y;
    end sinSf;
    
    model stepSf "Step flow source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real f0=1 "Height of step";
      parameter Real offset=0 "Offset of step";
      parameter Real startTime=0 "Start time of step";
      annotation (
        Icon(
          Text(
            extent=[-70,74; 36,-78],
            string="Sf",
            style(color=0)),
          Text(extent=[-76,102; 64,62],  string="%name"),
             Line(points=[-70,-80; 0,-80; 0,60; 69,60],     style(color=8))),
        Diagram(
          Polygon(points=[-80,90; -88,68; -72,68; -80,90],     style(color=8,
                fillColor=8)),
          Line(points=[-80,68; -80,-80],   style(color=8)),
          Line(points=[-80,-18; 0,-18; 0,50; 80,50],     style(color=0, thickness=
                 2)),
          Line(points=[-90,-70; 82,-70],   style(color=8)),
          Polygon(points=[90,-70; 68,-62; 68,-78; 90,-70],     style(color=8,
                fillColor=8)),
          Text(
            extent=[70,-80; 94,-100],
            string="time",
            style(color=9)),
          Text(
            extent=[-21,-72; 25,-90],
            string="startTime",
            style(color=9)),
          Line(points=[0,-17; 0,-71],   style(color=8, pattern=2)),
          Text(
            extent=[-68,-36; -22,-54],
            string="offset",
            style(color=9)),
          Line(points=[-13,50; -13,-17],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[2,50; -19,50; 2,50],    style(color=8, pattern=2)),
          Polygon(points=[-13,-17; -16,-4; -10,-4; -13,-17; -13,-17],      style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-13,50; -16,37; -9,37; -13,50],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-50,26; -4,8],
            style(color=9),
            string="f0"),
          Polygon(points=[-13,-69; -16,-56; -10,-56; -13,-69; -13,-69],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-13,-18; -13,-70],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-13,-18; -16,-31; -9,-31; -13,-18],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-91,93; -32,70],
            style(color=9),
            string="f")),
        Documentation(info="<html>
The step flow source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The step flow to be generated is modeled as a set of three parameters. <p>

The flow source has its causality stroke at the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 f0:         Height of step to be generated (default value = 1)

 offset:     Offset of step to be generated (default value = 0)

 startTime:  Start time of step to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = offset + (if time &lt; startTime then 0 else f0)</b>
</html>
"));
      Modelica.Blocks.Sources.Step Step1(
        offset=offset,
        startTime=startTime,
        height=f0) annotation (extent=[70,68; 90,88]);
    equation 
      f = Step1.y;
    end stepSf;
    
    model rampSf "Ramp flow source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real f0=1 "Height of ramp";
      parameter Real duration=2 "Duration of ramp";
      parameter Real offset=0 "Offset of ramp";
      parameter Real startTime=0 "Start time of ramp";
      annotation (
        Icon(
          Text(
            extent=[-60,64; 36,-68],
            style(color=0),
            string="Sf"),
          Text(extent=[-70,106; 70,66],  string="%name"),
             Line(points=[-80,-60; -50,-60; 50,60; 80,60],     style(color=8))),
        Diagram(
          Polygon(points=[-80,80; -88,58; -72,58; -80,80],     style(color=8,
                fillColor=8)),
          Line(points=[-80,-30; -20,-30; 50,40],    style(color=0, thickness=2)),
          Line(points=[-90,-80; 82,-80],   style(color=8)),
          Polygon(points=[90,-80; 68,-72; 68,-88; 90,-80],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-40,-30; -42,-40; -37,-40; -40,-30],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-40,-30; -40,-80],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-40,-80; -43,-70; -38,-70; -40,-80; -40,-80],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-80,-43; -41,-59],
            string="offset",
            style(color=9)),
          Text(
            extent=[-40,-80; 6,-98],
            string="startTime",
            style(color=9)),
          Text(
            extent=[-83,83; -38,58],
            style(color=9),
            string="f"),
          Text(
            extent=[70,-86; 94,-106],
            string="time",
            style(color=9)),
          Line(points=[-20,-30; -20,-80],   style(color=8, pattern=2)),
          Line(points=[-19,-30; 50,-30],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Line(points=[50,40; 101,40],   style(color=0, thickness=2)),
          Line(points=[50,40; 50,-30],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[50,-30; 42,-28; 42,-32; 50,-30],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-20,-30; -11,-28; -11,-32; -20,-30],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[50,40; 48,30; 53,30; 50,40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[50,-30; 47,-20; 52,-20; 50,-30; 50,-30],      style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[53,15; 82,-3],
            style(color=9),
            string="f0"),
          Text(
            extent=[0,-27; 35,-47],
            string="duration",
            style(color=9))),
        Documentation(info="<html>
The ramp flow source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The ramp flow to be generated is modeled as a set of four parameters. <p>

The flow source has its causality stroke at the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 f0:         Height of ramp to be generated (default value = 1)

 duration:   Duration of ramp to be generated (default value = 2)

 offset:     Offset of ramp to be generated (default value = 0)

 startTime:  Start time of ramp to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = offset + (if time &lt; startTime then 0 else if time &lt; (startTime + duration)
                 then (time - startTime)*f0/duration else f0);</b>
</html>
"));
      Modelica.Blocks.Sources.Ramp Ramp1(
        duration=duration,
        offset=offset,
        startTime=startTime,
        height=f0)           annotation (extent=[68,66; 90,88]);
    equation 
      f = Ramp1.y;
    end rampSf;
    
    model expsinSf 
      "Damped sinusoidal flow source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real f0=1 "Amplitude of sine wave";
      parameter Real phase=0 "Phase of sine wave";
      parameter Real freqHz=2 "Frequency of sine wave";
      parameter Real damping=1 "Damping coefficient of sine wave";
      parameter Real offset=0 "Offset of sine wave";
      parameter Real startTime=0 "Start time of sine wave";
      annotation (
        Icon(
          Text(
            extent=[-70,62; 24,-64],
            style(color=0),
            string="Sf"),
          Text(extent=[-68,102; 72,62],  string="%name"),
             Line(points=[-80,-4; -75.2,28.3; -72,46.3; -68.7,60.5; -65.5,70.2;
                -62.3,75.3; -59.1,75.6; -55.9,71.3; -52.7,63.1; -48.6,48.2; -43,
                21.8; -35,-17.9; -30.2,-37.7; -26.1,-49.9; -22.1,-57.2; -18.1,
                -59.3; -14.1,-56.5; -10.1,-49.3; -5.23,-36.1; 8.44,9.7; 13.3,
                22.4; 18.1,30.8; 22.1,34; 26.9,33.2; 31.8,27.8; 38.2,15.4; 51.1,
                -14.5; 57.5,-25.2; 63.1,-29.9; 68.7,-29.9; 75.2,-24.5; 80,-17.8],
                                               style(color=8))),
        Diagram(
          Line(points=[-88,-92; -88,82],   style(color=8)),
          Polygon(points=[-88,98; -94,82; -82,82; -88,98],       style(color=8,
                fillColor=8)),
          Line(points=[-107,-42; 77,-42],  style(color=8)),
          Polygon(points=[93,-42; 77,-36; 77,-48; 93,-42],       style(color=8,
                fillColor=8)),
          Line(points=[-58,-2; -54.1,26.2; -51.5,42; -48.9,54.4; -46.2,62.9;
                -43.6,67.4; -41,67.6; -38.4,63.9; -35.8,56.7; -32.5,43.7; -27.9,
                20.5; -21.4,-14.2; -17.5,-31.5; -14.23,-42.1; -10.96,-48.5;
                -7.698,-50.4; -4.43,-47.9; -1.17,-41.6; 2.8,-30.1; 13.9,10;
                17.8,21.1; 21.7,28.5; 25,31.3; 28.9,30.5; 32.8,25.8; 38,14.9;
                48.5,-11.2; 53.7,-20.6; 58.3,-24.7; 62.9,-24.6; 68.1,-20; 72,
                -14.1],         style(color=0, thickness=2)),
          Text(
            extent=[-86,-1; -63,-21],
            string="offset",
            style(color=9)),
          Text(
            extent=[-80,-38; -34,-56],
            string="startTime",
            style(color=9)),
          Text(
            extent=[76,-54; 100,-74],
            string="time",
            style(color=9)),
          Line(points=[-58,-2; 10,-2], style(color=8, pattern=2)),
          Line(points=[-58,-2; -89,-2], style(color=0, thickness=2)),
          Line(points=[-58,75; -58,-2],  style(color=8, pattern=2)),
          Line(points=[10,-3; 10,74],   style(color=8, pattern=2)),
          Line(points=[10,71; -58,71],   style(color=8)),
          Text(
            extent=[-50,86; 1,72],
            string="1/freqHz",
            style(color=9)),
          Polygon(points=[-57,71; -48,73; -48,69; -57,71],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[10,71; 2,73; 2,69; 10,71],       style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-58,-63; -27,-63],   style(color=8)),
          Polygon(points=[-26,-63; -34,-61; -34,-65; -26,-63],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-59,-65; -35,-77],
            string="t",
            style(color=9)),
          Text(
            extent=[-90,-69; 100,-98],
            style(color=9),
            string="f0*exp(-damping*t)*sin(2*pi*freqHz*t+phase)"),
          Line(points=[-58,-2; -58,-42],  style(color=8, pattern=2)),
          Line(points=[-58,-56; -58,-74],   style(color=8, pattern=2)),
          Line(points=[10,-78; -9,-50],   style(color=8, pattern=2)),
          Text(
            extent=[-93,101; -54,82],
            style(color=9),
            string="f")),
        Documentation(info="<html>
The damped sinusoidal flow source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The damped sinusoidal flow to be generated is modeled as a set of six parameters. <p>

The flow source has its causality stroke at the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 f0:         Amplitude of damped sine wave to be generated (default value = 1)

 phase:      Phase of damped sine wave to be generated (default value = 0)

 freqHz:     Frequency of damped sine wave to be generated (default value = 2)

 damping:    Damping coefficient of damped sine wave to be generated (default value = 1)

 offset:     Offset of damped sine wave to be generated (default value = 0)

 startTime:  Start time of damped sine wave to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = offset + (if time &lt; startTime then 0 else f0*exp(-(time
       - startTime)*damping)*sin(2*pi*freqHz*(time - startTime) + phase))</b>
</html>
"));
      Modelica.Blocks.Sources.ExpSine ExpSine1(
        freqHz=freqHz,
        phase=phase,
        damping=damping,
        offset=offset,
        startTime=startTime,
        amplitude=f0) annotation (extent=[66,68; 88,90]);
    equation 
      f = ExpSine1.y;
    end expsinSf;
    
    model expSf "Step response flow source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real f0=1 "Height of step response after infinite time";
      parameter Real riseTime(min=0) = 0.5 "Rise time";
      parameter Real riseTimeConst(min=Modelica.Constants.small) = 0.1 
        "Rise time constant";
      parameter Real fallTimeConst(min=Modelica.Constants.small) = riseTimeConst 
        "Fall time constant";
      parameter Real offset=0 "Offset of step response";
      parameter Real startTime=0 "Start time of step response";
      annotation (
        Icon(
          Text(
            extent=[-60,78; 34,-80],
            style(color=0),
            string="Sf"),
          Text(extent=[-68,98; 72,58],   string="%name"),
             Line(points=[-70,-69; -67.2,-54.3; -64.3,-41.1; -60.8,-26.6; -57.3,
                -14; -53.7,-3.08; -49.5,8.18; -45.3,17.7; -40.3,27; -34.6,35.5;
                -28.3,43.1; -21.2,49.6; -12.7,55.3; -2.1,60.2; 0,61; 2.12,48.5;
                4.95,33.7; 7.78,20.8; 10.606,9.45; 14.14,-2.7; 17.68,-13; 21.9,
                -23.2; 26.2,-31.6; 31.1,-39.5; 36.8,-46.4; 43.1,-52.3; 50.9,
                -57.5; 60.8,-61.8; 70,-64.4],                            style(
                color=8))),
        Diagram(
          Line(points=[-100,-80; 84,-80],   style(color=8)),
          Polygon(points=[100,-80; 84,-74; 84,-86; 100,-80],     style(color=8,
                fillColor=8)),
          Line(points=[-40,-40; -37.2,-25.3; -34.3,-12.1; -30.8,2.4; -27.3,15;
                -23.7,25.92; -19.5,37.18; -15.3,46.7; -10.3,56; -4.6,64.5; 1.7,
                72.1; 8.8,78.6; 17.3,84.3; 27.9,89.2; 30,90; 32.12,77.5; 34.95,
                62.7; 37.78,49.8; 40.606,38.45; 44.14,26.3; 47.68,16; 51.9,5.8;
                56.2,-2.6; 61.1,-10.5; 66.8,-17.4; 73.1,-23.3; 80.9,-28.5; 90.8,
                -32.8; 100,-35.4],                              style(color=0,
                thickness=2)),
          Polygon(points=[-80,80; -88,58; -72,58; -80,80],     style(color=8,
                fillColor=8)),
          Line(points=[-80,58; -80,-90],   style(color=8)),
          Text(
            extent=[-78,-53; -46,-66],
            string="offset",
            style(color=9)),
          Polygon(points=[-40,-80; -43,-70; -38,-70; -40,-80; -40,-80],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-40,-39; -40,-70],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-40,-40; -42,-50; -37,-50; -40,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-39,-40; -80,-40],   style(color=0, thickness=2)),
          Text(
            extent=[-59,-81; -13,-99],
            string="startTime",
            style(color=9)),
          Polygon(points=[-41,-40; -32,-38; -32,-42; -41,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-40,-40; 29,-40],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[29,-40; 21,-38; 21,-42; 29,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-26,-22; 19,-38],
            string="riseTime",
            style(color=9)),
          Text(
            extent=[78,-86; 102,-106],
            string="time",
            style(color=9)),
          Line(points=[-100,-80; 84,-80],   style(color=8)),
          Polygon(points=[100,-80; 84,-74; 84,-86; 100,-80],     style(color=8,
                fillColor=8)),
          Line(points=[-40,-40; -37.2,-25.3; -34.3,-12.1; -30.8,2.4; -27.3,15;
                -23.7,25.92; -19.5,37.18; -15.3,46.7; -10.3,56; -4.6,64.5; 1.7,
                72.1; 8.8,78.6; 17.3,84.3; 27.9,89.2; 30,90; 32.12,77.5; 34.95,
                62.7; 37.78,49.8; 40.606,38.45; 44.14,26.3; 47.68,16; 51.9,5.8;
                56.2,-2.6; 61.1,-10.5; 66.8,-17.4; 73.1,-23.3; 80.9,-28.5; 90.8,
                -32.8; 100,-35.4],                              style(color=0,
                thickness=2)),
          Polygon(points=[-80,80; -88,58; -72,58; -80,80],     style(color=8,
                fillColor=8)),
          Line(points=[-80,58; -80,-90],   style(color=8)),
          Text(
            extent=[-82,81; -41,61],
            style(color=9),
            string="f"),
          Text(
            extent=[-78,-53; -46,-66],
            string="offset",
            style(color=9)),
          Polygon(points=[-40,-80; -43,-70; -38,-70; -40,-80; -40,-80],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-40,-39; -40,-70],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-40,-40; -42,-50; -37,-50; -40,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-39,-40; -80,-40],   style(color=0, thickness=2)),
          Text(
            extent=[-59,-81; -13,-99],
            string="startTime",
            style(color=9)),
          Polygon(points=[-41,-40; -32,-38; -32,-42; -41,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-40,-40; 29,-40],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[29,-40; 21,-38; 21,-42; 29,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-26,-22; 19,-38],
            string="riseTime",
            style(color=9)),
          Text(
            extent=[78,-86; 102,-106],
            string="time",
            style(color=9)),
          Line(points=[30,90; 30,-44],    style(color=8, pattern=2))),
        Documentation(info="<html>
The step response flow source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The step response flow to be generated is modeled as a set of six parameters. <p>

The flow source has its causality stroke at the source. <p>

<hr>

<pre>
Potential variables:

 e:              Bondgraphic effort variable

 f:              Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 f0:             Height of step response after infinite time (default value = 1)

 riseTime:       Rise time of step response to be generated (default value = 0.5)

 riseTimeConst:  Rise time constant of step response to be generated (default value = 0.1)

 fallTimeConst:  Fall time constant of step response to be generated (default value = riseTimeConst)

 offset:         Offset of step response to be generated (default value = 0)

 startTime:      Start time of step response to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f_riseTime = f0*(1 - exp(-riseTime/riseTimeConst))</b> <br>
<b>f = offset + (if (time &lt; startTime) then 0 else if (time &lt; (startTime
     + riseTime)) then f0*(1 - exp(-(time - startTime)/riseTimeConst)) else 
          f_riseTime*exp(-(time - startTime - riseTime)/fallTimeConst));</b>
</html>
"));
      Modelica.Blocks.Sources.Exponentials Exponentials1(
        riseTime=riseTime,
        riseTimeConst=riseTimeConst,
        fallTimeConst=fallTimeConst,
        offset=offset,
        startTime=startTime,
        outMax=f0) annotation (extent=[68,66; 90,88]);
    equation 
      f = Exponentials1.y;
    end expSf;
    
    model pulseSf "Pulse flow source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real f0=1 "Amplitude of pulse";
      parameter Real width(
        final min=Modelica.Constants.small,
        final max=100) = 50 "Width of pulse in % of period";
      parameter Real period(final min=Modelica.Constants.small) = 1 
        "Time for one period";
      parameter Real offset=0 "Offset of pulse";
      parameter Real startTime=0 "Start time of pulse";
      annotation (
        Icon(
          Text(
            extent=[-62,58; 50,-60],
            style(color=0),
            string="Sf"),
          Text(extent=[-70,100; 70,60],  string="%name"),
             Line(points=[-76,-80; -46,-80; -46,60; -6,60; -6,-80; 34,-80; 35,
                60; 74,60],    style(color=8))),
        Diagram(
          Polygon(points=[-80,90; -88,68; -72,68; -80,90],     style(color=8,
                fillColor=8)),
          Line(points=[-80,68; -80,-80],   style(color=8)),
          Line(points=[-90,-70; 82,-70],   style(color=8)),
          Polygon(points=[90,-70; 68,-62; 68,-78; 90,-70],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-34,1; -37,-12; -30,-12; -34,1],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-34,-1; -34,-70],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-33,-70; -36,-57; -30,-57; -33,-70; -33,-70],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-78,-24; -35,-36],
            string="offset",
            style(color=9)),
          Text(
            extent=[-39,-69; 7,-87],
            string="startTime",
            style(color=9)),
          Text(
            extent=[70,-80; 94,-100],
            string="time",
            style(color=9)),
          Line(points=[-18,0; -18,-70],   style(color=8, pattern=2)),
          Line(points=[-80,0; -20,0; -20,50; 20,50; 20,0; 40,0; 40,50; 80,50],
                       style(color=0, thickness=2)),
          Line(points=[-19,88; -19,49],   style(color=8, pattern=2)),
          Line(points=[21,74; 21,50],   style(color=9, pattern=2)),
          Line(points=[41,88; 41,50],   style(color=8, pattern=2)),
          Line(points=[-19,83; 42,83],   style(color=8)),
          Line(points=[-19,69; 21,69],   style(color=8)),
          Text(
            extent=[-9,97; 37,85],
            string="period",
            style(color=9)),
          Text(
            extent=[-18,81; 21,69],
            string="width",
            style(color=9)),
          Line(points=[-52,50; -19,50],   style(color=8, pattern=2)),
          Line(points=[-34,50; -34,1],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Text(
            extent=[-66,32; -25,18],
            style(color=9),
            string="f0"),
          Polygon(points=[-34,49; -37,36; -30,36; -34,49],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-34,1; -37,14; -31,14; -34,1; -34,1],      style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[80,50; 80,0; 92,0],     style(color=0, thickness=2)),
          Polygon(points=[-19,69; -10,71; -10,67; -19,69],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[21,69; 13,71; 13,67; 21,69],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-19,83; -10,85; -10,81; -19,83],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[41,83; 33,85; 33,81; 41,83],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-74,91; -56,72],
            style(color=9),
            string="f")),
        Documentation(info="<html>
The pulse flow source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The pulse flow to be generated is modeled as a set of five parameters. <p>

The flow source has its causality stroke at the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 f0:         Amplitude of pulse to be generated (default value = 1)

 width:      Percentage of period in on state (default value = 50)

 period:     Length of period of pulse to be generated (default value = 1)

 offset:     Offset of pulse to be generated (default value = 0)

 startTime:  Start time of pulse to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>when sample(startTime, period) then</b> <br>
<b>T0 = time</b> <br>
<b>end when</b> <br>
<b>f = offset + (if time &lt; startTime or time &gt;= T0 + T_width then 0 else f0)</b>
</html>
"));
      Modelica.Blocks.Sources.Pulse Pulse1(
        width=width,
        period=period,
        offset=offset,
        startTime=startTime,
        amplitude=f0) annotation (extent=[68,70; 90,92]);
    equation 
      f = Pulse1.y;
    end pulseSf;
    
    model sawSf "Saw tooth flow source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real f0=1 "Amplitude of saw tooth";
      parameter Real period(final min=Modelica.Constants.small) = 1 
        "Time for one period";
      parameter Real offset=0 "Offset of saw tooth";
      parameter Real startTime=0 "Start time of saw tooth";
      annotation (
        Icon(
          Text(
            extent=[-58,50; 38,-70],
            style(color=0),
            string="Sf"),
          Text(extent=[-72,104; 68,64],  string="%name"),
             Line(points=[-82,-79; -62,-79; -2,62; -2,-79; 58,62; 58,-79],
              style(color=8))),
        Diagram(
          Polygon(points=[-80,80; -88,58; -72,58; -80,80],     style(color=8,
                fillColor=8)),
          Line(points=[-80,58; -80,-90],   style(color=8)),
          Line(points=[-90,-80; 82,-80],   style(color=8)),
          Polygon(points=[90,-80; 68,-72; 68,-88; 90,-80],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-34,-29; -37,-42; -30,-42; -34,-29],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-34,-30; -34,-80],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-34,-80; -37,-67; -31,-67; -34,-80; -34,-80],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-78,-34; -35,-46],
            string="offset",
            style(color=9)),
          Text(
            extent=[-31,-79; 15,-97],
            string="startTime",
            style(color=9)),
          Text(
            extent=[74,-84; 98,-104],
            string="time",
            style(color=9)),
          Line(points=[-10,-30; -10,-80],   style(color=8, pattern=2)),
          Line(points=[-10,78; -10,-30],   style(color=8, pattern=2)),
          Line(points=[30,78; 30,49],   style(color=8, pattern=2)),
          Line(points=[-10,73; 30,73],   style(color=8)),
          Text(
            extent=[-12,87; 34,75],
            string="period",
            style(color=9)),
          Line(points=[-44,50; 30,50],   style(color=8, pattern=2)),
          Line(points=[-34,37; -34,-17],  style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Text(
            extent=[-66,18; -25,4],
            style(color=9),
            string="f0"),
          Polygon(points=[-34,50; -37,37; -30,37; -34,50],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-34,-30; -37,-17; -31,-17; -34,-30; -34,-30],    style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-10,73; -1,75; -1,71; -10,73],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[30,73; 22,75; 22,71; 30,73],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-80,-30; -10,-30; 30,50; 30,-30; 72,50; 72,-30],
              style(color=0, thickness=2)),
          Text(
            extent=[-75,82; -56,62],
            style(color=9),
            string="f")),
        Documentation(info="<html>
The saw tooth flow source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The saw tooth flow to be generated is modeled as a set of four parameters. <p>

The flow source has its causality stroke at the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 f0:         Amplitude of saw tooth to be generated (default value = 1)

 period:     Length of period of saw tooth to be generated (default value = 1)

 offset:     Offset of saw tooth to be generated (default value = 0)

 startTime:  Start time of saw tooth to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>when sample(startTime, period) then</b> <br>
<b>T0 = time</b> <br>
<b>end when</b> <br>
<b>f = offset + (if time &lt; startTime then 0 else (f0/period)*(time - T0))</b>
</html>
"));
      Modelica.Blocks.Sources.SawTooth SawTooth1(
        period=period,
        offset=offset,
        startTime=startTime,
        amplitude=f0) annotation (extent=[68,66; 90,88]);
    equation 
      f = SawTooth1.y;
    end sawSf;
    
    model trapSf "Trapezoidal flow source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real f0=1 "Amplitude of trapezoidal function";
      parameter Real rising(final min=0) = 0 "Rising duration of trapezoid";
      parameter Real width(final min=0) = 0.5 "Width duration of trapezoid";
      parameter Real falling(final min=0) = 0 "Falling duration of trapezoid";
      parameter Real period(final min=Modelica.Constants.small) = 1 
        "Time for one period";
      parameter Integer nperiod=-1 
        "Number of periods (< 0 means infinite number of periods)";
      parameter Real offset=0 "Offset of saw tooth";
      parameter Real startTime=0 "Start time of saw tooth";
      annotation (
        Icon(
          Text(
            extent=[-60,46; 36,-68],
            style(color=0),
            string="Sf"),
          Text(extent=[-66,104; 74,64],  string="%name"),
             Line(points=[-81,-78; -60,-78; -30,62; 1,62; 30,-78; 51,-78; 80,62],
                         style(color=8))),
        Diagram(
          Polygon(points=[-80,80; -88,58; -72,58; -80,80],     style(color=8,
                fillColor=8)),
          Line(points=[-80,58; -80,-90],   style(color=8)),
          Line(points=[-90,-80; 82,-80],   style(color=8)),
          Polygon(points=[90,-80; 68,-72; 68,-88; 90,-80],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-45,-40; -47,-51; -43,-51; -45,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-45,-41; -45,-80],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Polygon(points=[-45,-80; -47,-70; -43,-70; -45,-80; -45,-80],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-86,-53; -43,-65],
            string="offset",
            style(color=9)),
          Text(
            extent=[-47,-79; -1,-97],
            string="startTime",
            style(color=9)),
          Text(
            extent=[76,-84; 100,-104],
            string="time",
            style(color=9)),
          Line(points=[-30,71; -30,-80],   style(color=8, pattern=2)),
          Line(points=[-10,49; -10,30],   style(color=8, pattern=2)),
          Line(points=[20,49; 20,29],   style(color=9, pattern=2)),
          Line(points=[40,49; 40,-40],   style(color=8, pattern=2)),
          Line(points=[-29,46; 40,46],   style(color=8)),
          Text(
            extent=[-8,60; 21,50],
            string="width",
            style(color=9)),
          Line(points=[-42,30; -10,30],   style(color=8, pattern=2)),
          Line(points=[-39,30; -39,-29],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Text(
            extent=[-67,6; -30,-8],
            style(color=9),
            string="f0"),
          Polygon(points=[-29,46; -22,48; -22,44; -29,46],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-10,46; -17,48; -17,44; -10,46],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-80,-40; -30,-40; -9,36; 21,36; 40,-40; 60,-40; 80,36;
                100,36],      style(color=0, thickness=2)),
          Polygon(points=[-39,30; -41,19; -37,19; -39,30],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-39,-39; -41,-29; -37,-29; -39,-39; -39,-39],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[60,71; 60,-40],   style(color=8, pattern=2)),
          Polygon(points=[39,46; 32,48; 32,44; 39,46],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[20,46; 27,48; 27,44; 20,46],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[20,46; 13,48; 13,44; 20,46],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-12,46; -5,48; -5,44; -12,46],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-34,60; -5,50],
            string="rising",
            style(color=9)),
          Text(
            extent=[16,60; 45,50],
            string="falling",
            style(color=9)),
          Text(
            extent=[-77,83; -48,60],
            style(color=9),
            string="f"),
          Line(points=[-20,66; 61,66],   style(color=8)),
          Polygon(points=[-29,66; -20,68; -20,64; -29,66],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[61,66; 53,68; 53,64; 61,66],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Text(
            extent=[-2,76; 25,67],
            string="period",
            style(color=9))),
        Documentation(info="<html>
The trapezoidal flow source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The trapezoidal flow to be generated is modeled as a set of eight parameters. <p>

The flow source has its causality stroke at the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 f0:         Amplitude of trapezoid to be generated (default value = 1)

 rising:     Length of rising time of trapezoid to be generated (default value = 0)

 width :     Length of on state of trapezoid to be generated (default value = 0.5)

 falling:    Length of falling time of trapezoid to be generated (default value = 0)

 period:     Length of period of trapezoid to be generated (default value = 1)

 nperiod:    Number of periods of trapezoid to be generated
             an infinite number of periods is being generated if nperiod &lt; 0 (default value = -1)

 offset:     Offset of trapezoid to be generated (default value = 0)

 startTime:  Start time of trapezoid to be generated (default value = 0)
</pre> <p>

<hr> <p>

Equations: <p>

<b>when pre(counter2) &lt;&gt; 0 and sample(startTime, period) then</b> <br>
<b>T0 = time</b> <br>
<b>counter2 = pre(counter)</b> <br>
<b>counter = pre(counter) - (if pre(counter) &gt; 0 then 1 else 0)</b> <br>
<b>end when</b> <br>
<b>f = offset + (if (time &lt; startTime or counter2 == 0 or time &gt;= T0 +
    T_falling) then 0 else if (time &lt; T0 + T_rising) then (time - T0)*f0/T_rising
    else if (time &lt; T0 + T_width) then f0 else 
    (T0 + T_falling - time)*f0/(T_falling - T_width))</b>
</html>
"));
      Modelica.Blocks.Sources.Trapezoid Trapezoid1(
        rising=rising,
        width=width,
        falling=falling,
        period=period,
        nperiod=nperiod,
        offset=offset,
        startTime=startTime,
        amplitude=f0) annotation (extent=[68,66; 90,88]);
    equation 
      f = Trapezoid1.y;
    end trapSf;
    
    model tableSf "Tabular flow source of the Modelica bond graph library" 
      extends Interfaces.ActiveOnePort;
      parameter Real table[:, :]=[0, 0; 1, 1; 2, 4] 
        "Table matrix (time = first column, voltage = second column)";
      parameter Real offset=0 "Offset of saw tooth";
      parameter Real startTime=0 "Start time of saw tooth";
      annotation (
        Icon(
          Text(
            extent=[-54,66; 46,-68],
            style(color=0),
            string="Sf"),
          Text(extent=[-66,102; 74,62],  string="%name"),
             Line(points=[-64,-64; -64,56; 36,56; 36,-64; -64,-64; -64,-34; 36,
                -34; 36,-4; -64,-4; -64,26; 36,26; 36,56; -14,56; -14,-65],
                     style(color=8))),
        Diagram(
          Polygon(points=[-80,80; -88,58; -72,58; -80,80],     style(color=8,
                fillColor=8)),
          Line(points=[-80,58; -80,-90],   style(color=8)),
          Line(points=[-90,-80; 82,-80],   style(color=8)),
          Polygon(points=[90,-80; 68,-72; 68,-88; 90,-80],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Rectangle(extent=[-20,80; 30,-40],   style(
              color=7,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-20,-40; -20,80; 80,80; 80,-40; -20,-40; -20,-10; 80,-10;
                80,20; -20,20; -20,50; 80,50; 80,80; 30,80; 30,-41],
              style(color=0)),
          Text(
            extent=[-77,-52; -38,-68],
            string="offset",
            style(color=9)),
          Polygon(points=[-31,-40; -33,-50; -28,-50; -31,-40],     style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Polygon(points=[-30,-80; -33,-70; -28,-70; -30,-80; -30,-80],
              style(
              color=8,
              fillColor=8,
              fillPattern=1)),
          Line(points=[-31,-41; -31,-80],   style(
              color=8,
              pattern=1,
              thickness=1,
              arrow=0)),
          Line(points=[-20,-42; -20,-80],   style(color=8, pattern=2)),
          Text(
            extent=[-38,-80; 8,-98],
            string="startTime",
            style(color=9)),
          Line(points=[-20,-40; -80,-40],   style(color=8, pattern=2)),
          Text(
            extent=[72,-87; 97,-99],
            string="time",
            style(color=9)),
          Text(
            extent=[-15,73; 24,58],
            string="time",
            style(color=0)),
          Text(
            extent=[33,73; 76,57],
            string="v",
            style(color=0)),
          Text(
            extent=[-77,80; -54,58],
            style(color=9),
            string="f")),
        Documentation(info="<html>
The tabular flow source is an active OnePort element.  It inherits the effort and flow variables from the active OnePort.  The tabular flow to be generated is modeled as a two-dimensional parameter table plus a set of two scalar parameters. <p>

The flow source has its causality stroke at the source. <p>

<hr>

<pre>
Potential variables:

 e:          Bondgraphic effort variable

 f:          Bondgraphic flow variable, normalized positive for flows out of the model


Parameters:

 table:      Two-dimensional table with supporting values (default value = [0, 0; 1, 1; 2, 4])

 offset:     Offset of time function to be generated (default value = 0)

 startTime:  Start time of time function to be generated (default value = 0)
</pre> <p>

<hr> <p>

The model generates a flow source by <b>linear interpolation</b> in
a table. The time points and flow values are stored in a matrix
<b>table[i,j]</b>, where the first column table[:,1] contains the
time points, and the second column contains the flow to be interpolated.
The table interpolation has the following proporties: <p>

<ul>
<li>The time points need to be <b>monotonically increasing</b>.
<li><b>Discontinuities</b> are allowed, by providing the same
    time point twice in the table.
<li>Values <b>outside</b> of the table range, are computed by
    <b>extrapolation</b> through the last or first two points of the
    table.
<li>If the table has only <b>one row</b>, no interpolation is performed and
    the voltage value is just returned independantly of the
    actual time instant, i.e., this is a constant voltage source.
<li>Via parameters <b>startTime</b> and <b>offset</b> the curve defined
    by the table can be shifted both in time and in the voltage.
<li>The table is implemented in a numerically sound way by
    generating <b>time events</b> at interval boundaries,
    in order to not integrate over a discontinuous or not differentiable
    points.
</ul> <p>

<hr> <p>

<b>Example:</b> <p>

<pre>
   table = [0  0
            1  0
            1  1
            2  4
            3  9
            4 16]
If, e.g., time = 1.0, the flow f =  0.0 (before event), 1.0 (after event)
    e.g., time = 1.5, the flow f =  2.5,
    e.g., time = 2.0, the flow f =  4.0,
    e.g., time = 5.0, the flow f = 23.0 (i.e. extrapolation).
</pre>
</html>
"));
      Modelica.Blocks.Sources.TimeTable TimeTable1(
        table=table,
        offset=offset,
        startTime=startTime) annotation (extent=[68,68; 90,90]);
    equation 
      f = TimeTable1.y;
    end tableSf;
    
    model mSf2 
      extends Interfaces.ModTwoPort;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-60, 80; 60, -80],
            string="mSf",
            style(color=0))),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="mSf",
            style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
        Window(
          x=0.45,
          y=0.01,
          width=0.35,
          height=0.63),
        Documentation(info="<html>
The modulated internal flow source is a modulated directed TwoPort element.  It inherits the effort and flow variables from the modulated directed TwoPort. <p>

The internal source takes power out of the system to the left, and feeds it into the system to the right.  The modulation signal is used to set the <b>flow</b> of the inflow.  The <b>flow</b> of the outflow is computed such that power in equals power out. <p>

The internal flow source is primarily used in the computation of convective flows, when entropy flow has to accompany mass flow. <p>

The modulated internal flow source has two causality strokes. <p>

<hr>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 s:   Modulation input signal
</pre> <p>

<hr> <p>

Equations: <p>

<b>f1 = s</b> <br>
<b>f2 = f1*(e1/e2)</b>
</html>
"));
    equation 
      f1 = s;
      e1*f1 = e2*f2;
    end mSf2;
    
    model mSf_int "Internal modulated flow source of the bond graph library" 
      extends Interfaces.ModTwoPort;
      Real f0 "Bondgraphic Flow Source";
      annotation (
        Icon(   Text(
            extent=[-62,80; 58,-80],
            style(color=0),
            string="mSf"),   Text(extent=[-70,90; 70,50],   string="%name")),
        Diagram(Text(
            extent=[-62,80; 58,-80],
            style(color=0),
            string="mSf")),
        Documentation(info="<html>
The modulated internal flow source is a modulated directed TwoPort element.  It inherits the effort and flow variables from the modulated directed TwoPort.  The modulated flow to be generated is modeled as a real-valued variable. <p>

The modulated internal flow source is a modulated flow source on its secondary side.  The primary side provides the power needed by the flow source.  This element can e.g. be used to model a DC current supply together with the power cable that draws the required energy from the grid. <p>

The flow source has its secondary causality stroke away from the source.  Its primary causality stroke is free. <p>

<hr>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 f0:  Flow to be generated (modulated input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f2 = f0</b> <br>
<b>e1*f1 = e2*f2</b>
</html>
"));
    equation 
      f0 = s;
      f2 = f0;
      e1*f1 = e2*f2;
    end mSf_int;
    
    model mSP "Source of power" 
      extends Interfaces.ModActiveOnePort;
      Real P0 "Bondgraphic Power Source";
      annotation (
        Diagram(Text(
            extent=[-62, 80; 58, -80],
            style(color=0),
            string="mSP")),
        Icon(Text(
            extent=[-62, 80; 58, -80],
            style(color=0),
            string="mSP"), Text(extent=[-70, 92; 70, 52], string="%name")),
        Documentation(info="<html>
The modulated power source is a modulated active OnePort element.  It inherits the effort and flow variables from the modulated active OnePort.  The modulated power to be generated is modeled as a real-valued variable. <p>

Modulated sources are commonly used to model actuators of control systems.  They are the most common and convenient way for converting signal variables to bondgraphic variables, thereby allowing individual blocks of a block diagram, e.g. describing a control system, to be modeled internally using bond graphs. <p>

The power source has free causality. <p>

<hr>

<pre>
Potential variables:

 e:   Bondgraphic effort variable

 f:   Bondgraphic flow variable, normalized positive for flows out of the model

 P0:  Power to be generated (modulated input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e*f = P0</b>
</html>
"));
    equation 
      P0 = s;
      P0 = e*f;
    end mSP;
  end Sources;
  
    package Spice "Spice-style semiconductor models" 
      annotation (Icon(
          Rectangle(extent=[-100,-100; 80,50],   style(fillColor=30,
                fillPattern=
                  1)),
          Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50],      style(
                fillColor=30, fillPattern=1)),
          Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70],      style(
                fillColor=30, fillPattern=1)),
          Text(
            extent=[-85,35; 65,-85],
            string="Library",
            style(color=3)),
          Text(
            extent=[-120,122; 120,73],
            string="%name",
            style(color=1))), Documentation(info="<html>
This package contains a set of Spice-style bond graph models for electronic circuit modeling.
</html>
"));
      package Interfaces "Interfaces for Spice-style electronic circuit models" 
      annotation (Icon(
            Rectangle(extent=[-100,-100; 80,50],   style(
                color=58,
                fillColor=30,
                fillPattern=1)),
            Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50],      style(
                color=58,
                fillColor=30,
                fillPattern=1)),
            Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70],      style(
                color=58,
                fillColor=30,
                fillPattern=1)),
            Text(
              extent=[-85,35; 65,-85],
              string="Library",
              style(color=58)),
            Text(
              extent=[-120,122; 120,73],
              string="%name",
              style(color=1))), Documentation(info="<html>
This package contains some common interfaces for Spice-style electronic circuit models.
</html>
"));
        partial model SpiceTwoPort 
        "Special twoPort element used by Spice models" 
          extends BondLib.Interfaces.TwoPort;
          parameter Modelica.SIunits.Temperature Tnom=300.15 
          "Reference temperature";
          Modelica.SIunits.Temperature DTemp 
          "Difference between circuit temperature and reference temperature";
          Real DTempSq "Square of DTemp";
        annotation (Icon(
              Text(
                extent=[24,-4; 92,-34],
                string="Spice",
                style(color=0, rgbcolor={0,0,0})),
              Text(extent=[-40,86; 40,56],   string="%name")), Diagram(
              Text(
                extent=[24,-4; 92,-34],
                string="Spice",
                style(color=0, rgbcolor={0,0,0}))));
        equation 
          DTemp = e2 - Tnom;
          DTempSq = DTemp*DTemp;
        end SpiceTwoPort;
      end Interfaces;
    
      model RS "Spice-style resistor model" 
        extends Interfaces.SpiceTwoPort;
        parameter Modelica.SIunits.Resistance R=1 
        "Resistance at reference temperature";
        parameter Real TR1=0 "Linear temperature coefficient [Ohm/degree]";
        parameter Real TR2=0 
        "Quadratic temperature coefficient [Ohm/(degree*degree)]";
        parameter Real Area=1 "Relative area occupied by resistor";
        Modelica.SIunits.Resistance Rval 
        "Resistance value at circuit temperature";
        annotation (
          Icon(
            Text(
              extent=[-82,76; 28,-80],
              string="RS",
              style(color=0)),
            Text(extent=[-72,-58; 66,-86],   string="R=%R")),
          Diagram(
            Text(
              extent=[-84,78; 26,-78],
              string="RS",
              style(color=0))),
          Documentation(info="<html>
The Spice-style resistor has a reference resistance value computed at the reference temperature, <b>Tnom</b>, and for a relative area of <b>Area=1</b>.  It changes its value as a function of the circuit temperature and the relative area occupied by the resistor. <p>

<hr> <p>

<pre>
Parameters:

 R:     Reference resistance (default value = 1 Ohm)

 Tnom:  Reference temperature (default value = 300.15 <sup>o</sup>K)

 TR1:   Linear temperature variation coefficient (default value = 0 Ohm/<sup>o</sup>K)

 TR2:   Quadratic temperature variation coefficient (default value = 0 Ohm/<sup>o</sup>K<sup>2</sup>)

 Area:  Relative area occupied by resistor (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>DTemp = e2 - Tnom</b> <br>
<b>Rval = R*(1 + TR1*DTemp + TR2*DTemp*DTemp)/Area</b> <br>
<b>e1 = Rval*f1</b> <br>
<b>f2 = (e1/e2)*f1</b>
</html>
"));
      equation 
        Rval = R*(1 + TR1*DTemp + TR2*DTempSq)/Area;
        e1 = Rval*f1;
        e1*f1 = e2*f2;
      end RS;
    
      model CS "Spice-style capacitor model" 
        extends Interfaces.SpiceTwoPort;
        parameter Modelica.SIunits.Capacitance C=1 
        "Capacitance at reference temperature";
        parameter Real TC1=0 "Linear temperature coefficient [F/degree]";
        parameter Real TC2=0 
        "Quadratic temperature coefficient [F/(degree*degree)]";
        parameter Real Area=1 "Relative area occupied by capacitor";
        Modelica.SIunits.Capacitance Cval 
        "Capacitance value at circuit temperature";
        Modelica.SIunits.Charge q1 "Charge value at circuit temperature";
        annotation (
          Icon(
            Text(
              extent=[-84,76; 26,-80],
              style(color=0),
              string="CS"),
            Text(extent=[-62,-58; 48,-86], string="C=%C")),
          Diagram(
            Text(
              extent=[-84,76; 26,-80],
              style(color=0),
              string="CS")),
          Documentation(info="<html>
The Spice-style capacitor has a reference capacitance value computed at the reference temperature, <b>Tnom</b>, and for a relative area of <b>Area=1</b>.  It changes its value as a function of the circuit temperature and the relative area occupied by the capacitor. <p>

<hr> <p>

<pre>
Parameters:

 C:     Reference capacitance (default value = 1 F)

 Tnom:  Reference temperature (default value = 300.15 <sup>o</sup>K)

 TC1:   Linear temperature variation coefficient (default value = 0 F/<sup>o</sup>K)

 TC2:   Quadratic temperature variation coefficient (default value = 0 F/<sup>o</sup>K<sup>2</sup>)

 Area:  Relative area occupied by capacitor (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>DTemp = e2 - Tnom</b> <br>
<b>Cval = C*(1 + TC1*DTemp + TC2*DTemp*DTemp)*Area</b> <br>
<b>q1 = Cval*e1</b> <br>
<b>der(q1) = f1</b> <br>
<b>f2 = 0</b>
</html>
"));
      equation 
        Cval = C*(1 + TC1*DTemp + TC2*DTempSq)*Area;
        q1 = Cval*e1;
        der(q1) = f1;
        f2 = 0;
      end CS;
    
      model LS "Spice-style inductor model" 
        extends Interfaces.SpiceTwoPort;
        parameter Modelica.SIunits.Inductance L=1 
        "Inductance at reference temperature";
        parameter Real TL1=0 "Linear temperature coefficient [H/degree]";
        parameter Real TL2=0 
        "Quadratic temperature coefficient [H/(degree*degree)]";
        Modelica.SIunits.Capacitance Lval 
        "Inductance value at circuit temperature";
        Modelica.SIunits.Charge p1 "Flux value at circuit temperature";
        annotation (
          Icon(
            Text(
              extent=[-82,76; 28,-80],
              style(color=0),
              string="LS"),
            Text(extent=[-74,-58; 70,-88], string="L=%L")),
          Diagram(
            Text(
              extent=[-82,76; 28,-80],
              style(color=0),
              string="LS")),
          Documentation(info="<html>
The Spice-style inductor has a reference inductance value computed at the reference temperature, <b>Tnom</b>.  It changes its value as a function of the circuit temperature. <p>

<hr> <p>

<pre>
Parameters:

 L:     Reference inductance (default value = 1 H)

 Tnom:  Reference temperature (default value = 300.15 <sup>o</sup>K)

 TL1:   Linear temperature variation coefficient (default value = 0 H/<sup>o</sup>K)

 TL2:   Quadratic temperature variation coefficient (default value = 0 H/<sup>o</sup>K<sup>2</sup>)
</pre> <p>

<hr> <p>

Equations: <p>

<b>DTemp = e2 - Tnom</b> <br>
<b>Lval = L*(1 + TL1*DTemp + TL2*DTemp*DTemp)</b> <br>
<b>p1 = Lval*f1</b> <br>
<b>der(p1) = e1</b> <br>
<b>f2 = 0</b>
</html>
"));
      equation 
        Lval = L*(1 + TL1*DTemp + TL2*DTempSq);
        p1 = Lval*f1;
        der(p1) = e1;
        f2 = 0;
      end LS;
    
        model DS 
      "Spice-style diode model used inside the bipolar transistor models" 
          extends Interfaces.SpiceTwoPort;
          constant Real k=Modelica.Constants.k "Boltzmann's constant";
          constant Modelica.SIunits.ElectricCharge q=1.6021892e-19 
        "Electron charge";
          constant Real GapC1=7.02E-4 "First bandgap correction factor Silicon";
          constant Real GapC2=1108.0 "Second bandgap correction factor Silicon";
          parameter Modelica.SIunits.Current IS=1e-16 
        "Saturation current at reference temperature";
          parameter Modelica.SIunits.Voltage EG=1.16 
        "Activation energy at reference temperature";
          parameter Real N=1 "Emission coefficient";
          parameter Real XTI=3 "Temperature exponent of saturation current";
          parameter Real Area=1 "Relative area occupied by diode";
          parameter Real EMin=-100 
        "if x < EMin, the exp(x) function is linearized";
          parameter Real EMax=40 
        "if x > EMax, the exp(x) function is linearized";
          Modelica.SIunits.Voltage Vt "Thermal voltage";
          Modelica.SIunits.Current ISval 
        "Saturation current at device temperature";
          Modelica.SIunits.Energy EGval 
        "Activation energy at device temperature";
      
    protected 
          Real RTemp "Temperature quotient";
          Real ExMin;
          Real ExMax;
          Real et;
        annotation (
          Icon(
              Text(
                extent=[-82,76; 28,-80],
                style(color=0),
              string="DS")),
          Diagram(
              Line(points=[-80,0; 80,0],   style(color=10)),
              Polygon(points=[70,4; 80,0; 70,-4; 70,4],     style(color=10,
                    fillColor=10)),
              Line(points=[0,80; 0,-80],   style(
                  color=10,
                  fillColor=10,
                  fillPattern=1)),
              Polygon(points=[-4,70; 0,80; 4,70; -4,70],     style(
                  color=10,
                  fillColor=10,
                  fillPattern=1)),
              Text(
                extent=[4,82; 14,72],
                style(
                  color=10,
                  fillColor=10,
                  fillPattern=1),
                string="f"),
              Text(
                extent=[70,-4; 80,-14],
                style(
                  color=10,
                  fillColor=10,
                  fillPattern=1),
                string="e"),
              Line(points=[-80,-4; -28,-4; -6,-2; 0,0],         style(
                  color=0,
                  thickness=2,
                  fillColor=10,
                  fillPattern=1)),
              Text(
                extent=[-66,-6; -36,-14],
                style(
                  color=10,
                  pattern=3,
                  fillColor=10,
                  fillPattern=1),
                string="blocking"),
              Text(
                extent=[16,50; 48,42],
                style(
                  color=10,
                  pattern=3,
                  fillColor=10,
                  fillPattern=1),
                string="conducting"),
              Line(points=[0,0; 6,10; 12,28; 16,66],            style(
                  color=0,
                  thickness=2,
                  fillColor=10,
                  fillPattern=1))),
          Documentation(info="<html>
The Spice junction diode model is a simple diode with an exponential characteristic. The diode formula essentially is: <p>

<b>f = IS*(exp(e/Vt) - 1)</b> <p>

However, if the exponent <b>e/Vt</b> reaches either an upper limit <b>EMax</b> or a lower limit <b>Emin</b>, the diode characterisic is linearly continued to avoid overflow or underflow, respectively. Furthermore, both the thermal voltage, <b>Vt</b>, as well as the saturation current, <b>IS</b>, depend on the current device temperature. <p>

<hr>

<pre>
Potential variables:

 e1:      Bondgraphic effort variable of inflow

 f1:      Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:      Bondgraphic effort variable of outflow

 f2:      Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 Vt:      Thermal voltage

 ISval:   Saturation current at device temperature

 EGval:   Activation energy at device temperature


Parameters:

 Tnom:    Reference temperature (default value = 300.15 K)

 IS:      Saturation current at reference temperature (default value = 1e-6 Amp)

 EG:      Activation energy at reference temperature (default value = 1.16 Volt)

 N:       Emission coefficient (default value = 1)

 XTI:     Temperature exponent of saturation current (default value = 3)

 Area:    Relative area occupied by the diode (default value = 1)

 EMin:    if x < EMin, the exp(x) function is linearized (default value = -100)

 EMax:    if x > EMax, the exp(x) function is linearized (default value = 40)
</pre> <p>

<hr> <p>

Equations: <p>

<b>Vt = k*e2/q</b> <br>
<b>RTemp = e2/Tnom</b> <br>
<b>EGval = EG - GapC1*e2*e2/(e2 + GapC2)</b> <br>
<b>ISval = IS*exp((RTemp - 1)*EGval/(Vt*N) + (XTI/N)*ln(RTemp))</b> <br>
<b>ExMin = exp(EMin)</b> <br>
<b>ExMax = exp(EMax)</b> <br>
<b>et = e1/(Vt*N)</b> <br>
<b>f1 = ISval*Area*(if et &lt; EMin then ExMin*(et - EMin + 1) - 1 else 
                    if et &gt; EMax then ExMax*(et - EMax + 1) - 1 else exp(et) - 1)</b> <br>
<b>f2 = (e1/e2)*f1</b></html>
"));
        equation 
          /* Compute thermal voltage as function of temperature */
          Vt = k*e2/q;
      
          /* Compute temperature dependence of saturation current */
          RTemp = e2/Tnom;
          EGval = EG - GapC1*e2*e2/(e2 + GapC2);
          ISval = IS*exp((RTemp - 1)*EGval/(Vt*N) + (XTI/N)*ln(RTemp));
      
          /* Compute diode characteristic */
          ExMin = exp(EMin);
          ExMax = exp(EMax);
          et = e1/(Vt*N);
          f1 = ISval*Area*(if et < EMin then ExMin*(et - EMin + 1) - 1 else 
                           if et > EMax then ExMax*(et - EMax + 1) - 1 else exp(et) - 1);
      
          /* Compute heat flow */
          f1*e1 = f2*e2;
        end DS;
    
      model NPNlat "Spice-style laterally diffused NPN bipolar transistor" 
        /* DC model parameters */
        parameter Real BF=50 
        "Forward beta coefficient at reference temperature";
        parameter Real BR=0.1 
        "Reverse beta coefficient at reference temperature";
        parameter Modelica.SIunits.Current IS=1e-16 
        "Saturation current at reference temperature";
        parameter Modelica.SIunits.Current ISS=1e-16 
        "Saturation current of substrate diode at reference temperature";
        parameter Real NF=1 "Forward emission coefficient";
        parameter Real NR=1 "Reverse emission coefficient";
        parameter Real NS=1 "Emission coefficient of substrate diode";
        parameter Modelica.SIunits.Conductance GminDC=1e-15 
        "Leakage conductance";
      
        /* Low current beta degradation effect parameters */
        parameter Modelica.SIunits.Current ISC=1e-16 
        "Collector saturation current at reference temperature";
        parameter Modelica.SIunits.Current ISE=1e-16 
        "Emitter saturation current at reference temperature";
        parameter Real NC=2 "Collector beta degradation coefficient";
        parameter Real NE=1.5 "Emitter beta degradation coefficient";
      
        /* Base width modulation parameters */
        parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
        parameter Modelica.SIunits.Voltage VAR=9e30 "Reverse early voltage";
      
        /* High current beta degradation effect parameters */
        parameter Modelica.SIunits.Current IKF=9e30 
        "Forward junction beta degradation current";
        parameter Modelica.SIunits.Current IKR=9e30 
        "Reverse junction beta degradation current";
      
        /* Parasitic Resistor Parameters */
        parameter Modelica.SIunits.Current IRB=0 
        "Parasitic base resistor current";
        parameter Modelica.SIunits.Resistance RB=0 
        "Parasitic base resistance value";
        parameter Modelica.SIunits.Resistance RBM=0 
        "Parasitic modified base resistance value";
        parameter Modelica.SIunits.Resistance RC=0 
        "Parasitic collector resistance value";
        parameter Modelica.SIunits.Resistance RE=0 
        "Parasitic emitter resistance value";
      
        /* Junction capacitor parameters */
        parameter Modelica.SIunits.Capacitance CJC=0.5e-12 
        "Base-collector zero bias depletion capacitance at reference temperature";
        parameter Real MJC=0.333 "Base-collector gradation exponent";
        parameter Modelica.SIunits.Voltage VJC=0.8 
        "Base-collector diffusion voltage at reference temperature";
        parameter Modelica.SIunits.Capacitance CJE=0.4e-12 
        "Base-emitter zero bias depletion capacitance at reference temperature";
        parameter Real MJE=0.4 "Base-emitter gradation exponent";
        parameter Modelica.SIunits.Voltage VJE=0.8 
        "Base-emitter diffusion voltage at reference temperature";
        parameter Modelica.SIunits.Capacitance CJS=0.4e-12 
        "Substrate zero bias depletion capacitance at reference temperature";
        parameter Real MJS=0.4 "Substrate gradation exponent";
        parameter Modelica.SIunits.Voltage VJS=0.8 
        "Substrate diffusion voltage at reference temperature";
        parameter Real XCJC=1 
        "Portion of depletion capacitance considered inside base-collector junction";
      
        /* Transit time parameters */
        parameter Modelica.SIunits.Time TF=0.12e-9 "Ideal forward transit time";
        parameter Modelica.SIunits.Time TR=5e-9 "Ideal reverse transit time";
      
        /* Temperature compensation and area parameters */
        parameter Real TRB1=0 
        "Linear temperature coefficient of base resistance [Ohm/degree]";
        parameter Real TRB2=0 
        "Quadratic temperature coefficient of base resistance [Ohm/(degree*degree)]";
        parameter Real TRM1=0 
        "Linear temperature coefficient of modified base resistance [Ohm/degree]";
        parameter Real TRM2=0 
        "Quadratic temperature coefficient of modified base resistance [Ohm/(degree*degree)]";
        parameter Real TRC1=0 
        "Linear temperature coefficient of collector resistance [Ohm/degree]";
        parameter Real TRC2=0 
        "Quadratic temperature coefficient of collector resistance [Ohm/(degree*degree)]";
        parameter Real TRE1=0 
        "Linear temperature coefficient of emitter resistance [Ohm/degree]";
        parameter Real TRE2=0 
        "Quadratic temperature coefficient of emitter resistance [Ohm/(degree*degree)]";
        parameter Modelica.SIunits.Temperature Tnom=300.15 
        "Reference temperature";
        parameter Real XTI=3 "Temperature exponent of saturation current";
        parameter Real XTB=0 "Temperature ratio exponent";
        parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
        parameter Real Area=1 "Relative area occupied by device";
      
        /* Substrate parameters */
        parameter Modelica.SIunits.Voltage VS=0 "Substrate potential";
      
        /* Numerical parameters */
        parameter Real EMin=-100 
        "if x < EMin, the exp(x) function is linearized";
        parameter Real EMax=40 "if x > EMax, the exp(x) function is linearized";
      annotation (Coordsys(extent=[-120,-120; 120,120]), Diagram(
          Text(
            extent=[-126,22; -114,8],
            string="B",
            style(color=10, rgbcolor={95,95,95})),
          Text(
            extent=[-20,128; -8,114],
            style(color=10, rgbcolor={95,95,95}),
            string="C"),
          Text(
            extent=[-20,-114; -8,-128],
            style(color=10, rgbcolor={95,95,95}),
            string="E"),
          Text(
            extent=[108,-6; 134,-22],
            style(color=10, rgbcolor={95,95,95}),
            string="Heat"),
          Text(
            extent=[78,50; 104,34],
            style(color=10, rgbcolor={95,95,95}),
            string="Heat"),
          Text(
            extent=[42,-34; 52,-46],
            style(color=10, rgbcolor={95,95,95}),
            string="qb"),
          Text(
            extent=[-28,66; -18,54],
            style(color=10, rgbcolor={95,95,95}),
            string="qb")),
        Icon(
          Text(
            extent=[-126,24; -114,10],
            string="B",
            style(color=10, rgbcolor={95,95,95})),
          Text(
            extent=[10,126; 22,112],
            style(color=10, rgbcolor={95,95,95}),
            string="C"),
          Text(
            extent=[8,-114; 20,-128],
            style(color=10, rgbcolor={95,95,95}),
            string="E"),
          Text(
            extent=[106,26; 132,6],
            style(color=10, rgbcolor={95,95,95}),
            string="Heat"),
            Text(
              extent=[-96,84; 68,-92],
              style(color=0),
              string="NPN"),
            Text(
              extent=[62,4; 102,-38],
              style(color=0),
            string="lat"),
            Line(points=[0,100; 0,-100],
                                       style(
                color=9,
                rgbcolor={149,164,171},
                thickness=2,
                fillColor=74,
                rgbfillColor={0,0,185},
                fillPattern=1)),
            Line(points=[0,-100; 20,-80],style(
                color=9,
                rgbcolor={149,164,171},
                thickness=2,
                fillColor=74,
                rgbfillColor={0,0,185},
                fillPattern=1)),
            Line(points=[-20,-80; 0,-100],style(
                color=9,
                rgbcolor={149,164,171},
                thickness=2,
                fillColor=74,
                rgbfillColor={0,0,185},
                fillPattern=1)),
          Line(points=[-100,-60; 100,-60], style(color=3, rgbcolor={0,0,255})),
          Line(points=[80,-80; 100,-60], style(color=3, rgbcolor={0,0,255})),
          Line(points=[80,-40; 100,-60], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-80,100; 80,60],
            style(color=3, rgbcolor={0,0,255}),
            string="%name"),
          Text(
            extent=[-88,-72; -44,-108],
            string="%Area x",
            style(color=3, rgbcolor={0,0,255}))),
        Documentation(info="<html>
The <b>NPNlat</b> element of the Spice bond graph library implements a full-fledges Spice-stye model of the laterally diffused NPN bipolar transistor [1-3]. The model contains a <b>NPNint</b> model implementing the inner parts of the NPN transistor up to the internal nodes. <p>

The NPN bipolar transistor is a directed FourPort.  The direction of positive power flow is assumed into the model at the base, <b>B</b>, and at the collector, <b>C</b>, whereas it is assumed out of the model at the emitter, <b>E</b>, and at the <b>Heat</b> port. <p>

The causality of the NPN model is free. <p>

<hr>

<pre>
<b>DC Model Parameters:</b>

 BF:      Forward beta coefficient (default value = 50)

 BR:      Reverse beta coefficient (default value = 0.1)

 IS:      Transport saturation current (default value = 1e-16 Amp)

 ISS:     Transport saturation current of substrate diode (default value = 1e-16 Amp)

 NF:      Forward emission coefficient (default value = 1)

 NR:      Reverse emission coefficient (default value = 1)

 NS:      Emission coefficient of substrate diode (default value = 1)

 GminDC:  Junction leakage conductance (default value = 1e-15 Mho)


<b>Low Current Beta Degradation Effect Parameters:</b>

 ISC:     Collector saturation current at reference temperature (default value = 1e-16 Amp)

 ISE:     Emitter saturation current at reference temperature (default value = 1e-16 Amp)

 NC:      Collector beta degradation coefficient (default value = 2)

 NE:      Emitter beta degradation coefficient (default value = 1.5)


<b>Base Width Modulation Parameters:</b>
  
 VAF:     Forward early voltage (default value = 9e30 Volt)

 VAR:     Reverse early voltage (default value = 9e30 Volt)


<b>High Current Beta Degradation Effect Parameters:</b>

 IKF:     Forward junction beta degradation current (default value = 9e30 Amp)

 IKR:     Reverse junction beta degradation current (default value = 9e30 Amp)


<b>Parasitic Resistor Parameters:</b>

 IRB:     Parasitic base resistor current (default value = 0 Amp)

 RB:      Parasitic base resistance value (default value = 0 Ohm)

 RBM:     Parasitic modified base resistance value (default value = 0 Ohm)

 RC:      Parasitic collector resistance value (default value = 0 Ohm)

 RE:      Parasitic emitter resistance value (default value = 0 Ohm)


<b>Junction Capacitor Parameters:</b>

 CJC:     Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 MJC:     Base-collector gradation exponent (default value = 0.333)

 VJC:     Base-collector diffusion voltage (default value = 0.8 Volt)

 CJE:     Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 MJE:     Base-emitter gradation exponent (default value = 0.4)

 VJE:     Base-emitter diffusion voltage (default value = 0.8 Volt)

 CJS:     Substrate zero bias depletion capacitance (default value = 0.4e-12 F)

 MJS:     Substrate gradation exponent (default value = 0.4)

 VJS:     Substrate diffusion voltage (default value = 0.8 Volt)

 XCJC:    Portion of depletion capacitance considered inside base-collector junction (default value = 1)


<b>Transit Time Parameters:</b>

 TF:      Ideal forward transit time (default value = 0.12e-9 sec)

 TR:      Ideal reverse transit time (default value = 5e-9 sec)


<b>Temperature Compensation and Area Parameters:</b>

 TRB1:    Linear temperature coefficient of base resistance (default value = 0 Ohm/degree)

 TRB2:    Quadratic temperature coefficient of base resistance (default value = 0 Ohm/(degree*degree))

 TRM1:    Linear temperature coefficient of modified base resistance (default value = 0 Ohm/degree)

 TRM2:    Quadratic temperature coefficient of modified base resistance (default value = 0 Ohm/(degree*degree))

 TRC1:    Linear temperature coefficient of collector resistance (default value = 0 Ohm/degree)

 TRC2:    Quadratic temperature coefficient of collector resistance (default value = 0 Ohm/(degree*degree))

 TRE1:    Linear temperature coefficient of emitter resistance (default value = 0 Ohm/degree)

 TRE2:    Quadratic temperature coefficient of emitter resistance (default value = 0 Ohm/(degree*degree))

 Tnom:    Reference temperature (default value = 300.15 <sup>o</sup>K)

 XTI:     Temperature exponent of saturation current (default value = 3)

 XTB:     Temperature ratio exponent (default value = 0)

 EG:      Activation energy (default value = 1.16 Volt)

 Area:    Relative area occupied by device (default value = 1)


<b>Substrate parameters:</b>

 VS:      Substrate potential (default value = 0 Volt)

  
<b>Numerical Parameters:</b>

 EMin:    Minimum exponent (default value = -100)

 EMax:    Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li>Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York.
<li>Hild, D.R. and F.E. Cellier (1994), \"Object-oriented electronic circuit modeling using Dymola,\"
    <i>Proc. OOS'94, SCS Object Oriented Simulation Conference</i>, Tempe, AZ, pp.68-75.
<li>Hild, D.R. (1993), <i>Circuit Modeling in Dymola</i>, MS Thesis, Dept. of Electr. &amp; Comp. Engr.,
    University of Arizona, Tucson.
<li>Schweisguth, M.C. and F.E. Cellier (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/BJT.pdf\">A
    bond graph model of the bipolar junction transistor</a>,\" <i>Proc. SCS Intl. Conf. on Bond Graph Modeling</i>,
    San Francisco, CA, pp.344-349.
<li>Schweisguth, M.C. (1997), <a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/schweisguth_ms.pdf\"><i>Semiconductor
    Modeling with Bondgraphs</i></a>, MS Thesis, Dept. of Electr. &amp; Comp. Engr., University of Arizona, Tucson.
</ol> 
</html>
"));
      BondLib.Interfaces.BondCon BondCon1 
        annotation (extent=[-130,-10; -110,10]);
      BondLib.Interfaces.BondCon BondCon2 
        annotation (extent=[-10,-130; 10,-110]);
      BondLib.Interfaces.BondCon BondCon3 annotation (extent=[110,-10; 130,10]);
      BondLib.Interfaces.BondCon BondCon4 annotation (extent=[-10,110; 10,130]);
      BondLib.Spice.Utilities.NPNint NPNint1(
        BF=BF,
        BR=BR,
        IS=IS,
        NF=NF,
        NR=NR,
        GminDC=GminDC,
        ISC=ISC,
        ISE=ISE,
        NC=NC,
        NE=NE,
        VAF=VAF,
        VAR=VAR,
        IKF=IKF,
        IKR=IKR) annotation (extent=[0,-40; 40,0]);
      BondLib.Bonds.Bond B1 annotation (extent=[-20,-30; 0,-10], rotation=0);
      BondLib.Junctions.J0p3 J0p3_1 
        annotation (extent=[-40,-30; -20,-10], rotation=90);
      BondLib.Bonds.Bond B2 annotation (extent=[-50,-10; -30,10], rotation=0);
      BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-70,10; -50,-10]);
      BondLib.Bonds.Bond B3 annotation (extent=[-90,-10; -70,10], rotation=0);
      BondLib.Bonds.Bond B4 annotation (extent=[-70,10; -50,30], rotation=90);
      BondLib.Spice.Utilities.RBS RB1(
        Tnom=Tnom,
        RB=RB,
        RBM=RBM,
        IRB=IRB,
        TRB1=TRB1,
        TRB2=TRB2,
        TRM1=TRM1,
        TRM2=TRM2,
        Area=Area) annotation (extent=[-60,30; -20,50], rotation=0);
      BondLib.Bonds.eBond B5 annotation (extent=[-20,30; 0,50]);
      BondLib.Bonds.Bond B6 annotation (extent=[-50,-50; -30,-30], rotation=180);
      BondLib.Junctions.J1p3 J1p3_2 annotation (extent=[-70,-50; -50,-30]);
      BondLib.Bonds.Bond B7 annotation (extent=[-90,-50; -70,-30], rotation=180);
      BondLib.Junctions.J0p2 J0p2_2 
        annotation (extent=[-110,-68; -90,-48], rotation=90);
      BondLib.Bonds.fBond B8 
        annotation (extent=[-110,-88; -90,-68], rotation=90);
      BondLib.Sources.Se VS1(e0=VS) 
        annotation (extent=[-110,-114; -90,-88], rotation=-90);
      BondLib.Bonds.Bond B9 annotation (extent=[-70,-70; -50,-50], rotation=270);
      BondLib.Spice.Utilities.DjS DS1(
        Tnom=Tnom,
        IS=ISS,
        EG=EG,
        N=NS,
        XTI=XTI,
        VJ=VJS,
        CJ=CJS,
        XCJ=1,
        MJ=MJS,
        GminDC=GminDC,
        Area=Area,
        BE=false,
        Tau=0,
        EMin=EMin,
        EMax=EMax) annotation (extent=[-60,-90; -20,-70]);
      BondLib.Bonds.eBond B10 annotation (extent=[-20,-90; 0,-70]);
      Modelica.Blocks.Sources.Constant C01(k=0) 
        annotation (extent=[-14,-106; -26,-94]);
      Modelica.Blocks.Sources.Constant qb1(k=1) 
        annotation (extent=[-66,-106; -54,-94]);
      BondLib.Bonds.Bond B11 annotation (extent=[10,40; 30,60], rotation=270);
      BondLib.Junctions.J1p3 J1p3_3 
        annotation (extent=[30,80; 10,60], rotation=-90);
      BondLib.Bonds.Bond B12 annotation (extent=[10,80; 30,100], rotation=270);
      BondLib.Junctions.J0p2 J0p2_3 
        annotation (extent=[10,100; 30,120], rotation=90);
      BondLib.Bonds.Bond B13 annotation (extent=[30,60; 50,80], rotation=0);
      BondLib.Spice.RS RC1(
        Tnom=Tnom,
        R=RC,
        TR1=TRC1,
        TR2=TRC2,
        Area=Area) annotation (extent=[50,60; 90,80]);
      BondLib.Bonds.eBond B14 annotation (extent=[90,60; 110,80], rotation=0);
      BondLib.Bonds.Bond B15 annotation (extent=[10,-60; 30,-40], rotation=270);
      BondLib.Junctions.J1p3 J1p3_4 
        annotation (extent=[30,-60; 10,-80], rotation=-90);
      BondLib.Bonds.Bond B16 annotation (extent=[10,-100; 30,-80], rotation=270);
      BondLib.Junctions.J0p2 J0p2_4 
        annotation (extent=[10,-120; 30,-100], rotation=90);
      BondLib.Bonds.Bond B17 annotation (extent=[30,-80; 50,-60], rotation=0);
      BondLib.Spice.RS RE1(
        Tnom=Tnom,
        Area=Area,
        R=RE,
        TR1=TRE1,
        TR2=TRE2) annotation (extent=[50,-80; 90,-60]);
      BondLib.Bonds.eBond B18 annotation (extent=[90,-80; 110,-60], rotation=0);
      BondLib.Bonds.eBond B19 annotation (extent=[40,-30; 60,-10]);
      BondLib.Junctions.J0p6 J0p6_1 annotation (extent=[60,20; 80,40]);
      BondLib.Bonds.Bond B20 annotation (extent=[10,0; 30,20], rotation=270);
      BondLib.Junctions.J0p3 J0p3_2 
        annotation (extent=[10,20; 30,40], rotation=90);
      BondLib.Junctions.J0p3 J0p3_3 
        annotation (extent=[-110,-10; -90,10], rotation=180);
      BondLib.Bonds.Bond B21 annotation (extent=[-110,10; -90,30], rotation=90);
      BondLib.Junctions.J1p3 J1p3_5 
        annotation (extent=[-110,30; -90,50], rotation=90);
      BondLib.Bonds.Bond B22 annotation (extent=[-110,50; -90,70], rotation=90);
      BondLib.Bonds.Bond B23 annotation (extent=[-90,50; -70,70], rotation=90);
      Utilities.CbxS Cbx1(
        Tnom=Tnom,
        EG=EG,
        VJ=VJC,
        CJ=CJC,
        XCJ=XCJC,
        MJ=MJC,
        Area=Area) annotation (extent=[-80,70; -40,90], rotation=0);
      BondLib.Bonds.eBond B24 annotation (extent=[-40,70; -20,90]);
      BondLib.Bonds.eBond B25 annotation (extent=[80,20; 100,40]);
      BondLib.Junctions.J0p3 J0p3_4 
        annotation (extent=[100,20; 120,40], rotation=180);
      equation 
      connect(B2.BondCon2, J0p3_1.BondCon2) annotation (points=[-30,0; -30,-10],
          style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_1.BondCon2, B2.BondCon1) annotation (points=[-50,0; -49.8,0],
          style(color=8, rgbcolor={192,192,192}));
      connect(B3.BondCon2, J1p3_1.BondCon1) annotation (points=[-70,0; -70,0],
          style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_1.BondCon3, B4.BondCon1) annotation (points=[-60,10; -60,
            10.2], style(color=8, rgbcolor={192,192,192}));
      connect(RB1.BondCon1, B4.BondCon2) annotation (points=[-60,40; -60,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(RB1.BondCon2, B5.fBondCon1) annotation (points=[-20,40; -20,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_1.BondCon1, B6.BondCon1) annotation (points=[-30,-30; -30,
            -40; -30.2,-40], style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_2.BondCon2, B6.BondCon2) annotation (points=[-50,-40; -50,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(B7.BondCon1, J1p3_2.BondCon1) annotation (points=[-70.2,-40; -70,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(J0p2_2.BondCon2, B7.BondCon2) annotation (points=[-100,-48; -100,
            -40; -90,-40], style(color=8, rgbcolor={192,192,192}));
      connect(B8.fBondCon1, J0p2_2.BondCon1) annotation (points=[-100,-68; -100,
            -68], style(color=8, rgbcolor={192,192,192}));
      connect(VS1.BondCon1, B8.eBondCon1) annotation (points=[-100,-88; -100,
            -88], style(color=8, rgbcolor={192,192,192}));
      connect(B9.BondCon1, J1p3_2.BondCon3) annotation (points=[-60,-50.2; -60,
            -50], style(color=8, rgbcolor={192,192,192}));
      connect(B9.BondCon2, DS1.BondCon1) annotation (points=[-60,-70; -60,-80],
          style(color=8, rgbcolor={192,192,192}));
      connect(DS1.BondCon2, B10.fBondCon1) annotation (points=[-20,-80; -20,-80],
          style(color=8, rgbcolor={192,192,192}));
      connect(C01.y, DS1.C0) annotation (points=[-26.6,-100; -32,-100; -32,-90],
          style(color=74, rgbcolor={0,0,127}));
      connect(qb1.y, DS1.qb) annotation (points=[-53.4,-100; -48,-100; -48,-90],
          style(color=74, rgbcolor={0,0,127}));
      connect(J1p3_3.BondCon1, B11.BondCon1) annotation (points=[20,60; 20,59.9; 
            20,59.8; 20,59.8], style(color=8, rgbcolor={192,192,192}));
      connect(B12.BondCon2, J1p3_3.BondCon2) annotation (points=[20,80; 20,80],
          style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_3.BondCon3, B13.BondCon1) annotation (points=[30,70; 30.2,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B13.BondCon2, RC1.BondCon1) annotation (points=[50,70; 50,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(NPNint1.BondCon2, B15.BondCon1) annotation (points=[20,-40; 20,
            -40.1; 20,-40.2; 20,-40.2], style(color=8, rgbcolor={192,192,192}));
      connect(B15.BondCon2, J1p3_4.BondCon2) annotation (points=[20,-60; 20,-60],
          style(color=8, rgbcolor={192,192,192}));
      connect(B16.BondCon1, J1p3_4.BondCon1) annotation (points=[20,-80.2; 20,
            -80.1; 20,-80.1; 20,-80], style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_4.BondCon3, B17.BondCon1) annotation (points=[30,-70; 30.2,
            -70], style(color=8, rgbcolor={192,192,192}));
      connect(B17.BondCon2, RE1.BondCon1) annotation (points=[50,-70; 50,-70],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p2_3.BondCon1, B12.BondCon1) annotation (points=[20,100; 20,
            99.9; 20,99.8; 20,99.8], style(color=8, rgbcolor={192,192,192}));
      connect(B16.BondCon2, J0p2_4.BondCon2) annotation (points=[20,-100; 20,
            -100], style(color=8, rgbcolor={192,192,192}));
      connect(J0p2_4.BondCon1, BondCon2) annotation (points=[20,-120; 0,-120],
          style(color=8, rgbcolor={192,192,192}));
      connect(NPNint1.BondCon3, B19.fBondCon1) annotation (points=[40,-20; 40,
            -20], style(color=8, rgbcolor={192,192,192}));
      connect(B20.BondCon2, NPNint1.BondCon4) annotation (points=[20,0; 20,0],
          style(color=8, rgbcolor={192,192,192}));
      connect(B11.BondCon2, J0p3_2.BondCon2) annotation (points=[20,40; 20,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_2.BondCon1, B20.BondCon1) annotation (points=[20,20; 20,19.9; 
            20,19.8; 20,19.8], style(color=8, rgbcolor={192,192,192}));
      connect(J0p2_3.BondCon2, BondCon4) annotation (points=[20,120; 0,120],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_3.BondCon2, BondCon1) annotation (points=[-110,1.22461e-015; 
            -116,1.22461e-015; -114,0; -120,0], style(color=8, rgbcolor={192,
              192,192}));
      connect(J0p3_3.BondCon1, B3.BondCon1) annotation (points=[-90,
            -1.22461e-015; -90,0; -89.8,0], style(color=8, rgbcolor={192,192,
              192}));
      connect(J0p3_3.BondCon3, B21.BondCon1) annotation (points=[-100,10; -100,
            10.2], style(color=8, rgbcolor={192,192,192}));
      connect(B21.BondCon2, J1p3_5.BondCon1) annotation (points=[-100,30; -100,
            30], style(color=8, rgbcolor={192,192,192}));
      connect(B22.BondCon1, J1p3_5.BondCon2) annotation (points=[-100,50.2;
            -100,50], style(color=8, rgbcolor={192,192,192}));
      connect(B23.BondCon1, J1p3_5.BondCon3) annotation (points=[-80,50.2; -80,
            40; -90,40], style(color=8, rgbcolor={192,192,192}));
      connect(RC1.BondCon2, B14.fBondCon1) annotation (points=[90,70; 90,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(RE1.BondCon2, B18.fBondCon1) annotation (points=[90,-70; 90,-70],
          style(color=8, rgbcolor={192,192,192}));
      connect(Cbx1.BondCon1, B23.BondCon2) annotation (points=[-80,80; -80,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(Cbx1.BondCon2, B24.fBondCon1) annotation (points=[-40,80; -40,80],
          style(color=8, rgbcolor={192,192,192}));
      connect(B22.BondCon2, J0p3_2.BondCon3) annotation (points=[-100,70; -100,
            94; 40,94; 40,30; 30,30], style(color=8, rgbcolor={192,192,192}));
      connect(J0p6_1.BondCon2, B25.fBondCon1) annotation (points=[80,30; 80,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(B25.eBondCon1, J0p3_4.BondCon2) annotation (points=[100,30; 100,
            30], style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_4.BondCon1, BondCon3) annotation (points=[120,30; 120,0],
          style(color=8, rgbcolor={192,192,192}));
      connect(B14.eBondCon1, J0p3_4.BondCon3) annotation (points=[110,70; 110,
            40], style(color=8, rgbcolor={192,192,192}));
      connect(B19.eBondCon1, J0p6_1.BondCon1) annotation (points=[60,-20; 60,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(B5.eBondCon1, J0p6_1.BondCon5) annotation (points=[0,40; 0,48; 66,
            48; 66,40], style(color=8, rgbcolor={192,192,192}));
      connect(B24.eBondCon1, J0p6_1.BondCon6) annotation (points=[-20,80; 0,80;
            0,52; 74,52; 74,40], style(color=8, rgbcolor={192,192,192}));
      connect(B18.eBondCon1, J0p6_1.BondCon3) annotation (points=[110,-70; 110,
            -40; 66,-40; 66,20], style(color=8, rgbcolor={192,192,192}));
      connect(B10.eBondCon1, J0p6_1.BondCon4) annotation (points=[0,-80; 8,-80;
            8,-90; 114,-90; 114,-36; 74,-36; 74,20], style(color=8, rgbcolor={
              192,192,192}));
      connect(NPNint1.qb, RB1.qb) annotation (points=[41.4286,-33.4286; 52,
            -33.4286; 52,-48; -10,-48; -10,56; -40,56; -40,50], style(color=74,
            rgbcolor={0,0,127}));
      connect(B1.BondCon1, J0p3_1.BondCon3) annotation (points=[-19.8,-20; -20,
            -20], style(color=8, rgbcolor={192,192,192}));
      connect(B1.BondCon2, NPNint1.BondCon1) annotation (points=[0,-20; 0,-20],
          style(color=8, rgbcolor={192,192,192}));
      end NPNlat;
    
      model NPNvert "Spice-style vertically diffused NPN bipolar transistor" 
        /* DC model parameters */
        parameter Real BF=50 
        "Forward beta coefficient at reference temperature";
        parameter Real BR=0.1 
        "Reverse beta coefficient at reference temperature";
        parameter Modelica.SIunits.Current IS=1e-16 
        "Saturation current at reference temperature";
        parameter Modelica.SIunits.Current ISS=1e-16 
        "Saturation current of substrate diode at reference temperature";
        parameter Real NF=1 "Forward emission coefficient";
        parameter Real NR=1 "Reverse emission coefficient";
        parameter Real NS=1 "Emission coefficient of substrate diode";
        parameter Modelica.SIunits.Conductance GminDC=1e-15 
        "Leakage conductance";
      
        /* Low current beta degradation effect parameters */
        parameter Modelica.SIunits.Current ISC=1e-16 
        "Collector saturation current at reference temperature";
        parameter Modelica.SIunits.Current ISE=1e-16 
        "Emitter saturation current at reference temperature";
        parameter Real NC=2 "Collector beta degradation coefficient";
        parameter Real NE=1.5 "Emitter beta degradation coefficient";
      
        /* Base width modulation parameters */
        parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
        parameter Modelica.SIunits.Voltage VAR=9e30 "Reverse early voltage";
      
        /* High current beta degradation effect parameters */
        parameter Modelica.SIunits.Current IKF=9e30 
        "Forward junction beta degradation current";
        parameter Modelica.SIunits.Current IKR=9e30 
        "Reverse junction beta degradation current";
      
        /* Parasitic Resistor Parameters */
        parameter Modelica.SIunits.Current IRB=0 
        "Parasitic base resistor current";
        parameter Modelica.SIunits.Resistance RB=0 
        "Parasitic base resistance value";
        parameter Modelica.SIunits.Resistance RBM=0 
        "Parasitic modified base resistance value";
        parameter Modelica.SIunits.Resistance RC=0 
        "Parasitic collector resistance value";
        parameter Modelica.SIunits.Resistance RE=0 
        "Parasitic emitter resistance value";
      
        /* Junction capacitor parameters */
        parameter Modelica.SIunits.Capacitance CJC=0.5e-12 
        "Base-collector zero bias depletion capacitance at reference temperature";
        parameter Real MJC=0.333 "Base-collector gradation exponent";
        parameter Modelica.SIunits.Voltage VJC=0.8 
        "Base-collector diffusion voltage at reference temperature";
        parameter Modelica.SIunits.Capacitance CJE=0.4e-12 
        "Base-emitter zero bias depletion capacitance at reference temperature";
        parameter Real MJE=0.4 "Base-emitter gradation exponent";
        parameter Modelica.SIunits.Voltage VJE=0.8 
        "Base-emitter diffusion voltage at reference temperature";
        parameter Modelica.SIunits.Capacitance CJS=0.4e-12 
        "Substrate zero bias depletion capacitance at reference temperature";
        parameter Real MJS=0.4 "Substrate gradation exponent";
        parameter Modelica.SIunits.Voltage VJS=0.8 
        "Substrate diffusion voltage at reference temperature";
        parameter Real XCJC=1 
        "Portion of depletion capacitance considered inside base-collector junction";
      
        /* Transit time parameters */
        parameter Modelica.SIunits.Time TF=0.12e-9 "Ideal forward transit time";
        parameter Modelica.SIunits.Time TR=5e-9 "Ideal reverse transit time";
      
        /* Temperature compensation and area parameters */
        parameter Real TRB1=0 
        "Linear temperature coefficient of base resistance [Ohm/degree]";
        parameter Real TRB2=0 
        "Quadratic temperature coefficient of base resistance [Ohm/(degree*degree)]";
        parameter Real TRM1=0 
        "Linear temperature coefficient of modified base resistance [Ohm/degree]";
        parameter Real TRM2=0 
        "Quadratic temperature coefficient of modified base resistance [Ohm/(degree*degree)]";
        parameter Real TRC1=0 
        "Linear temperature coefficient of collector resistance [Ohm/degree]";
        parameter Real TRC2=0 
        "Quadratic temperature coefficient of collector resistance [Ohm/(degree*degree)]";
        parameter Real TRE1=0 
        "Linear temperature coefficient of emitter resistance [Ohm/degree]";
        parameter Real TRE2=0 
        "Quadratic temperature coefficient of emitter resistance [Ohm/(degree*degree)]";
        parameter Modelica.SIunits.Temperature Tnom=300.15 
        "Reference temperature";
        parameter Real XTI=3 "Temperature exponent of saturation current";
        parameter Real XTB=0 "Temperature ratio exponent";
        parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
        parameter Real Area=1 "Relative area occupied by device";
      
        /* Substrate parameters */
        parameter Modelica.SIunits.Voltage VS=0 "Substrate potential";
      
        /* Numerical parameters */
        parameter Real EMin=-100 
        "if x < EMin, the exp(x) function is linearized";
        parameter Real EMax=40 "if x > EMax, the exp(x) function is linearized";
      BondLib.Interfaces.BondCon BondCon1 
        annotation (extent=[-130,-10; -110,10]);
      BondLib.Interfaces.BondCon BondCon2 
        annotation (extent=[-10,-130; 10,-110]);
      BondLib.Interfaces.BondCon BondCon3 annotation (extent=[110,-10; 130,10]);
      BondLib.Interfaces.BondCon BondCon4 annotation (extent=[-10,110; 10,130]);
      BondLib.Spice.Utilities.NPNint NPNint1(
        BF=BF,
        BR=BR,
        IS=IS,
        NF=NF,
        NR=NR,
        GminDC=GminDC,
        ISC=ISC,
        ISE=ISE,
        NC=NC,
        NE=NE,
        VAF=VAF,
        VAR=VAR,
        IKF=IKF,
        IKR=IKR) annotation (extent=[0,-40; 40,0]);
      BondLib.Bonds.Bond B2 annotation (extent=[-50,-10; -30,10], rotation=0);
      BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-70,-10; -50,10]);
      BondLib.Bonds.Bond B3 annotation (extent=[-90,-10; -70,10], rotation=0);
      BondLib.Bonds.Bond B4 annotation (extent=[-70,-30; -50,-10], rotation=270);
      BondLib.Spice.Utilities.RBS RB1(
        Tnom=Tnom,
        RB=RB,
        RBM=RBM,
        IRB=IRB,
        TRB1=TRB1,
        TRB2=TRB2,
        TRM1=TRM1,
        TRM2=TRM2,
        Area=Area) annotation (extent=[-60,-50; -20,-30], rotation=0);
      BondLib.Bonds.eBond B5 annotation (extent=[-20,-50; 0,-30]);
      BondLib.Junctions.J1p3 J1p3_2 annotation (extent=[50,40; 70,20]);
      BondLib.Bonds.Bond B7 annotation (extent=[30,20; 50,40], rotation=180);
      BondLib.Sources.Se VS1(e0=VS) 
        annotation (extent=[90,20; 114,40], rotation=0);
      BondLib.Bonds.Bond B9 annotation (extent=[50,40; 70,60], rotation=90);
      BondLib.Spice.Utilities.DjS DS1(
        Tnom=Tnom,
        IS=ISS,
        EG=EG,
        N=NS,
        XTI=XTI,
        VJ=VJS,
        CJ=CJS,
        XCJ=1,
        MJ=MJS,
        GminDC=GminDC,
        Area=Area,
        BE=false,
        Tau=0,
        EMin=EMin,
        EMax=EMax) annotation (extent=[80,60; 120,80]);
      BondLib.Bonds.eBond B10 annotation (extent=[110,80; 130,100], rotation=90);
      Modelica.Blocks.Sources.Constant C01(k=0) 
        annotation (extent=[126,44; 114,56]);
      Modelica.Blocks.Sources.Constant qb1(k=1) 
        annotation (extent=[74,44; 86,56]);
      BondLib.Bonds.Bond B11 annotation (extent=[10,40; 30,60], rotation=270);
      BondLib.Junctions.J1p3 J1p3_3 
        annotation (extent=[10,80; 30,60], rotation=-90);
      BondLib.Bonds.Bond B12 annotation (extent=[10,80; 30,100], rotation=270);
      BondLib.Junctions.J0p2 J0p2_3 
        annotation (extent=[10,100; 30,120], rotation=90);
      BondLib.Bonds.Bond B13 annotation (extent=[-10,60; 10,80], rotation=180);
      BondLib.Spice.RS RC1(
        Tnom=Tnom,
        R=RC,
        TR1=TRC1,
        TR2=TRC2,
        Area=Area) annotation (extent=[-10,60; -50,80]);
      BondLib.Bonds.eBond B14 annotation (extent=[-70,60; -50,80], rotation=180);
      BondLib.Bonds.Bond B15 annotation (extent=[10,-60; 30,-40], rotation=270);
      BondLib.Junctions.J1p3 J1p3_4 
        annotation (extent=[10,-60; 30,-80], rotation=-90);
      BondLib.Bonds.Bond B16 annotation (extent=[10,-100; 30,-80], rotation=270);
      BondLib.Junctions.J0p2 J0p2_4 
        annotation (extent=[10,-120; 30,-100], rotation=90);
      BondLib.Bonds.Bond B17 annotation (extent=[-10,-80; 10,-60], rotation=180);
      BondLib.Spice.RS RE1(
        Tnom=Tnom,
        Area=Area,
        R=RE,
        TR1=TRE1,
        TR2=TRE2) annotation (extent=[-10,-80; -50,-60]);
      BondLib.Bonds.eBond B18 
        annotation (extent=[-70,-80; -50,-60], rotation=180);
      BondLib.Bonds.eBond B19 annotation (extent=[40,-30; 60,-10]);
      BondLib.Junctions.J0p6 J0p6_1 annotation (extent=[60,-100; 80,-80]);
      BondLib.Bonds.Bond B20 annotation (extent=[10,0; 30,20], rotation=270);
      BondLib.Junctions.J0p3 J0p3_3 
        annotation (extent=[-110,-10; -90,10], rotation=180);
      BondLib.Bonds.Bond B21 annotation (extent=[-110,10; -90,30], rotation=90);
      BondLib.Junctions.J1p3 J1p3_5 
        annotation (extent=[-110,30; -90,50], rotation=90);
      BondLib.Bonds.Bond B22 annotation (extent=[-110,50; -90,70], rotation=90);
      BondLib.Bonds.Bond B23 annotation (extent=[-90,30; -70,50], rotation=0);
      BondLib.Spice.Utilities.CbxS Cbx1(
        Tnom=Tnom,
        EG=EG,
        VJ=VJC,
        CJ=CJC,
        XCJ=XCJC,
        MJ=MJC,
        Area=Area) annotation (extent=[-70,30; -30,50], rotation=0);
      BondLib.Bonds.eBond B24 annotation (extent=[-30,30; -10,50]);
      BondLib.Bonds.eBond B25 annotation (extent=[80,-100; 100,-80]);
      BondLib.Junctions.J0p3 J0p3_4 
        annotation (extent=[100,-100; 120,-80], rotation=180);
      annotation (
        Diagram(
          Text(
            extent=[-126,22; -114,8],
            string="B",
            style(color=10, rgbcolor={95,95,95})),
          Text(
            extent=[-20,128; -8,114],
            style(color=10, rgbcolor={95,95,95}),
            string="C"),
          Text(
            extent=[-20,-114; -8,-128],
            style(color=10, rgbcolor={95,95,95}),
            string="E"),
          Text(
            extent=[92,-6; 118,-22],
            style(color=10, rgbcolor={95,95,95}),
            string="Heat"),
          Text(
            extent=[82,-96; 108,-112],
            style(color=10, rgbcolor={95,95,95}),
            string="Heat"),
          Text(
            extent=[38,-34; 48,-46],
            style(color=10, rgbcolor={95,95,95}),
            string="qb"),
          Text(
            extent=[-38,-14; -28,-26],
            style(color=10, rgbcolor={95,95,95}),
            string="qb")),
        Coordsys(extent=[-120,-120; 120,120]),
        Documentation(info="<html>
The <b>NPNvert</b> element of the Spice bond graph library implements a full-fledges Spice-stye model of the vertically diffused NPN bipolar transistor [1-3]. The model contains a <b>NPNint</b> model implementing the inner parts of the NPN transistor up to the internal nodes. <p>

The NPN bipolar transistor is a directed FourPort.  The direction of positive power flow is assumed into the model at the base, <b>B</b>, and at the collector, <b>C</b>, whereas it is assumed out of the model at the emitter, <b>E</b>, and at the <b>Heat</b> port. <p>

The causality of the NPN model is free. <p>

<hr>

<pre>
<b>DC Model Parameters:</b>

 BF:      Forward beta coefficient (default value = 50)

 BR:      Reverse beta coefficient (default value = 0.1)

 IS:      Transport saturation current (default value = 1e-16 Amp)

 ISS:     Transport saturation current of substrate diode (default value = 1e-16 Amp)

 NF:      Forward emission coefficient (default value = 1)

 NR:      Reverse emission coefficient (default value = 1)

 NS:      Emission coefficient of substrate diode (default value = 1)

 GminDC:  Junction leakage conductance (default value = 1e-15 Mho)


<b>Low Current Beta Degradation Effect Parameters:</b>

 ISC:     Collector saturation current at reference temperature (default value = 1e-16 Amp)

 ISE:     Emitter saturation current at reference temperature (default value = 1e-16 Amp)

 NC:      Collector beta degradation coefficient (default value = 2)

 NE:      Emitter beta degradation coefficient (default value = 1.5)


<b>Base Width Modulation Parameters:</b>
  
 VAF:     Forward early voltage (default value = 9e30 Volt)

 VAR:     Reverse early voltage (default value = 9e30 Volt)


<b>High Current Beta Degradation Effect Parameters:</b>

 IKF:     Forward junction beta degradation current (default value = 9e30 Amp)

 IKR:     Reverse junction beta degradation current (default value = 9e30 Amp)


<b>Parasitic Resistor Parameters:</b>

 IRB:     Parasitic base resistor current (default value = 0 Amp)

 RB:      Parasitic base resistance value (default value = 0 Ohm)

 RBM:     Parasitic modified base resistance value (default value = 0 Ohm)

 RC:      Parasitic collector resistance value (default value = 0 Ohm)

 RE:      Parasitic emitter resistance value (default value = 0 Ohm)


<b>Junction Capacitor Parameters:</b>

 CJC:     Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 MJC:     Base-collector gradation exponent (default value = 0.333)

 VJC:     Base-collector diffusion voltage (default value = 0.8 Volt)

 CJE:     Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 MJE:     Base-emitter gradation exponent (default value = 0.4)

 VJE:     Base-emitter diffusion voltage (default value = 0.8 Volt)

 CJS:     Substrate zero bias depletion capacitance (default value = 0.4e-12 F)

 MJS:     Substrate gradation exponent (default value = 0.4)

 VJS:     Substrate diffusion voltage (default value = 0.8 Volt)

 XCJC:    Portion of depletion capacitance considered inside base-collector junction (default value = 1)


<b>Transit Time Parameters:</b>

 TF:      Ideal forward transit time (default value = 0.12e-9 sec)

 TR:      Ideal reverse transit time (default value = 5e-9 sec)


<b>Temperature Compensation and Area Parameters:</b>

 TRB1:    Linear temperature coefficient of base resistance (default value = 0 Ohm/degree)

 TRB2:    Quadratic temperature coefficient of base resistance (default value = 0 Ohm/(degree*degree))

 TRM1:    Linear temperature coefficient of modified base resistance (default value = 0 Ohm/degree)

 TRM2:    Quadratic temperature coefficient of modified base resistance (default value = 0 Ohm/(degree*degree))

 TRC1:    Linear temperature coefficient of collector resistance (default value = 0 Ohm/degree)

 TRC2:    Quadratic temperature coefficient of collector resistance (default value = 0 Ohm/(degree*degree))

 TRE1:    Linear temperature coefficient of emitter resistance (default value = 0 Ohm/degree)

 TRE2:    Quadratic temperature coefficient of emitter resistance (default value = 0 Ohm/(degree*degree))

 Tnom:    Reference temperature (default value = 300.15 <sup>o</sup>K)

 XTI:     Temperature exponent of saturation current (default value = 3)

 XTB:     Temperature ratio exponent (default value = 0)

 EG:      Activation energy (default value = 1.16 Volt)

 Area:    Relative area occupied by device (default value = 1)


<b>Substrate parameters:</b>

 VS:      Substrate potential (default value = 0 Volt)

  
<b>Numerical Parameters:</b>

 EMin:    Minimum exponent (default value = -100)

 EMax:    Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li>Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York.
<li>Hild, D.R. and F.E. Cellier (1994), \"Object-oriented electronic circuit modeling using Dymola,\"
    <i>Proc. OOS'94, SCS Object Oriented Simulation Conference</i>, Tempe, AZ, pp.68-75.
<li>Hild, D.R. (1993), <i>Circuit Modeling in Dymola</i>, MS Thesis, Dept. of Electr. &amp; Comp. Engr.,
    University of Arizona, Tucson.
<li>Schweisguth, M.C. and F.E. Cellier (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/BJT.pdf\">A
    bond graph model of the bipolar junction transistor</a>,\" <i>Proc. SCS Intl. Conf. on Bond Graph Modeling</i>,
    San Francisco, CA, pp.344-349.
<li>Schweisguth, M.C. (1997), <a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/schweisguth_ms.pdf\"><i>Semiconductor
    Modeling with Bondgraphs</i></a>, MS Thesis, Dept. of Electr. &amp; Comp. Engr., University of Arizona, Tucson.
</ol> 
</html>
"),     Icon(
            Text(
              extent=[-102,84; 62,-92],
              style(color=0),
              string="NPN"),
            Line(points=[0,100; 0,-100],
                                       style(
                color=9,
                rgbcolor={149,164,171},
                thickness=2,
                fillColor=74,
                rgbfillColor={0,0,185},
                fillPattern=1)),
            Line(points=[-20,-80; 0,-100],style(
                color=9,
                rgbcolor={149,164,171},
                thickness=2,
                fillColor=74,
                rgbfillColor={0,0,185},
                fillPattern=1)),
            Line(points=[0,-100; 20,-80],style(
                color=9,
                rgbcolor={149,164,171},
                thickness=2,
                fillColor=74,
                rgbfillColor={0,0,185},
                fillPattern=1)),
          Text(
            extent=[-88,-72; -44,-108],
            string="%Area x",
            style(color=3, rgbcolor={0,0,255})),
          Line(points=[80,-80; 100,-60], style(color=3, rgbcolor={0,0,255})),
          Line(points=[80,-40; 100,-60], style(color=3, rgbcolor={0,0,255})),
          Line(points=[-100,-60; 100,-60], style(color=3, rgbcolor={0,0,255})),
            Text(
              extent=[58,4; 110,-42],
              style(color=0),
            string="vert"),
          Text(
            extent=[-80,100; 80,60],
            style(color=3, rgbcolor={0,0,255}),
            string="%name"),
          Text(
            extent=[-126,24; -114,10],
            string="B",
            style(color=10, rgbcolor={95,95,95})),
          Text(
            extent=[10,126; 22,112],
            style(color=10, rgbcolor={95,95,95}),
            string="C"),
          Text(
            extent=[106,26; 132,6],
            style(color=10, rgbcolor={95,95,95}),
            string="Heat"),
          Text(
            extent=[8,-114; 20,-128],
            style(color=10, rgbcolor={95,95,95}),
            string="E")));
      BondLib.Junctions.J0p4 J0p4_1 annotation (extent=[10,20; 30,40]);
      Bonds.fBond B6 annotation (extent=[70,20; 90,40], rotation=180);
      equation 
      connect(J1p3_1.BondCon2, B2.BondCon1) annotation (points=[-50,0; -49.8,0],
          style(color=8, rgbcolor={192,192,192}));
      connect(B3.BondCon2, J1p3_1.BondCon1) annotation (points=[-70,0; -70,0],
          style(color=8, rgbcolor={192,192,192}));
      connect(RB1.BondCon2, B5.fBondCon1) annotation (points=[-20,-40; -20,-40],
          style(color=8, rgbcolor={192,192,192}));
      connect(B7.BondCon1, J1p3_2.BondCon1) annotation (points=[49.8,30; 50,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(C01.y, DS1.C0) annotation (points=[113.4,50; 108,50; 108,60],
          style(color=74, rgbcolor={0,0,127}));
      connect(qb1.y, DS1.qb) annotation (points=[86.6,50; 92,50; 92,60], style(
            color=74, rgbcolor={0,0,127}));
      connect(J1p3_3.BondCon1, B11.BondCon1) annotation (points=[20,60; 20,59.9; 
            20,59.8; 20,59.8], style(color=8, rgbcolor={192,192,192}));
      connect(B12.BondCon2, J1p3_3.BondCon2) annotation (points=[20,80; 20,80],
          style(color=8, rgbcolor={192,192,192}));
      connect(NPNint1.BondCon2, B15.BondCon1) annotation (points=[20,-40; 20,
            -40.1; 20,-40.2; 20,-40.2], style(color=8, rgbcolor={192,192,192}));
      connect(B15.BondCon2, J1p3_4.BondCon2) annotation (points=[20,-60; 20,-60],
          style(color=8, rgbcolor={192,192,192}));
      connect(B16.BondCon1, J1p3_4.BondCon1) annotation (points=[20,-80.2; 20,
            -80.1; 20,-80.1; 20,-80], style(color=8, rgbcolor={192,192,192}));
      connect(J0p2_3.BondCon1, B12.BondCon1) annotation (points=[20,100; 20,
            99.9; 20,99.8; 20,99.8], style(color=8, rgbcolor={192,192,192}));
      connect(B16.BondCon2, J0p2_4.BondCon2) annotation (points=[20,-100; 20,
            -100], style(color=8, rgbcolor={192,192,192}));
      connect(J0p2_4.BondCon1, BondCon2) annotation (points=[20,-120; 0,-120],
          style(color=8, rgbcolor={192,192,192}));
      connect(NPNint1.BondCon3, B19.fBondCon1) annotation (points=[40,-20; 40,
            -20], style(color=8, rgbcolor={192,192,192}));
      connect(B20.BondCon2, NPNint1.BondCon4) annotation (points=[20,0; 20,0],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p2_3.BondCon2, BondCon4) annotation (points=[20,120; 0,120],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_3.BondCon2, BondCon1) annotation (points=[-110,1.22461e-015; 
            -115,1.22461e-015; -115,0; -120,0], style(color=8, rgbcolor={192,
              192,192}));
      connect(J0p3_3.BondCon1, B3.BondCon1) annotation (points=[-90,
            -1.22461e-015; -89.9,-1.22461e-015; -89.9,0; -89.8,0], style(color=
              8, rgbcolor={192,192,192}));
      connect(J0p3_3.BondCon3, B21.BondCon1) annotation (points=[-100,10; -100,
            10.2], style(color=8, rgbcolor={192,192,192}));
      connect(B21.BondCon2, J1p3_5.BondCon1) annotation (points=[-100,30; -100,
            30], style(color=8, rgbcolor={192,192,192}));
      connect(B22.BondCon1, J1p3_5.BondCon2) annotation (points=[-100,50.2;
            -100,50], style(color=8, rgbcolor={192,192,192}));
      connect(Cbx1.BondCon2, B24.fBondCon1) annotation (points=[-30,40; -30,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p6_1.BondCon2, B25.fBondCon1) annotation (points=[80,-90; 80,
            -90], style(color=8, rgbcolor={192,192,192}));
      connect(B25.eBondCon1, J0p3_4.BondCon2) annotation (points=[100,-90; 100,
            -90], style(color=8, rgbcolor={192,192,192}));
      connect(B4.BondCon1, J1p3_1.BondCon3) annotation (points=[-60,-10.2; -60,
            -10], style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_5.BondCon3, B23.BondCon1) annotation (points=[-90,40; -89.8,
            40], style(color=8, rgbcolor={192,192,192}));
      connect(B23.BondCon2, Cbx1.BondCon1) annotation (points=[-70,40; -70,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p4_1.BondCon4, B11.BondCon2) annotation (points=[20,40; 20,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p4_1.BondCon3, B20.BondCon1) annotation (points=[20,20; 25,20; 
            25,19.8; 20,19.8], style(color=8, rgbcolor={192,192,192}));
      connect(B4.BondCon2, RB1.BondCon1) annotation (points=[-60,-30; -60,-40],
          style(color=8, rgbcolor={192,192,192}));
      connect(B2.BondCon2, NPNint1.BondCon1) annotation (points=[-30,0; -20,0;
            -20,-20; 0,-20], style(color=8, rgbcolor={192,192,192}));
      connect(NPNint1.qb, RB1.qb) annotation (points=[41.4286,-33.4286; 50,
            -33.4286; 50,-48; -10,-48; -10,-24; -40,-24; -40,-30], style(color=
              74, rgbcolor={0,0,127}));
      connect(B13.BondCon1, J1p3_3.BondCon3) annotation (points=[9.8,70; 10,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(RC1.BondCon1, B13.BondCon2) annotation (points=[-10,70; -10,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B14.fBondCon1, RC1.BondCon2) annotation (points=[-50,70; -50,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B22.BondCon2, J0p4_1.BondCon1) annotation (points=[-100,70; -100,
            88; 0,88; 0,30; 10,30], style(color=8, rgbcolor={192,192,192}));
      connect(J0p4_1.BondCon2, B7.BondCon2) annotation (points=[30,30; 30,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(B9.BondCon1, J1p3_2.BondCon3) annotation (points=[60,40.2; 60,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(B9.BondCon2, DS1.BondCon1) annotation (points=[60,60; 60,70; 80,
            70], style(color=8, rgbcolor={192,192,192}));
      connect(B10.fBondCon1, DS1.BondCon2) annotation (points=[120,80; 120,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B17.BondCon1, J1p3_4.BondCon3) annotation (points=[9.8,-70; 10,
            -70], style(color=8, rgbcolor={192,192,192}));
      connect(RE1.BondCon1, B17.BondCon2) annotation (points=[-10,-70; -10,-70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B18.fBondCon1, RE1.BondCon2) annotation (points=[-50,-70; -50,-70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B10.eBondCon1, J0p3_4.BondCon1) annotation (points=[120,100; 120,
            108; 130,108; 130,-90; 120,-90], style(color=8, rgbcolor={192,192,
              192}));
      connect(B5.eBondCon1, J0p6_1.BondCon1) annotation (points=[0,-40; 8,-40;
            8,-52; 60,-52; 60,-90], style(color=8, rgbcolor={192,192,192}));
      connect(B19.eBondCon1, J0p6_1.BondCon5) annotation (points=[60,-20; 66,
            -20; 66,-80], style(color=8, rgbcolor={192,192,192}));
      connect(B24.eBondCon1, J0p6_1.BondCon6) annotation (points=[-10,40; -6,40;
            -6,12; 74,12; 74,-80], style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_4.BondCon3, BondCon3) annotation (points=[110,-80; 120,-80;
            120,0], style(color=8, rgbcolor={192,192,192}));
      connect(B18.eBondCon1, J0p6_1.BondCon3) annotation (points=[-70,-70; -76,
            -70; -76,-88; 48,-88; 48,-100; 66,-100], style(color=8, rgbcolor={
              192,192,192}));
      connect(B14.eBondCon1, J0p6_1.BondCon4) annotation (points=[-70,70; -80,
            70; -80,-92; 44,-92; 44,-104; 74,-104; 74,-100], style(color=8,
            rgbcolor={192,192,192}));
      connect(J1p3_2.BondCon2, B6.fBondCon1) annotation (points=[70,30; 70,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(B6.eBondCon1, VS1.BondCon1) annotation (points=[90,30; 90,30],
          style(color=8, rgbcolor={192,192,192}));
      end NPNvert;
    
      model PNPlat "Spice-style laterally diffused PNP bipolar transistor" 
        /* DC model parameters */
        parameter Real BF=50 
        "Forward beta coefficient at reference temperature";
        parameter Real BR=0.1 
        "Reverse beta coefficient at reference temperature";
        parameter Modelica.SIunits.Current IS=1e-16 
        "Saturation current at reference temperature";
        parameter Modelica.SIunits.Current ISS=1e-16 
        "Saturation current of substrate diode at reference temperature";
        parameter Real NF=1 "Forward emission coefficient";
        parameter Real NR=1 "Reverse emission coefficient";
        parameter Real NS=1 "Emission coefficient of substrate diode";
        parameter Modelica.SIunits.Conductance GminDC=1e-15 
        "Leakage conductance";
      
        /* Low current beta degradation effect parameters */
        parameter Modelica.SIunits.Current ISC=1e-16 
        "Collector saturation current at reference temperature";
        parameter Modelica.SIunits.Current ISE=1e-16 
        "Emitter saturation current at reference temperature";
        parameter Real NC=2 "Collector beta degradation coefficient";
        parameter Real NE=1.5 "Emitter beta degradation coefficient";
      
        /* Base width modulation parameters */
        parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
        parameter Modelica.SIunits.Voltage VAR=9e30 "Reverse early voltage";
      
        /* High current beta degradation effect parameters */
        parameter Modelica.SIunits.Current IKF=9e30 
        "Forward junction beta degradation current";
        parameter Modelica.SIunits.Current IKR=9e30 
        "Reverse junction beta degradation current";
      
        /* Parasitic Resistor Parameters */
        parameter Modelica.SIunits.Current IRB=0 
        "Parasitic base resistor current";
        parameter Modelica.SIunits.Resistance RB=0 
        "Parasitic base resistance value";
        parameter Modelica.SIunits.Resistance RBM=0 
        "Parasitic modified base resistance value";
        parameter Modelica.SIunits.Resistance RC=0 
        "Parasitic collector resistance value";
        parameter Modelica.SIunits.Resistance RE=0 
        "Parasitic emitter resistance value";
      
        /* Junction capacitor parameters */
        parameter Modelica.SIunits.Capacitance CJC=0.5e-12 
        "Base-collector zero bias depletion capacitance at reference temperature";
        parameter Real MJC=0.333 "Base-collector gradation exponent";
        parameter Modelica.SIunits.Voltage VJC=0.8 
        "Base-collector diffusion voltage at reference temperature";
        parameter Modelica.SIunits.Capacitance CJE=0.4e-12 
        "Base-emitter zero bias depletion capacitance at reference temperature";
        parameter Real MJE=0.4 "Base-emitter gradation exponent";
        parameter Modelica.SIunits.Voltage VJE=0.8 
        "Base-emitter diffusion voltage at reference temperature";
        parameter Modelica.SIunits.Capacitance CJS=0.4e-12 
        "Substrate zero bias depletion capacitance at reference temperature";
        parameter Real MJS=0.4 "Substrate gradation exponent";
        parameter Modelica.SIunits.Voltage VJS=0.8 
        "Substrate diffusion voltage at reference temperature";
        parameter Real XCJC=1 
        "Portion of depletion capacitance considered inside base-collector junction";
      
        /* Transit time parameters */
        parameter Modelica.SIunits.Time TF=0.12e-9 "Ideal forward transit time";
        parameter Modelica.SIunits.Time TR=5e-9 "Ideal reverse transit time";
      
        /* Temperature compensation and area parameters */
        parameter Real TRB1=0 
        "Linear temperature coefficient of base resistance [Ohm/degree]";
        parameter Real TRB2=0 
        "Quadratic temperature coefficient of base resistance [Ohm/(degree*degree)]";
        parameter Real TRM1=0 
        "Linear temperature coefficient of modified base resistance [Ohm/degree]";
        parameter Real TRM2=0 
        "Quadratic temperature coefficient of modified base resistance [Ohm/(degree*degree)]";
        parameter Real TRC1=0 
        "Linear temperature coefficient of collector resistance [Ohm/degree]";
        parameter Real TRC2=0 
        "Quadratic temperature coefficient of collector resistance [Ohm/(degree*degree)]";
        parameter Real TRE1=0 
        "Linear temperature coefficient of emitter resistance [Ohm/degree]";
        parameter Real TRE2=0 
        "Quadratic temperature coefficient of emitter resistance [Ohm/(degree*degree)]";
        parameter Modelica.SIunits.Temperature Tnom=300.15 
        "Reference temperature";
        parameter Real XTI=3 "Temperature exponent of saturation current";
        parameter Real XTB=0 "Temperature ratio exponent";
        parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
        parameter Real Area=1 "Relative area occupied by device";
      
        /* Substrate parameters */
        parameter Modelica.SIunits.Voltage VS=0 "Substrate potential";
      
        /* Numerical parameters */
        parameter Real EMin=-100 
        "if x < EMin, the exp(x) function is linearized";
        parameter Real EMax=40 "if x > EMax, the exp(x) function is linearized";
      annotation (
        Coordsys(extent=[-120,-120; 120,120]),
        Diagram(
          Text(
            extent=[-126,22; -114,8],
            string="B",
            style(color=10, rgbcolor={95,95,95})),
          Text(
            extent=[-20,128; -8,114],
            style(color=10, rgbcolor={95,95,95}),
            string="C"),
          Text(
            extent=[-20,-114; -8,-128],
            style(color=10, rgbcolor={95,95,95}),
            string="E"),
          Text(
            extent=[108,-6; 134,-22],
            style(color=10, rgbcolor={95,95,95}),
            string="Heat"),
          Text(
            extent=[78,50; 104,34],
            style(color=10, rgbcolor={95,95,95}),
            string="Heat"),
          Text(
            extent=[42,-34; 52,-46],
            style(color=10, rgbcolor={95,95,95}),
            string="qb"),
          Text(
            extent=[-28,66; -18,54],
            style(color=10, rgbcolor={95,95,95}),
            string="qb")),
        Documentation(info="<html>
The <b>PNPlat</b> element of the Spice bond graph library implements a full-fledges Spice-stye model of the laterally diffused PNP bipolar transistor [1-3]. The model contains a <b>PNPint</b> model implementing the inner parts of the PNP transistor up to the internal nodes. <p>

The PNP bipolar transistor is a directed FourPort.  The direction of positive power flow is assumed into the model at the emitter, <b>E</b>, whereas it is assumed out of the model at the base, <b>B</b>, at the collector, <b>C</b>, and at the <b>Heat</b> port. <p>

The causality of the PNP model is free. <p>

<hr>

<pre>
<b>DC Model Parameters:</b>

 BF:      Forward beta coefficient (default value = 50)

 BR:      Reverse beta coefficient (default value = 0.1)

 IS:      Transport saturation current (default value = 1e-16 Amp)

 ISS:     Transport saturation current of substrate diode (default value = 1e-16 Amp)

 NF:      Forward emission coefficient (default value = 1)

 NR:      Reverse emission coefficient (default value = 1)

 NS:      Emission coefficient of substrate diode (default value = 1)

 GminDC:  Junction leakage conductance (default value = 1e-15 Mho)


<b>Low Current Beta Degradation Effect Parameters:</b>

 ISC:     Collector saturation current at reference temperature (default value = 1e-16 Amp)

 ISE:     Emitter saturation current at reference temperature (default value = 1e-16 Amp)

 NC:      Collector beta degradation coefficient (default value = 2)

 NE:      Emitter beta degradation coefficient (default value = 1.5)


<b>Base Width Modulation Parameters:</b>
  
 VAF:     Forward early voltage (default value = 9e30 Volt)

 VAR:     Reverse early voltage (default value = 9e30 Volt)


<b>High Current Beta Degradation Effect Parameters:</b>

 IKF:     Forward junction beta degradation current (default value = 9e30 Amp)

 IKR:     Reverse junction beta degradation current (default value = 9e30 Amp)


<b>Parasitic Resistor Parameters:</b>

 IRB:     Parasitic base resistor current (default value = 0 Amp)

 RB:      Parasitic base resistance value (default value = 0 Ohm)

 RBM:     Parasitic modified base resistance value (default value = 0 Ohm)

 RC:      Parasitic collector resistance value (default value = 0 Ohm)

 RE:      Parasitic emitter resistance value (default value = 0 Ohm)


<b>Junction Capacitor Parameters:</b>

 CJC:     Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 MJC:     Base-collector gradation exponent (default value = 0.333)

 VJC:     Base-collector diffusion voltage (default value = 0.8 Volt)

 CJE:     Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 MJE:     Base-emitter gradation exponent (default value = 0.4)

 VJE:     Base-emitter diffusion voltage (default value = 0.8 Volt)

 CJS:     Substrate zero bias depletion capacitance (default value = 0.4e-12 F)

 MJS:     Substrate gradation exponent (default value = 0.4)

 VJS:     Substrate diffusion voltage (default value = 0.8 Volt)

 XCJC:    Portion of depletion capacitance considered inside base-collector junction (default value = 1)


<b>Transit Time Parameters:</b>

 TF:      Ideal forward transit time (default value = 0.12e-9 sec)

 TR:      Ideal reverse transit time (default value = 5e-9 sec)


<b>Temperature Compensation and Area Parameters:</b>

 TRB1:    Linear temperature coefficient of base resistance (default value = 0 Ohm/degree)

 TRB2:    Quadratic temperature coefficient of base resistance (default value = 0 Ohm/(degree*degree))

 TRM1:    Linear temperature coefficient of modified base resistance (default value = 0 Ohm/degree)

 TRM2:    Quadratic temperature coefficient of modified base resistance (default value = 0 Ohm/(degree*degree))

 TRC1:    Linear temperature coefficient of collector resistance (default value = 0 Ohm/degree)

 TRC2:    Quadratic temperature coefficient of collector resistance (default value = 0 Ohm/(degree*degree))

 TRE1:    Linear temperature coefficient of emitter resistance (default value = 0 Ohm/degree)

 TRE2:    Quadratic temperature coefficient of emitter resistance (default value = 0 Ohm/(degree*degree))

 Tnom:    Reference temperature (default value = 300.15 <sup>o</sup>K)

 XTI:     Temperature exponent of saturation current (default value = 3)

 XTB:     Temperature ratio exponent (default value = 0)

 EG:      Activation energy (default value = 1.16 Volt)

 Area:    Relative area occupied by device (default value = 1)


<b>Substrate parameters:</b>

 VS:      Substrate potential (default value = 0 Volt)

  
<b>Numerical Parameters:</b>

 EMin:    Minimum exponent (default value = -100)

 EMax:    Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li>Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York.
<li>Hild, D.R. and F.E. Cellier (1994), \"Object-oriented electronic circuit modeling using Dymola,\"
    <i>Proc. OOS'94, SCS Object Oriented Simulation Conference</i>, Tempe, AZ, pp.68-75.
<li>Hild, D.R. (1993), <i>Circuit Modeling in Dymola</i>, MS Thesis, Dept. of Electr. &amp; Comp. Engr.,
    University of Arizona, Tucson.
<li>Schweisguth, M.C. and F.E. Cellier (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/BJT.pdf\">A
    bond graph model of the bipolar junction transistor</a>,\" <i>Proc. SCS Intl. Conf. on Bond Graph Modeling</i>,
    San Francisco, CA, pp.344-349.
<li>Schweisguth, M.C. (1997), <a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/schweisguth_ms.pdf\"><i>Semiconductor
    Modeling with Bondgraphs</i></a>, MS Thesis, Dept. of Electr. &amp; Comp. Engr., University of Arizona, Tucson.
</ol> 
</html>
"),     Icon(
            Text(
              extent=[-96,84; 68,-92],
              style(color=0),
            string="PNP"),
            Text(
              extent=[64,4; 104,-38],
              style(color=0),
            string="lat"),
          Text(
            extent=[-80,100; 80,60],
            style(color=3, rgbcolor={0,0,255}),
            string="%name"),
          Text(
            extent=[-126,24; -114,10],
            string="B",
            style(color=10, rgbcolor={95,95,95})),
          Text(
            extent=[10,126; 22,112],
            style(color=10, rgbcolor={95,95,95}),
            string="C"),
          Text(
            extent=[106,26; 132,6],
            style(color=10, rgbcolor={95,95,95}),
            string="Heat"),
          Text(
            extent=[-88,-72; -44,-108],
            string="%Area x",
            style(color=3, rgbcolor={0,0,255})),
            Line(points=[0,100; 0,-100],
                                       style(
                color=9,
                rgbcolor={149,164,171},
                thickness=2,
                fillColor=74,
                rgbfillColor={0,0,185},
                fillPattern=1)),
            Line(points=[0,100; 20,80],   style(
                color=9,
                rgbcolor={149,164,171},
                thickness=2,
                fillColor=74,
                rgbfillColor={0,0,185},
                fillPattern=1)),
            Line(points=[-20,80; 0,100], style(
                color=9,
                rgbcolor={149,164,171},
                thickness=2,
                fillColor=74,
                rgbfillColor={0,0,185},
                fillPattern=1)),
          Line(points=[-100,-60; 100,-60], style(color=3, rgbcolor={0,0,255})),
          Line(points=[80,-80; 100,-60], style(color=3, rgbcolor={0,0,255})),
          Line(points=[80,-40; 100,-60], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[8,-114; 20,-128],
            style(color=10, rgbcolor={95,95,95}),
            string="E")));
      BondLib.Interfaces.BondCon BondCon1 
        annotation (extent=[-130,-10; -110,10]);
      BondLib.Interfaces.BondCon BondCon2 
        annotation (extent=[-10,-130; 10,-110]);
      BondLib.Interfaces.BondCon BondCon3 annotation (extent=[110,-10; 130,10]);
      BondLib.Interfaces.BondCon BondCon4 annotation (extent=[-10,110; 10,130]);
      BondLib.Bonds.Bond B1 annotation (extent=[-20,-30; 0,-10], rotation=180);
      BondLib.Junctions.J0p3 J0p3_1 
        annotation (extent=[-40,-30; -20,-10], rotation=90);
      BondLib.Bonds.Bond B2 annotation (extent=[-50,-10; -30,10], rotation=180);
      BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-70,10; -50,-10]);
      BondLib.Bonds.Bond B3 annotation (extent=[-90,-10; -70,10], rotation=180);
      BondLib.Bonds.Bond B4 annotation (extent=[-70,10; -50,30], rotation=90);
      BondLib.Spice.Utilities.RBS RB1(
        Tnom=Tnom,
        RB=RB,
        RBM=RBM,
        IRB=IRB,
        TRB1=TRB1,
        TRB2=TRB2,
        TRM1=TRM1,
        TRM2=TRM2,
        Area=Area) annotation (extent=[-60,30; -20,50], rotation=0);
      BondLib.Bonds.eBond B5 annotation (extent=[-20,30; 0,50]);
      BondLib.Bonds.Bond B6 annotation (extent=[-50,-50; -30,-30], rotation=0);
      BondLib.Junctions.J1p3 J1p3_2 annotation (extent=[-70,-50; -50,-30]);
      BondLib.Sources.Se VS1(e0=VS) 
        annotation (extent=[-90,-50; -116,-30], rotation=0);
      BondLib.Bonds.Bond B9 annotation (extent=[-70,-70; -50,-50], rotation=270);
      BondLib.Spice.Utilities.DjS DS1(
        Tnom=Tnom,
        IS=ISS,
        EG=EG,
        N=NS,
        XTI=XTI,
        VJ=VJS,
        CJ=CJS,
        XCJ=1,
        MJ=MJS,
        GminDC=GminDC,
        Area=Area,
        BE=false,
        Tau=0,
        EMin=EMin,
        EMax=EMax) annotation (extent=[-60,-90; -20,-70]);
      BondLib.Bonds.eBond B10 annotation (extent=[-20,-90; 0,-70]);
      Modelica.Blocks.Sources.Constant C01(k=0) 
        annotation (extent=[-14,-106; -26,-94]);
      Modelica.Blocks.Sources.Constant qb1(k=1) 
        annotation (extent=[-66,-106; -54,-94]);
      BondLib.Bonds.Bond B11 annotation (extent=[10,40; 30,60], rotation=90);
      BondLib.Junctions.J1p3 J1p3_3 
        annotation (extent=[30,80; 10,60], rotation=-90);
      BondLib.Bonds.Bond B12 annotation (extent=[10,80; 30,100], rotation=90);
      BondLib.Junctions.J0p2 J0p2_3 
        annotation (extent=[10,100; 30,120], rotation=90);
      BondLib.Bonds.Bond B13 annotation (extent=[30,60; 50,80], rotation=0);
      BondLib.Spice.RS RC1(
        Tnom=Tnom,
        R=RC,
        TR1=TRC1,
        TR2=TRC2,
        Area=Area) annotation (extent=[50,60; 90,80]);
      BondLib.Bonds.eBond B14 annotation (extent=[90,60; 110,80], rotation=0);
      BondLib.Bonds.Bond B15 annotation (extent=[10,-60; 30,-40], rotation=90);
      BondLib.Junctions.J1p3 J1p3_4 
        annotation (extent=[30,-60; 10,-80], rotation=-90);
      BondLib.Bonds.Bond B16 annotation (extent=[10,-100; 30,-80], rotation=90);
      BondLib.Junctions.J0p2 J0p2_4 
        annotation (extent=[10,-120; 30,-100], rotation=90);
      BondLib.Bonds.Bond B17 annotation (extent=[30,-80; 50,-60], rotation=0);
      BondLib.Spice.RS RE1(
        Tnom=Tnom,
        Area=Area,
        R=RE,
        TR1=TRE1,
        TR2=TRE2) annotation (extent=[50,-80; 90,-60]);
      BondLib.Bonds.eBond B18 annotation (extent=[90,-80; 110,-60], rotation=0);
      BondLib.Bonds.eBond B19 annotation (extent=[40,-30; 60,-10]);
      BondLib.Junctions.J0p6 J0p6_1 annotation (extent=[60,20; 80,40]);
      BondLib.Bonds.Bond B20 annotation (extent=[10,0; 30,20], rotation=90);
      BondLib.Junctions.J0p3 J0p3_2 
        annotation (extent=[10,20; 30,40], rotation=90);
      BondLib.Junctions.J0p3 J0p3_3 
        annotation (extent=[-110,-10; -90,10], rotation=180);
      BondLib.Bonds.Bond B21 annotation (extent=[-110,10; -90,30], rotation=90);
      BondLib.Junctions.J1p3 J1p3_5 
        annotation (extent=[-110,30; -90,50], rotation=90);
      BondLib.Bonds.Bond B22 annotation (extent=[-110,50; -90,70], rotation=90);
      BondLib.Bonds.Bond B23 annotation (extent=[-90,50; -70,70], rotation=90);
      BondLib.Spice.Utilities.CbxS Cbx1(
        Tnom=Tnom,
        EG=EG,
        VJ=VJC,
        CJ=CJC,
        XCJ=XCJC,
        MJ=MJC,
        Area=Area) annotation (extent=[-80,70; -40,90], rotation=0);
      BondLib.Bonds.eBond B24 annotation (extent=[-40,70; -20,90]);
      BondLib.Bonds.eBond B25 annotation (extent=[80,20; 100,40]);
      BondLib.Junctions.J0p3 J0p3_4 
        annotation (extent=[100,20; 120,40], rotation=180);
      BondLib.Spice.Utilities.PNPint PNPint1(
        BF=BF,
        BR=BR,
        IS=IS,
        NF=NF,
        NR=NR,
        GminDC=GminDC,
        ISC=ISC,
        ISE=ISE,
        NC=NC,
        NE=NE,
        VAF=VAF,
        VAR=VAR,
        IKF=IKF,
        IKR=IKR) annotation (extent=[0,-40; 40,0]);
      Bonds.fBond B7 annotation (extent=[-90,-50; -70,-30]);
      equation 
      connect(J1p3_1.BondCon3, B4.BondCon1) annotation (points=[-60,10; -60,
            10.2], style(color=8, rgbcolor={192,192,192}));
      connect(RB1.BondCon1, B4.BondCon2) annotation (points=[-60,40; -60,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(RB1.BondCon2, B5.fBondCon1) annotation (points=[-20,40; -20,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(B9.BondCon1, J1p3_2.BondCon3) annotation (points=[-60,-50.2; -60,
            -50], style(color=8, rgbcolor={192,192,192}));
      connect(B9.BondCon2, DS1.BondCon1) annotation (points=[-60,-70; -60,-80],
          style(color=8, rgbcolor={192,192,192}));
      connect(DS1.BondCon2, B10.fBondCon1) annotation (points=[-20,-80; -20,-80],
          style(color=8, rgbcolor={192,192,192}));
      connect(C01.y, DS1.C0) annotation (points=[-26.6,-100; -32,-100; -32,-90],
          style(color=74, rgbcolor={0,0,127}));
      connect(qb1.y, DS1.qb) annotation (points=[-53.4,-100; -48,-100; -48,-90],
          style(color=74, rgbcolor={0,0,127}));
      connect(J1p3_3.BondCon3, B13.BondCon1) annotation (points=[30,70; 30.2,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B13.BondCon2, RC1.BondCon1) annotation (points=[50,70; 50,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_4.BondCon3, B17.BondCon1) annotation (points=[30,-70; 30.2,
            -70], style(color=8, rgbcolor={192,192,192}));
      connect(B17.BondCon2, RE1.BondCon1) annotation (points=[50,-70; 50,-70],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p2_4.BondCon1, BondCon2) annotation (points=[20,-120; 0,-120],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p2_3.BondCon2, BondCon4) annotation (points=[20,120; 0,120],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_3.BondCon2, BondCon1) annotation (points=[-110,1.22461e-015; 
            -116,1.22461e-015; -114,0; -120,0], style(color=8, rgbcolor={192,
              192,192}));
      connect(J0p3_3.BondCon3, B21.BondCon1) annotation (points=[-100,10; -100,
            10.2], style(color=8, rgbcolor={192,192,192}));
      connect(B21.BondCon2, J1p3_5.BondCon1) annotation (points=[-100,30; -100,
            30], style(color=8, rgbcolor={192,192,192}));
      connect(B22.BondCon1, J1p3_5.BondCon2) annotation (points=[-100,50.2;
            -100,50], style(color=8, rgbcolor={192,192,192}));
      connect(B23.BondCon1, J1p3_5.BondCon3) annotation (points=[-80,50.2; -80,
            40; -90,40], style(color=8, rgbcolor={192,192,192}));
      connect(RC1.BondCon2, B14.fBondCon1) annotation (points=[90,70; 90,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(RE1.BondCon2, B18.fBondCon1) annotation (points=[90,-70; 90,-70],
          style(color=8, rgbcolor={192,192,192}));
      connect(Cbx1.BondCon1, B23.BondCon2) annotation (points=[-80,80; -80,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(Cbx1.BondCon2, B24.fBondCon1) annotation (points=[-40,80; -40,80],
          style(color=8, rgbcolor={192,192,192}));
      connect(B22.BondCon2, J0p3_2.BondCon3) annotation (points=[-100,70; -100,
            94; 40,94; 40,30; 30,30], style(color=8, rgbcolor={192,192,192}));
      connect(J0p6_1.BondCon2, B25.fBondCon1) annotation (points=[80,30; 80,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(B25.eBondCon1, J0p3_4.BondCon2) annotation (points=[100,30; 100,
            30], style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_4.BondCon1, BondCon3) annotation (points=[120,30; 120,0],
          style(color=8, rgbcolor={192,192,192}));
      connect(B14.eBondCon1, J0p3_4.BondCon3) annotation (points=[110,70; 110,
            40], style(color=8, rgbcolor={192,192,192}));
      connect(B19.eBondCon1, J0p6_1.BondCon1) annotation (points=[60,-20; 60,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(B5.eBondCon1, J0p6_1.BondCon5) annotation (points=[0,40; 0,48; 66,
            48; 66,40], style(color=8, rgbcolor={192,192,192}));
      connect(B24.eBondCon1, J0p6_1.BondCon6) annotation (points=[-20,80; 0,80;
            0,52; 74,52; 74,40], style(color=8, rgbcolor={192,192,192}));
      connect(B18.eBondCon1, J0p6_1.BondCon3) annotation (points=[110,-70; 110,
            -40; 66,-40; 66,20], style(color=8, rgbcolor={192,192,192}));
      connect(B10.eBondCon1, J0p6_1.BondCon4) annotation (points=[0,-80; 8,-80;
            8,-90; 114,-90; 114,-36; 74,-36; 74,20], style(color=8, rgbcolor={
              192,192,192}));
      connect(B12.BondCon2, J0p2_3.BondCon1) annotation (points=[20,100; 20,100],
          style(color=8, rgbcolor={192,192,192}));
      connect(B12.BondCon1, J1p3_3.BondCon2) annotation (points=[20,80.2; 20,80],
          style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_3.BondCon1, B11.BondCon2) annotation (points=[20,60; 20,60],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_2.BondCon2, B11.BondCon1) annotation (points=[20,40; 20,40.2],
          style(color=8, rgbcolor={192,192,192}));
      connect(B20.BondCon2, J0p3_2.BondCon1) annotation (points=[20,20; 20,20],
          style(color=8, rgbcolor={192,192,192}));
      connect(PNPint1.BondCon4, B20.BondCon1) annotation (points=[20,0; 20,0.2],
          style(color=8, rgbcolor={192,192,192}));
      connect(PNPint1.BondCon3, B19.fBondCon1) annotation (points=[40,-20; 40,
            -20], style(color=8, rgbcolor={192,192,192}));
      connect(B15.BondCon2, PNPint1.BondCon2) annotation (points=[20,-40; 20,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_4.BondCon2, B15.BondCon1) annotation (points=[20,-60; 20,
            -59.8], style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_4.BondCon1, B16.BondCon2) annotation (points=[20,-80; 20,-80],
          style(color=8, rgbcolor={192,192,192}));
      connect(B16.BondCon1, J0p2_4.BondCon2) annotation (points=[20,-99.8; 20,
            -100], style(color=8, rgbcolor={192,192,192}));
      connect(PNPint1.BondCon1, B1.BondCon1) annotation (points=[0,-20; -0.2,
            -20], style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_1.BondCon3, B1.BondCon2) annotation (points=[-20,-20; -20,
            -20], style(color=8, rgbcolor={192,192,192}));
      connect(B2.BondCon2, J1p3_1.BondCon2) annotation (points=[-50,
            1.22461e-015; -44,1.22461e-015; -42,0; -50,0], style(color=8,
            rgbcolor={192,192,192}));
      connect(J0p3_1.BondCon2, B2.BondCon1) annotation (points=[-30,-10; -30,-5; 
            -30,-1.20011e-015; -30.2,-1.20011e-015], style(color=8, rgbcolor={
              192,192,192}));
      connect(B3.BondCon2, J0p3_3.BondCon1) annotation (points=[-90,
            1.22461e-015; -90,-1.22461e-015], style(color=8, rgbcolor={192,192,
              192}));
      connect(B3.BondCon1, J1p3_1.BondCon1) annotation (points=[-70.2,
            -1.20011e-015; -72.1,-1.20011e-015; -72.1,0; -70,0], style(color=8,
            rgbcolor={192,192,192}));
      connect(B6.BondCon1, J1p3_2.BondCon2) annotation (points=[-49.8,-40; -50,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_1.BondCon1, B6.BondCon2) annotation (points=[-30,-30; -30,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(B7.fBondCon1, J1p3_2.BondCon1) annotation (points=[-70,-40; -70,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(VS1.BondCon1, B7.eBondCon1) annotation (points=[-90,-40; -90,-40],
          style(color=8, rgbcolor={192,192,192}));
      end PNPlat;
    
      model PNPvert "Spice-style vertically diffused PNP bipolar transistor" 
        /* DC model parameters */
        parameter Real BF=50 
        "Forward beta coefficient at reference temperature";
        parameter Real BR=0.1 
        "Reverse beta coefficient at reference temperature";
        parameter Modelica.SIunits.Current IS=1e-16 
        "Saturation current at reference temperature";
        parameter Modelica.SIunits.Current ISS=1e-16 
        "Saturation current of substrate diode at reference temperature";
        parameter Real NF=1 "Forward emission coefficient";
        parameter Real NR=1 "Reverse emission coefficient";
        parameter Real NS=1 "Emission coefficient of substrate diode";
        parameter Modelica.SIunits.Conductance GminDC=1e-15 
        "Leakage conductance";
      
        /* Low current beta degradation effect parameters */
        parameter Modelica.SIunits.Current ISC=1e-16 
        "Collector saturation current at reference temperature";
        parameter Modelica.SIunits.Current ISE=1e-16 
        "Emitter saturation current at reference temperature";
        parameter Real NC=2 "Collector beta degradation coefficient";
        parameter Real NE=1.5 "Emitter beta degradation coefficient";
      
        /* Base width modulation parameters */
        parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
        parameter Modelica.SIunits.Voltage VAR=9e30 "Reverse early voltage";
      
        /* High current beta degradation effect parameters */
        parameter Modelica.SIunits.Current IKF=9e30 
        "Forward junction beta degradation current";
        parameter Modelica.SIunits.Current IKR=9e30 
        "Reverse junction beta degradation current";
      
        /* Parasitic Resistor Parameters */
        parameter Modelica.SIunits.Current IRB=0 
        "Parasitic base resistor current";
        parameter Modelica.SIunits.Resistance RB=0 
        "Parasitic base resistance value";
        parameter Modelica.SIunits.Resistance RBM=0 
        "Parasitic modified base resistance value";
        parameter Modelica.SIunits.Resistance RC=0 
        "Parasitic collector resistance value";
        parameter Modelica.SIunits.Resistance RE=0 
        "Parasitic emitter resistance value";
      
        /* Junction capacitor parameters */
        parameter Modelica.SIunits.Capacitance CJC=0.5e-12 
        "Base-collector zero bias depletion capacitance at reference temperature";
        parameter Real MJC=0.333 "Base-collector gradation exponent";
        parameter Modelica.SIunits.Voltage VJC=0.8 
        "Base-collector diffusion voltage at reference temperature";
        parameter Modelica.SIunits.Capacitance CJE=0.4e-12 
        "Base-emitter zero bias depletion capacitance at reference temperature";
        parameter Real MJE=0.4 "Base-emitter gradation exponent";
        parameter Modelica.SIunits.Voltage VJE=0.8 
        "Base-emitter diffusion voltage at reference temperature";
        parameter Modelica.SIunits.Capacitance CJS=0.4e-12 
        "Substrate zero bias depletion capacitance at reference temperature";
        parameter Real MJS=0.4 "Substrate gradation exponent";
        parameter Modelica.SIunits.Voltage VJS=0.8 
        "Substrate diffusion voltage at reference temperature";
        parameter Real XCJC=1 
        "Portion of depletion capacitance considered inside base-collector junction";
      
        /* Transit time parameters */
        parameter Modelica.SIunits.Time TF=0.12e-9 "Ideal forward transit time";
        parameter Modelica.SIunits.Time TR=5e-9 "Ideal reverse transit time";
      
        /* Temperature compensation and area parameters */
        parameter Real TRB1=0 
        "Linear temperature coefficient of base resistance [Ohm/degree]";
        parameter Real TRB2=0 
        "Quadratic temperature coefficient of base resistance [Ohm/(degree*degree)]";
        parameter Real TRM1=0 
        "Linear temperature coefficient of modified base resistance [Ohm/degree]";
        parameter Real TRM2=0 
        "Quadratic temperature coefficient of modified base resistance [Ohm/(degree*degree)]";
        parameter Real TRC1=0 
        "Linear temperature coefficient of collector resistance [Ohm/degree]";
        parameter Real TRC2=0 
        "Quadratic temperature coefficient of collector resistance [Ohm/(degree*degree)]";
        parameter Real TRE1=0 
        "Linear temperature coefficient of emitter resistance [Ohm/degree]";
        parameter Real TRE2=0 
        "Quadratic temperature coefficient of emitter resistance [Ohm/(degree*degree)]";
        parameter Modelica.SIunits.Temperature Tnom=300.15 
        "Reference temperature";
        parameter Real XTI=3 "Temperature exponent of saturation current";
        parameter Real XTB=0 "Temperature ratio exponent";
        parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
        parameter Real Area=1 "Relative area occupied by device";
      
        /* Substrate parameters */
        parameter Modelica.SIunits.Voltage VS=0 "Substrate potential";
      
        /* Numerical parameters */
        parameter Real EMin=-100 
        "if x < EMin, the exp(x) function is linearized";
        parameter Real EMax=40 "if x > EMax, the exp(x) function is linearized";
      BondLib.Interfaces.BondCon BondCon1 
        annotation (extent=[-130,-10; -110,10]);
      BondLib.Interfaces.BondCon BondCon2 
        annotation (extent=[-10,-130; 10,-110]);
      BondLib.Interfaces.BondCon BondCon3 annotation (extent=[110,-10; 130,10]);
      BondLib.Interfaces.BondCon BondCon4 annotation (extent=[-10,110; 10,130]);
      BondLib.Bonds.Bond B2 annotation (extent=[-50,-10; -30,10], rotation=180);
      BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-70,-10; -50,10]);
      BondLib.Bonds.Bond B3 annotation (extent=[-90,-10; -70,10], rotation=180);
      BondLib.Bonds.Bond B4 annotation (extent=[-70,-30; -50,-10], rotation=270);
      BondLib.Spice.Utilities.RBS RB1(
        Tnom=Tnom,
        RB=RB,
        RBM=RBM,
        IRB=IRB,
        TRB1=TRB1,
        TRB2=TRB2,
        TRM1=TRM1,
        TRM2=TRM2,
        Area=Area) annotation (extent=[-60,-50; -20,-30], rotation=0);
      BondLib.Bonds.eBond B5 annotation (extent=[-20,-50; 0,-30]);
      BondLib.Bonds.Bond B6 annotation (extent=[70,20; 90,40], rotation=0);
      BondLib.Junctions.J1p3 J1p3_2 annotation (extent=[50,40; 70,20]);
      BondLib.Bonds.Bond B7 annotation (extent=[30,20; 50,40], rotation=0);
      BondLib.Sources.Se VS1(e0=VS) 
        annotation (extent=[78,-36; 102,-10], rotation=-90);
      BondLib.Bonds.Bond B9 annotation (extent=[50,40; 70,60], rotation=90);
      BondLib.Spice.Utilities.DjS DS1(
        Tnom=Tnom,
        IS=ISS,
        EG=EG,
        N=NS,
        XTI=XTI,
        VJ=VJS,
        CJ=CJS,
        XCJ=1,
        MJ=MJS,
        GminDC=GminDC,
        Area=Area,
        BE=false,
        Tau=0,
        EMin=EMin,
        EMax=EMax) annotation (extent=[80,60; 120,80]);
      BondLib.Bonds.eBond B10 annotation (extent=[110,80; 130,100], rotation=90);
      Modelica.Blocks.Sources.Constant C01(k=0) 
        annotation (extent=[126,44; 114,56]);
      Modelica.Blocks.Sources.Constant qb1(k=1) 
        annotation (extent=[74,44; 86,56]);
      BondLib.Bonds.Bond B11 annotation (extent=[10,40; 30,60], rotation=90);
      BondLib.Junctions.J1p3 J1p3_3 
        annotation (extent=[10,80; 30,60], rotation=-90);
      BondLib.Bonds.Bond B12 annotation (extent=[10,80; 30,100], rotation=90);
      BondLib.Junctions.J0p2 J0p2_3 
        annotation (extent=[10,100; 30,120], rotation=90);
      BondLib.Bonds.Bond B13 annotation (extent=[-10,60; 10,80], rotation=180);
      BondLib.Spice.RS RC1(
        Tnom=Tnom,
        R=RC,
        TR1=TRC1,
        TR2=TRC2,
        Area=Area) annotation (extent=[-10,60; -50,80]);
      BondLib.Bonds.eBond B14 annotation (extent=[-70,60; -50,80], rotation=180);
      BondLib.Bonds.Bond B15 annotation (extent=[10,-60; 30,-40], rotation=90);
      BondLib.Junctions.J1p3 J1p3_4 
        annotation (extent=[10,-60; 30,-80], rotation=-90);
      BondLib.Bonds.Bond B16 annotation (extent=[10,-100; 30,-80], rotation=90);
      BondLib.Junctions.J0p2 J0p2_4 
        annotation (extent=[10,-120; 30,-100], rotation=90);
      BondLib.Bonds.Bond B17 annotation (extent=[-10,-80; 10,-60], rotation=180);
      BondLib.Spice.RS RE1(
        Tnom=Tnom,
        Area=Area,
        R=RE,
        TR1=TRE1,
        TR2=TRE2) annotation (extent=[-10,-80; -50,-60]);
      BondLib.Bonds.eBond B18 
        annotation (extent=[-70,-80; -50,-60], rotation=180);
      BondLib.Bonds.eBond B19 annotation (extent=[40,-30; 60,-10]);
      BondLib.Junctions.J0p6 J0p6_1 annotation (extent=[60,-100; 80,-80]);
      BondLib.Bonds.Bond B20 annotation (extent=[10,0; 30,20], rotation=90);
      BondLib.Junctions.J0p3 J0p3_3 
        annotation (extent=[-110,-10; -90,10], rotation=180);
      BondLib.Bonds.Bond B21 annotation (extent=[-110,10; -90,30], rotation=90);
      BondLib.Junctions.J1p3 J1p3_5 
        annotation (extent=[-110,30; -90,50], rotation=90);
      BondLib.Bonds.Bond B22 annotation (extent=[-110,50; -90,70], rotation=90);
      BondLib.Bonds.Bond B23 annotation (extent=[-90,30; -70,50], rotation=0);
      BondLib.Spice.Utilities.CbxS Cbx1(
        Tnom=Tnom,
        EG=EG,
        VJ=VJC,
        CJ=CJC,
        XCJ=XCJC,
        MJ=MJC,
        Area=Area) annotation (extent=[-70,30; -30,50], rotation=0);
      BondLib.Bonds.eBond B24 annotation (extent=[-30,30; -10,50]);
      BondLib.Bonds.eBond B25 annotation (extent=[80,-100; 100,-80]);
      BondLib.Junctions.J0p3 J0p3_4 
        annotation (extent=[100,-100; 120,-80], rotation=180);
      BondLib.Junctions.J0p4 J0p4_1 annotation (extent=[10,20; 30,40]);
      annotation (
        Diagram(
          Text(
            extent=[-126,22; -114,8],
            string="B",
            style(color=10, rgbcolor={95,95,95})),
          Text(
            extent=[-20,128; -8,114],
            style(color=10, rgbcolor={95,95,95}),
            string="C"),
          Text(
            extent=[-20,-114; -8,-128],
            style(color=10, rgbcolor={95,95,95}),
            string="E"),
          Text(
            extent=[106,22; 132,6],
            style(color=10, rgbcolor={95,95,95}),
            string="Heat"),
          Text(
            extent=[82,-96; 108,-112],
            style(color=10, rgbcolor={95,95,95}),
            string="Heat"),
          Text(
            extent=[38,-34; 48,-46],
            style(color=10, rgbcolor={95,95,95}),
            string="qb"),
          Text(
            extent=[-38,-14; -28,-26],
            style(color=10, rgbcolor={95,95,95}),
            string="qb")),
        Coordsys(extent=[-120,-120; 120,120]),
        Icon(
          Text(
            extent=[-80,100; 80,60],
            style(color=3, rgbcolor={0,0,255}),
            string="%name"),
            Line(points=[0,100; 0,-100],
                                       style(
                color=9,
                rgbcolor={149,164,171},
                thickness=2,
                fillColor=74,
                rgbfillColor={0,0,185},
                fillPattern=1)),
            Text(
              extent=[-94,84; 70,-92],
              style(color=0),
            string="PNP"),
            Text(
              extent=[58,4; 110,-42],
              style(color=0),
            string="vert"),
          Line(points=[-100,-60; 100,-60], style(color=3, rgbcolor={0,0,255})),
          Line(points=[80,-80; 100,-60], style(color=3, rgbcolor={0,0,255})),
          Line(points=[80,-40; 100,-60], style(color=3, rgbcolor={0,0,255})),
            Line(points=[-20,80; 0,100], style(
                color=9,
                rgbcolor={149,164,171},
                thickness=2,
                fillColor=74,
                rgbfillColor={0,0,185},
                fillPattern=1)),
            Line(points=[0,100; 20,80],   style(
                color=9,
                rgbcolor={149,164,171},
                thickness=2,
                fillColor=74,
                rgbfillColor={0,0,185},
                fillPattern=1)),
          Text(
            extent=[-88,-72; -44,-108],
            string="%Area x",
            style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[8,-114; 20,-128],
            style(color=10, rgbcolor={95,95,95}),
            string="E"),
          Text(
            extent=[106,26; 132,6],
            style(color=10, rgbcolor={95,95,95}),
            string="Heat"),
          Text(
            extent=[10,126; 22,112],
            style(color=10, rgbcolor={95,95,95}),
            string="C"),
          Text(
            extent=[-126,24; -114,10],
            string="B",
            style(color=10, rgbcolor={95,95,95}))),
        Documentation(info="<html>
The <b>PNPvert</b> element of the Spice bond graph library implements a full-fledges Spice-stye model of the vertically diffused PNP bipolar transistor [1-3]. The model contains a <b>PNPint</b> model implementing the inner parts of the PNP transistor up to the internal nodes. <p>

The PNP bipolar transistor is a directed FourPort.  The direction of positive power flow is assumed into the model at the emitter, <b>E</b>, whereas it is assumed out of the model at the base, <b>B</b>, at the collector, <b>C</b>, and at the <b>Heat</b> port. <p>

The causality of the PNP model is free. <p>

<hr>

<pre>
<b>DC Model Parameters:</b>

 BF:      Forward beta coefficient (default value = 50)

 BR:      Reverse beta coefficient (default value = 0.1)

 IS:      Transport saturation current (default value = 1e-16 Amp)

 ISS:     Transport saturation current of substrate diode (default value = 1e-16 Amp)

 NF:      Forward emission coefficient (default value = 1)

 NR:      Reverse emission coefficient (default value = 1)

 NS:      Emission coefficient of substrate diode (default value = 1)

 GminDC:  Junction leakage conductance (default value = 1e-15 Mho)


<b>Low Current Beta Degradation Effect Parameters:</b>

 ISC:     Collector saturation current at reference temperature (default value = 1e-16 Amp)

 ISE:     Emitter saturation current at reference temperature (default value = 1e-16 Amp)

 NC:      Collector beta degradation coefficient (default value = 2)

 NE:      Emitter beta degradation coefficient (default value = 1.5)


<b>Base Width Modulation Parameters:</b>
  
 VAF:     Forward early voltage (default value = 9e30 Volt)

 VAR:     Reverse early voltage (default value = 9e30 Volt)


<b>High Current Beta Degradation Effect Parameters:</b>

 IKF:     Forward junction beta degradation current (default value = 9e30 Amp)

 IKR:     Reverse junction beta degradation current (default value = 9e30 Amp)


<b>Parasitic Resistor Parameters:</b>

 IRB:     Parasitic base resistor current (default value = 0 Amp)

 RB:      Parasitic base resistance value (default value = 0 Ohm)

 RBM:     Parasitic modified base resistance value (default value = 0 Ohm)

 RC:      Parasitic collector resistance value (default value = 0 Ohm)

 RE:      Parasitic emitter resistance value (default value = 0 Ohm)


<b>Junction Capacitor Parameters:</b>

 CJC:     Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 MJC:     Base-collector gradation exponent (default value = 0.333)

 VJC:     Base-collector diffusion voltage (default value = 0.8 Volt)

 CJE:     Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 MJE:     Base-emitter gradation exponent (default value = 0.4)

 VJE:     Base-emitter diffusion voltage (default value = 0.8 Volt)

 CJS:     Substrate zero bias depletion capacitance (default value = 0.4e-12 F)

 MJS:     Substrate gradation exponent (default value = 0.4)

 VJS:     Substrate diffusion voltage (default value = 0.8 Volt)

 XCJC:    Portion of depletion capacitance considered inside base-collector junction (default value = 1)


<b>Transit Time Parameters:</b>

 TF:      Ideal forward transit time (default value = 0.12e-9 sec)

 TR:      Ideal reverse transit time (default value = 5e-9 sec)


<b>Temperature Compensation and Area Parameters:</b>

 TRB1:    Linear temperature coefficient of base resistance (default value = 0 Ohm/degree)

 TRB2:    Quadratic temperature coefficient of base resistance (default value = 0 Ohm/(degree*degree))

 TRM1:    Linear temperature coefficient of modified base resistance (default value = 0 Ohm/degree)

 TRM2:    Quadratic temperature coefficient of modified base resistance (default value = 0 Ohm/(degree*degree))

 TRC1:    Linear temperature coefficient of collector resistance (default value = 0 Ohm/degree)

 TRC2:    Quadratic temperature coefficient of collector resistance (default value = 0 Ohm/(degree*degree))

 TRE1:    Linear temperature coefficient of emitter resistance (default value = 0 Ohm/degree)

 TRE2:    Quadratic temperature coefficient of emitter resistance (default value = 0 Ohm/(degree*degree))

 Tnom:    Reference temperature (default value = 300.15 <sup>o</sup>K)

 XTI:     Temperature exponent of saturation current (default value = 3)

 XTB:     Temperature ratio exponent (default value = 0)

 EG:      Activation energy (default value = 1.16 Volt)

 Area:    Relative area occupied by device (default value = 1)


<b>Substrate parameters:</b>

 VS:      Substrate potential (default value = 0 Volt)

  
<b>Numerical Parameters:</b>

 EMin:    Minimum exponent (default value = -100)

 EMax:    Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li>Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York.
<li>Hild, D.R. and F.E. Cellier (1994), \"Object-oriented electronic circuit modeling using Dymola,\"
    <i>Proc. OOS'94, SCS Object Oriented Simulation Conference</i>, Tempe, AZ, pp.68-75.
<li>Hild, D.R. (1993), <i>Circuit Modeling in Dymola</i>, MS Thesis, Dept. of Electr. &amp; Comp. Engr.,
    University of Arizona, Tucson.
<li>Schweisguth, M.C. and F.E. Cellier (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/BJT.pdf\">A
    bond graph model of the bipolar junction transistor</a>,\" <i>Proc. SCS Intl. Conf. on Bond Graph Modeling</i>,
    San Francisco, CA, pp.344-349.
<li>Schweisguth, M.C. (1997), <a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/schweisguth_ms.pdf\"><i>Semiconductor
    Modeling with Bondgraphs</i></a>, MS Thesis, Dept. of Electr. &amp; Comp. Engr., University of Arizona, Tucson.
</ol> 
</html>
"));
      BondLib.Spice.Utilities.PNPint PNPint1(
        BF=BF,
        BR=BR,
        IS=IS,
        NF=NF,
        NR=NR,
        GminDC=GminDC,
        ISC=ISC,
        ISE=ISE,
        NC=NC,
        NE=NE,
        VAF=VAF,
        VAR=VAR,
        IKF=IKF,
        IKR=IKR) annotation (extent=[0,-40; 40,0]);
      BondLib.Junctions.J0p2 J0p2_1 
        annotation (extent=[80,10; 100,30], rotation=90);
      BondLib.Bonds.fBond B8 annotation (extent=[80,-10; 100,10], rotation=90);
      equation 
      connect(RB1.BondCon2, B5.fBondCon1) annotation (points=[-20,-40; -20,-40],
          style(color=8, rgbcolor={192,192,192}));
      connect(C01.y, DS1.C0) annotation (points=[113.4,50; 108,50; 108,60],
          style(color=74, rgbcolor={0,0,127}));
      connect(qb1.y, DS1.qb) annotation (points=[86.6,50; 92,50; 92,60], style(
            color=74, rgbcolor={0,0,127}));
      connect(J0p2_4.BondCon1, BondCon2) annotation (points=[20,-120; 0,-120],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p2_3.BondCon2, BondCon4) annotation (points=[20,120; 0,120],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_3.BondCon2, BondCon1) annotation (points=[-110,1.22461e-015; 
            -115,1.22461e-015; -115,0; -120,0], style(color=8, rgbcolor={192,
              192,192}));
      connect(J0p3_3.BondCon3, B21.BondCon1) annotation (points=[-100,10; -100,
            10.2], style(color=8, rgbcolor={192,192,192}));
      connect(B21.BondCon2, J1p3_5.BondCon1) annotation (points=[-100,30; -100,
            30], style(color=8, rgbcolor={192,192,192}));
      connect(B22.BondCon1, J1p3_5.BondCon2) annotation (points=[-100,50.2;
            -100,50], style(color=8, rgbcolor={192,192,192}));
      connect(Cbx1.BondCon2, B24.fBondCon1) annotation (points=[-30,40; -30,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p6_1.BondCon2, B25.fBondCon1) annotation (points=[80,-90; 80,
            -90], style(color=8, rgbcolor={192,192,192}));
      connect(B25.eBondCon1, J0p3_4.BondCon2) annotation (points=[100,-90; 100,
            -90], style(color=8, rgbcolor={192,192,192}));
      connect(B4.BondCon1, J1p3_1.BondCon3) annotation (points=[-60,-10.2; -60,
            -10], style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_5.BondCon3, B23.BondCon1) annotation (points=[-90,40; -89.8,
            40], style(color=8, rgbcolor={192,192,192}));
      connect(B23.BondCon2, Cbx1.BondCon1) annotation (points=[-70,40; -70,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(B4.BondCon2, RB1.BondCon1) annotation (points=[-60,-30; -60,-40],
          style(color=8, rgbcolor={192,192,192}));
      connect(B13.BondCon1, J1p3_3.BondCon3) annotation (points=[9.8,70; 10,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(RC1.BondCon1, B13.BondCon2) annotation (points=[-10,70; -10,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B14.fBondCon1, RC1.BondCon2) annotation (points=[-50,70; -50,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B22.BondCon2, J0p4_1.BondCon1) annotation (points=[-100,70; -100,
            88; 0,88; 0,30; 10,30], style(color=8, rgbcolor={192,192,192}));
      connect(B9.BondCon1, J1p3_2.BondCon3) annotation (points=[60,40.2; 60,40],
          style(color=8, rgbcolor={192,192,192}));
      connect(B9.BondCon2, DS1.BondCon1) annotation (points=[60,60; 60,70; 80,
            70], style(color=8, rgbcolor={192,192,192}));
      connect(B10.fBondCon1, DS1.BondCon2) annotation (points=[120,80; 120,70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B17.BondCon1, J1p3_4.BondCon3) annotation (points=[9.8,-70; 10,
            -70], style(color=8, rgbcolor={192,192,192}));
      connect(RE1.BondCon1, B17.BondCon2) annotation (points=[-10,-70; -10,-70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B18.fBondCon1, RE1.BondCon2) annotation (points=[-50,-70; -50,-70],
          style(color=8, rgbcolor={192,192,192}));
      connect(B10.eBondCon1, J0p3_4.BondCon1) annotation (points=[120,100; 120,
            108; 132,108; 132,-90; 120,-90], style(color=8, rgbcolor={192,192,
              192}));
      connect(B5.eBondCon1, J0p6_1.BondCon1) annotation (points=[0,-40; 8,-40;
            8,-52; 60,-52; 60,-90], style(color=8, rgbcolor={192,192,192}));
      connect(B19.eBondCon1, J0p6_1.BondCon5) annotation (points=[60,-20; 66,
            -20; 66,-80], style(color=8, rgbcolor={192,192,192}));
      connect(B24.eBondCon1, J0p6_1.BondCon6) annotation (points=[-10,40; -6,40;
            -6,12; 74,12; 74,-80], style(color=8, rgbcolor={192,192,192}));
      connect(J0p3_4.BondCon3, BondCon3) annotation (points=[110,-80; 120,-80;
            120,0], style(color=8, rgbcolor={192,192,192}));
      connect(B18.eBondCon1, J0p6_1.BondCon3) annotation (points=[-70,-70; -76,
            -70; -76,-88; 48,-88; 48,-100; 66,-100], style(color=8, rgbcolor={
              192,192,192}));
      connect(B14.eBondCon1, J0p6_1.BondCon4) annotation (points=[-70,70; -80,
            70; -80,-92; 44,-92; 44,-104; 74,-104; 74,-100], style(color=8,
            rgbcolor={192,192,192}));
      connect(PNPint1.BondCon3, B19.fBondCon1) annotation (points=[40,-20; 40,
            -20], style(color=8, rgbcolor={192,192,192}));
      connect(PNPint1.qb, RB1.qb) annotation (points=[41.4286,-33.4286; 50,
            -33.4286; 50,-48; 12,-48; 12,-24; -40,-24; -40,-30], style(color=74,
            rgbcolor={0,0,127}));
      connect(B2.BondCon2, J1p3_1.BondCon2) annotation (points=[-50,
            1.22461e-015; -41,1.22461e-015; -41,0; -50,0], style(color=8,
            rgbcolor={192,192,192}));
      connect(B2.BondCon1, PNPint1.BondCon1) annotation (points=[-30.2,
            -1.20011e-015; -20,-1.20011e-015; -20,-20; 0,-20], style(color=8,
            rgbcolor={192,192,192}));
      connect(B3.BondCon1, J1p3_1.BondCon1) annotation (points=[-70.2,
            -1.20011e-015; -70,-1.20011e-015; -70,0], style(color=8, rgbcolor={
              192,192,192}));
      connect(B3.BondCon2, J0p3_3.BondCon1) annotation (points=[-90,
            1.22461e-015; -90,-1.22461e-015], style(color=8, rgbcolor={192,192,
              192}));
      connect(J0p2_3.BondCon1, B12.BondCon2) annotation (points=[20,100; 20,100],
          style(color=8, rgbcolor={192,192,192}));
      connect(B12.BondCon1, J1p3_3.BondCon2) annotation (points=[20,80.2; 20,80],
          style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_3.BondCon1, B11.BondCon2) annotation (points=[20,60; 20,60],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p4_1.BondCon4, B11.BondCon1) annotation (points=[20,40; 20,40.2],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p4_1.BondCon3, B20.BondCon2) annotation (points=[20,20; 20,20],
          style(color=8, rgbcolor={192,192,192}));
      connect(PNPint1.BondCon4, B20.BondCon1) annotation (points=[20,0; 20,0.2],
          style(color=8, rgbcolor={192,192,192}));
      connect(PNPint1.BondCon2, B15.BondCon2) annotation (points=[20,-40; 20,
            -40], style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_4.BondCon2, B15.BondCon1) annotation (points=[20,-60; 20,
            -59.8], style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_4.BondCon1, B16.BondCon2) annotation (points=[20,-80; 20,-80],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p2_4.BondCon2, B16.BondCon1) annotation (points=[20,-100; 20,
            -99.8], style(color=8, rgbcolor={192,192,192}));
      connect(J0p4_1.BondCon2, B7.BondCon1) annotation (points=[30,30; 30.2,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_2.BondCon1, B7.BondCon2) annotation (points=[50,30; 50,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(J1p3_2.BondCon2, B6.BondCon1) annotation (points=[70,30; 70.2,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(J0p2_1.BondCon2, B6.BondCon2) annotation (points=[90,30; 90,30],
          style(color=8, rgbcolor={192,192,192}));
      connect(B8.fBondCon1, J0p2_1.BondCon1) annotation (points=[90,10; 90,10],
          style(color=8, rgbcolor={192,192,192}));
      connect(B8.eBondCon1, VS1.BondCon1) annotation (points=[90,-10; 90,-10],
          style(color=8, rgbcolor={192,192,192}));
      end PNPvert;
    
      package Utilities "Utility models of Spice circuit element models" 
      annotation (Icon(
            Rectangle(extent=[-100,-100; 80,50], style(
                color=42,
                rgbcolor={127,0,0},
                fillColor=30,
                rgbfillColor={235,235,235},
                fillPattern=1)),
            Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50], style(
                color=42,
                rgbcolor={127,0,0},
                fillColor=30,
                rgbfillColor={235,235,235},
                fillPattern=1)),
            Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70], style(
                color=42,
                rgbcolor={127,0,0},
                fillColor=30,
                rgbfillColor={235,235,235},
                fillPattern=1)),
            Text(
              extent=[-85,35; 65,-85],
              string="Library",
              style(color=42, rgbcolor={127,0,0})),
            Text(
              extent=[-120,122; 120,73],
              string="%name",
              style(color=1))), Documentation(info="<html>
This package contains some utility models used within the Spice-style circuit element models.
</html>
"));
        block BJTvars 
        "Space charge and injected currents of bipolar transistors" 
          constant Real k=Modelica.Constants.k "Boltzmann's constant";
          constant Modelica.SIunits.ElectricCharge q=1.6021892e-19 
          "Electron charge";
          constant Real GapC1=7.02E-4 "First bandgap correction factor Silicon";
          constant Real GapC2=1108.0 "Second bandgap correction factor Silicon";
          parameter Modelica.SIunits.Temperature Tnom=300.15 
          "Reference temperature";
          parameter Real BF=50 
          "Forward beta coefficient at reference temperature";
          parameter Real BR=0.1 
          "Reverse beta coefficient at reference temperature";
          parameter Modelica.SIunits.Time TF=0.12e-9 
          "Ideal forward transit time";
          parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
          parameter Real XTI=3 "Temperature exponent of saturation current";
          parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
          parameter Modelica.SIunits.Voltage VAR=9e30 "Backward early voltage";
          parameter Modelica.SIunits.Current IKF=9e30 
          "Forward junction beta degradation current";
          parameter Modelica.SIunits.Current IKR=9e30 
          "Backward junction beta degradation current";
          parameter Modelica.SIunits.Current ISC 
          "Collector saturation current at reference temperature";
          parameter Modelica.SIunits.Current ISE 
          "Emitter saturation current at reference temperature";
          parameter Real NC=2 "Collector beta degradation coefficient";
          parameter Real NE=1.5 "Emitter beta degradation coefficient";
          parameter Real XTB=0 "Temperature ratio exponent";
          parameter Real Area=1 "Relative area occupied by resistor";
          output Modelica.SIunits.Voltage Vt "Thermal voltage";
          output Modelica.SIunits.Energy EGval 
          "Activation energy at device temperature";
          output Modelica.SIunits.Current ISCval 
          "Collector saturation current at device temperature";
          output Modelica.SIunits.Current ISEval 
          "Emitter saturation current at device temperature";
          output Modelica.SIunits.Current icn 
          "Beta degradation collector current";
          output Modelica.SIunits.Current ien 
          "Beta degradation emitter current";
        
      protected 
          Real RTemp "Temperature quotient";
          Real Rxtb "Exponentiated temperature quotient";
          Real q1 "Primary base charge";
          Real q2 "Secondary base charge";
          Real dq1 "Derivative of q1";
          Real dq2 "Derivative of q2";
          Real dqb "Derivative of qb";
          Real BFval "Forward beta coefficient at device temperature";
          Real BRval "Backward beta coefficient at device temperature";
          Real facln 
          "Logarithm of temperature dependence of saturation current";
      public 
        Modelica.Blocks.Interfaces.RealInput vbc 
          annotation (extent=[-120,50; -100,70]);
        Modelica.Blocks.Interfaces.RealInput vbe 
          annotation (extent=[-120,-30; -100,-10]);
        Modelica.Blocks.Interfaces.RealInput ibc 
          annotation (extent=[-120,10; -100,30]);
        annotation (Diagram(
            Rectangle(extent=[-100,100; 100,-100], style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=7,
                rgbfillColor={255,255,255})),
            Text(
              extent=[-72,58; 76,20],
              style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1),
              string="Injected currents"),
            Text(
              extent=[-18,22; 16,-2],
              style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1),
              string="and"),
            Text(
              extent=[-68,-6; 70,-28],
              style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1),
              string="base charge")), Icon(
            Rectangle(extent=[-100,100; 100,-100], style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=7,
                rgbfillColor={255,255,255})),
            Text(
              extent=[-70,58; 78,20],
              style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1),
              string="Injected currents"),
            Text(
              extent=[-18,22; 16,-2],
              style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1),
              string="and"),
            Text(
              extent=[-68,-6; 70,-28],
              style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1),
              string="base charge")));
        Modelica.Blocks.Interfaces.RealInput ibe 
          annotation (extent=[-120,-70; -100,-50]);
        Modelica.Blocks.Interfaces.RealOutput qb 
          annotation (extent=[100,-30; 120,-10]);
        Modelica.Blocks.Interfaces.RealOutput C0 
          annotation (extent=[100,-70; 120,-50]);
        Modelica.Blocks.Interfaces.RealOutput ib0 
          annotation (extent=[100,50; 120,70]);
        Modelica.Blocks.Interfaces.RealOutput ic0 
          annotation (extent=[100,10; 120,30]);
        Modelica.Blocks.Interfaces.RealInput Tdev 
          annotation (extent=[-10,-120; 10,-100], rotation=90);
        equation 
          RTemp = Tdev/Tnom;
          Rxtb = RTemp^XTB;
        
          /* Compute thermal voltage as function of temperature */
          Vt = k*Tdev/q;
        
          /* Compute base charge */
          q1 = 1/(1 - vbc/VAF - vbe/VAR);
          q2 = (ibc/IKR + ibe/IKF) / Area;
          qb = q1*0.5*(1 + sqrt(1 + 4*q2));
        
          /* Compute derivatives of base charge */
          dq1 = 1/(VAR*q1*q1);
          dq2 = (ien + ISEval)/(Vt*NC*IKF);
          dqb = qb*dq1/q1 + q1*dq2/sqrt(1+4*q2);
          C0 = ibe*TF*dqb/(qb*qb);
        
          /* Compute non-linear current sources */
          BFval = BF*Rxtb;
          BRval = BR*Rxtb;
          EGval = EG - GapC1*Tdev*Tdev/(Tdev + GapC2);
          facln  = (RTemp - 1)*EGval/Vt + XTI*ln(RTemp);
          ISCval = ISC*exp(facln/NC)/Rxtb;
          ISEval = ISE*exp(facln/NE)/Rxtb;
          icn = Area*ISCval*(exp(vbc/(Vt*NC)) - 1);
          ien = Area*ISEval*(exp(vbe/(Vt*NE)) - 1);
          ic0 = (ibe - ibc)/qb - ibc/BRval - icn;
          ib0 = ibe/BFval + ibc/BRval + ien + icn - ibe;
        
        end BJTvars;
      
        model RBS "Spice-style base resistor model of bipolar transistors" 
          extends Interfaces.SpiceTwoPort;
          constant Real pi=Modelica.Constants.pi;
          parameter Modelica.SIunits.Resistance RB=0 
          "Resistance at reference temperature";
          parameter Modelica.SIunits.Resistance RBM=0 
          "Modified resistance at reference temperature";
          parameter Modelica.SIunits.Current IRB=0 
          "Reference base current at reference temperature";
          parameter Real TRB1=0 "Linear temperature coefficient [Ohm/degree]";
          parameter Real TRB2=0 
          "Quadratic temperature coefficient [Ohm/(degree*degree)]";
          parameter Real TRM1=0 "Linear temperature coefficient [Ohm/degree]";
          parameter Real TRM2=0 
          "Quadratic temperature coefficient [Ohm/(degree*degree)]";
          parameter Real Area=1 "Relative area occupied by resistor";
          Modelica.SIunits.Resistance RBval 
          "Base resistance value at circuit temperature";
          Modelica.SIunits.Resistance RBMval 
          "Modified base resistance value at circuit temperature";
          Modelica.SIunits.Resistance Rval 
          "Resistance value at circuit temperature";
        
      protected 
          parameter Real piSq = pi*pi;
          /*
  Real z;
  Real tz;
  */
        annotation (
          Icon(
              Text(
                extent=[-82,76; 28,-80],
                style(color=0),
              string="RBS"),
              Text(extent=[-72,-58; 66,-86], string="R=%RB")),
          Diagram(
              Text(
                extent=[-82,76; 28,-80],
                style(color=0),
              string="RBS")),
          Documentation(info="<html>
The base resistor is the most important of the parasitic resistors of a bipolar transistor.  For this reason, Spice models this resistor using a more sophisticated model with additional parameters. <p>

<hr> <p>

<pre>
Parameters:

 RB:    Reference base resistance (default value = 0 Ohm)

 RBM:   Reference modified base resistance (default value = 0 Ohm)

 IRB:   Reference base resistance current (default value = 0 Amp)

 Tnom:  Reference temperature (default value = 300.15 <sup>o</sup>K)

 TRB1:  Linear temperature variation coefficient of RB (default value = 0 Ohm/<sup>o</sup>K)

 TRB2:  Quadratic temperature variation coefficient of RB (default value = 0 Ohm/<sup>o</sup>K<sup>2</sup>)

 TRM1:  Linear temperature variation coefficient of RBM (default value = 0 Ohm/<sup>o</sup>K)

 TRM2:  Quadratic temperature variation coefficient of RBM (default value = 0 Ohm/<sup>o</sup>K<sup>2</sup>)

 Area:  Relative area occupied by resistor (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>DTemp = e2 - Tnom</b> <br>
<b>RBval = RB*(1 + TRB1*DTemp + TRB2*DTemp*DTemp)/Area</b> <br>
<b>RBMval = RBM*(1 + TRM1*DTemp + TRM2*DTemp*DTemp)/Area</b> <br>
<b>z = if IRB &gt; 0 then (-1 + sqrt(1 + 144*f1/(pi*pi*IRB*Area)))/(24*sqrt(f1/(IRB*Area))/(pi*pi)) else 0</b> <br>
<b>tz = if IRB &gt; 0 then tan(z) else 0</b> <br>
<b>Rval = if IRB &gt; 0 then (Rbmval + 3*(Rbval - Rbmval)*(tz-z)/(z*tz*tz)) else (Rbmval + (Rbval - Rbmval)/qb)</b> <br>
<b>e1 = Rval*f1</b> <br>
<b>f2 = (e1/e2)*f1</b>
</html>
"));
      public 
        Modelica.Blocks.Interfaces.RealInput qb 
          annotation (extent=[-10,90; 10,110], rotation=-90);
        equation 
          RBval = RB*(1 + TRB1*DTemp + TRB2*DTempSq)/Area;
          RBMval = RBM*(1 + TRM1*DTemp + TRM2*DTempSq)/Area;
          /*
  z = if IRB > 0 then (-1 + sqrt(1 + 144*f1/(piSq*IRB*Area)))/(24*sqrt(f1/(IRB*Area))/piSq) else 0;
  tz = if IRB > 0 then tan(z) else 0;
  Rval = if IRB > 0 then (RBMval + 3*(RBval - RBMval)*(tz-z)/(z*tz*tz)) else (RBMval + (RBval - RBMval)/qb);
  */
          Rval = RBMval + (RBval - RBMval)/qb;
          e1 = Rval*f1;
          e1*f1 = e2*f2;
        end RBS;
      
        model CjS 
        "Spice-style junction capacitor model for bipolar transistors" 
          extends Interfaces.SpiceTwoPort;
          constant Real k=Modelica.Constants.k "Boltzmann's constant";
          constant Modelica.SIunits.ElectricCharge q=1.6021892e-19 
          "Electron charge";
          constant Real GapC1=7.02E-4 "First bandgap correction factor Silicon";
          constant Real GapC2=1108.0 "Second bandgap correction factor Silicon";
          parameter Modelica.SIunits.Current IS=1e-16 
          "Saturation current at reference temperature";
          parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
          parameter Real N=1 "Emission coefficient";
          parameter Real XTI=3 "Temperature exponent of saturation current";
          parameter Modelica.SIunits.Voltage VJ=0.75 
          "Junction diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJ=0.5e-12 
          "Junction zero bias depletion capacitance at reference temperature";
          parameter Real XCJ=1 
          "Portion of depletion capacitance considered inside the junction";
          parameter Real MJ=0.333 "Junction gradation exponent";
          parameter Modelica.SIunits.Time Tau=1e-9 "Ideal transit time";
          parameter Modelica.SIunits.Conductance GminDC=1e-15 
          "Leakage conductance";
          parameter Real Area=1 "Relative area occupied by capacitor";
          parameter Boolean BE=true "True if base-emitter junction";
          Modelica.SIunits.Voltage Vt "Thermal voltage";
          Modelica.SIunits.Current ISval 
          "Saturation current at device temperature";
          Modelica.SIunits.Voltage VJval 
          "Diffusion voltage at device temperature";
          Modelica.SIunits.Capacitance CJval 
          "Depletion capacitance at device temperature";
          Modelica.SIunits.Energy EGval 
          "Activation energy at device temperature";
          Modelica.SIunits.Energy EGref 
          "Activation energy at reference temperature";
          Modelica.SIunits.Capacitance Cval 
          "Total junction capacitance at device temperature";
        
      protected 
          Real RTemp "Temperature quotient";
          Modelica.SIunits.Current ISe 
          "Diodic current responsible for diffusion";
          Modelica.SIunits.Capacitance Cdiff1 
          "Part of diffusion capacitance at device temperature";
          Modelica.SIunits.Capacitance Cdiff 
          "Diffusion capacitance at device temperature";
          Modelica.SIunits.Capacitance Cdepl 
          "Corrected depletion capacitance at device temperature";
        annotation (
          Icon(
              Text(
                extent=[-82,76; 28,-80],
                style(color=0),
              string="CjS")),
          Diagram(
              Text(
                extent=[-82,76; 28,-80],
                style(color=0),
              string="CjS")),
          Documentation(info="<html>
The Spice-style junction capacitance computes both the depletion capacitance value and the diffusion capacitance value of a junction used in a bipolar transistor.  Different Spice dialects vary in the formulae they use for this purpose.  Many Spice dialects actually don't use a formula for the junction capacitance at all, but rather compute the electric charge stored in the junction directly, which is conceptually cleaner.  However, that approach is computationally cumbersome, as it leads to an awkward algebraic loop [1].  Thus, we chose to compute the junction capacitance, and use a (physically incorrect) approximate non-linear capacitor model (just as in the case of the simpler Ebers-Moll model).  The numerical error should remain small, as the time constants associated with temperature change are much larger than those associated with electrical phenomena. <p>

This particular model uses the space charge formula proposed by van Halen [2].  Since: <p>

<b>f = der(q)</b> <p>

the space charge, <b>q</b>, was symbolically differentiated.  In the differentiation, only electrical signals, i.e., the voltage, <b>e</b>, were considered time-varying.  The temperature gradients were assumed to be negligible.  This produced an equation of the form: <p>

<b>f = C(e)*der(e)</b> <p>

which is the formula that was used to compute the non-linear capacitance <b>C(e)</b> in the model. <p>

<hr>

<pre>
Parameters:

 Is:      Transport saturation current (default value = 1e-16 Amp)

 EG:      Activation energy (default value = 1.16 Volt)

 N:       Emission coefficient (default value = 1)

 XTI:     Temperature exponent of saturation current (default value = 3)

 VJ:      Diffusion voltage (default value = 0.75 Volt)

 CJ:      Zero bias depletion capacitance (default value = 0.5e-12 F)

 XCJ:     Portion of depletion capacitance considered inside the junction (default value = 1)

 MJ:      Gradation exponent (default value = 0.333)

 Tau:     Ideal transit time (default value = 1e-9 sec)

 GminDC:  Leakage conductance (default value = 1e-15 Mho)

 Area:    Relative area occupied by the diode (default value = 1)

 BE:      True if base-emitter junction (default value = true)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York, pp. 224-225.
<li> van Halen, P. (1988), \"A new semiconductor junction diode space charge layer capacitance model,\"
     <i>Proc. IEEE 1988 Bipolar Circuits &amp; Technology Meeting</i>, Minneapolis, MN, pp. 168-171.
</ol>
</html>
"));
      public 
        Modelica.Blocks.Interfaces.RealInput qb 
          annotation (extent=[-50,-110; -30,-90], rotation=90);
        Modelica.Blocks.Interfaces.RealInput C0 
          annotation (extent=[30,-110; 50,-90], rotation=90);
        equation 
          /* Compute thermal voltage as function of temperature */
          Vt = k*e2/q;
        
          /* Compute temperature dependence of saturation current and junction capacitance */
          RTemp = e2/Tnom;
          EGval = EG - GapC1*e2*e2/(e2 + GapC2);
          EGref = EG - GapC1*Tnom*Tnom/(Tnom + GapC2);
          ISval = IS*exp((RTemp - 1)*EGval/(Vt*N) + (XTI/N)*ln(RTemp));
          VJval = VJ*RTemp + EGval - EGref*RTemp - 3*Vt*ln(RTemp);
          CJval = CJ*(1 + MJ*(1 - VJval/VJ + 4e-4*DTemp));
        
          /* Compute diffusion capacitance */
          ISe = ISval*exp(e1/(Vt*N));
          Cdiff1 = Tau*(ISe/(Vt*N) + GminDC);
          Cdiff = if BE then Cdiff1/qb - C0 else Cdiff1;
        
          /* Compute depletion capacitance */
          Cdepl = Area*CJval/((1 - (e1 - 0.5*Vt*exp((e1 - VJval)/Vt))/VJval)^MJ);
        
          /* Non-linear capacitor */
          Cval = Cdiff + XCJ*Cdepl;
          f1 = Cval*der(e1);
        
          /* Compute heat flow */
          f2 = 0;
        end CjS;
      
        model CbxS 
        "Spice-style extenral base-collector capacitance model for bipolar transistors" 
          extends Interfaces.SpiceTwoPort;
          constant Real k=Modelica.Constants.k "Boltzmann's constant";
          constant Modelica.SIunits.ElectricCharge q=1.6021892e-19 
          "Electron charge";
          constant Real GapC1=7.02E-4 "First bandgap correction factor Silicon";
          constant Real GapC2=1108.0 "Second bandgap correction factor Silicon";
          parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
          parameter Modelica.SIunits.Voltage VJ=0.75 
          "Junction diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJ=0.5e-12 
          "Junction zero bias depletion capacitance at reference temperature";
          parameter Real XCJ=1 
          "Portion of depletion capacitance considered inside the junction";
          parameter Real MJ=0.333 "Junction gradation exponent";
          parameter Real Area=1 "Relative area occupied by capacitor";
          Modelica.SIunits.Voltage Vt "Thermal voltage";
          Modelica.SIunits.Voltage VJval 
          "Diffusion voltage at device temperature";
          Modelica.SIunits.Capacitance CJval 
          "Depletion capacitance at device temperature";
          Modelica.SIunits.Energy EGval 
          "Activation energy at device temperature";
          Modelica.SIunits.Energy EGref 
          "Activation energy at reference temperature";
          Modelica.SIunits.Capacitance Cval 
          "Total junction capacitance at device temperature";
        
      protected 
          Real RTemp "Temperature quotient";
          Modelica.SIunits.Capacitance Cdepl 
          "Corrected depletion capacitance at device temperature";
        annotation (
          Icon(
              Text(
                extent=[-84,76; 26,-80],
                style(color=0),
              string="CbxS")),
          Diagram(
              Text(
                extent=[-84,76; 26,-80],
                style(color=0),
              string="CbxS")),
          Documentation(info="<html>
The Spice-style external base-collector capacitance computes the external depletion capacitance value of a bipolar transistor.  The external base-collector capacitance leads invariably to a higher-index DAE, when used.  For this reason, an if statement has been added to prevent unnecessary differentiation in the (frequent) case, where the entire depletion capacitance is considered inside the base-collector junction. <p>

<hr>

<pre>
Parameters:

 EG:      Activation energy (default value = 1.16 Volt)

 VJ:      Diffusion voltage (default value = 0.75 Volt)

 CJ:      Zero bias depletion capacitance (default value = 0.5e-12 F)

 XCJ:     Portion of depletion capacitance considered inside the junction (default value = 1)

 MJ:      Gradation exponent (default value = 0.333)

 Area:    Relative area occupied by the diode (default value = 1)
</pre>
</html>
"));
        equation 
          /* Compute thermal voltage as function of temperature */
          Vt = k*e2/q;
        
          /* Compute temperature dependence of saturation current and junction capacitance */
          RTemp = e2/Tnom;
          EGval = EG - GapC1*e2*e2/(e2 + GapC2);
          EGref = EG - GapC1*Tnom*Tnom/(Tnom + GapC2);
          VJval = VJ*RTemp + EGval - EGref*RTemp - 3*Vt*ln(RTemp);
          CJval = CJ*(1 + MJ*(1 - VJval/VJ + 4e-4*DTemp));
        
          /* Compute external depletion capacitance */
          Cdepl = Area*CJval/((1 - (e1 - 0.5*Vt*exp((e1 - VJval)/Vt))/VJval)^MJ);
        
          /* Non-linear capacitor */
          Cval = (1 - XCJ)*Cdepl;
          f1 = if XCJ < 1 then Cval*der(e1) else 0;
        
          /* Compute heat flow */
          f2 = 0;
        end CbxS;
      
        model DjS "Spice-style junction diode model for bipolar transistors" 
          extends BondLib.Interfaces.TwoPort;
          parameter Modelica.SIunits.Temperature Tnom=300.15 
          "Reference temperature";
          parameter Modelica.SIunits.Current IS=1e-16 
          "Saturation current at reference temperature";
          parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
          parameter Real N=1 "Emission coefficient";
          parameter Real XTI=3 "Temperature exponent of saturation current";
          parameter Modelica.SIunits.Voltage VJ=0.75 
          "Junction diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJ=0.5e-12 
          "Junction zero bias depletion capacitance at reference temperature";
          parameter Real XCJ=1 
          "Portion of depletion capacitance considered inside the junction";
          parameter Real MJ=0.333 "Junction gradation exponent";
          parameter Modelica.SIunits.Time Tau=1e-9 "Ideal transit time";
          parameter Modelica.SIunits.Conductance GminDC=1e-15 
          "Leakage conductance";
          parameter Real Area=1 "Relative area occupied by diode";
          parameter Boolean BE=true "True if base-emitter junction";
          parameter Real EMin=-100 
          "if x < EMin, the exp(x) function is linearized";
          parameter Real EMax=40 
          "if x > EMax, the exp(x) function is linearized";
        annotation (
          Icon(
              Text(
                extent=[-82,78; 28,-78],
                style(color=0),
              string="DjS"),
              Text(
                extent=[24,-4; 92,-34],
                string="Spice",
                style(color=0, rgbcolor={0,0,0})),
              Text(extent=[-40,80; 40,50],   string="%name")),
          Diagram,
          Documentation(info="<html>
The Spice-style junction diode consists of a parallel connection of a regular diode, a highly non-linear junction capacitance, and a leakage conductance. <p>

<hr>

<pre>
Parameters:

 Is:      Transport saturation current (default value = 1e-16 Amp)

 EG:      Activation energy (default value = 1.16 Volt)

 N:       Emission coefficient (default value = 1)

 XTI:     Temperature exponent of saturation current (default value = 3)

 VJ:      Diffusion voltage (default value = 0.75 Volt)

 CJ:      Zero bias depletion capacitance (default value = 0.5e-12 F)

 XCJ:     Portion of depletion capacitance considered inside the junction (default value = 1)

 MJ:      Gradation exponent (default value = 0.333)

 Tau:     Ideal transit time (default value = 1e-9 sec)

 GminDC:  Leakage conductance (default value = 1e-15 Mho)

 Area:    Relative area occupied by the diode (default value = 1)

 BE:      True if base-emitter junction (default value = true)

 EMin:    if x &lt; EMin, the exp(x) function is linearized (default value = -100)

 EMax:    if x &gt; EMax, the exp(x) function is linearized (default value = 40)

</pre>
</html>
"));
        Bonds.Bond B2 annotation (extent=[-10,-10; 10,10]);
        Bonds.Bond B1 annotation (extent=[-40,10; -20,30]);
        Bonds.Bond B3 annotation (extent=[-40,-50; -20,-30]);
        DS D1(
          Tnom=Tnom,
          IS=IS,
          EG=EG,
          N=N,
          XTI=XTI,
          Area=Area,
          EMin=EMin,
          EMax=EMax) annotation (extent=[10,30; 50,50]);
        CjS C1(
          Tnom=Tnom,
          IS=IS,
          EG=EG,
          N=N,
          XTI=XTI,
          VJ=VJ,
          CJ=CJ,
          XCJ=XCJ,
          MJ=MJ,
          Tau=Tau,
          GminDC=GminDC,
          Area=Area,
          BE=BE)     annotation (extent=[-20,-50; 20,-30]);
        RS R1(
          Tnom=Tnom,
          R=1/GminDC,
          TR1=0,
          TR2=0,
          Area=1) annotation (extent=[10,-10; 50,10]);
        Junctions.J0p4 J0p4_2 annotation (extent=[70,-10; 90,10]);
        Bonds.eBond B4 annotation (extent=[50,30; 70,50]);
        Bonds.eBond B5 annotation (extent=[50,-10; 70,10]);
        Bonds.eBond B6 annotation (extent=[20,-50; 40,-30]);
        Junctions.J1p3 J1p3_1 annotation (extent=[-60,30; -40,10]);
        Bonds.Bond B7 annotation (extent=[-80,10; -60,30]);
        Bonds.eBond B8 annotation (extent=[-60,30; -40,50], rotation=90);
        Sensors.Df Df1 annotation (extent=[-60,50; -40,70], rotation=90);
        Modelica.Blocks.Interfaces.RealOutput id 
          annotation (extent=[-10,90; 10,110], rotation=90);
        Junctions.J0p3 J0p3_1 annotation (extent=[-20,10; 0,30], rotation=-90);
        Bonds.Bond B9 annotation (extent=[-10,30; 10,50]);
        Modelica.Blocks.Interfaces.RealInput qb 
          annotation (extent=[-50,-110; -30,-90], rotation=90);
        Modelica.Blocks.Interfaces.RealInput C0 
          annotation (extent=[30,-110; 50,-90], rotation=90);
        Junctions.J0p3 J0p3_2 
          annotation (extent=[-90,-10; -70,10], rotation=-90);
        equation 
        connect(J0p4_2.BondCon1, B5.eBondCon1) annotation (points=[70,0; 70,0],
            style(color=8, rgbcolor={192,192,192}));
        connect(J0p4_2.BondCon2, BondCon2) annotation (points=[90,0; 100,0],
            style(color=8, rgbcolor={192,192,192}));
        connect(B4.fBondCon1, D1.BondCon2) annotation (points=[50,40; 50,40],
            style(color=8, rgbcolor={192,192,192}));
        connect(B4.eBondCon1, J0p4_2.BondCon4) annotation (points=[70,40; 80,40;
              80,10], style(color=8, rgbcolor={192,192,192}));
        connect(B6.eBondCon1, J0p4_2.BondCon3) annotation (points=[40,-40; 80,
              -40; 80,-10], style(color=8, rgbcolor={192,192,192}));
        connect(J1p3_1.BondCon2, B1.BondCon1) annotation (points=[-40,20; -39.8,
              20], style(color=8, rgbcolor={192,192,192}));
        connect(B7.BondCon2, J1p3_1.BondCon1) annotation (points=[-60,20; -60,
              20], style(color=8, rgbcolor={192,192,192}));
        connect(J1p3_1.BondCon3, B8.fBondCon1) annotation (points=[-50,30; -50,
              30], style(color=8, rgbcolor={192,192,192}));
        connect(B8.eBondCon1, Df1.BondCon1) annotation (points=[-50,50; -50,50],
            style(color=8, rgbcolor={192,192,192}));
        connect(Df1.OutPort1, id) annotation (points=[-50,71; -50,80; 0,80; 0,
              100], style(color=74, rgbcolor={0,0,127}));
        connect(B1.BondCon2, J0p3_1.BondCon3) annotation (points=[-20,20; -20,
              20], style(color=8, rgbcolor={192,192,192}));
        connect(J0p3_1.BondCon1, B9.BondCon1) annotation (points=[-10,30; -10,
              40; -9.8,40], style(color=8, rgbcolor={192,192,192}));
        connect(B9.BondCon2, D1.BondCon1) annotation (points=[10,40; 10,40],
            style(color=8, rgbcolor={192,192,192}));
        connect(J0p3_1.BondCon2, B2.BondCon1) annotation (points=[-10,10; -10,0;
              -9.8,0], style(color=8, rgbcolor={192,192,192}));
        connect(R1.BondCon1, B2.BondCon2) annotation (points=[10,0; 10,0],
            style(color=8, rgbcolor={192,192,192}));
        connect(R1.BondCon2, B5.fBondCon1) annotation (points=[50,0; 50,0],
            style(color=8, rgbcolor={192,192,192}));
        connect(C1.BondCon1, B3.BondCon2) annotation (points=[-20,-40; -20,-40],
            style(color=8, rgbcolor={192,192,192}));
        connect(C1.BondCon2, B6.fBondCon1) annotation (points=[20,-40; 20,-40],
            style(color=8, rgbcolor={192,192,192}));
        connect(C1.qb, qb) annotation (points=[-8,-50; -8,-70; -40,-70; -40,
              -100], style(color=74, rgbcolor={0,0,127}));
        connect(C1.C0, C0) annotation (points=[8,-50; 8,-70; 40,-70; 40,-100],
            style(color=74, rgbcolor={0,0,127}));
        connect(J0p3_2.BondCon3, BondCon1) annotation (points=[-90,
              -6.12303e-016; -90,-6.12303e-016; -88,0; -100,0], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(J0p3_2.BondCon1, B7.BondCon1) annotation (points=[-80,10; -80,
              15; -80,20; -79.8,20], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(J0p3_2.BondCon2, B3.BondCon1) annotation (points=[-80,-10; -80,
              -40; -39.8,-40], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        end DjS;
      
        model NPNint 
        "Spice-style NPN transistor model without parasitic resistors and substrate diode" 
          /* DC model parameters */
          parameter Real BF=50 
          "Forward beta coefficient at reference temperature";
          parameter Real BR=0.1 
          "Reverse beta coefficient at reference temperature";
          parameter Modelica.SIunits.Current IS=1e-16 
          "Saturation current at reference temperature";
          parameter Real NF=1 "Forward emission coefficient";
          parameter Real NR=1 "Reverse emission coefficient";
          parameter Modelica.SIunits.Conductance GminDC=1e-15 
          "Leakage conductance";
        
          /* Low current beta degradation effect parameters */
          parameter Modelica.SIunits.Current ISC=1e-16 
          "Collector saturation current at reference temperature";
          parameter Modelica.SIunits.Current ISE=1e-16 
          "Emitter saturation current at reference temperature";
          parameter Real NC=2 "Collector beta degradation coefficient";
          parameter Real NE=1.5 "Emitter beta degradation coefficient";
        
          /* Base width modulation parameters */
          parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
          parameter Modelica.SIunits.Voltage VAR=9e30 "Reverse early voltage";
        
          /* High current beta degradation effect parameters */
          parameter Modelica.SIunits.Current IKF=9e30 
          "Forward junction beta degradation current";
          parameter Modelica.SIunits.Current IKR=9e30 
          "Reverse junction beta degradation current";
        
          /* Junction capacitor parameters */
          parameter Modelica.SIunits.Capacitance CJC=0.5e-12 
          "Base-collector zero bias depletion capacitance at reference temperature";
          parameter Real MJC=0.333 "Base-collector gradation exponent";
          parameter Modelica.SIunits.Voltage VJC=0.8 
          "Base-collector diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJE=0.4e-12 
          "Base-emitter zero bias depletion capacitance at reference temperature";
          parameter Real MJE=0.4 "Base-emitter gradation exponent";
          parameter Modelica.SIunits.Voltage VJE=0.8 
          "Base-emitter diffusion voltage at reference temperature";
          parameter Real XCJC=1 
          "Portion of depletion capacitance considered inside base-collector junction";
        
          /* Transit time parameters */
          parameter Modelica.SIunits.Time TF=0.12e-9 
          "Ideal forward transit time";
          parameter Modelica.SIunits.Time TR=5e-9 "Ideal reverse transit time";
        
          /* Temperature compensation and area parameters */
          parameter Modelica.SIunits.Temperature Tnom=300.15 
          "Reference temperature";
          parameter Real XTI=3 "Temperature exponent of saturation current";
          parameter Real XTB=0 "Temperature ratio exponent";
          parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
          parameter Real Area=1 "Relative area occupied by device";
        
          /* Numerical parameters */
          parameter Real EMin=-100 
          "if x < EMin, the exp(x) function is linearized";
          parameter Real EMax=40 
          "if x > EMax, the exp(x) function is linearized";
        annotation (Coordsys(extent=[-140,-140; 140,140]), Diagram(Ellipse(extent=[
                  128,-92; 134,-98], style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=74,
                rgbfillColor={0,0,127},
                fillPattern=1)),
            Text(
              extent=[-152,28; -126,12],
              style(color=10, rgbcolor={135,135,135}),
              string="Bint"),
            Text(
              extent=[10,148; 36,130],
              style(color=10, rgbcolor={135,135,135}),
              string="Cint"),
            Text(
              extent=[10,-132; 36,-150],
              style(color=10, rgbcolor={135,135,135}),
              string="Eint"),
            Text(
              extent=[126,-2; 158,-28],
              style(color=10, rgbcolor={135,135,135}),
              string="Heat"),
            Text(
              extent=[-90,22; -78,10],
              style(color=10, rgbcolor={135,135,135}),
              string="vbc"),
            Text(
              extent=[-98,-12; -86,-24],
              style(color=10, rgbcolor={135,135,135}),
              string="vbe"),
            Text(
              extent=[-126,-38; -114,-50],
              style(color=10, rgbcolor={135,135,135}),
              string="ibe"),
            Text(
              extent=[-124,122; -112,110],
              style(color=10, rgbcolor={135,135,135}),
              string="ibc"),
            Text(
              extent=[92,-124; 110,-140],
              style(color=10, rgbcolor={135,135,135}),
              string="Tdev"),
            Text(
              extent=[136,40; 154,24],
              style(color=10, rgbcolor={135,135,135}),
              string="Tdev"),
            Text(
              extent=[138,-64; 150,-78],
              style(color=10, rgbcolor={135,135,135}),
              string="IB0"),
            Text(
              extent=[-22,-114; -10,-128],
              style(color=10, rgbcolor={135,135,135}),
              string="IB0"),
            Text(
              extent=[100,-20; 112,-34],
              style(color=10, rgbcolor={135,135,135}),
              string="IC0"),
            Text(
              extent=[132,-98; 142,-110],
              style(color=10, rgbcolor={135,135,135}),
              string="qb"),
            Text(
              extent=[-80,-108; -70,-120],
              style(color=10, rgbcolor={135,135,135}),
              string="qb"),
            Text(
              extent=[110,-152; 122,-164],
              style(color=10, rgbcolor={135,135,135}),
              string="C0"),
            Text(
              extent=[-112,-108; -100,-120],
              style(color=10, rgbcolor={135,135,135}),
              string="C0")),
          Icon(
              Text(
                extent=[-112,90; 96,-84],
                style(color=0),
                string="NPN"),
              Line(points=[0,100; 0,-100],
                                         style(
                  color=9,
                  rgbcolor={149,164,171},
                  thickness=2,
                  fillColor=74,
                  rgbfillColor={0,0,185},
                  fillPattern=1)),
              Line(points=[-20,-80; 0,-100],style(
                  color=9,
                  rgbcolor={149,164,171},
                  thickness=2,
                  fillColor=74,
                  rgbfillColor={0,0,185},
                  fillPattern=1)),
              Line(points=[0,-100; 20,-80],style(
                  color=9,
                  rgbcolor={149,164,171},
                  thickness=2,
                  fillColor=74,
                  rgbfillColor={0,0,185},
                  fillPattern=1)),
              Text(
                extent=[8,-126; 38,-152],
                style(color=9, rgbcolor={149,164,171}),
              string="Eint"),
              Text(
                extent=[-156,28; -124,4],
                style(color=9, rgbcolor={149,164,171}),
              string="Bint"),
              Text(
                extent=[10,150; 38,126],
                style(color=9, rgbcolor={149,164,171}),
              string="Cint"),
              Text(
                extent=[122,30; 158,6],
                style(color=9, rgbcolor={149,164,171}),
              string="Heat"),
              Text(
                extent=[142,-66; 164,-86],
                style(color=9, rgbcolor={149,164,171}),
              string="qb"),
            Line(points=[-100,-60; 100,-60], style(color=3, rgbcolor={0,0,255})),
            Line(points=[80,-40; 100,-60], style(color=3, rgbcolor={0,0,255})),
            Line(points=[80,-80; 100,-60], style(color=3, rgbcolor={0,0,255})),
              Text(
                extent=[88,4; 128,-38],
                style(color=0),
              string="int"),
            Text(
              extent=[-80,120; 80,80],
              style(color=3, rgbcolor={0,0,255}),
              string="%name")),
          Documentation(info="<html>
The NPN element of the Spice bond graph library implements a full-fledges Spice-stye model of the NPN bipolar transistor [1-3].  <b>NPNint</b> is a partial model that implements only the internal nodes of the bipolar transistor.  The external parasitic resistances, the external capacitor between base and collector, and the substrate are being added from the outside. <p>

Notice the use of the two internal modulated current sources.  They are connected on the primary side to the <b>Heat</b> port.  As shown in [4,5], these current sources are in fact non-linear resistors, as voltage and current through these sources are always pointing in the same direction.  Thus, they generate heat. <p>

The NPN bipolar transistor is a directed FourPort.  The direction of positive power flow is assumed into the model at the base, <b>B</b>, and at the collector, <b>C</b>, whereas it is assumed out of the model at the emitter, <b>E</b>, and at the <b>Heat</b> port. <p>

The causality of the NPN model is free. <p>

<hr>

<pre>
<b>DC Model Parameters:</b>

 BF:      Forward beta coefficient (default value = 50)

 BR:      Reverse beta coefficient (default value = 0.1)

 IS:      Transport saturation current (default value = 1e-16 Amp)

 NF:      Forward emission coefficient (default value = 1)

 NR:      Reverse emission coefficient (default value = 1)

 GminDC:  Junction leakage conductance (default value = 1e-15 Mho)


<b>Low Current Beta Degradation Effect Parameters:</b>

 ISC:     Collector saturation current at reference temperature (default value = 1e-16 Amp)

 ISE:     Emitter saturation current at reference temperature (default value = 1e-16 Amp)

 NC:      Collector beta degradation coefficient (default value = 2)

 NE:      Emitter beta degradation coefficient (default value = 1.5)


<b>Base Width Modulation Parameters:</b>
  
 VAF:     Forward early voltage (default value = 9e30 Volt)

 VAR:     Reverse early voltage (default value = 9e30 Volt)


<b>High Current Beta Degradation Effect Parameters:</b>

 IKF:     Forward junction beta degradation current (default value = 9e30 Amp)

 IKR:     Reverse junction beta degradation current (default value = 9e30 Amp)


<b>Junction Capacitor Parameters:</b>

 CJC:     Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 MJC:     Base-collector gradation exponent (default value = 0.333)

 VJC:     Base-collector diffusion voltage (default value = 0.8 Volt)

 CJE:     Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 MJE:     Base-emitter gradation exponent (default value = 0.4)

 VJE:     Base-emitter diffusion voltage (default value = 0.8 Volt)

 XCJC:    Portion of depletion capacitance considered inside base-collector junction (default value = 1)


<b>Transit Time Parameters:</b>

 TF:      Ideal forward transit time (default value = 0.12e-9 sec)

 TR:      Ideal reverse transit time (default value = 5e-9 sec)


<b>Temperature Compensation and Area Parameters:</b>

 Tnom:    Reference temperature (default value = 300.15 <sup>o</sup>K)

 XTI:     Temperature exponent of saturation current (default value = 3)

 XTB:     Temperature ratio exponent (default value = 0)

 EG:      Activation energy (default value = 1.16 Volt)

 Area:    Relative area occupied by device (default value = 1)


<b>Numerical Parameters:</b>

 EMin:    Minimum exponent (default value = -100)

 EMax:    Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li>Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York.
<li>Hild, D.R. and F.E. Cellier (1994), \"Object-oriented electronic circuit modeling using Dymola,\"
    <i>Proc. OOS'94, SCS Object Oriented Simulation Conference</i>, Tempe, AZ, pp.68-75.
<li>Hild, D.R. (1993), <i>Circuit Modeling in Dymola</i>, MS Thesis, Dept. of Electr. &amp; Comp. Engr.,
    University of Arizona, Tucson.
<li>Schweisguth, M.C. and F.E. Cellier (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/BJT.pdf\">A
    bond graph model of the bipolar junction transistor</a>,\" <i>Proc. SCS Intl. Conf. on Bond Graph Modeling</i>,
    San Francisco, CA, pp.344-349.
<li>Schweisguth, M.C. (1997), <a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/schweisguth_ms.pdf\"><i>Semiconductor
    Modeling with Bondgraphs</i></a>, MS Thesis, Dept. of Electr. &amp; Comp. Engr., University of Arizona, Tucson.
</ol> 
</html>
"));
        
        BondLib.Interfaces.BondCon BondCon1 
          annotation (extent=[-150,-10; -130,10]);
        BondLib.Interfaces.BondCon BondCon2 
          annotation (extent=[-10,-150; 10,-130]);
        BondLib.Interfaces.BondCon BondCon3 
          annotation (extent=[130,-10; 150,10]);
        BondLib.Interfaces.BondCon BondCon4 
          annotation (extent=[-10,130; 10,150]);
          BondLib.Junctions.J0p3 J0p3_1 
          annotation (extent=[-10,-10; 10,10], rotation=-90);
          BondLib.Bonds.Bond B1 annotation (extent=[-10,10; 10,70], rotation=90);
          BondLib.Junctions.J1p3 J1p3_1 
          annotation (extent=[-10,70; 10,90], rotation=-90);
          BondLib.Bonds.Bond B2 
          annotation (extent=[-10,-72; 10,-12], rotation=270);
          BondLib.Junctions.J1p3 J1p3_2 
          annotation (extent=[-10,-90; 10,-70], rotation=-90);
          BondLib.Bonds.Bond B3 annotation (extent=[-30,70; -10,90], rotation=180);
          BondLib.Bonds.Bond B4 
          annotation (extent=[-30,-90; -10,-70], rotation=180);
          BondLib.Junctions.J0p3 J0p3_2 
          annotation (extent=[-50,70; -30,90], rotation=0);
          BondLib.Bonds.fBond B5 
          annotation (extent=[-50,50; -30,70], rotation=-90);
          BondLib.Sensors.De Vbc 
          annotation (extent=[-50,24; -30,50], rotation=-90);
          BondLib.Junctions.J0p4 J0p4_1 annotation (extent=[-50,-90; -30,-70]);
          BondLib.Bonds.fBond B6 
          annotation (extent=[-50,-70; -30,-50], rotation=90);
          BondLib.Sensors.De Vbe 
          annotation (extent=[-50,-48; -30,-22], rotation=90);
          BondLib.Bonds.Bond B7 annotation (extent=[-10,90; 10,110], rotation=90);
          BondLib.Bonds.Bond B8 
          annotation (extent=[-10,-110; 10,-90], rotation=270);
          BondLib.Junctions.J0p3 J0p3_3 
          annotation (extent=[10,-130; -10,-110], rotation=-90);
          BondLib.Junctions.J1p3 J1p3_5 
          annotation (extent=[30,10; 50,-10], rotation=90);
          BondLib.Bonds.Bond B9 annotation (extent=[30,10; 50,70], rotation=270);
          BondLib.Bonds.Bond B10 annotation (extent=[30,-68; 50,-8], rotation=270);
          BondLib.Bonds.eBond B11 
          annotation (extent=[50,-10; 70,10], rotation=180);
          BondLib.Spice.Utilities.DjS Dbc(
            Tnom=Tnom,
            IS=IS,
            EG=EG,
            N=NR,
            XTI=XTI,
            VJ=VJC,
            CJ=CJC,
            XCJ=XCJC,
            MJ=MJC,
            Tau=TR,
            GminDC=GminDC,
            Area=Area,
            BE=false,
            EMin=EMin,
            EMax=EMax) annotation (extent=[-72,60; -112,100]);
          BondLib.Bonds.Bond B13 
          annotation (extent=[-70,70; -50,90], rotation=180);
          BondLib.Bonds.eBond B14 
          annotation (extent=[-132,70; -112,90], rotation=180);
          BondLib.Bonds.Bond B15 
          annotation (extent=[-70,-90; -50,-70], rotation=180);
          BondLib.Spice.Utilities.DjS Dbe(
            Tnom=Tnom,
            IS=IS,
            EG=EG,
            XTI=XTI,
            GminDC=GminDC,
            Area=Area,
            EMin=EMin,
            EMax=EMax,
            N=NF,
            VJ=VJE,
            CJ=CJE,
            XCJ=1,
            MJ=MJE,
            Tau=TF,
            BE=true) annotation (extent=[-70,-100; -110,-60]);
          BondLib.Bonds.eBond B16 
          annotation (extent=[-130,-90; -110,-70], rotation=180);
          BondLib.Bonds.eBond B12 
          annotation (extent=[-50,-110; -30,-90], rotation=90);
          BondLib.Junctions.J0p3 J0p3_4 
          annotation (extent=[10,110; -10,130], rotation=-90);
          BondLib.Spice.Utilities.BJTvars BJTvars1(
          Tnom=Tnom,
          BF=BF,
          BR=BR,
          TF=TF,
          EG=EG,
          XTI=XTI,
          VAF=VAF,
          VAR=VAR,
          IKF=IKF,
          IKR=IKR,
          ISC=ISC,
          ISE=ISE,
          NC=NC,
          NE=NE,
          XTB=XTB,
          Area=Area) 
          annotation (extent=[64,-116; 116,-64]);
          BondLib.Junctions.J0p6 J0p6_1 annotation (extent=[80,80; 120,120]);
          Modelica.Blocks.Interfaces.RealOutput qb 
          annotation (extent=[140,-104; 160,-84]);
        Sources.mSf_int IC0 annotation (extent=[100,-14; 70,14]);
        Bonds.fBond B17 annotation (extent=[100,-10; 120,10], rotation=180);
        Sources.mSf_int IB0 
          annotation (extent=[-56,-140; -24,-110], rotation=90);
        Bonds.fBond B18 annotation (extent=[-70,-150; -50,-130], rotation=0);
          BondLib.Bonds.eBond B19 
          annotation (extent=[98,60; 118,80],      rotation=270);
        Sensors.De Tdev annotation (extent=[96,36; 120,60], rotation=-90);
        Modelica.Blocks.Sources.Constant qb1(k=1) 
          annotation (extent=[-64,42; -76,54]);
        Modelica.Blocks.Sources.Constant C01(k=0) 
          annotation (extent=[-120,42; -108,54]);
        equation 
          connect(J1p3_2.BondCon1,B2. BondCon2) annotation (points=[
              -6.12303e-016,-70; 0,-70; 0,-72; -1.83691e-015,-72],
                                                     style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B3.BondCon1,J1p3_1. BondCon3) annotation (points=[-10.2,80;
              -10,80],
                   style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B4.BondCon1,J1p3_2. BondCon3) annotation (points=[-10.2,-80;
              -10,-80], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J0p3_2.BondCon2,B3. BondCon2) annotation (points=[-30,80; -30,
              80], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B5.eBondCon1,J0p3_2. BondCon3) annotation (points=[-40,70;
              -40,70],
                   style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Vbc.BondCon1,B5. fBondCon1) annotation (points=[-40,50; -40,
              50],
            style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J0p4_1.BondCon2,B4. BondCon2) annotation (points=[-30,-80;
              -30,-80],
                    style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J0p4_1.BondCon4,B6. eBondCon1) annotation (points=[-40,-70;
              -40,-70],
                    style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B6.fBondCon1,Vbe. BondCon1) annotation (points=[-40,-50; -40,
              -48], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J1p3_1.BondCon1,B7. BondCon1) annotation (points=[
              -6.12303e-016,90; -6.12303e-016,90.2; -6.00057e-016,90.2],
                                                         style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B9.BondCon2,J1p3_5. BondCon1) annotation (points=[40,10; 40,
              10],
            style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J1p3_5.BondCon2,B10. BondCon1) annotation (points=[40,-10; 40,
              -8.6], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B11.eBondCon1,J1p3_5. BondCon3) annotation (points=[50,
              1.22461e-015; 65,1.22461e-015; 65,6.12303e-016; 50,6.12303e-016],
            style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B13.BondCon1,J0p3_2. BondCon1) annotation (points=[-50.2,80;
              -50,80], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Dbc.BondCon1,B13. BondCon2) annotation (points=[-72,80; -70,
              80],
            style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B14.fBondCon1,Dbc. BondCon2) annotation (points=[-112,80;
              -112,80],
                   style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B15.BondCon1,J0p4_1. BondCon1) annotation (points=[-50.2,-80;
              -50,-80], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Dbe.BondCon1,B15. BondCon2) annotation (points=[-70,-80; -70,
              -80], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B16.fBondCon1,Dbe. BondCon2) annotation (points=[-110,-80;
              -110,-80],
                    style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B12.eBondCon1,J0p4_1. BondCon3) annotation (points=[-40,-90;
              -40,-90], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B7.BondCon2,J0p3_4. BondCon2) annotation (points=[
              6.12303e-016,110; -6.12303e-016,110],
                                       style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J0p3_4.BondCon3,B9. BondCon1) annotation (points=[10,120; 40,
              120; 40,69.4], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B8.BondCon1,J1p3_2. BondCon2) annotation (points=[
              1.80017e-015,-90.2; 1.80017e-015,-98.1; 0,-90; 6.12303e-016,-90],
            style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J0p3_3.BondCon1,B8. BondCon2) annotation (points=[
              6.12303e-016,-110; -1.83691e-015,-110],
                                         style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J0p3_3.BondCon3,B10. BondCon2) annotation (points=[10,-120;
              40,-120; 40,-68],
                             style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J0p3_1.BondCon1,B1. BondCon1) annotation (points=[
              -6.12303e-016,10; -6.12303e-016,10.6; -6.00057e-016,10.6],
                                                         style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B1.BondCon2,J1p3_1. BondCon2) annotation (points=[
              6.12303e-016,70; 6.12303e-016,70],
                                    style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J0p3_1.BondCon2,B2. BondCon1) annotation (points=[
              6.12303e-016,-10; 6.12303e-016,-15; 0,-12.6; 1.80017e-015,-12.6],
                                                                            style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Vbc.OutPort1,BJTvars1. vbc) annotation (points=[-40,22.7; -40,
              12; -152,12; -152,-160; 44,-160; 44,-74.4; 61.4,-74.4], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Dbc.id,BJTvars1. ibc) annotation (points=[-92,100; -92,112;
              -156,112; -156,-164; 48,-164; 48,-84.8; 61.4,-84.8], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Vbe.OutPort1,BJTvars1. vbe) annotation (points=[-40,-20.7;
              -40,-12; -160,-12; -160,-168; 52,-168; 52,-95.2; 61.4,-95.2],
                                                                        style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Dbe.id,BJTvars1. ibe) annotation (points=[-90,-60; -90,-50;
              -164,-50; -164,-172; 56,-172; 56,-105.6; 61.4,-105.6], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(BJTvars1.qb,Dbe. qb) annotation (points=[118.6,-95.2; 130,
              -95.2; 130,-180; -82,-180; -82,-100],
                                             style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(BJTvars1.C0,Dbe. C0) annotation (points=[118.6,-105.6; 124,
              -105.6; 124,-184; -98,-184; -98,-100], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(BJTvars1.qb,qb)  annotation (points=[118.6,-95.2; 129.3,-95.2;
              129.3,-94; 150,-94], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(J0p3_4.BondCon1, BondCon4) annotation (points=[6.12303e-016,130; 
              0,130; 0,140], style(color=8, rgbcolor={192,192,192}));
        connect(J0p3_1.BondCon3, BondCon1) annotation (points=[-10,
              -6.12303e-016; -74,-6.12303e-016; -74,0; -140,0], style(color=8,
              rgbcolor={192,192,192}));
        connect(J0p3_3.BondCon2, BondCon2) annotation (points=[-6.12303e-016,
              -130; 0,-130; 0,-140], style(color=8, rgbcolor={192,192,192}));
        connect(IC0.BondCon2, B11.fBondCon1) annotation (points=[70,
              1.77636e-015; 74,1.77636e-015; 76,-1.22461e-015; 70,-1.22461e-015],
            style(color=8, rgbcolor={192,192,192}));
        connect(B17.fBondCon1, IC0.BondCon1) annotation (points=[100,
              1.22461e-015; 102,1.22461e-015; 104,1.77636e-015; 100,
              1.77636e-015], style(color=8, rgbcolor={192,192,192}));
        connect(BJTvars1.ic0, IC0.InPort1) annotation (points=[118.6,-84.8; 124,
              -84.8; 124,-30; 85,-30; 85,-12.6], style(color=74, rgbcolor={0,0,
                127}));
        connect(J0p6_1.BondCon2, BondCon3) annotation (points=[120,100; 128,100;
              128,0; 140,0], style(color=8, rgbcolor={192,192,192}));
        connect(IB0.BondCon2, B12.fBondCon1) annotation (points=[-40,-110; -40,
              -110], style(color=8, rgbcolor={192,192,192}));
        connect(BJTvars1.ib0, IB0.InPort1) annotation (points=[118.6,-74.4; 160,
              -74.4; 160,-176; -14,-176; -14,-125; -25.6,-125], style(color=74,
              rgbcolor={0,0,127}));
        connect(B17.eBondCon1, J0p6_1.BondCon3) annotation (points=[120,
              -1.22461e-015; 120,20; 92,20; 92,80], style(color=8, rgbcolor={
                192,192,192}));
        connect(B18.fBondCon1, IB0.BondCon1) annotation (points=[-50,-140; -40,
              -140], style(color=8, rgbcolor={192,192,192}));
        connect(B16.eBondCon1, J0p6_1.BondCon5) annotation (points=[-130,-80;
              -168,-80; -168,156; 92,156; 92,120], style(color=8, rgbcolor={192,
                192,192}));
        connect(B14.eBondCon1, J0p6_1.BondCon1) annotation (points=[-132,80;
              -164,80; -164,152; 80,152; 80,100], style(color=8, rgbcolor={192,
                192,192}));
        connect(B18.eBondCon1, J0p6_1.BondCon6) annotation (points=[-70,-140;
              -172,-140; -172,160; 108,160; 108,120], style(color=8, rgbcolor={
                192,192,192}));
        connect(J0p6_1.BondCon4, B19.fBondCon1) annotation (points=[108,80; 108,
              80], style(color=8, rgbcolor={192,192,192}));
        connect(B19.eBondCon1, Tdev.BondCon1) annotation (points=[108,60; 108,
              60], style(color=8, rgbcolor={192,192,192}));
        connect(Tdev.OutPort1, BJTvars1.Tdev) annotation (points=[108,34.8; 108,
              28; 164,28; 164,-136; 90,-136; 90,-118.6], style(color=74,
              rgbcolor={0,0,127}));
        connect(qb1.y, Dbc.qb) annotation (points=[-76.6,48; -84,48; -84,60],
            style(color=74, rgbcolor={0,0,127}));
        connect(C01.y, Dbc.C0) annotation (points=[-107.4,48; -100,48; -100,60],
            style(color=74, rgbcolor={0,0,127}));
        end NPNint;
      
        model PNPint 
        "Spice-style PNP transistor model without parasitic resistors and substrate diode" 
          /* DC model parameters */
          parameter Real BF=50 
          "Forward beta coefficient at reference temperature";
          parameter Real BR=0.1 
          "Reverse beta coefficient at reference temperature";
          parameter Modelica.SIunits.Current IS=1e-16 
          "Saturation current at reference temperature";
          parameter Real NF=1 "Forward emission coefficient";
          parameter Real NR=1 "Reverse emission coefficient";
          parameter Modelica.SIunits.Conductance GminDC=1e-15 
          "Leakage conductance";
        
          /* Low current beta degradation effect parameters */
          parameter Modelica.SIunits.Current ISC=1e-16 
          "Collector saturation current at reference temperature";
          parameter Modelica.SIunits.Current ISE=1e-16 
          "Emitter saturation current at reference temperature";
          parameter Real NC=2 "Collector beta degradation coefficient";
          parameter Real NE=1.5 "Emitter beta degradation coefficient";
        
          /* Base width modulation parameters */
          parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
          parameter Modelica.SIunits.Voltage VAR=9e30 "Reverse early voltage";
        
          /* High current beta degradation effect parameters */
          parameter Modelica.SIunits.Current IKF=9e30 
          "Forward junction beta degradation current";
          parameter Modelica.SIunits.Current IKR=9e30 
          "Reverse junction beta degradation current";
        
          /* Junction capacitor parameters */
          parameter Modelica.SIunits.Capacitance CJC=0.5e-12 
          "Base-collector zero bias depletion capacitance at reference temperature";
          parameter Real MJC=0.333 "Base-collector gradation exponent";
          parameter Modelica.SIunits.Voltage VJC=0.8 
          "Base-collector diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJE=0.4e-12 
          "Base-emitter zero bias depletion capacitance at reference temperature";
          parameter Real MJE=0.4 "Base-emitter gradation exponent";
          parameter Modelica.SIunits.Voltage VJE=0.8 
          "Base-emitter diffusion voltage at reference temperature";
          parameter Real XCJC=1 
          "Portion of depletion capacitance considered inside base-collector junction";
        
          /* Transit time parameters */
          parameter Modelica.SIunits.Time TF=0.12e-9 
          "Ideal forward transit time";
          parameter Modelica.SIunits.Time TR=5e-9 "Ideal reverse transit time";
        
          /* Temperature compensation and area parameters */
          parameter Modelica.SIunits.Temperature Tnom=300.15 
          "Reference temperature";
          parameter Real XTI=3 "Temperature exponent of saturation current";
          parameter Real XTB=0 "Temperature ratio exponent";
          parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
          parameter Real Area=1 "Relative area occupied by device";
        
          /* Numerical parameters */
          parameter Real EMin=-100 
          "if x < EMin, the exp(x) function is linearized";
          parameter Real EMax=40 
          "if x > EMax, the exp(x) function is linearized";
        annotation (
          Coordsys(extent=[-140,-140; 140,140]),
          Diagram(                                                 Ellipse(extent=[
                  128,-92; 134,-98], style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=74,
                rgbfillColor={0,0,127},
                fillPattern=1)),
            Text(
              extent=[-152,28; -126,12],
              style(color=10, rgbcolor={135,135,135}),
              string="Bint"),
            Text(
              extent=[10,148; 36,130],
              style(color=10, rgbcolor={135,135,135}),
              string="Cint"),
            Text(
              extent=[10,-132; 36,-150],
              style(color=10, rgbcolor={135,135,135}),
              string="Eint"),
            Text(
              extent=[126,-2; 158,-28],
              style(color=10, rgbcolor={135,135,135}),
              string="Heat"),
            Text(
              extent=[-90,22; -78,10],
              style(color=10, rgbcolor={135,135,135}),
              string="vbc"),
            Text(
              extent=[-98,-12; -86,-24],
              style(color=10, rgbcolor={135,135,135}),
              string="vbe"),
            Text(
              extent=[-126,-38; -114,-50],
              style(color=10, rgbcolor={135,135,135}),
              string="ibe"),
            Text(
              extent=[-124,122; -112,110],
              style(color=10, rgbcolor={135,135,135}),
              string="ibc"),
            Text(
              extent=[92,-124; 110,-140],
              style(color=10, rgbcolor={135,135,135}),
              string="Tdev"),
            Text(
              extent=[136,40; 154,24],
              style(color=10, rgbcolor={135,135,135}),
              string="Tdev"),
            Text(
              extent=[138,-64; 150,-78],
              style(color=10, rgbcolor={135,135,135}),
              string="IB0"),
            Text(
              extent=[-22,-114; -10,-128],
              style(color=10, rgbcolor={135,135,135}),
              string="IB0"),
            Text(
              extent=[100,-20; 112,-34],
              style(color=10, rgbcolor={135,135,135}),
              string="IC0"),
            Text(
              extent=[132,-98; 142,-110],
              style(color=10, rgbcolor={135,135,135}),
              string="qb"),
            Text(
              extent=[-80,-108; -70,-120],
              style(color=10, rgbcolor={135,135,135}),
              string="qb"),
            Text(
              extent=[110,-152; 122,-164],
              style(color=10, rgbcolor={135,135,135}),
              string="C0"),
            Text(
              extent=[-112,-108; -100,-120],
              style(color=10, rgbcolor={135,135,135}),
              string="C0")),
          Icon(
            Text(
              extent=[-80,120; 80,80],
              style(color=3, rgbcolor={0,0,255}),
              string="%name"),
              Line(points=[0,100; 0,-100],
                                         style(
                  color=9,
                  rgbcolor={149,164,171},
                  thickness=2,
                  fillColor=74,
                  rgbfillColor={0,0,185},
                  fillPattern=1)),
              Line(points=[0,100; 20,80],   style(
                  color=9,
                  rgbcolor={149,164,171},
                  thickness=2,
                  fillColor=74,
                  rgbfillColor={0,0,185},
                  fillPattern=1)),
              Line(points=[-20,80; 0,100], style(
                  color=9,
                  rgbcolor={149,164,171},
                  thickness=2,
                  fillColor=74,
                  rgbfillColor={0,0,185},
                  fillPattern=1)),
            Line(points=[-100,-60; 100,-60], style(color=3, rgbcolor={0,0,255})),
            Line(points=[80,-40; 100,-60], style(color=3, rgbcolor={0,0,255})),
            Line(points=[80,-80; 100,-60], style(color=3, rgbcolor={0,0,255})),
              Text(
                extent=[-112,90; 96,-84],
                style(color=0),
              string="PNP"),
              Text(
                extent=[88,4; 128,-38],
                style(color=0),
              string="int"),
              Text(
                extent=[-156,28; -124,4],
                style(color=9, rgbcolor={149,164,171}),
              string="Bint"),
              Text(
                extent=[10,150; 38,126],
                style(color=9, rgbcolor={149,164,171}),
              string="Cint"),
              Text(
                extent=[122,30; 158,6],
                style(color=9, rgbcolor={149,164,171}),
              string="Heat"),
              Text(
                extent=[8,-126; 38,-152],
                style(color=9, rgbcolor={149,164,171}),
              string="Eint")),
          Documentation(info="<html>
The PNP element of the Spice bond graph library implements a full-fledges Spice-stye model of the PNP bipolar transistor [1-3].  <b>PNPint</b> is a partial model that implements only the internal nodes of the bipolar transistor.  The external parasitic resistances, the external capacitor between base and collector, and the substrate are being added from the outside. <p>

Notice the use of the two internal modulated current sources.  They are connected on the primary side to the <b>Heat</b> port.  As shown in [4,5], these current sources are in fact non-linear resistors, as voltage and current through these sources are always pointing in the same direction.  Thus, they generate heat. <p>

The PNP bipolar transistor is a directed FourPort.  The direction of positive power flow is assumed into the model at the emitter, <b>E</b>, whereas it is assumed out of the model at the base, <b>B</b>, at the collector, <b>C</b>, and at the <b>Heat</b> port. <p>

The causality of the PNP model is free. <p>

<hr>

<pre>
<b>DC Model Parameters:</b>

 BF:      Forward beta coefficient (default value = 50)

 BR:      Reverse beta coefficient (default value = 0.1)

 IS:      Transport saturation current (default value = 1e-16 Amp)

 NF:      Forward emission coefficient (default value = 1)

 NR:      Reverse emission coefficient (default value = 1)

 GminDC:  Junction leakage conductance (default value = 1e-15 Mho)


<b>Low Current Beta Degradation Effect Parameters:</b>

 ISC:     Collector saturation current at reference temperature (default value = 1e-16 Amp)

 ISE:     Emitter saturation current at reference temperature (default value = 1e-16 Amp)

 NC:      Collector beta degradation coefficient (default value = 2)

 NE:      Emitter beta degradation coefficient (default value = 1.5)


<b>Base Width Modulation Parameters:</b>
  
 VAF:     Forward early voltage (default value = 9e30 Volt)

 VAR:     Reverse early voltage (default value = 9e30 Volt)


<b>High Current Beta Degradation Effect Parameters:</b>

 IKF:     Forward junction beta degradation current (default value = 9e30 Amp)

 IKR:     Reverse junction beta degradation current (default value = 9e30 Amp)


<b>Junction Capacitor Parameters:</b>

 CJC:     Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 MJC:     Base-collector gradation exponent (default value = 0.333)

 VJC:     Base-collector diffusion voltage (default value = 0.8 Volt)

 CJE:     Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 MJE:     Base-emitter gradation exponent (default value = 0.4)

 VJE:     Base-emitter diffusion voltage (default value = 0.8 Volt)

 XCJC:    Portion of depletion capacitance considered inside base-collector junction (default value = 1)


<b>Transit Time Parameters:</b>

 TF:      Ideal forward transit time (default value = 0.12e-9 sec)

 TR:      Ideal reverse transit time (default value = 5e-9 sec)


<b>Temperature Compensation and Area Parameters:</b>

 Tnom:    Reference temperature (default value = 300.15 <sup>o</sup>K)

 XTI:     Temperature exponent of saturation current (default value = 3)

 XTB:     Temperature ratio exponent (default value = 0)

 EG:      Activation energy (default value = 1.16 Volt)

 Area:    Relative area occupied by device (default value = 1)


<b>Numerical Parameters:</b>

 EMin:    Minimum exponent (default value = -100)

 EMax:    Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li>Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York.
<li>Hild, D.R. and F.E. Cellier (1994), \"Object-oriented electronic circuit modeling using Dymola,\"
    <i>Proc. OOS'94, SCS Object Oriented Simulation Conference</i>, Tempe, AZ, pp.68-75.
<li>Hild, D.R. (1993), <i>Circuit Modeling in Dymola</i>, MS Thesis, Dept. of Electr. &amp; Comp. Engr.,
    University of Arizona, Tucson.
<li>Schweisguth, M.C. and F.E. Cellier (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/BJT.pdf\">A
    bond graph model of the bipolar junction transistor</a>,\" <i>Proc. SCS Intl. Conf. on Bond Graph Modeling</i>,
    San Francisco, CA, pp.344-349.
<li>Schweisguth, M.C. (1997), <a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/schweisguth_ms.pdf\"><i>Semiconductor
    Modeling with Bondgraphs</i></a>, MS Thesis, Dept. of Electr. &amp; Comp. Engr., University of Arizona, Tucson.
</ol> 
</html>
"));
        BondLib.Interfaces.BondCon BondCon1 
          annotation (extent=[-150,-10; -130,10]);
        BondLib.Interfaces.BondCon BondCon2 
          annotation (extent=[-10,-150; 10,-130]);
        BondLib.Interfaces.BondCon BondCon3 
          annotation (extent=[130,-10; 150,10]);
        BondLib.Interfaces.BondCon BondCon4 
          annotation (extent=[-10,130; 10,150]);
          BondLib.Junctions.J0p3 J0p3_1 
          annotation (extent=[-10,-10; 10,10], rotation=-90);
          BondLib.Bonds.Bond B1 annotation (extent=[-10,10; 10,70], rotation=
              270);
          BondLib.Junctions.J1p3 J1p3_1 
          annotation (extent=[-10,70; 10,90], rotation=-90);
          BondLib.Bonds.Bond B2 
          annotation (extent=[-10,-70; 10,-10], rotation=90);
          BondLib.Junctions.J1p3 J1p3_2 
          annotation (extent=[-10,-90; 10,-70], rotation=-90);
          BondLib.Bonds.Bond B3 annotation (extent=[-30,70; -10,90], rotation=180);
          BondLib.Bonds.Bond B4 
          annotation (extent=[-30,-90; -10,-70], rotation=180);
          BondLib.Junctions.J0p3 J0p3_2 
          annotation (extent=[-50,70; -30,90], rotation=0);
          BondLib.Bonds.fBond B5 
          annotation (extent=[-50,50; -30,70], rotation=-90);
          BondLib.Sensors.De Vbc 
          annotation (extent=[-50,24; -30,50], rotation=-90);
          BondLib.Junctions.J0p4 J0p4_1 annotation (extent=[-50,-90; -30,-70]);
          BondLib.Bonds.fBond B6 
          annotation (extent=[-50,-70; -30,-50], rotation=90);
          BondLib.Sensors.De Vbe 
          annotation (extent=[-50,-48; -30,-22], rotation=90);
          BondLib.Bonds.Bond B7 annotation (extent=[-10,90; 10,110], rotation=
              270);
          BondLib.Bonds.Bond B8 
          annotation (extent=[-10,-110; 10,-90], rotation=90);
          BondLib.Junctions.J0p3 J0p3_3 
          annotation (extent=[10,-130; -10,-110], rotation=-90);
          BondLib.Junctions.J1p3 J1p3_5 
          annotation (extent=[30,10; 50,-10], rotation=90);
          BondLib.Bonds.Bond B9 annotation (extent=[30,10; 50,70], rotation=90);
          BondLib.Bonds.Bond B10 annotation (extent=[30,-70; 50,-10],rotation=
              90);
          BondLib.Bonds.eBond B11 
          annotation (extent=[50,-10; 70,10], rotation=180);
          BondLib.Spice.Utilities.DjS Dbc(
            Tnom=Tnom,
            IS=IS,
            EG=EG,
            N=NR,
            XTI=XTI,
            VJ=VJC,
            CJ=CJC,
            XCJ=XCJC,
            MJ=MJC,
            Tau=TR,
            GminDC=GminDC,
            Area=Area,
            BE=false,
            EMin=EMin,
            EMax=EMax) annotation (extent=[-72,60; -112,100]);
          BondLib.Bonds.Bond B13 
          annotation (extent=[-70,70; -50,90], rotation=180);
          BondLib.Bonds.eBond B14 
          annotation (extent=[-132,70; -112,90], rotation=180);
          BondLib.Bonds.Bond B15 
          annotation (extent=[-70,-90; -50,-70], rotation=180);
          BondLib.Spice.Utilities.DjS Dbe(
            Tnom=Tnom,
            IS=IS,
            EG=EG,
            XTI=XTI,
            GminDC=GminDC,
            Area=Area,
            EMin=EMin,
            EMax=EMax,
            N=NF,
            VJ=VJE,
            CJ=CJE,
            XCJ=1,
            MJ=MJE,
            Tau=TF,
            BE=true) annotation (extent=[-70,-100; -110,-60]);
          BondLib.Bonds.eBond B16 
          annotation (extent=[-130,-90; -110,-70], rotation=180);
          BondLib.Bonds.eBond B12 
          annotation (extent=[-50,-110; -30,-90], rotation=90);
          BondLib.Junctions.J0p3 J0p3_4 
          annotation (extent=[10,110; -10,130], rotation=-90);
          BondLib.Spice.Utilities.BJTvars BJTvars1(
          Tnom=Tnom,
          BF=BF,
          BR=BR,
          TF=TF,
          EG=EG,
          XTI=XTI,
          VAF=VAF,
          VAR=VAR,
          IKF=IKF,
          IKR=IKR,
          ISC=ISC,
          ISE=ISE,
          NC=NC,
          NE=NE,
          XTB=XTB,
          Area=Area) 
          annotation (extent=[64,-116; 116,-64]);
          BondLib.Junctions.J0p6 J0p6_1 annotation (extent=[80,80; 120,120]);
          Modelica.Blocks.Interfaces.RealOutput qb 
          annotation (extent=[140,-104; 160,-84]);
        BondLib.Sources.mSf_int IC0 
                            annotation (extent=[100,-14; 70,14]);
        BondLib.Bonds.fBond B17 
                        annotation (extent=[100,-10; 120,10], rotation=180);
        BondLib.Sources.mSf_int IB0 
          annotation (extent=[-56,-140; -24,-110], rotation=90);
        BondLib.Bonds.fBond B18 
                        annotation (extent=[-70,-150; -50,-130], rotation=0);
          BondLib.Bonds.eBond B19 
          annotation (extent=[98,60; 118,80],      rotation=270);
        BondLib.Sensors.De Tdev 
                        annotation (extent=[96,36; 120,60], rotation=-90);
        Modelica.Blocks.Sources.Constant qb1(k=1) 
          annotation (extent=[-64,42; -76,54]);
        Modelica.Blocks.Sources.Constant C01(k=0) 
          annotation (extent=[-120,42; -108,54]);
        equation 
          connect(B3.BondCon1,J1p3_1. BondCon3) annotation (points=[-10.2,80;
              -10,80],
                   style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B4.BondCon1,J1p3_2. BondCon3) annotation (points=[-10.2,-80;
              -10,-80], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J0p3_2.BondCon2,B3. BondCon2) annotation (points=[-30,80; -30,
              80], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B5.eBondCon1,J0p3_2. BondCon3) annotation (points=[-40,70;
              -40,70],
                   style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Vbc.BondCon1,B5. fBondCon1) annotation (points=[-40,50; -40,
              50],
            style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J0p4_1.BondCon2,B4. BondCon2) annotation (points=[-30,-80;
              -30,-80],
                    style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(J0p4_1.BondCon4,B6. eBondCon1) annotation (points=[-40,-70;
              -40,-70],
                    style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B6.fBondCon1,Vbe. BondCon1) annotation (points=[-40,-50; -40,
              -48], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B11.eBondCon1,J1p3_5. BondCon3) annotation (points=[50,
              1.22461e-015; 65,1.22461e-015; 65,6.12303e-016; 50,6.12303e-016],
            style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B13.BondCon1,J0p3_2. BondCon1) annotation (points=[-50.2,80;
              -50,80], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Dbc.BondCon1,B13. BondCon2) annotation (points=[-72,80; -70,
              80],
            style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B14.fBondCon1,Dbc. BondCon2) annotation (points=[-112,80;
              -112,80],
                   style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B15.BondCon1,J0p4_1. BondCon1) annotation (points=[-50.2,-80;
              -50,-80], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Dbe.BondCon1,B15. BondCon2) annotation (points=[-70,-80; -70,
              -80], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B16.fBondCon1,Dbe. BondCon2) annotation (points=[-110,-80;
              -110,-80],
                    style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(B12.eBondCon1,J0p4_1. BondCon3) annotation (points=[-40,-90;
              -40,-90], style(
            color=8,
            rgbcolor={192,192,192},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Vbc.OutPort1,BJTvars1. vbc) annotation (points=[-40,22.7; -40,
              12; -152,12; -152,-160; 44,-160; 44,-74.4; 61.4,-74.4], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Dbc.id,BJTvars1. ibc) annotation (points=[-92,100; -92,112;
              -156,112; -156,-164; 48,-164; 48,-84.8; 61.4,-84.8], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Vbe.OutPort1,BJTvars1. vbe) annotation (points=[-40,-20.7;
              -40,-12; -160,-12; -160,-168; 52,-168; 52,-95.2; 61.4,-95.2],
                                                                        style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(Dbe.id,BJTvars1. ibe) annotation (points=[-90,-60; -90,-50;
              -164,-50; -164,-172; 56,-172; 56,-105.6; 61.4,-105.6], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(BJTvars1.qb,Dbe. qb) annotation (points=[118.6,-95.2; 130,
              -95.2; 130,-180; -82,-180; -82,-100],
                                             style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(BJTvars1.C0,Dbe. C0) annotation (points=[118.6,-105.6; 124,
              -105.6; 124,-184; -98,-184; -98,-100], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
          connect(BJTvars1.qb,qb)  annotation (points=[118.6,-95.2; 129.3,-95.2;
              129.3,-94; 150,-94], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(J0p3_4.BondCon1,BondCon4)  annotation (points=[6.12303e-016,130; 
              0,130; 0,140], style(color=8, rgbcolor={192,192,192}));
        connect(J0p3_1.BondCon3,BondCon1)  annotation (points=[-10,
              -6.12303e-016; -74,-6.12303e-016; -74,0; -140,0], style(color=8,
              rgbcolor={192,192,192}));
        connect(J0p3_3.BondCon2,BondCon2)  annotation (points=[-6.12303e-016,
              -130; 0,-130; 0,-140], style(color=8, rgbcolor={192,192,192}));
        connect(IC0.BondCon2,B11. fBondCon1) annotation (points=[70,
              1.77636e-015; 74,1.77636e-015; 70,0; 70,-1.22461e-015],
            style(color=8, rgbcolor={192,192,192}));
        connect(B17.fBondCon1,IC0. BondCon1) annotation (points=[100,
              1.22461e-015; 102,1.22461e-015; 100,0; 100,1.77636e-015],
                             style(color=8, rgbcolor={192,192,192}));
        connect(BJTvars1.ic0,IC0. InPort1) annotation (points=[118.6,-84.8; 124,
              -84.8; 124,-30; 85,-30; 85,-12.6], style(color=74, rgbcolor={0,0,
                127}));
        connect(J0p6_1.BondCon2,BondCon3)  annotation (points=[120,100; 128,100;
              128,0; 140,0], style(color=8, rgbcolor={192,192,192}));
        connect(IB0.BondCon2,B12. fBondCon1) annotation (points=[-40,-110; -40,
              -110], style(color=8, rgbcolor={192,192,192}));
        connect(BJTvars1.ib0,IB0. InPort1) annotation (points=[118.6,-74.4; 160,
              -74.4; 160,-176; -14,-176; -14,-125; -25.6,-125], style(color=74,
              rgbcolor={0,0,127}));
        connect(B17.eBondCon1,J0p6_1. BondCon3) annotation (points=[120,
              -1.22461e-015; 120,20; 92,20; 92,80], style(color=8, rgbcolor={
                192,192,192}));
        connect(B18.fBondCon1,IB0. BondCon1) annotation (points=[-50,-140; -40,
              -140], style(color=8, rgbcolor={192,192,192}));
        connect(B16.eBondCon1,J0p6_1. BondCon5) annotation (points=[-130,-80;
              -168,-80; -168,156; 92,156; 92,120], style(color=8, rgbcolor={192,
                192,192}));
        connect(B14.eBondCon1,J0p6_1. BondCon1) annotation (points=[-132,80;
              -164,80; -164,152; 80,152; 80,100], style(color=8, rgbcolor={192,
                192,192}));
        connect(B18.eBondCon1,J0p6_1. BondCon6) annotation (points=[-70,-140;
              -172,-140; -172,160; 108,160; 108,120], style(color=8, rgbcolor={
                192,192,192}));
        connect(J0p6_1.BondCon4,B19. fBondCon1) annotation (points=[108,80; 108,
              80], style(color=8, rgbcolor={192,192,192}));
        connect(B19.eBondCon1,Tdev. BondCon1) annotation (points=[108,60; 108,
              60], style(color=8, rgbcolor={192,192,192}));
        connect(Tdev.OutPort1,BJTvars1. Tdev) annotation (points=[108,34.8; 108,
              28; 164,28; 164,-136; 90,-136; 90,-118.6], style(color=74,
              rgbcolor={0,0,127}));
        connect(qb1.y,Dbc. qb) annotation (points=[-76.6,48; -84,48; -84,60],
            style(color=74, rgbcolor={0,0,127}));
        connect(C01.y,Dbc. C0) annotation (points=[-107.4,48; -100,48; -100,60],
            style(color=74, rgbcolor={0,0,127}));
        connect(J1p3_1.BondCon1, B7.BondCon2) annotation (points=[-6.12303e-016,
              90; -1.83691e-015,90], style(color=8, rgbcolor={192,192,192}));
        connect(J0p3_4.BondCon2, B7.BondCon1) annotation (points=[-6.12303e-016,
              110; 1.80017e-015,110; 1.80017e-015,109.8], style(color=8,
              rgbcolor={192,192,192}));
        connect(J0p3_1.BondCon1, B1.BondCon2) annotation (points=[-6.12303e-016,
              10; -1.83691e-015,10], style(color=8, rgbcolor={192,192,192}));
        connect(J1p3_1.BondCon2, B1.BondCon1) annotation (points=[6.12303e-016,
              70; 1.80017e-015,70; 1.80017e-015,69.4], style(color=8, rgbcolor=
                {192,192,192}));
        connect(J0p3_1.BondCon2, B2.BondCon2) annotation (points=[6.12303e-016,
              -10; 6.12303e-016,-10], style(color=8, rgbcolor={192,192,192}));
        connect(B2.BondCon1, J1p3_2.BondCon1) annotation (points=[-6.00057e-016,
              -69.4; -6.00057e-016,-68.7; -6.12303e-016,-68.7; -6.12303e-016,
              -70], style(color=8, rgbcolor={192,192,192}));
        connect(J1p3_2.BondCon2, B8.BondCon2) annotation (points=[6.12303e-016,
              -90; 6.12303e-016,-90], style(color=8, rgbcolor={192,192,192}));
        connect(B8.BondCon1, J0p3_3.BondCon1) annotation (points=[-6.00057e-016,
              -109.8; -6.00057e-016,-107.9; 6.12303e-016,-107.9; 6.12303e-016,
              -110], style(color=8, rgbcolor={192,192,192}));
        connect(B10.BondCon2, J1p3_5.BondCon2) annotation (points=[40,-10; 40,
              -10], style(color=8, rgbcolor={192,192,192}));
        connect(J0p3_3.BondCon3, B10.BondCon1) annotation (points=[10,-120; 40,
              -120; 40,-69.4], style(color=8, rgbcolor={192,192,192}));
        connect(J1p3_5.BondCon1, B9.BondCon1) annotation (points=[40,10; 40,
              10.6], style(color=8, rgbcolor={192,192,192}));
        connect(J0p3_4.BondCon3, B9.BondCon2) annotation (points=[10,120; 40,
              120; 40,70], style(color=8, rgbcolor={192,192,192}));
        end PNPint;
      end Utilities;
    end Spice;
  
  package Switches "Switches of Modelica bond graph library" 
    annotation (
      Coordsys(
        extent=[0, 0; 442, 394],
        grid=[2, 2],
        component=[20, 20]),
      Icon(
        Rectangle(extent=[-100, -100; 80, 50], style(fillColor=30, fillPattern=
                1)),
        Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50], style(
              fillColor=30, fillPattern=1)),
        Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70], style(
              fillColor=30, fillPattern=1)),
        Text(
          extent=[-85, 35; 65, -85],
          string="Library",
          style(color=3)),
        Text(
          extent=[-120, 122; 120, 73],
          string="%name",
          style(color=1))),
      Window(
        x=0.45,
        y=0.01,
        width=0.44,
        height=0.65,
        library=1,
        autolayout=1),
      Documentation(info="<html>
This package contains a collecion of switching elements for the Modelica bond graph library. <p>

Switches change their computational causality as a function of the switch position.  For this reason, switches must always be attached to a-causal bonds. <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Cellier, F.E., M. Otter, and H. Elmqvist (1995), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/VarStruc.pdf\">Bond
     Graph Modeling of Variable Structure Systems</a>,\" <i>Proc. ICBGM'95, 2<sup>nd</sup> SCS Intl. Conf. on Bond Graph
     Modeling and Simulation</i>, Las Vegas, Nevada, pp. 49-55.
<li> Krebs, M. (1997), <i><a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/krebs_ms.pdf\">Modeling of Conditional
     Index Changes</a></i>, MS Thesis, Dept. of Electr. & Comp. Engr., University of Arizona, Tucson, AZ. 
</ol>
</html>
"));
    model Sw "Generic switch element of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      Boolean open "Switch position";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(
          Line(points=[-86,0; 74,0],   style(color=10)),
          Polygon(points=[64,4; 74,0; 64,-4; 64,4],     style(color=10,
                fillColor=10)),
          Line(points=[-6,80; -6,-80], style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[-10,70; -6,80; -2,70; -10,70], style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[0,80; 10,70],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Text(
            extent=[64,-4; 74,-14],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e"),
          Line(points=[-82,0; -26,0; 16,0; 60,0],           style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Ellipse(extent=[-8,2; -4,-2], style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[-6,-44; 16,-52],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="closed"),
          Text(
            extent=[20,10; 42,2],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="open"),
          Text(
            extent=[-6,0; 14,-10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s=0"),
          Line(points=[-6,-74; -6,-18; -6,16; -6,62],       style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[-6,38; 16,30],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="closed"),
          Text(
            extent=[-60,10; -38,2],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="open")),
        Icon(Text(
            extent=[-60, 80; 60, -80],
            string="Sw",
            style(color=0)), Text(extent=[-70, 80; 70, 40], string="%name")),
        Documentation(info="<html>
The generic switch element is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The switch has an additional modulating Boolean input signal modeling the switch position.  If the modulating input signal has a value of <b>true</b>, the switch is considered <b>open</b>. <p>

The causality of the switch element must be free, i.e., the switch element must be placed inside an algebraic loop. <p>

<hr>

<pre>
Potential variables:

 e:     Bondgraphic effort variable

 f:     Bondgraphic flow variable, normalized positive for flows into the model

 open:  Boolean variable denoting the switch position (modulation input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>0 = if open then f else e</b>
</html>
"));
      Modelica.Blocks.Interfaces.BooleanInput BooleanInPort1  annotation (
          extent=[100, -10; 80, 10]);
    equation 
      open =BooleanInPort1;
      0 = if open then f else e;
    end Sw;
    
    model Sw2 "Leaking switch of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      parameter Real Ron(final min=0) = 1.E-5 "Closed switch resistance";
      parameter Real Goff(final min=0) = 1.E-5 "Opened switch conductance";
    protected 
      Real s "Curve parameter";
      Boolean OpenSwitch;
    public 
      Modelica.Blocks.Interfaces.BooleanInput BooleanInPort1  annotation (
          extent=[100, -10; 80, 10]);
      annotation (
        Diagram(
          Line(points=[-86,0; 74,0],   style(color=10)),
          Polygon(points=[64,4; 74,0; 64,-4; 64,4],     style(color=10,
                fillColor=10)),
          Line(points=[-6,80; -6,-80], style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[-10,70; -6,80; -2,70; -10,70], style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[0,80; 10,70],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Text(
            extent=[64,-4; 74,-14],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e"),
          Line(points=[-80,-38; -26,-10; 14,10; 64,36],     style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[16,68; 36,58],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
      string="Ron"),
          Text(
            extent=[-52,-6; -32,-16],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
      string="Goff"),
          Ellipse(extent=[-8,2; -4,-2], style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[-28,-50; -6,-58],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="closed"),
          Text(
            extent=[28,18; 50,10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="open"),
          Text(
            extent=[-6,0; 14,-10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s=0"),
          Line(points=[-36,-74; -12,-16; 0,16; 20,76],      style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[6,38; 28,30],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="closed"),
          Text(
            extent=[-54,-22; -32,-30],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="open")),
        Icon(
          Text(
            extent=[-74, 78; 32, -82],
            string="Sw",
            style(color=0)),
          Text(
            extent=[24, -14; 86, -48],
            string="Leak",
            style(color=0, pattern=0)),
          Text(extent=[-70, 100; 70, 60], string="%name")),
        Documentation(info="<html>
The leaking switch element is a passive OnePort element with modulation.  It inherits the effort and flow variables from the passive OnePort.  If the modulating signal has a value of <b>true</b>, the switch is considered <b>open</b>. <p>

The causality of the leaking switch element is free. <p>

<hr>

<pre>
Potential variables:

 e:           Bondgraphic effort variable

 f:           Bondgraphic flow variable, normalized positive for flows into the model

 OpenSwitch:  Boolean variable denoting the switch position (modulation signal)

 s:           Curve parameter


Parameters:

 Ron:         Leakage resistance in <b>on</b> state (default value = 1e-5)

 Goff:        Leakage conductance in <b>off</b> state (default value = 1e-5)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f = s*(if OpenSwitch then Goff else 1)</b> <br>
<b>e = s*(if OpenSwitch then 1 else Ron)</b> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Otter, M., H. Elmqvist, and S.E. Mattsson (1999), \"<a href=\"http://www.modelica.org/publications/papers/hybrid99.pdf\">Hybrid
     Modeling in Modelica Based on the Synchronous Data Flow Principle</a>,\" <i>Proc. CACSD'99, IEEE Symposium on
     Computer-Aided Control System Design</i>, Hawaii, August 22-27, 1999, pp. 151-157.
</ol>
</html>

"));
    equation 
      OpenSwitch =BooleanInPort1;
      f = s*(if OpenSwitch then Goff else 1);
      e = s*(if OpenSwitch then 1 else Ron);
    end Sw2;
    
    model D "Electrical ideal diode of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      Real s "Curve parameter";
      Boolean blocking;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(
          Line(points=[-80,0; 80,0],   style(color=10)),
          Polygon(points=[70,4; 80,0; 70,-4; 70,4],     style(color=10,
                fillColor=10)),
          Line(points=[0,80; 0,-80],   style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[-4,70; 0,80; 4,70; -4,70],     style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[6,80; 16,70],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Text(
            extent=[70,-4; 80,-14],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e"),
          Line(points=[-80,0; -20,0; 0,0; 0,66],            style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Line(points=[20,9; 20,0],   style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Ellipse(extent=[-2,2; 2,-2],  style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[2,48; 36,38],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="conducting"),
          Text(
            extent=[-54,-2; -24,-10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="blocking"),
          Text(
            extent=[0,10; 20,0],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s=0")),
        Icon(Text(
            extent=[-82, 70; 80, -74],
            string="D",
            style(color=0)), Text(extent=[-70, 88; 70, 48], string="%name")),
        Documentation(info="<html>
The ideal diode element is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The ideal diode is a switch element with internal modulation.  If the modulating signal has a value of <b>true</b>, the diode is considered <b>blocking</b>. <p>

Diodes are switching elements that are primarily being used in electrical circuits, although nothing prevents them from being used also in other energy domains. <p>

The causality of the ideal diode element must be free, i.e., the ideal diode element must be placed inside an algebraic loop.  If the causality of the diode is not free, use the leaking diode model, <b>D2</b>, instead. <p>

<hr>

<pre>
Potential variables:

 e:         Bondgraphic effort variable

 f:         Bondgraphic flow variable, normalized positive for flows into the model

 blocking:  Boolean variable denoting the switch position (internal modulation signal)

 s:         Curve parameter
</pre> <p>

<hr> <p>

Equations: <p>

<b>blocking = s &lt; 0</b> <br>
<b>f = if blocking then 0 else s</b> <br>
<b>e = if blocking then s else 0</b> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Otter, M., H. Elmqvist, and S.E. Mattsson (1999), \"<a href=\"http://www.modelica.org/publications/papers/hybrid99.pdf\">Hybrid
     Modeling in Modelica Based on the Synchronous Data Flow Principle</a>,\" <i>Proc. CACSD'99, IEEE Symposium on
     Computer-Aided Control System Design</i>, Hawaii, August 22-27, 1999, pp. 151-157.
</ol>
</html>

"));
    equation 
      blocking = s < 0;
      f = if blocking then 0 else s;
      e = if blocking then s else 0;
    end D;
    
    model D2 "Electrical leaking diode of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      parameter Real Ron=1E-5 "Leakage Resistance";
      parameter Real Goff=1E-5 "Leakage Conductance";
      parameter Real e0=0 "Forward threshold effort";
      Real s "Curve parameter";
      Boolean blocking;
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(
          Line(points=[-80,0; 80,0],   style(color=10)),
          Polygon(points=[70,4; 80,0; 70,-4; 70,4],     style(color=10,
                fillColor=10)),
          Line(points=[0,80; 0,-80],   style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[-4,70; 0,80; 4,70; -4,70],     style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[6,80; 16,70],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Text(
            extent=[70,-4; 80,-14],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e"),
          Line(points=[-80,-40; -20,-10; 20,10; 40,70],     style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Line(points=[20,9; 20,0],   style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[12,-2; 32,-12],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="e0"),
          Text(
            extent=[20,70; 40,60],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
      string="Ron"),
          Text(
            extent=[-20,10; 0,0],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
      string="Goff"),
          Ellipse(extent=[18,12; 22,8], style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[32,38; 66,28],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="conducting"),
          Text(
            extent=[-52,-28; -22,-36],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="blocking"),
          Text(
            extent=[20,14; 40,4],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s=0")),
        Icon(
          Text(
            extent=[-82, 70; 80, -74],
            string="D",
            style(color=0)),
          Text(
            extent=[40, -16; 102, -50],
            string="Leak",
            style(color=0, pattern=0)),
          Text(extent=[-70,94; 70,54],   string="%name")),
        Documentation(info="<html>
The ideal diode element is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The leaking diode is a switch element with internal modulation.  If the modulating signal has a value of <b>true</b>, the diode is considered <b>blocking</b>. <p>

Diodes are switching elements that are primarily being used in electrical circuits, although nothing prevents them from being used also in other energy domains.  Leaking diodes are a special class of non-linear resistors. <p>

The causality of the leaking diode element is free. <p>

<hr>

<pre>
Potential variables:

 e:         Bondgraphic effort variable

 f:         Bondgraphic flow variable, normalized positive for flows into the model

 blocking:  Boolean variable denoting the switch position (internal modulation signal)

 s:         Curve parameter


Parameters:

 Ron:       Leakage resistance in <b>conducting</b> state (default value = 1e-5 Ohm)

 Goff:      Leakage conductance in <b>blocking</b> state (default value = 1e-5 Mho)

 e0:        Forward threshold effort (default value = 0 Volt)
</pre> <p>

<hr> <p>

Equations: <p>

<b>blocking = s &lt; 0</b> <br>
<b>f = s*(if blocking then Goff else 1) + Goff*e0</b> <br>
<b>e = s*(if blocking then 1 else Ron) + e0</b> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Otter, M., H. Elmqvist, and S.E. Mattsson (1999), \"<a href=\"http://www.modelica.org/publications/papers/hybrid99.pdf\">Hybrid
     Modeling in Modelica Based on the Synchronous Data Flow Principle</a>,\" <i>Proc. CACSD'99, IEEE Symposium on
     Computer-Aided Control System Design</i>, Hawaii, August 22-27, 1999, pp. 151-157.
</ol>
</html>

"));
    equation 
      blocking = s < 0;
      f = s*(if blocking then Goff else 1) + Goff*e0;
      e = s*(if blocking then 1 else Ron) + e0;
    end D2;
    
    model Z "Electrical ideal Zener diode of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      constant Integer conducting=1;
      constant Integer blocking=2;
      constant Integer avalanche=3;
      parameter Real e0=1 "Avalanche breakdown Voltage";
      Real s "Curve parameter";
      Integer mode "Operating mode";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(
          Line(points=[-80,0; 80,0],   style(color=10)),
          Line(points=[0,80; 0,-80],   style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[-4,70; 0,80; 4,70; -4,70],     style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[6,80; 16,70],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Line(points=[0,-66; 0,0; 40,0; 40,70],            style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Ellipse(extent=[-2,2; 2,-2],  style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[2,-30; 34,-40],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="conducting"),
          Text(
            extent=[6,8; 36,0],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="blocking"),
          Text(
            extent=[0,0; 20,-10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s=0"),
          Text(
            extent=[42,40; 72,30],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="avalanche"),
          Text(
            extent=[42,10; 62,0],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s=e0"),
          Ellipse(extent=[38,2; 42,-2], style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[32,-2; 52,-12],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="e0"),
          Polygon(points=[80,4; 90,0; 80,-4; 80,4],     style(color=10,
                fillColor=10)),
          Text(
            extent=[80,-4; 90,-14],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e")),
        Icon(
          Text(
            extent=[-82, 70; 80, -74],
            string="Z",
            style(color=0)),
          Text(extent=[-70, 88; 70, 48], string="%name"),
          Text(extent=[-60, -54; 58, -88], string="e0=%e0")),
        Window(
          x=0.45,
          y=0.01,
          width=0.44,
          height=0.65),
        Documentation(info="<html>
The ideal Zener diode element is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The ideal Zener diode is a switch element with internal modulation.  The modulating signal, <b>mode</b>, is a ternary signal with the values <b>conducting</b>, <b>blocking</b>, and <b>avalanche</b>. Zener diodes are usually placed between a circuit node and the ground node.  Thus, the bondgraphic Zener diode is usually attached to a 0-junction via a bond. <p>

Diodes are switching elements that are primarily being used in electrical circuits, although nothing prevents them from being used also in other energy domains.  Zener diodes are always used as reversed diodes.  Thus, the positive and negative pins have been reversed in the model. <p>

The causality of the ideal diode element must be free, i.e., the ideal diode element must be placed inside an algebraic loop. <p>

<hr>

<pre>
Potential variables:

 e:     Bondgraphic effort variable

 f:     Bondgraphic flow variable, normalized positive for flows into the model

 mode:  Ternary variable denoting the switch position (internal modulation signal)

 s:     Curve parameter


Parameters:

 e0:    Avalanche breakdown voltage (default value = 1 Volt)
</pre> <p>

<hr> <p>

Equations: <p>

<b>mode = if s &lt; 0 then conducting else if s &lt; e0 then blocking else avalanche</b> <br>
<b>e = if mode == conducting then 0 else if mode == blocking then s else e0</b> <br>
<b>f = if mode == conducting then s else if mode == blocking then 0 else s - e0</b> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Otter, M., H. Elmqvist, and S.E. Mattsson (1999), \"<a href=\"http://www.modelica.org/publications/papers/hybrid99.pdf\">Hybrid
     Modeling in Modelica Based on the Synchronous Data Flow Principle</a>,\" <i>Proc. CACSD'99, IEEE Symposium on
     Computer-Aided Control System Design</i>, Hawaii, August 22-27, 1999, pp. 151-157.
</ol>
</html>

"));
    equation 
      mode = if s < 0 then conducting else if s < e0 then blocking else avalanche;
      e = if mode == conducting then 0 else if mode == blocking then s else e0;
      f = if mode == conducting then s else if mode == blocking then 0 else s - e0;
    end Z;
    
    model Z2 
      "Electrical ideal leaking Zener diode of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      constant Integer conducting=1;
      constant Integer blocking=2;
      constant Integer avalanche=3;
      parameter Real Ron=1E-5 "Leakage Resistance";
      parameter Real Raval=1E-5 "Leakage Resistance";
      parameter Real Goff=1E-5 "Leakage Conductance";
      parameter Real e0=1 "Avalanche breakdown Voltage";
      Real s1 "Curve parameter";
      Real s2 "Curve parameter";
      Integer mode "Operating mode";
      annotation (
        Icon(
          Text(
            extent=[-80,72; 82,-72],
            string="Z",
            style(color=0)),
          Text(extent=[-68,90; 72,50],   string="%name"),
          Text(extent=[-58,-52; 60,-86], string="e0=%e0"),
          Text(
            extent=[36,-16; 98,-50],
            string="Leak",
            style(color=0, pattern=0))),
        Diagram(
          Line(points=[-70,10; 90,10], style(color=10)),
          Line(points=[10,90; 10,-70], style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[6,80; 10,90; 14,80; 6,80],     style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[16,90; 26,80],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Line(points=[-4,-64; 10,10; 52,22; 64,80],        style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Ellipse(extent=[8,12; 12,8],  style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[-34,-34; -2,-44],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="conducting"),
          Text(
            extent=[14,28; 44,20],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="blocking"),
          Text(
            extent=[10,10; 30,0],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s1=0"),
          Text(
            extent=[60,56; 90,46],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="avalanche"),
          Text(
            extent=[56,26; 76,16],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s2=0"),
          Ellipse(extent=[50,24; 54,20],style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[44,8; 64,-2],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="e0"),
          Polygon(points=[90,14; 100,10; 90,6; 90,14],  style(color=10,
                fillColor=10)),
          Text(
            extent=[90,6; 100,-4],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e"),
          Line(points=[52,19; 52,10], style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[34,18; 54,8],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
      string="Goff"),
          Text(
            extent=[4,-20; 24,-30],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
      string="Ron"),
          Text(
            extent=[40,74; 60,64],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="Raval")),
        Documentation(info="<html>
The ideal leaking Zener diode element is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The ideal leaking Zener diode is a switch element with internal modulation.  The modulating signal, <b>mode</b>, is a ternary signal with the values <b>conducting</b>, <b>blocking</b>, and <b>avalanche</b>. Zener diodes are usually placed between a circuit node and the ground node.  Thus, the bondgraphic Zener diode is usually attached to a 0-junction via a bond. <p>

Diodes are switching elements that are primarily being used in electrical circuits, although nothing prevents them from being used also in other energy domains.  Zener diodes are always used as reversed diodes.  Thus, the positive and negative pins have been reversed in the model.  Leaking diodes are a special class of non-linear resistors. <p>

The causality of the leaking Zener diode element is free. <p>

<hr>

<pre>
Potential variables:

 e:      Bondgraphic effort variable

 f:      Bondgraphic flow variable, normalized positive for flows into the model

 mode:   Ternary variable denoting the switch position (internal modulation signal)

 s1:     Curve parameter

 s2:     Curve parameter


Parameters:

 Ron:    Leakage resistance in <b>conducting</b> state (default value = 1e-5 Ohm)

 Raval:  Leakage resistance in <b>avalanche</b> state (default value = 1e-5 Ohm)

 Goff:   Leakage conductance in <b>blocking</b> state (default value = 1e-5 Mho)

 e0:     Avalanche breakdown voltage (default value = 1 Volt)
</pre> <p>

<hr> <p>

Equations: <p>

<b>s2 = s1 - e0</b> <br>
<b>mode = if s1 &lt; 0 then conducting else if s1 &lt; e0 then blocking else avalanche</b> <br>
<b>e = if mode == conducting then Ron*s1 else if mode == blocking then s1 else (s2*Ron + e0)</b> <br>
<b>f = if mode == conducting then s1 else if mode == blocking then Goff*s1 else (s2 + Goff*e0)</b> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Otter, M., H. Elmqvist, and S.E. Mattsson (1999), \"<a href=\"http://www.modelica.org/publications/papers/hybrid99.pdf\">Hybrid
     Modeling in Modelica Based on the Synchronous Data Flow Principle</a>,\" <i>Proc. CACSD'99, IEEE Symposium on
     Computer-Aided Control System Design</i>, Hawaii, August 22-27, 1999, pp. 151-157.
</ol>
</html>
"));
    equation 
      s2 = s1 - e0;
      mode = if s1 < 0 then conducting else if s1 < e0 then blocking else avalanche;
      e = if mode == conducting then Ron*s1 else if mode == blocking then s1 else (s2*Ron + e0);
      f = if mode == conducting then s1 else if mode == blocking then Goff*s1 else (s2 + Goff*e0);
    end Z2;
    
    model T "Electrical ideal tunnel diode of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      constant Integer blocking=1;
      constant Integer c1=2;
      constant Integer b1=3;
      constant Integer c2=4;
      constant Integer b2=5;
      constant Integer conducting=6;
      parameter Real em=1 "Intermediate forward voltage";
      parameter Real e0=2 "Maximum forward voltage";
      parameter Real fm=1 "Intermediate bottom current";
      parameter Real f0=2 "Intermediate top current";
      Real s1 "Curve parameter";
      Real s2 "Curve parameter";
      Real s3 "Curve parameter";
      Real s4 "Curve parameter";
      Real s5 "Curve parameter";
      Integer mode "Operating mode";
      annotation (
        Icon(
          Text(
            extent=[-80,70; 82,-74],
            style(color=0),
            string="T"),
          Text(extent=[-70,92; 70,52],   string="%name")),
        Diagram(
          Line(points=[-80,0; 80,0],   style(color=10)),
          Line(points=[0,80; 0,-80],   style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[-4,70; 0,80; 4,70; -4,70],     style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[6,80; 16,70],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Ellipse(extent=[-2,2; 2,-2],  style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[42,62; 74,52],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="conducting"),
          Text(
            extent=[-52,8; -22,0],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="blocking"),
          Text(
            extent=[-14,-2; -2,-8],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s1=0"),
          Text(
            extent=[-12,18; 2,10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="c1"),
          Ellipse(extent=[-2,62; 2,58], style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[30,0; 50,-10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="e0"),
          Polygon(points=[80,4; 90,0; 80,-4; 80,4],     style(color=10,
                fillColor=10)),
          Text(
            extent=[80,-4; 90,-14],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e"),
          Line(points=[-72,0; 0,0; 0,60; 20,60],            style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Line(points=[40,80; 40,30; 20,30; 20,60],         style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[18,50; 32,42],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="c2"),
          Text(
            extent=[22,28; 36,20],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="b2"),
          Text(
            extent=[4,68; 18,60],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="b1"),
          Text(
            extent=[10,0; 30,-10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="em"),
          Text(
            extent=[-18,36; 2,26],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="fm"),
          Text(
            extent=[-16,64; 4,54],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="f0"),
          Line(points=[40,28; 40,0],  style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Line(points=[20,28; 20,0],  style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Line(points=[18,30; 0,30],  style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[2,60; 14,54],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s2=0"),
          Text(
            extent=[20,68; 32,62],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s3=0"),
          Text(
            extent=[22,36; 34,30],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s4=0"),
          Text(
            extent=[42,30; 54,24],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s5=0"),
          Ellipse(extent=[18,62; 22,58],style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Ellipse(extent=[18,32; 22,28],style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Ellipse(extent=[38,32; 42,28],style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1))),
        Documentation(info="<html>
The ideal tunnel diode element is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The ideal tunnel diode is a switch element with internal modulation.  The modulating signal, <b>mode</b>, is a sextary signal with the values <b>blocking</b>, <b>c1</b>, <b>b1</b>, <b>c2</b>, <b>b2</b>, and <b>blocking</b>. <p>

Diodes are switching elements that are primarily being used in electrical circuits, although nothing prevents them from being used also in other energy domains. <p>

The causality of the ideal diode element must be free, i.e., the ideal diode element must be placed inside an algebraic loop. <p>

<hr>

<pre>
Potential variables:

 e:     Bondgraphic effort variable

 f:     Bondgraphic flow variable, normalized positive for flows into the model

 mode:  Sextary variable denoting the switch position (internal modulation signal)

 s1:    Curve parameter

 s2:    Curve parameter

 s3:    Curve parameter

 s4:    Curve parameter

 s5:    Curve parameter


Parameters:

 em:    Intermediate forward voltage (default value = 1 Volt)

 e0:    Maximum forward voltage (default value = 2 Volt)

 fm:    Bottom intermediate current (default value = 1 Amp)

 f0:    Top intermediate current (default value = 2 Amp)
</pre> <p>

<hr> <p>

Equations: <p>

<b>s2 = s1 - f0</b> <br>
<b>s3 = s2 - em</b> <br>
<b>s4 = s3 - (f0-fm)</b> <br>
<b>s5 = s4 - (e0-em)</b> <br>
<b>mode = if s1 &lt; 0 then blockinging else
          if s2 &lt; 0 then c1 else 
          if s3 &lt; 0 then b1 else 
          if s4 &lt; 0 then c2 else 
          if s5 &lt; 0 then b2 else conducting</b> <br>
<b>e = if mode == blocking then s1 else 
       if mode == c1 then 0 else 
       if mode == b1 then s2 else 
       if mode == c2 then em else 
       if mode == b2 then (em + s4) else e0</b> <br>
<b>f = if mode == blocking then 0 else 
       if mode == c1 then s1 else 
       if mode == b1 then f0 else 
       if mode == c2 then (f0 - s3) else 
       if mode == b2 then fm else (fm + s5)</b> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Otter, M., H. Elmqvist, and S.E. Mattsson (1999), \"<a href=\"http://www.modelica.org/publications/papers/hybrid99.pdf\">Hybrid
     Modeling in Modelica Based on the Synchronous Data Flow Principle</a>,\" <i>Proc. CACSD'99, IEEE Symposium on
     Computer-Aided Control System Design</i>, Hawaii, August 22-27, 1999, pp. 151-157.
</ol>
</html>
"));
    equation 
      s2 = s1 - f0;
      s3 = s2 - em;
      s4 = s3 - (f0-fm);
      s5 = s4 - (e0-em);
      mode = if s1 < 0 then blocking else 
             if s2 < 0 then c1 else 
             if s3 < 0 then b1 else 
             if s4 < 0 then c2 else 
             if s5 < 0 then b2 else conducting;
      e = if mode == blocking then s1 else 
          if mode == c1 then 0 else 
          if mode == b1 then s2 else 
          if mode == c2 then em else 
          if mode == b2 then (em + s4) else e0;
      f = if mode == blocking then 0 else 
          if mode == c1 then s1 else 
          if mode == b1 then f0 else 
          if mode == c2 then (f0 - s3) else 
          if mode == b2 then fm else (fm + s5);
    end T;
    
    model T2 
      "Electrical ideal leaking tunnel diode of the Modelica bond graph library" 
      extends Interfaces.PassiveOnePort;
      constant Integer blocking=1;
      constant Integer c1=2;
      constant Integer b1=3;
      constant Integer c2=4;
      constant Integer b2=5;
      constant Integer conducting=6;
      parameter Real G0=1E-5 "Leakage Conductance";
      parameter Real R1=1E-5 "Leakage Resistance";
      parameter Real R2=1E-5 "Leakage Resistance";
      parameter Real R3=1E-5 "Leakage Resistance";
      parameter Real em1=1 "Intermediate forward voltage";
      parameter Real em2=2 "Intermediate forward voltage";
      parameter Real em3=3 "Intermediate forward voltage";
      parameter Real e0=4 "Maximum forward voltage";
      parameter Real fm=1 "Intermediate bottom current";
      parameter Real f0=2 "Intermediate top current";
      Real s1 "Curve parameter";
      Real s2 "Curve parameter";
      Real s3 "Curve parameter";
      Real s4 "Curve parameter";
      Real s5 "Curve parameter";
      Integer mode "Operating mode";
      annotation (
        Icon(
          Text(
            extent=[-78,70; 84,-74],
            style(color=0),
            string="T"),
          Text(extent=[-68,92; 72,52],   string="%name"),
          Text(
            extent=[22,-18; 84,-52],
            string="Leak",
            style(color=0, pattern=0))),
        Diagram(
          Line(points=[-80,0; 80,0],   style(color=10)),
          Line(points=[0,80; 0,-80],   style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[-4,70; 0,80; 4,70; -4,70],     style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[6,80; 16,70],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Ellipse(extent=[-2,2; 2,-2],  style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[46,70; 78,60],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="conducting"),
          Text(
            extent=[-52,-10; -22,-18],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="blocking"),
          Text(
            extent=[-6,-2; 6,-8],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s1=0"),
          Text(
            extent=[-4,50; 10,42],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="c1"),
          Ellipse(extent=[10,58; 6,62], style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[30,0; 50,-10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="e0"),
          Polygon(points=[80,4; 90,0; 80,-4; 80,4],     style(color=10,
                fillColor=10)),
          Text(
            extent=[80,-4; 90,-14],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e"),
          Line(points=[-72,-12; 0,0; 8,60; 20,60],          style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Line(points=[48,92; 40,30; 28,30; 20,60],         style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[22,54; 36,46],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="c2"),
          Text(
            extent=[28,30; 42,22],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="b2"),
          Text(
            extent=[8,68; 22,60],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="b1"),
          Text(
            extent=[4,-6; 14,-16],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="em1"),
          Text(
            extent=[-18,36; 2,26],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="fm"),
          Text(
            extent=[-16,64; 4,54],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="f0"),
          Line(points=[40,28; 40,0],  style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Line(points=[20,58; 20,0],  style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Line(points=[26,30; 0,30],  style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[-4,68; 8,62],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s2=0"),
          Text(
            extent=[22,66; 34,60],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s3=0"),
          Text(
            extent=[14,30; 26,24],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s4=0"),
          Text(
            extent=[42,32; 54,26],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s5=0"),
          Ellipse(extent=[18,62; 22,58],style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Ellipse(extent=[26,32; 30,28],style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Ellipse(extent=[38,32; 42,28],style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Line(points=[6,60; 0,60],   style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[14,0; 24,-10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="em2"),
          Text(
            extent=[22,-6; 32,-16],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="em3"),
          Line(points=[8,58; 8,-8],   style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Line(points=[28,28; 28,-8], style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[-60,2; -42,-8],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="G0"),
          Text(
            extent=[-12,16; 6,6],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="R1"),
          Text(
            extent=[10,42; 28,32],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="R2"),
          Text(
            extent=[40,52; 58,42],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="R3")),
        Documentation(info="<html>
The ideal leaking tunnel diode element is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The ideal leaking tunnel diode is a switch element with internal modulation.  The modulating signal, <b>mode</b>, is a sextary signal with the values <b>blocking</b>, <b>c1</b>, <b>b1</b>, <b>c2</b>, <b>b2</b>, and <b>blocking</b>. <p>

Diodes are switching elements that are primarily being used in electrical circuits, although nothing prevents them from being used also in other energy domains.  Leaking diodes are a special class of non-linear resistors. <p>

The causality of the ideal leaking diode element is free. <p>

<hr>

<pre>
Potential variables:

 e:     Bondgraphic effort variable

 f:     Bondgraphic flow variable, normalized positive for flows into the model

 mode:  Sextary variable denoting the switch position (internal modulation signal)

 s1:    Curve parameter

 s2:    Curve parameter

 s3:    Curve parameter

 s4:    Curve parameter

 s5:    Curve parameter


Parameters:

 G0:    Leakage conductance in blocking state (default value = 1e-5 Mho)

 R1:    Leakage resistance in conducting state (default value = 1e-5 Ohm)

 R2:    Leakage resistance in conducting state (default value = 1e-5 Ohm)

 R3:    Leakage resistance in conducting state (default value = 1e-5 Ohm)

 em1:   First knee voltage (default value = 1 Volt)

 em2:   Second knee voltage (default value = 2 Volt)

 em3:   Third knee voltage (default value = 3 Volt)

 e0:    Fourth knee voltage (default value = 4 Volt)

 fm:    Bottom intermediate current (default value = 1 Amp)

 f0:    Top intermediate current (default value = 2 Amp)
</pre> <p>

<hr> <p>

Equations: <p>

<b>s2 = s1 - f0</b> <br>
<b>s3 = s3 = s2 - (em2-em1)</b> <br>
<b>s4 = s3 - (f0-fm)</b> <br>
<b>s5 = s4 - (e0-em3)</b> <br>
<b>mode = if s1 &lt; 0 then blockinging else
          if s2 &lt; 0 then c1 else 
          if s3 &lt; 0 then b1 else 
          if s4 &lt; 0 then c2 else 
          if s5 &lt; 0 then b2 else conducting</b> <br>
<b>e = if mode == blocking then s1 else 
       if mode == c1 then R1*s1 else 
       if mode == b1 then (em1 + s2) else 
       if mode == c2 then (em2 + R2*s3) else 
       if mode == b2 then (em3 + s4) else (e0 + R3*s5)</b> <br>
<b>f = if mode == blocking then G0*s1 else 
       if mode == c1 then s1 else 
       if mode == b1 then f0 else 
       if mode == c2 then (f0 - s3) else 
       if mode == b2 then fm else (fm + s5)</b> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Otter, M., H. Elmqvist, and S.E. Mattsson (1999), \"<a href=\"http://www.modelica.org/publications/papers/hybrid99.pdf\">Hybrid
     Modeling in Modelica Based on the Synchronous Data Flow Principle</a>,\" <i>Proc. CACSD'99, IEEE Symposium on
     Computer-Aided Control System Design</i>, Hawaii, August 22-27, 1999, pp. 151-157.
</ol>
</html>
"));
    equation 
      s2 = s1 - f0;
      s3 = s2 - (em2-em1);
      s4 = s3 - (f0-fm);
      s5 = s4 - (e0-em3);
      mode = if s1 < 0 then blocking else 
             if s2 < 0 then c1 else 
             if s3 < 0 then b1 else 
             if s4 < 0 then c2 else 
             if s5 < 0 then b2 else conducting;
      e = if mode == blocking then s1 else 
          if mode == c1 then R1*s1 else 
          if mode == b1 then (em1 + s2) else 
          if mode == c2 then (em2 + R2*s3) else 
          if mode == b2 then (em3 + s4) else (e0 + R3*s5);
      f = if mode == blocking then G0*s1 else 
          if mode == c1 then s1 else 
          if mode == b1 then f0 else 
          if mode == c2 then (f0 - s3) else 
          if mode == b2 then fm else (fm + s5);
    end T2;
  end Switches;
  
  package Thermal "Thermal models of Modelica bond graph library" 
    annotation (
      Coordsys(
        extent=[0, 0; 442, 394],
        grid=[2, 2],
        component=[20, 20]),
      Icon(
        Rectangle(extent=[-100, -100; 80, 50], style(fillColor=30, fillPattern=
                1)),
        Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50], style(
              fillColor=30, fillPattern=1)),
        Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70], style(
              fillColor=30, fillPattern=1)),
        Text(
          extent=[-85, 35; 65, -85],
          string="Library",
          style(color=3)),
        Text(
          extent=[-116, 124; 124, 75],
          string="%name",
          style(color=1))),
      Window(
        x=0.45,
        y=0.01,
        width=0.44,
        height=0.65,
        library=1,
        autolayout=1),
      Documentation(info="<html>
This package contains a number of modeling elements that are used in thermal modeling without convective heat flows, such as in the thermal modeling of buildings. <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Nebot, A., F.E. Cellier, and F. Mugica (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/ecoeng_bio2.pdf\">Simulation
     of Heat and Humidity Budget of Biosphere 2 without its Air Conditioning</a>,\" <i>Ecological Engineering</i>,
     <b>13</b>, pp. 333-356.
<li> Weiner, M., and F.E. Cellier (1993), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/Weiner.pdf\">Modeling
     and Simulation of a Solar Energy System by Use of Bond Graphs</a>,\" <i>Proc. SCS 1<sup>st</sup> Intl. Conf. on Bond
     Graph Modeling</i>, San Diego, California, pp.301-306. 
</ol>
</html>"));
    model RS "The bondgraphic linear resistive source element" 
      extends Interfaces.TwoPort;
      parameter Real R=1 "Bondgraphic Resistance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-74, 80; 74, -80],
            string="RS",
            style(color=0))),
        Icon(
          Text(
            extent=[-72, 78; 76, -82],
            string="RS",
            style(color=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(extent=[-78, -48; 80, -88], string="R=%R")),
        Documentation(info="<html>
The bondgraphic linear resistive source is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The resistance is modeled as a parameter. <p>

The linear resistive source element is to be used as a replacement for resistors in modeling the thermal behavior of non-thermal systems.  The primary side of the linear resistive source element is assumed to not be in the thermal domain. <p>

The resistive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model


Parameters:

 R:   Resistance (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e1 = R*f1</b> <br>
<b>f2 = f1*(e1/e2)</b>
</html>
"));
    equation 
      e1 = R*f1;
      e1*f1 = e2*f2;
    end RS;
    
    model mRS "The modulated bondgraphic resistive source element" 
      extends Interfaces.ModTwoPort;
      Real R "Bondgraphic Resistance";
      annotation (
        Diagram(Text(
            extent=[-84,80; 84,-82],
            style(color=0),
            string="mRS")),
        Icon(
          Text(extent=[-70,100; 70,60],  string="%name"),
                Text(
            extent=[-84,80; 84,-82],
            style(color=0),
            string="mRS")),
        Documentation(info="<html>
The bondgraphic modulated resistive source is a directed modulated TwoPort element.  It inherits the effort and flow variables from the directed modulated TwoPort.  The resistance is modeled as a real-valued variable. <p>

The modulated resistive source element is to be used as a replacement for resistors in modeling the thermal behavior of non-thermal systems.  The primary side of the modulated resistive source element is assumed to not be in the thermal domain. <p>

The resistive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 R:   Resistance value (modulation input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>e1 = R*f1</b> <br>
<b>f2 = f1*(e1/e2)</b>
</html>
"));
    equation 
      R = s;
      e1 = R*f1;
      e1*f1 = e2*f2;
    end mRS;
    
    model RSth "The bondgraphic linear conductive resistive source element" 
      extends Interfaces.TwoPort;
      parameter Real theta=1 "Thermal Resistance Constant";
      Real R "Bondgraphic Thermal Resistance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-74, 80; 36, -82],
            string="RS",
            style(color=0)), Text(
            extent=[34, 42; 78, -60],
            string="th",
            style(color=0))),
        Icon(
          Text(
            extent=[34, 40; 78, -62],
            string="th",
            style(color=0)),
          Text(
            extent=[-74, 80; 36, -82],
            string="RS",
            style(color=0)),
          Text(extent=[-78, -48; 80, -88], string="theta=%theta"),
          Text(extent=[-70, 90; 70, 50], string="%name")),
        Documentation(info="<html>
The bondgraphic linear conductive resistive source is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The thermal resistance is modeled as a parameter. <p>

The resistance, <b>R</b>, is proportional to the temperature at the inflow, <b>T1</b>.  Since <b>e1</b> represents the temperature difference, <b>e1 = T1 - T2</b>, and since <b>e2</b> represents the temperature at the outflow, <b>e2 = T2</b>, the temperature at the inflow can be computed as: <b>T1 = e1 + e2</b>. <p>

The linear conductive resistive source element is to be used in linear conduction of thermal systems.  The primary side of the linear resistive source element is assumed to be in the thermal domain. <p>

The resistive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:      Bondgraphic effort variable of inflow

 f1:      Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:      Bondgraphic effort variable of outflow

 f2:      Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 R:       Bondgraphic thermal resistance


Parameters:

 theta:   Thermal resistance constant (default value = 1 <sup>o</sup>K/W)
</pre> <p>

<hr> <p>

Equations: <p>

<b>R = theta*(e1+e2)</b> <br>
<b>e1 = R*f1</b> <br>
<b>f2 = f1*(e1/e2)</b>
</html>
"));
    equation 
      R = theta*(e1 + e2);
      e1 = R*f1;
      e1*f1 = e2*f2;
    end RSth;
    
    model mRSth "The bondgraphic modulated resistive source element" 
      extends Interfaces.ModTwoPort;
      Real R0 "Thermal Resistance";
      Real R "Bondgraphic Resistance";
      annotation (
        Icon(
          Text(extent=[-60,90; 80,50],   string="%name"),
          Text(
            extent=[-80,86; 58,-88],
            style(color=0),
            string="mRS"),
          Text(
            extent=[56,30; 90,-64],
            string="th",
            style(color=0))),
        Diagram(
          Text(
            extent=[-80,86; 58,-88],
            style(color=0),
            string="mRS"),
          Text(
            extent=[56,30; 90,-64],
            string="th",
            style(color=0))),
        Documentation(info="<html>
The bondgraphic modulated resistive source is a directed modulated TwoPort element.  It inherits the effort and flow variables from the directed modulated TwoPort.  The thermal resistance is modeled as a real-valued variable. <p>

The resistance, <b>R</b>, is proportional to the temperature at the inflow, <b>T1</b>.  Since <b>e1</b> represents the temperature difference, <b>e1 = T1 - T2</b>, and since <b>e2</b> represents the temperature at the outflow, <b>e2 = T2</b>, the temperature at the inflow can be computed as: <b>T1 = e1 + e2</b>. <p>

The modulated resistive source element is to be used in conduction of thermal systems.  The primary side of the modulated conductive source element is assumed to be in the thermal domain. <p>

The resistive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:   Bondgraphic effort variable of inflow

 f1:   Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:   Bondgraphic effort variable of outflow

 f2:   Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 R:    Bondgraphic thermal resistance

 R0:   Thermal resistance constant (modulation input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>R = R0*(e1+e2)</b> <br>
<b>e1 = R*f1</b> <br>
<b>f2 = f1*(e1/e2)</b>
</html>
"));
    equation 
      R0 = s;
      R = R0*(e1 + e2);
      e1 = R*f1;
      e1*f1 = e2*f2;
    end mRSth;
    
    model RSrad "The bondgraphic radiative resistive source element" 
      extends Interfaces.TwoPort;
      parameter Real sigma=1 "Specific Radiation Constant";
      parameter Real A=1 "Radiating Surface";
      Real R "Bondgraphic Radiative Resistance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-74, 80; 18, -82],
            string="RS",
            style(color=0)), Text(
            extent=[20, 42; 80, -74],
            string="rad",
            style(color=0))),
        Icon(
          Text(
            extent=[20, 42; 80, -74],
            string="rad",
            style(color=0)),
          Text(
            extent=[-74, 80; 18, -82],
            string="RS",
            style(color=0)),
          Text(extent=[-78, -48; 80, -88], string="sigma=%sigma"),
          Text(extent=[-70, 90; 70, 50], string="%name")),
        Documentation(info="<html>
The bondgraphic radiative resistive source is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The specific radiation constant and the rediating surface are modeled as parameters. <p>

The resistance, <b>R</b>, is inverse proportional to the square of the temperature at the inflow, <b>T1 = e1</b>. <p>

The radiative resistive source element is to be used in radiation of thermal systems.  The primary side of the radiative resistive source element is assumed to be in the thermal domain. <p>

The resistive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:      Bondgraphic effort variable of inflow

 f1:      Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:      Bondgraphic effort variable of outflow

 f2:      Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 R:       Bondgraphic radiative resistance


Parameters:

 sigma:   Specific radiation constant (default value = 1 W/(m<sup>2</sup>*<sup>o</sup>K<sup>4</sup>)

 A:       Radiating surface (default value = 1 m<sup>2</sup>)
</pre> <p>

<hr> <p>

Equations: <p>

<b>R = 1/(sigma*A*e1*e1)</b> <br>
<b>e1 = R*f1</b> <br>
<b>f2 = f1*(e1/e2)</b>
</html>
"));
    equation 
      R = 1/(A*sigma*(e1^2));
      e1 = R*f1;
      e1*f1 = e2*f2;
    end RSrad;
    
    model GS "The bondgraphic linear conductive source element" 
      extends Interfaces.TwoPort;
      parameter Real G=1 "Bondgraphic Cunductance";
      annotation (
        Icon(
          Text(extent=[-64,90; 76,50],   string="%name"),
          Text(
            extent=[-66,78; 82,-82],
            style(color=0),
            string="GS"),
          Text(extent=[-72,-48; 86,-88], string="G=%G")),
        Diagram(
          Text(
            extent=[-66,78; 82,-82],
            style(color=0),
            string="GS")),
        Documentation(info="<html>
The bondgraphic linear conductive source is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The conductance is modeled as a parameter. <p>

The linear conductive source element is to be used as a replacement for conductors in modeling the thermal behavior of non-thermal systems.  The primary side of the linear conductive source element is assumed to not be in the thermal domain. <p>

The conductive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model


Parameters:

 G:   Conductance (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f1 = G*e1</b> <br>
<b>f2 = f1*(e1/e2)</b>
</html>
"));
    equation 
      f1 = G*e1;
      e1*f1 = e2*f2;
    end GS;
    
    model mGS "The modulated bondgraphic conductive source element" 
      extends Interfaces.ModTwoPort;
      Real G "Bondgraphic Conductance";
      annotation (
        Icon(   Text(
            extent=[-82,80; 86,-82],
            style(color=0),
            string="mGS"),
          Text(extent=[-68,100; 72,60],  string="%name")),
        Diagram(Text(
            extent=[-82,80; 86,-82],
            style(color=0),
            string="mGS")),
        Documentation(info="<html>
The bondgraphic modulated conductive source is a directed modulated TwoPort element.  It inherits the effort and flow variables from the modulated directed TwoPort.  The conductance is modeled as a real-valued variable. <p>

The modulated conductive source element is to be used as a replacement for  modulated conductors in modeling the thermal behavior of non-thermal systems.  The primary side of the modulated conductive source element is assumed to not be in the thermal domain. <p>

The conductive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:  Bondgraphic effort variable of inflow

 f1:  Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:  Bondgraphic effort variable of outflow

 f2:  Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 G:   Conductance value (modulation input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>f1 = G*e1</b> <br>
<b>f2 = f1*(e1/e2)</b>
</html>
"));
    equation 
      G = s;
      f1 = G*e1;
      e1*f1 = e2*f2;
    end mGS;
    
    model GSth "The bondgraphic linear conductive source element" 
      extends Interfaces.TwoPort;
      parameter Real G0=1 "Thermal Conductance";
      Real G "Bondgraphic Conductance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-74, 80; 36, -82],
            style(color=0),
            string="GS"), Text(
            extent=[34, 42; 78, -60],
            string="th",
            style(color=0))),
        Icon(
          Text(
            extent=[34, 40; 78, -62],
            string="th",
            style(color=0)),
          Text(
            extent=[-74, 80; 36, -82],
            style(color=0),
            string="GS"),
          Text(extent=[-78, -48; 80, -88], string="G0=%G0"),
          Text(extent=[-70, 90; 70, 50], string="%name")),
        Documentation(info="<html>
The bondgraphic linear conductive source is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The thermal conductance is modeled as a parameter. <p>

The conductance, <b>G</b>, is inverse proportional to the temperature at the inflow, <b>T1</b>.  Since <b>e1</b> represents the temperature difference, <b>e1 = T1 - T2</b>, and since <b>e2</b> represents the temperature at the outflow, <b>e2 = T2</b>, the temperature at the inflow can be computed as: <b>T1 = e1 + e2</b>. <p>

The linear conductive source element is to be used in linear conduction of thermal systems.  The primary side of the linear conductive source element is assumed to be in the thermal domain. <p>

The conductive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:   Bondgraphic effort variable of inflow

 f1:   Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:   Bondgraphic effort variable of outflow

 f2:   Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 G:    Bondgraphic thermal conductance


Parameters:

 G0:   Thermal conductance constant (default value = 1 W/<sup>o</sup>K)
</pre> <p>

<hr> <p>

Equations: <p>

<b>G = G0/(e1+e2)</b> <br>
<b>f1 = G*e1</b> <br>
<b>f2 = f1*(e1/e2)</b>
</html>
"));
    equation 
      G = G0/(e1 + e2);
      f1 = G*e1;
      e1*f1 = e2*f2;
    end GSth;
    
    model mGSth "The bondgraphic modulated conductive source element" 
      extends Interfaces.ModTwoPort;
      Real G0 "Thermal Conductance";
      Real G "Bondgraphic Conductance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-88, 86; 50, -88],
            style(color=0),
            string="mGS"), Text(
            extent=[52, 30; 86, -64],
            string="th",
            style(color=0))),
        Icon(
          Text(
            extent=[52, 30; 86, -64],
            string="th",
            style(color=0)),
          Text(
            extent=[-88, 86; 50, -88],
            style(color=0),
            string="mGS"),
          Text(extent=[-70, 90; 70, 50], string="%name")),
        Documentation(info="<html>
The bondgraphic modulated conductive source is a directed modulated TwoPort element.  It inherits the effort and flow variables from the directed modulated TwoPort.  The thermal conductance is modeled as a real-valued variable. <p>

The conductance, <b>G</b>, is inverse proportional to the temperature at the inflow, <b>T1</b>.  Since <b>e1</b> represents the temperature difference, <b>e1 = T1 - T2</b>, and since <b>e2</b> represents the temperature at the outflow, <b>e2 = T2</b>, the temperature at the inflow can be computed as: <b>T1 = e1 + e2</b>. <p>

The modulated conductive source element is to be used in conduction of thermal systems.  The primary side of the modulated conductive source element is assumed to be in the thermal domain. <p>

The conductive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:   Bondgraphic effort variable of inflow

 f1:   Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:   Bondgraphic effort variable of outflow

 f2:   Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 G:    Bondgraphic thermal conductance

 G0:   Thermal conductance constant (modulation input signal)
</pre> <p>

<hr> <p>

Equations: <p>

<b>G = G0/(e1+e2)</b> <br>
<b>f1 = G*e1</b> <br>
<b>f2 = f1*(e1/e2)</b>
</html>
"));
    equation 
      G0 = s;
      G = G0/(e1 + e2);
      f1 = G*e1;
      e1*f1 = e2*f2;
    end mGSth;
    
    model GSrad "The bondgraphic radiative conductive source element" 
      extends Interfaces.TwoPort;
      parameter Real sigma=1 "Specific radiation constant";
      parameter Real A=1 "Radiating surface";
      Real G "Bondgraphic Radiative Conductance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[-80, 78; 16, -84],
            string="GS",
            style(color=0)), Text(
            extent=[18, 40; 74, -76],
            string="rad",
            style(color=0))),
        Icon(
          Text(
            extent=[18, 40; 74, -76],
            string="rad",
            style(color=0)),
          Text(
            extent=[-80, 78; 16, -84],
            string="GS",
            style(color=0)),
          Text(extent=[-78, -48; 80, -88], string="sigma=%sigma"),
          Text(extent=[-70, 90; 70, 50], string="%name")),
        Documentation(info="<html>
The bondgraphic radiative conductive source is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The specific radiation constant and the rediating surface are modeled as parameters. <p>

The conductance, <b>G</b>, is proportional to the square of the temperature at the inflow, <b>T1 = e1</b>. <p>

The radiative conductive source element is to be used in radiation of thermal systems.  The primary side of the radiative conductive source element is assumed to be in the thermal domain. <p>

The conductive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:      Bondgraphic effort variable of inflow

 f1:      Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:      Bondgraphic effort variable of outflow

 f2:      Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 G:       Bondgraphic radiative conductance


Parameters:

 sigma:   Specific radiation constant (default value = 1 W/(m<sup>2</sup>*<sup>o</sup>K<sup>4</sup>)

 A:       Radiating surface (default value = 1 m<sup>2</sup>)
</pre> <p>

<hr> <p>

Equations: <p>

<b>G = sigma*A*e1*e1</b> <br>
<b>f1 = G*e1</b> <br>
<b>f2 = f1*(e1/e2)</b>
</html>
"));
    equation 
      G = A*sigma*(e1^2);
      f1 = G*e1;
      e1*f1 = e2*f2;
    end GSrad;
    
    model Cth "The bondgraphic thermal capacitor element" 
      extends Interfaces.PassiveOnePort;
      parameter Real gamma=1 "Thermal Capacity";
      Real C "Bondgraphic Capacitance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(Text(
            extent=[26, 38; 90, -80],
            string="th",
            style(color=0)), Text(
            extent=[-66, 74; 30, -78],
            string="C",
            style(color=0))),
        Icon(
          Text(
            extent=[26, 38; 90, -80],
            string="th",
            style(color=0)),
          Text(
            extent=[-66, 74; 30, -78],
            string="C",
            style(color=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(extent=[-66, -48; 72, -88], string="gamma=%gamma")),
        Documentation(info="<html>
The bondgraphic thermal capacitor is a passive OnePort element.  It inherits the effort and flow variables from the passive OnePort.  The thermal capacitance is modeled as a parameter. <p>

The capacitance, <b>C</b>, is inverse proportional to the temperature. <p>

The capacitor model has a preferred causality away from the element. <p>

<hr>

<pre>
Potential variables:

 e:  Bondgraphic effort variable

 f:  Bondgraphic flow variable, normalized positive for flows into the model

 C:  Bondgraphic thermal capacitance


Parameters:

 gamma:  Thermal capacitance (default value = 1 W*sec/<sup>o</sup>K)
</pre> <p>

<hr> <p>

Equations: <p>

<b>C = gamma/e</b> <br>
<b>f = C*der(e)</b>
</html>
"));
    equation 
      C = gamma/e;
      f = C*der(e);
    end Cth;
    
    model HE "Symmetric linear heat exchange element" 
      extends Interfaces.TwoPort;
      parameter Real theta=1 "Thermal Resistance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram,
        Icon(
          Text(
            extent=[-86, 80; 62, -80],
            string="HE",
            style(color=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(extent=[-78, -48; 80, -88], string="theta=%theta"),
          Text(
            extent=[52, 14; 94, -46],
            string="s",
            style(color=0))),
        Documentation(info="<html>
The bondgraphic symmetric linear heat exchange element is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The thermal resistance is modeled as a parameter. <p>

The heat exchange is driven by the temperature difference between the two sides.  The generated entropy is divided evenly to the left and the right. <p>

The heat exchange element has two causality strokes at the element. <p>

<hr>

<pre>
Potential variables:

 e1:      Bondgraphic effort variable of inflow

 f1:      Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:      Bondgraphic effort variable of outflow

 f2:      Bondgraphic flow variable of outflow, normalized positive for flows out of the model


Parameters:

 theta:   Thermal resistance (default value = 1 <sup>o</sup>K/W)
</pre>
</html>
"));
      Junctions.J0p3 J0p3_1 annotation (extent=[-70, 10; -50, -10]);
      Junctions.J0p3 J0p3_2 annotation (extent=[50, 10; 70, -10]);
      Junctions.J1p3 J1p3_1 annotation (extent=[-10, 10; 10, -10]);
      Bonds.fBond B3 annotation (extent=[-10, 10; 10, 30], rotation=90);
      Junctions.J0p3 J0p3_3 annotation (extent=[-10, 30; 10, 50]);
      Bonds.fBond B4 annotation (extent=[10, 30; 30, 50]);
      Bonds.fBond B5 annotation (extent=[-30, 30; -10, 50], rotation=180);
      RSth RSr(theta=2*theta) annotation (extent=[30, 30; 50, 50]);
      Bonds.eBond B2 annotation (extent=[20, -10; 40, 10]);
      Bonds.eBond B6 annotation (extent=[50, 10; 70, 30], rotation=-90);
      Bonds.fBond B1 annotation (extent=[-40, -10; -20, 10]);
      RSth RSl(theta=2*theta) annotation (extent=[-30, 30; -50, 50]);
      Bonds.eBond B7 annotation (extent=[-70, 10; -50, 30], rotation=-90);
    equation 
      connect(J0p3_2.BondCon2, BondCon2) annotation (points=[70,0; 100,0],
          style(color=8));
      connect(J1p3_1.BondCon3, B3.eBondCon1) annotation (points=[0,10; 
            -6.12303e-016,10],
            style(color=8));
      connect(B3.fBondCon1, J0p3_3.BondCon3) annotation (points=[6.12303e-016,
            30; 0,30],
            style(color=8));
      connect(J0p3_3.BondCon2, B4.eBondCon1) annotation (points=[10, 40; 10, 40],
               style(color=8));
      connect(J0p3_3.BondCon1, B5.eBondCon1) annotation (points=[-10, 40; -10,
            40], style(color=8));
      connect(B4.fBondCon1, RSr.BondCon1) annotation (points=[30, 40; 30, 40],
          style(color=8));
      connect(J1p3_1.BondCon2, B2.fBondCon1) annotation (points=[10, 0; 20, 0],
            style(color=8));
      connect(B2.eBondCon1, J0p3_2.BondCon1) annotation (points=[40, 0; 50, 0],
            style(color=8));
      connect(B6.eBondCon1, J0p3_2.BondCon3) annotation (points=[60, 10; 60, 10],
               style(color=8));
      connect(RSr.BondCon2, B6.fBondCon1) annotation (points=[50, 40; 60, 40;
            60, 30], style(color=8));
      connect(J0p3_1.BondCon2, B1.eBondCon1) annotation (points=[-50, 0; -40, 0],
               style(color=8));
      connect(B1.fBondCon1, J1p3_1.BondCon1) annotation (points=[-20, 0; -10, 0],
               style(color=8));
      connect(B5.fBondCon1, RSl.BondCon1) annotation (points=[-30, 40; -30, 40],
            style(color=8));
      connect(B7.eBondCon1, J0p3_1.BondCon3) annotation (points=[-60, 10; -60,
            10], style(color=8));
      connect(RSl.BondCon2, B7.fBondCon1) annotation (points=[-50, 40; -60, 40;
              -60, 30], style(color=8));
      connect(BondCon1, J0p3_1.BondCon1) annotation (points=[-100,0; -70,0],
          style(color=8, rgbcolor={192,192,192}));
    end HE;
    
    model HEr "Asymmetric linear heat exchange element" 
      extends Interfaces.TwoPort;
      parameter Real theta=1 "Thermal Resistance";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Icon(
          Text(
            extent=[-92, 78; 38, -82],
            string="HE",
            style(color=0)),
          Text(
            extent=[36, 18; 88, -48],
            string="as",
            style(color=0)),
          Text(extent=[-70, 90; 70, 50], string="%name"),
          Text(extent=[-78, -54; 80, -94], string="theta=%theta")),
        Documentation(info="<html>
The bondgraphic asymmetric linear heat exchange element is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The thermal resistance is modeled as a parameter. <p>

The heat exchange is driven by the temperature difference between the two sides.  The generated entropy is reintroduced at the right. <p>

The heat exchange element has two causality strokes at the element. <p>

<hr>

<pre>
Potential variables:

 e1:      Bondgraphic effort variable of inflow

 f1:      Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:      Bondgraphic effort variable of outflow

 f2:      Bondgraphic flow variable of outflow, normalized positive for flows out of the model


Parameters:

 theta:   Thermal resistance (default value = 1 <sup>o</sup>K/W)
</pre>
</html>
"));
      Junctions.J0p2 J0p2_1 annotation (extent=[-50, -10; -30, 10]);
      Junctions.J1p3 J1p3_1 annotation (extent=[-10, 10; 10, -10]);
      Bonds.fBond B1 annotation (extent=[-30, -10; -10, 10]);
      Bonds.eBond B2 annotation (extent=[10, -10; 30, 10]);
      Junctions.J0p3 J0p3_2 annotation (extent=[30, 10; 50, -10]);
      Bonds.eBond B4 annotation (extent=[30, 10; 50, 30], rotation=-90);
      RSth RS(theta=theta) annotation (extent=[10, 30; 30, 50]);
      Bonds.fBond B3 annotation (extent=[-10, 10; 10, 30], rotation=90);
    equation 
      connect(B1.fBondCon1, J1p3_1.BondCon1) annotation (points=[-10, 0; -10, 0],
               style(color=8));
      connect(J0p2_1.BondCon2, B1.eBondCon1) annotation (points=[-30, 0; -30, 0],
               style(color=8));
      connect(BondCon1, J0p2_1.BondCon1) annotation (points=[-100,0; -50,0],
          style(color=8));
      connect(J1p3_1.BondCon2, B2.fBondCon1) annotation (points=[10, 0; 10, 0],
            style(color=8));
      connect(B2.eBondCon1, J0p3_2.BondCon1) annotation (points=[30, 0; 30, 0],
            style(color=8));
      connect(J0p3_2.BondCon2, BondCon2) annotation (points=[50,0; 100,0],
          style(color=8));
      connect(B4.eBondCon1, J0p3_2.BondCon3) annotation (points=[40, 10; 40, 10],
               style(color=8));
      connect(RS.BondCon2, B4.fBondCon1) annotation (points=[30, 40; 40, 40; 40,
              30], style(color=8));
      connect(J1p3_1.BondCon3, B3.eBondCon1) annotation (points=[0,10; 
            -6.12303e-016,10],
            style(color=8));
      connect(B3.fBondCon1, RS.BondCon1) annotation (points=[6.12303e-016,30; 
            6.12303e-016,40; 10,40],
                 style(color=8));
    end HEr;
    
    model RA "Radiative heat exchange element" 
      extends Interfaces.TwoPort;
      parameter Real A=1 "Radiating Surface";
      parameter Real sigma=1 "Specific radiation constant";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Icon(Text(
            extent=[-66, 80; 64, -80],
            string="RA",
            style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
        Diagram(Line(points=[-10, 0; -10, 0], style(color=8)), Line(points=[10,
                  0; 10, 0], style(color=8))),
        Window(
          x=0.45,
          y=0.01,
          width=0.44,
          height=0.65),
        Documentation(info="<html>
The bondgraphic radiative heat exchange element is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The specific radiation constant and the radiating surface are modeled as parameters. <p>

The radiative heat exchange element has two causality strokes at the element. <p>

<hr>

<pre>
Potential variables:

 e1:      Bondgraphic effort variable of inflow

 f1:      Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:      Bondgraphic effort variable of outflow

 f2:      Bondgraphic flow variable of outflow, normalized positive for flows out of the model


Parameters:

 sigma:   Specific radiation constant (default value = 1 W/(m<sup>2</sup>*<sup>o</sup>K<sup>4</sup>)

 A:       Radiating surface (default value = 1 m<sup>2</sup>)
</pre>
</html>
"));
      Bonds.fBond B1 annotation (extent=[-30, 10; -10, 30]);
      Bonds.eBond B2 annotation (extent=[10, 10; 30, 30]);
      Junctions.J0p3 J0p3_2 annotation (extent=[50, 10; 30, -10], rotation=-90);
      Bonds.eBond B4 annotation (extent=[-30, -30; -10, -10], rotation=-180);
      Bonds.fBond B3 annotation (extent=[10, -30; 30, -10], rotation=180);
      Thermal.GSrad GSrad1(sigma=sigma, A=A) annotation (extent=[-10, 10; 10,
            30]);
      Junctions.J0p3 J0p3_1 annotation (extent=[-50, 10; -30, -10], rotation=-
            90);
      Thermal.GSrad GSrad2(sigma=sigma, A=A) annotation (extent=[10, -30; -10,
            -10]);
    equation 
      connect(GSrad1.BondCon2, B2.fBondCon1) annotation (points=[10, 20; 10, 20],
               style(color=8));
      connect(B1.fBondCon1, GSrad1.BondCon1) annotation (points=[-10, 20; -10,
            20], style(color=8));
      connect(B3.fBondCon1, GSrad2.BondCon1) annotation (points=[10, -20; 10, -
            20], style(color=8));
      connect(GSrad2.BondCon2, B4.fBondCon1) annotation (points=[-10, -20; -10,
              -20], style(color=8));
      connect(J0p3_1.BondCon2, B1.eBondCon1) annotation (points=[-40, 10; -40,
            20; -30, 20], style(color=8));
      connect(B2.eBondCon1, J0p3_2.BondCon2) annotation (points=[30, 20; 40, 20;
              40, 10], style(color=8));
      connect(J0p3_2.BondCon1, B3.eBondCon1) annotation (points=[40, -10; 40, -
            20; 30, -20], style(color=8));
      connect(B4.eBondCon1, J0p3_1.BondCon1) annotation (points=[-30, -20; -40,
              -20; -40, -10], style(color=8));
      connect(J0p3_1.BondCon3, BondCon1) annotation (points=[-50,6.12303e-016; 
            -72,6.12303e-016; -72,0; -100,0], style(color=8, rgbcolor={192,192,
              192}));
      connect(J0p3_2.BondCon3, BondCon2) annotation (points=[50,6.12303e-016; 
            72,6.12303e-016; 72,0; 100,0], style(color=8, rgbcolor={192,192,192}));
    end RA;
    
    model DS "Bondgraphic non-linear resistive (diode) source element" 
      extends Interfaces.TwoPort;
      parameter Real Ron=1E-5 "Leakage Resistance";
      parameter Real Goff=1E-5 "Leakage Conductance";
      parameter Real e0=0 "Forward threshold effort";
      Real s "Curve parameter";
      Boolean blocking;
      annotation (
        Icon(
          Text(extent=[-70,90; 70,50],   string="%name"),
          Text(
            extent=[-72,78; 76,-82],
            style(color=0),
            string="DS")),
        Diagram(
          Line(points=[-80,0; 80,0],   style(color=10)),
          Polygon(points=[70,4; 80,0; 70,-4; 70,4],     style(color=10,
                fillColor=10)),
          Line(points=[0,80; 0,-80],   style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[-4,70; 0,80; 4,70; -4,70],     style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[6,80; 16,70],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Text(
            extent=[70,-4; 80,-14],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e"),
          Line(points=[-80,-40; -20,-10; 20,10; 40,70],     style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Line(points=[20,9; 20,0],   style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[12,-2; 32,-12],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="e0"),
          Text(
            extent=[20,70; 40,60],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
      string="Ron"),
          Text(
            extent=[-20,10; 0,0],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
      string="Goff"),
          Ellipse(extent=[18,12; 22,8], style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[32,38; 66,28],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="conducting"),
          Text(
            extent=[-52,-28; -22,-36],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="blocking"),
          Text(
            extent=[20,14; 40,4],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s=0")),
        Documentation(info="<html>
The resistive (diode) source element is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The non-linear resistance is modeled by a set of parameters. <p>

Diodes are switching elements that are primarily being used in electrical circuits, although nothing prevents them from being used also in other energy domains.  Leaking diodes are a special class of non-linear resistors. <p>

The resistive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>
<hr>

<pre>
Potential variables:

 e1:        Bondgraphic effort variable of inflow

 f1:        Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:        Bondgraphic effort variable of outflow

 f2:        Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 blocking:  Boolean variable denoting the switch position (internal modulation signal)

 s:         Curve parameter


Parameters:

 Ron:       Leakage resistance in <b>conducting</b> state (default value = 1e-5 Ohm)

 Goff:      Leakage conductance in <b>blocking</b> state (default value = 1e-5 Mho)

 e0:        Forward threshold effort (default value = 0 Volt)
</pre> <p>

<hr> <p>

Equations: <p>

<b>blocking = s &lt; 0</b> <br>
<b>f1 = s*(if blocking then Goff else 1) + Goff*e0</b> <br>
<b>e1 = s*(if blocking then 1 else Ron) + e0</b> <br>
<b>f2 = (e1/e2)*f1</b> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Otter, M., H. Elmqvist, and S.E. Mattsson (1999), \"<a href=\"http://www.modelica.org/publications/papers/hybrid99.pdf\">Hybrid
     Modeling in Modelica Based on the Synchronous Data Flow Principle</a>,\" <i>Proc. CACSD'99, IEEE Symposium on
     Computer-Aided Control System Design</i>, Hawaii, August 22-27, 1999, pp. 151-157.
</ol>
</html>
"));
    equation 
      blocking = s < 0;
      f1 = s*(if blocking then Goff else 1) + Goff*e0;
      e1 = s*(if blocking then 1 else Ron) + e0;
      e1*f1 = e2*f2;
    end DS;
    
    model DSreal "Electrical real diode of the Modelica bond graph library" 
      extends Interfaces.TwoPort;
      constant Real k=Modelica.Constants.k "Boltzmann's constant";
      constant Modelica.SIunits.ElectricCharge q=1.6021892e-19 
        "Electron charge";
      parameter Modelica.SIunits.Current Ids=1.e-6 "Saturation current";
      parameter Real EG=1.11 "activation energy";
      parameter Real N=1 "Emission coefficient";
      parameter Modelica.SIunits.Temperature TNOM=300.15 "Nominal temperature";
      parameter Real XTI=3 "Temperature exponent of saturation current";
      parameter Real Maxexp(final min=Modelica.Constants.small) = 15 
        "Max. exponent for linear continuation";
      parameter Modelica.SIunits.Resistance R=1.e8 "Parallel Ohmic resistance";
      Modelica.SIunits.Voltage Vt "Thermal voltage";
    protected 
      Real dchar "Diode characteristic";
      Real tdep "Temperature dependence";
      
      function exlin "Exponential function linearly continued for x > Maxexp" 
        input Real x;
        input Real Maxexp;
        output Real z;
      algorithm 
        z := if x > Maxexp then exp(Maxexp)*(1 + x - Maxexp) else exp(x);
      end exlin;
      
      function pow "Just a helper function for x^y" 
        input Real x;
        input Real y;
        output Real z;
      algorithm 
        z:=x^y;
      end pow;
      annotation (
        Icon(
          Text(
            extent=[-78,68; 44,-72],
            style(color=0),
            string="DS"),
          Text(
            extent=[34,-10; 96,-44],
            style(color=0, pattern=0),
            string="real"),
          Text(extent=[-70,96; 70,56],   string="%name")),
        Diagram(
          Line(points=[-80,0; 80,0],   style(color=10)),
          Polygon(points=[70,4; 80,0; 70,-4; 70,4],     style(color=10,
                fillColor=10)),
          Line(points=[0,80; 0,-80],   style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[-4,70; 0,80; 4,70; -4,70],     style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[4,82; 14,72],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Text(
            extent=[70,-4; 80,-14],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e"),
          Line(points=[-80,-4; -28,-4; -6,-2; 0,0],         style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[-66,-6; -36,-14],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="blocking"),
          Text(
            extent=[16,50; 48,42],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="conducting"),
          Line(points=[0,0; 6,10; 12,28; 16,66],            style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1))),
        Documentation(info="<html>
The real diode source element is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  Real diodes are a special class of non-linear resistors. <p>

The real diode model consists of the diode itself and an parallel Ohmic resistance <b>R</b>. The diode formula essentially is: <p>

<b>f = Ids*(exp(e/Vt) - 1)</b> <p>

However, if the exponent <b>e/Vt</b> reaches the limit <b>Maxexp</b>, the diode characterisic is linearly continued to avoid overflow. <p>

The diode source element is a bit more complex than the diode element, because it not only computes the heat flow, but also the temperature dependence of the diode characteristic. <p>

The resistive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:      Bondgraphic effort variable of inflow

 f1:      Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:      Bondgraphic effort variable of outflow

 f2:      Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 Vt:      Thermal voltage


Parameters:

 Ids:     Saturation current (default value = 1e-6 Amp)

 Maxexp:  Maximum exponent (default value = 15)

 R:       Parallel Ohmic leakage resistance (default value = 1e8 Ohm)

 EG:      Activation energy (default value = 1.11 J)

 N:       Emission coefficient (default value = 1)

 TNOM:    Nominal temperature (default value = 300.15 K)

 XTI:     Temperature exponent of saturation current (default value = 3)
</pre> <p>

<hr> <p>

Equations: <p>

<b>Vt = k*e2/q</b> <br>
<b>dchar = exlin((v/(N*Vt)), Maxexp) - 1</b> <br>
<b>tdep = exp((e2/TNOM - 1)*EG/(N*Vt))*pow(e2/TNOM, XTI/N)</b> <br>
<b>f1 = Ids*tdep*dchar + e1/R</b> <br>
<b>f2 = (e1/e2)*f1</b>
</html>
"));
    equation 
      /* Compute thermal voltage as function of temperature */
      Vt = k*e2/q;
      
      /* Compute diode characteristic */
      dchar = exlin((e1/(N*Vt)), Maxexp) - 1;
      
      /* Compute temperature dependence */
      tdep = exp((e2/TNOM - 1)*EG/(N*Vt))*pow(e2/TNOM, XTI/N);
      
      /* Compute diode current */
      f1 = Ids*tdep*dchar + e1/R;
      
      /* Compute heat flow */
      f1*e1 = f2*e2;
    end DSreal;
    
    model ZS "Bondgraphic non-linear resistive (Zener diode) source element" 
      extends Interfaces.TwoPort;
      constant Integer conducting=1;
      constant Integer blocking=2;
      constant Integer avalanche=3;
      parameter Real Ron=1E-5 "Leakage Resistance";
      parameter Real Raval=1E-5 "Leakage Resistance";
      parameter Real Goff=1E-5 "Leakage Conductance";
      parameter Real e0=1 "Avalanche breakdown Voltage";
      Real s1 "Curve parameter";
      Real s2 "Curve parameter";
      Integer mode "Operating mode";
      annotation (
        Icon(
          Text(extent=[-70,90; 70,50],   string="%name"),
          Text(
            extent=[-72,74; 72,-76],
            style(color=0),
            string="ZS"),
          Text(extent=[-62,-56; 56,-90], string="e0=%e0")),
        Diagram(
          Line(points=[-86,0; 74,0],   style(color=10)),
          Line(points=[-6,80; -6,-80], style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[-10,70; -6,80; -2,70; -10,70], style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[0,80; 10,70],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Line(points=[-20,-74; -6,0; 36,12; 48,70],        style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Ellipse(extent=[-8,2; -4,-2], style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[-50,-44; -18,-54],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="conducting"),
          Text(
            extent=[-2,18; 28,10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="blocking"),
          Text(
            extent=[-6,0; 14,-10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s1=0"),
          Text(
            extent=[44,46; 74,36],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="avalanche"),
          Text(
            extent=[40,16; 60,6],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s2=0"),
          Ellipse(extent=[34,14; 38,10],style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[28,-2; 48,-12],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="e0"),
          Polygon(points=[74,4; 84,0; 74,-4; 74,4],     style(color=10,
                fillColor=10)),
          Text(
            extent=[74,-4; 84,-14],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e"),
          Line(points=[36,9; 36,0],   style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[18,8; 38,-2],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
      string="Goff"),
          Text(
            extent=[-12,-30; 8,-40],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
      string="Ron"),
          Text(
            extent=[24,64; 44,54],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="Raval")),
        Documentation(info="<html>
The non-linear resistive (Zener diode) source element is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The non-linear resistance is modeled by a set of parameters. <p>

Diodes are switching elements that are primarily being used in electrical circuits, although nothing prevents them from being used also in other energy domains.  Zener diodes are always used as reversed diodes.  Thus, the positive and negative pins have been reversed in the model.  Leaking diodes are a special class of non-linear resistors. <p>

The resistive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:     Bondgraphic effort variable of inflow

 f1:     Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:     Bondgraphic effort variable of outflow

 f2:     Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 mode:   Ternary variable denoting the switch position (internal modulation signal)

 s1:     Curve parameter

 s2:     Curve parameter


Parameters:

 Ron:    Leakage resistance in <b>conducting</b> state (default value = 1e-5 Ohm)

 Raval:  Leakage resistance in <b>avalanche</b> state (default value = 1e-5 Ohm)

 Goff:   Leakage conductance in <b>blocking</b> state (default value = 1e-5 Mho)

 e0:     Avalanche breakdown voltage (default value = 1 Volt)
</pre> <p>

<hr> <p>

Equations: <p>

<b>s2 = s1 - e0</b> <br>
<b>mode = if s1 &lt; 0 then conducting else if s1 &lt; e0 then blocking else avalanche</b> <br>
<b>e1 = if mode == conducting then Ron*s1 else if mode == blocking then s1 else (s2*Ron + e0)</b> <br>
<b>f1 = if mode == conducting then s1 else if mode == blocking then Goff*s1 else (s2 + Goff*e0)</b> <br>
<b>f2 = (e1/e2)*f1</b> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Otter, M., H. Elmqvist, and S.E. Mattsson (1999), \"<a href=\"http://www.modelica.org/publications/papers/hybrid99.pdf\">Hybrid
     Modeling in Modelica Based on the Synchronous Data Flow Principle</a>,\" <i>Proc. CACSD'99, IEEE Symposium on
     Computer-Aided Control System Design</i>, Hawaii, August 22-27, 1999, pp. 151-157.
</ol>
</html>
"));
    equation 
      s2 = s1 - e0;
      mode = if s1 < 0 then conducting else if s1 < e0 then blocking else avalanche;
      e1 = if mode == conducting then Ron*s1 else if mode == blocking then s1 else (s2*Ron + e0);
      f1 = if mode == conducting then s1 else if mode == blocking then Goff*s1 else (s2 + Goff*e0);
      e1*f1 = e2*f2;
    end ZS;
    
    model TS "Bondgraphic non-linear resistive (tunnel diode) source element" 
      extends Interfaces.TwoPort;
      constant Integer blocking=1;
      constant Integer c1=2;
      constant Integer b1=3;
      constant Integer c2=4;
      constant Integer b2=5;
      constant Integer conducting=6;
      parameter Real G0=1E-5 "Leakage Conductance";
      parameter Real R1=1E-5 "Leakage Resistance";
      parameter Real R2=1E-5 "Leakage Resistance";
      parameter Real R3=1E-5 "Leakage Resistance";
      parameter Real em1=1 "Intermediate forward voltage";
      parameter Real em2=2 "Intermediate forward voltage";
      parameter Real em3=3 "Intermediate forward voltage";
      parameter Real e0=4 "Maximum forward voltage";
      parameter Real fm=1 "Intermediate bottom current";
      parameter Real f0=2 "Intermediate top current";
      Real s1 "Curve parameter";
      Real s2 "Curve parameter";
      Real s3 "Curve parameter";
      Real s4 "Curve parameter";
      Real s5 "Curve parameter";
      Integer mode "Operating mode";
      annotation (
        Icon(
          Text(
            extent=[-68,74; 76,-76],
            style(color=0),
            string="TS"),
          Text(extent=[-66,90; 74,50],   string="%name")),
        Diagram(
          Line(points=[-86,0; 74,0],   style(color=10)),
          Line(points=[-6,80; -6,-80], style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Polygon(points=[-10,70; -6,80; -2,70; -10,70], style(
              color=10,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[0,80; 10,70],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="f"),
          Ellipse(extent=[-8,2; -4,-2], style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[40,70; 72,60],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="conducting"),
          Text(
            extent=[-58,-10; -28,-18],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="blocking"),
          Text(
            extent=[-12,-2; 0,-8],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s1=0"),
          Text(
            extent=[-10,50; 4,42],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="c1"),
          Ellipse(extent=[4,58; 0,62],  style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[24,0; 44,-10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="e0"),
          Polygon(points=[74,4; 84,0; 74,-4; 74,4],     style(color=10,
                fillColor=10)),
          Text(
            extent=[74,-4; 84,-14],
            style(
              color=10,
              fillColor=10,
              fillPattern=1),
            string="e"),
          Line(points=[-78,-12; -6,0; 2,60; 14,60],         style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Line(points=[42,92; 34,30; 22,30; 14,60],         style(
              color=0,
              thickness=2,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[16,54; 30,46],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="c2"),
          Text(
            extent=[22,30; 36,22],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="b2"),
          Text(
            extent=[2,68; 16,60],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="b1"),
          Text(
            extent=[-2,-6; 8,-16],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="em1"),
          Text(
            extent=[-24,36; -4,26],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="fm"),
          Text(
            extent=[-22,64; -2,54],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="f0"),
          Line(points=[34,28; 34,0],  style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Line(points=[14,58; 14,0],  style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Line(points=[20,30; -6,30], style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[-10,68; 2,62],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s2=0"),
          Text(
            extent=[16,66; 28,60],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s3=0"),
          Text(
            extent=[8,30; 20,24],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s4=0"),
          Text(
            extent=[36,32; 48,26],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="s5=0"),
          Ellipse(extent=[12,62; 16,58],style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Ellipse(extent=[20,32; 24,28],style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Ellipse(extent=[32,32; 36,28],style(
              color=0,
              rgbcolor={0,0,0},
              pattern=3,
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Line(points=[0,60; -6,60],  style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[8,0; 18,-10],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="em2"),
          Text(
            extent=[16,-6; 26,-16],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="em3"),
          Line(points=[2,58; 2,-8],   style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Line(points=[22,28; 22,-8], style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1)),
          Text(
            extent=[-66,2; -48,-8],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="G0"),
          Text(
            extent=[-18,16; 0,6],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="R1"),
          Text(
            extent=[4,42; 22,32],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="R2"),
          Text(
            extent=[34,52; 52,42],
            style(
              color=10,
              pattern=3,
              fillColor=10,
              fillPattern=1),
            string="R3")),
        Documentation(info="<html>
The non-linear resistive (tunnel diode) source element is a directed TwoPort element.  It inherits the effort and flow variables from the directed TwoPort.  The non-linear resistance is modeled by a set of parameters. <p>

Diodes are switching elements that are primarily being used in electrical circuits, although nothing prevents them from being used also in other energy domains.  Leaking diodes are a special class of non-linear resistors. <p>

The resistive source element has free causality on the primary side, and fixed causality on the secondary side.  The causality stroke is at the element on the secondary side (a source of entropy, rather than a source of temperature). <p>

<hr>

<pre>
Potential variables:

 e1:    Bondgraphic effort variable of inflow

 f1:    Bondgraphic flow variable of inflow, normalized positive for flows into the model

 e2:    Bondgraphic effort variable of outflow

 f2:    Bondgraphic flow variable of outflow, normalized positive for flows out of the model

 mode:  Sextary variable denoting the switch position (internal modulation signal)

 s1:    Curve parameter

 s2:    Curve parameter

 s3:    Curve parameter

 s4:    Curve parameter

 s5:    Curve parameter


Parameters:

 G0:    Leakage conductance in blocking state (default value = 1e-5 Mho)

 R1:    Leakage resistance in conducting state (default value = 1e-5 Ohm)

 R2:    Leakage resistance in conducting state (default value = 1e-5 Ohm)

 R3:    Leakage resistance in conducting state (default value = 1e-5 Ohm)

 em1:   First ntermediate forward voltage (default value = 1 Volt)

 em2:   Second intermediate forward voltage (default value = 2 Volt)

 em3:   Third intermediate forward voltage (default value = 3 Volt)

 e0:    Maximum forward voltage (default value = 4 Volt)

 fm:    Intermediate bottom current (default value = 1 Amp)

 f0:    Intermediate top current (default value = 2 Amp)
</pre> <p>

<hr> <p>

Equations: <p>

<b>s2 = s1 - f0</b> <br>
<b>s3 = s2 - (em2-em1)</b> <br>
<b>s4 = s3 - (f0-fm)</b> <br>
<b>s5 = s4 - (e0-em3)</b> <br>
<b>mode = if s1 &lt; 0 then blockinging else
          if s2 &lt; 0 then c1 else 
          if s3 &lt; 0 then b1 else 
          if s4 &lt; 0 then c2 else 
          if s5 &lt; 0 then b2 else conducting</b> <br>
<b>e1 = if mode == blocking then s1 else 
        if mode == c1 then R1*s1 else 
        if mode == b1 then (em1 + s2) else 
        if mode == c2 then (em2 + R2*s3) else 
        if mode == b2 then (em3 + s4) else (e0 + R3*s5)</b> <br>
<b>f1 = if mode == blocking then G0*s1 else 
        if mode == c1 then s1 else 
        if mode == b1 then f0 else 
        if mode == c2 then (f0 - s3) else 
        if mode == b2 then fm else (fm + s5)</b> <br>
<b>f2 = (e1/e2)*f1</b> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Otter, M., H. Elmqvist, and S.E. Mattsson (1999), \"<a href=\"http://www.modelica.org/publications/papers/hybrid99.pdf\">Hybrid
     Modeling in Modelica Based on the Synchronous Data Flow Principle</a>,\" <i>Proc. CACSD'99, IEEE Symposium on
     Computer-Aided Control System Design</i>, Hawaii, August 22-27, 1999, pp. 151-157.
</ol>
</html>
"));
    equation 
      s2 = s1 - f0;
      s3 = s2 - (em2-em1);
      s4 = s3 - (f0-fm);
      s5 = s4 - (e0-em3);
      mode = if s1 < 0 then blocking else 
             if s2 < 0 then c1 else 
             if s3 < 0 then b1 else 
             if s4 < 0 then c2 else 
             if s5 < 0 then b2 else conducting;
      e1 = if mode == blocking then s1 else 
           if mode == c1 then R1*s1 else 
           if mode == b1 then (em1 + s2) else 
           if mode == c2 then (em2 + R2*s3) else 
           if mode == b2 then (em3 + s4) else (e0 + R3*s5);
      f1 = if mode == blocking then G0*s1 else 
           if mode == c1 then s1 else 
           if mode == b1 then f0 else 
           if mode == c2 then (f0 - s3) else 
           if mode == b2 then fm else (fm + s5);
    end TS;
  end Thermal;
  
  package Electrical "Electrical circuit diagrams built from bond graphs" 
    annotation (
      Coordsys(
        extent=[0, 0; 504, 364],
        grid=[2, 2],
        component=[20, 20]),
      Icon(
        Rectangle(extent=[-100, -100; 80, 50], style(
            color=42,
            fillColor=30,
            fillPattern=1)),
        Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50], style(
            color=42,
            fillColor=30,
            fillPattern=1)),
        Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70], style(
            color=42,
            fillColor=30,
            fillPattern=1)),
        Text(
          extent=[-85, 35; 65, -85],
          string="Library",
          style(color=42)),
        Text(
          extent=[-120, 122; 120, 73],
          string="%name",
          style(color=1))),
      Window(
        x=0,
        y=0.6,
        width=0.4,
        height=0.4,
        library=1,
        autolayout=1),
      Documentation(info="<html>
This package offers a partial reimplementation of the standard electrical Modelica library using bond graph technology.
</html>
"));
    package Analog 
      "Analog electircal circuits built from bond graph technology" 
      annotation (Icon(
          Text(
            extent=[-120, 120; 120, 71],
            string="%name",
            style(color=1)),
          Rectangle(extent=[-100, -98; 80, 52], style(fillColor=30, fillPattern
                =1)),
          Polygon(points=[-100, 52; -80, 72; 100, 72; 80, 52; -100, 52], style(
                fillColor=30, fillPattern=1)),
          Polygon(points=[100, 72; 100, -78; 80, -98; 80, 52; 100, 72], style(
                fillColor=30, fillPattern=1)),
          Text(
            extent=[-85, 37; 65, -83],
            string="Library",
            style(color=3))), Documentation(info="<html>
This package offers a partial reimplementation of the standard analog electrical Modelica library using bond graph technology.
</html>
"));
      package Interfaces "Interfaces of the analog electrical library" 
        annotation (Icon(
            Text(
              extent=[-118, 112; 122, 63],
              string="%name",
              style(color=1)),
            Rectangle(extent=[-100, -100; 80, 50], style(
                color=58,
                fillColor=30,
                fillPattern=1)),
            Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50],
                style(
                color=58,
                fillColor=30,
                fillPattern=1)),
            Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70],
                style(
                color=58,
                fillColor=30,
                fillPattern=1)),
            Text(
              extent=[-85, 35; 65, -85],
              string="Library",
              style(color=58))), Documentation(info="<html>
This package provides some interface models for the analog electrical library built in bond graph technology.
</html>
"));
        model El2BG "Electrical to bond graph conversion" 
          Modelica.Electrical.Analog.Interfaces.PositivePin p 
            annotation (extent=[-110, -10; -90, 10]);
          BondLib.Interfaces.BondCon BondCon1 annotation (extent=[90, -10; 110,
                  10]);
          annotation (
            Icon(
              Line(points=[-80, -80; -80, 80; 80, 80; -80, -80]),
              Line(points=[80, 80; 80, -80; -80, -80], style(color=9)),
              Line(points=[94, 0; 80, 0], style(color=9)),
              Line(points=[-90, 0; -80, 0], style(color=77)),
              Text(
                extent=[-64, 56; 0, 12],
                string="El",
                style(color=75)),
              Text(
                extent=[4, -14; 70, -64],
                string="BG",
                style(color=9))),
            Diagram(
              Line(points=[-80, -80; -80, 80; 80, 80; -80, -80]),
              Line(points=[80, 80; 80, -80; -80, -80], style(color=9)),
              Line(points=[94, 0; 80, 0], style(color=9)),
              Line(points=[-96,0; -80,0],   style(color=77)),
              Text(
                extent=[-64, 56; 0, 12],
                string="El",
                style(color=75)),
              Text(
                extent=[4, -14; 70, -64],
                string="BG",
                style(color=9))),
            Documentation(info="<html>
This model converts an electrical wire to a bondgraphic power signal.
</html>
"));
        equation 
          BondCon1.e = p.v;
          BondCon1.f = p.i;
        end El2BG;
        
        model BG2El "Bond graph to electrical conversion" 
          Modelica.Electrical.Analog.Interfaces.NegativePin n 
            annotation (extent=[90, -10; 110, 10]);
          BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -
                90, 10]);
          annotation (
            Diagram(
              Line(points=[-80, -80; -80, 80; 80, 80; -80, -80], style(color=9)),
              Line(points=[-94, 0; -80, 0], style(color=9)),
              Line(points=[80, 80; 80, -80; -80, -80]),
              Line(points=[96,0; 80,0]),
              Text(
                extent=[-64, 70; 2, 20],
                string="BG",
                style(color=9)),
              Text(
                extent=[0, -16; 64, -60],
                string="El",
                style(color=75))),
            Icon(
              Line(points=[-80, -80; -80, 80; 80, 80; -80, -80], style(color=9)),
              Line(points=[-94, 0; -80, 0], style(color=9)),
              Line(points=[80, 80; 80, -80; -80, -80]),
              Line(points=[90, 0; 80, 0]),
              Text(
                extent=[-64, 70; 2, 20],
                string="BG",
                style(color=9)),
              Text(
                extent=[0, -16; 64, -60],
                string="El",
                style(color=75))),
            Documentation(info="<html>
This model converts a bondgraphic power signal to an electrical wire.
</html>
"));
        equation 
          BondCon1.e = n.v;
          BondCon1.f = -n.i;
        end BG2El;
        
        model BG2Rot "Bond graph to mechanical conversion" 
          BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-110, -10; -
                90, 10]);
          annotation (
            Diagram(
              Line(points=[-80, -80; -80, 80; 80, 80; -80, -80], style(color=9)),
              Line(points=[-94, 0; -80, 0], style(color=9)),
              Line(points=[80, 80; 80, -80; -80, -80]),
              Line(points=[96,0; 80,0]),
              Text(
                extent=[-64, 70; 2, 20],
                string="BG",
                style(color=9)),
              Text(
                extent=[-8, -18; 70, -66],
                style(color=75),
                string="Rot")),
            Icon(
              Line(points=[-80, -80; -80, 80; 80, 80; -80, -80], style(color=9)),
              Line(points=[-94, 0; -80, 0], style(color=9)),
              Line(points=[80, 80; 80, -80; -80, -80]),
              Line(points=[90, 0; 80, 0]),
              Text(
                extent=[-64, 70; 2, 20],
                string="BG",
                style(color=9)),
              Text(
                extent=[-8, -18; 70, -66],
                style(color=75),
                string="Rot")),
            Documentation(info="<html>
This model converts a bondgraphic power signal to a rotational mechanical flange.  Notice that the definition of efforts and flows is different in mechanical bond graphs and the standard mechanical library of Modelica.  The bondgraphic effort variable is the torque, <b>tau</b>, whereas the bondgraphic flow variable is the angular velocity, <b>omega</b>.  Since the mechanical connector uses the angular position, <b>phi</b>, as the potential variable, the model contains an integrator, to integrate <b>omega</b> into <b>phi</b>.
</html>
"));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b 
            annotation (extent=[90, -10; 110, 10]);
        equation 
          BondCon1.e = -flange_b.tau;
          BondCon1.f = der(flange_b.phi);
        end BG2Rot;
        
        model BG2Heat "Bond graph to heat conversion" 
          BondLib.Interfaces.BondCon BondCon1 
            annotation (extent=[-110,-10; -90,10]);
          Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b 
            annotation (extent=[90,-10; 110,10]);
          annotation (
            Icon(
              Line(points=[-80,-80; -80,80; 80,80; -80,-80],     style(color=9)),
              Line(points=[-94,0; -80,0],   style(color=9)),
              Line(points=[80,80; 80,-80; -80,-80]),
              Line(points=[90,0; 80,0]),
              Text(
                extent=[-64,70; 2,20],
                string="BG",
                style(color=9)),
              Text(
                extent=[-8,-16; 68,-66],
                style(color=75),
                string="Heat")),
            Diagram(
              Line(points=[-80,-80; -80,80; 80,80; -80,-80],     style(color=9)),
              Line(points=[-94,0; -80,0],   style(color=9)),
              Line(points=[80,80; 80,-80; -80,-80]),
              Line(points=[90,0; 80,0]),
              Text(
                extent=[-64,70; 2,20],
                string="BG",
                style(color=9)),
              Text(
                extent=[-8,-16; 68,-66],
                style(color=75),
                string="Heat")),
            Documentation(info="<html>
This model converts a bondgraphic power signal to a heat signal.
</html>"));
        equation 
          BondCon1.e = port_b.T;
          BondCon1.e*BondCon1.f = -port_b.Q_flow;
        end BG2Heat;
        
        partial model OnePort 
          "OnePort partial model of analog electrical library" 
          Modelica.SIunits.Voltage v "Voltage drop between the two pins";
          Modelica.SIunits.Current i "Current flowing from pin p to pin n";
          Modelica.Electrical.Analog.Interfaces.PositivePin p 
            annotation (extent=[-110,-10; -90,10]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n 
            annotation (extent=[90, -10; 110, 10]);
          annotation (Icon, Diagram(
              Line(points=[-110,18; -85,18],   style(color=9, fillColor=9)),
              Polygon(points=[-95,21; -85,18; -95,15; -95,21],     style(
                  color=9,
                  fillColor=9,
                  fillPattern=1)),
              Line(points=[90,18; 115,18],   style(color=9, fillColor=9)),
              Text(
                extent=[-114,17; -94,37],
                string="i",
                style(color=9)),
              Polygon(points=[105,21; 115,18; 105,15; 105,21],     style(
                  color=9,
                  fillColor=9,
                  fillPattern=1)),
              Text(
                extent=[98,39; 118,19],
                string="i",
                style(color=9)),
              Line(points=[-127,0; -117,0],   style(color=9)),
              Line(points=[-122,-5; -122,5],   style(color=9)),
              Line(points=[117,0; 127,0],   style(color=9))));
        equation 
          v = p.v - n.v;
          i = p.i;
        end OnePort;
        
        partial model ModOnePort 
          "Modulated OnePort partial model of analog electrical library" 
          Modelica.SIunits.Voltage v "Voltage drop between the two pins";
          Modelica.SIunits.Current i "Current flowing from pin p to pin n";
          Modelica.Electrical.Analog.Interfaces.PositivePin p 
            annotation (extent=[-110,-10; -90,10]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n 
            annotation (extent=[90,-10; 110,10]);
          Modelica.Blocks.Interfaces.RealInput u 
            annotation (extent=[-10,80; 10,100], rotation=-90);
          annotation (Icon, Diagram(
              Line(points=[-112,18; -87,18],   style(color=9, fillColor=9)),
              Polygon(points=[-97,21; -87,18; -97,15; -97,21],     style(
                  color=9,
                  fillColor=9,
                  fillPattern=1)),
              Line(points=[88,18; 113,18],   style(color=9, fillColor=9)),
              Text(
                extent=[-116,17; -96,37],
                string="i",
                style(color=9)),
              Polygon(points=[103,21; 113,18; 103,15; 103,21],     style(
                  color=9,
                  fillColor=9,
                  fillPattern=1)),
              Text(
                extent=[96,39; 116,19],
                string="i",
                style(color=9)),
              Line(points=[-123,0; -113,0],   style(color=9)),
              Line(points=[-118,-5; -118,5],   style(color=9)),
              Line(points=[115,0; 125,0],   style(color=9))));
        equation 
          v = p.v - n.v;
          i = p.i;
        end ModOnePort;
        
        partial model TwoPort 
          "TwoPort partial model of analog electrical library" 
          Modelica.SIunits.Voltage v1 "Voltage drop over the left port";
          Modelica.SIunits.Voltage v2 "Voltage drop over the right port";
          Modelica.SIunits.Current i1 
            "Current flowing from pos. to neg. pin of the left port";
          Modelica.SIunits.Current i2 
            "Current flowing from pos. to neg. pin of the right port";
          Modelica.Electrical.Analog.Interfaces.PositivePin p1 
            annotation (extent=[-110, 40; -90, 60]);
          Modelica.Electrical.Analog.Interfaces.PositivePin p2 
            annotation (extent=[90, 40; 110, 60]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n1 
            annotation (extent=[-110, -60; -90, -40]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n2 
            annotation (extent=[90, -60; 110, -40]);
          annotation (Diagram(
              Polygon(points=[-120,53; -110,50; -120,47; -120,53],     style(
                  color=9,
                  fillColor=9,
                  fillPattern=1)),
              Line(points=[-136,50; -111,50],   style(color=9, fillColor=9)),
              Text(
                extent=[-136,53; -119,68],
                string="i1",
                style(color=9, fillColor=9)),
              Polygon(points=[-126,-46; -136,-49; -126,-52; -126,-46],     style(
                  color=9,
                  fillColor=9,
                  fillPattern=1)),
              Line(points=[-136,-49; -111,-49],   style(color=9, fillColor=9)),
              Text(
                extent=[-127,-46; -110,-31],
                string="i1",
                style(color=9, fillColor=9)),
              Line(points=[111,50; 136,50],   style(
                  color=9,
                  gradient=2,
                  fillColor=9)),
              Polygon(points=[120,53; 110,50; 120,47; 120,53],     style(
                  color=9,
                  gradient=2,
                  fillColor=9,
                  fillPattern=1)),
              Text(
                extent=[118,52; 135,67],
                string="i2",
                style(
                  color=9,
                  gradient=2,
                  fillColor=9)),
              Text(
                extent=[112,-44; 128,-29],
                string="i2",
                style(color=9, fillColor=9)),
              Polygon(points=[127,-47; 137,-50; 127,-53; 127,-47],     style(
                  color=9,
                  fillColor=9,
                  fillPattern=1)),
              Line(points=[111,-50; 136,-50],   style(color=9, fillColor=9))));
        equation 
          v1 = p1.v - n1.v;
          v2 = p2.v - n2.v;
          i1 = p1.i;
          i2 = p2.i;
        end TwoPort;
      end Interfaces;
      
      package Basic "Basic elements of the analog electrical library" 
        model Ground "Electrical ground" 
          Modelica.Electrical.Analog.Interfaces.Pin p    annotation (extent=[-
                10, 90; 10, 110]);
          annotation (
            Icon(
              Line(points=[-60, 40; 60, 40]),
              Line(points=[-40, 20; 40, 20]),
              Line(points=[-20, 0; 20, 0]),
              Line(points=[0, 90; 0, 40]),
              Text(extent=[-100, -78; 100, -20], string="%name")),
            Diagram,
            Documentation(info="<html>
The electrical ground is modeled as an effort source injecting zero effort.
</html>
"));
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-20, 20; 20, 60], rotation=-90);
          BondLib.Sources.Se V0(e0=0) annotation (extent=[-20, -60; 20, -20],
              rotation=-90);
          BondLib.Bonds.fBond B1 annotation (extent=[-20, -20; 20, 20],
              rotation=90);
        equation 
          connect(El2BG1.BondCon1, B1.fBondCon1) annotation (points=[
                1.22461e-015,20; 1.22461e-015,20],
                                   style(color=8));
          connect(B1.eBondCon1, V0.BondCon1) annotation (points=[-1.22461e-015,
                -20; -1.22461e-015,-20],
                                style(color=8));
          connect(El2BG1.p, p) annotation (points=[-1.22461e-015,60; 0,60; 0,
                100], style(color=3, rgbcolor={0,0,255}));
        end Ground;
        
        model Resistor "Linear resistor of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Resistance R=1 "Resistance";
          annotation (
            Icon(
              Text(extent=[-100,42; 100,102],   string="%name"),
              Rectangle(extent=[-70, 30; 70, -30], style(
                  color=3,
                  fillColor=7,
                  fillPattern=1)),
              Line(points=[-90, 0; -70, 0]),
              Line(points=[70, 0; 90, 0]),
              Text(
                extent=[-96, -34; 104, -96],
                string="R=%R",
                style(color=0))),
            Diagram,
            Documentation(info="<html>
The ideal linear resistor is built in bondgraphic technology from a bond graph <b>R</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the resistor in its environment. <p>

<hr>

<pre>
Parameters:

 R:  Resistance (default value = 1 Ohm)
</pre>
</html>
"));
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, 12; 12, -12]);
          BondLib.Bonds.Bond B1 annotation (extent=[-38, -12; -12, 12]);
          BondLib.Bonds.Bond B2 annotation (extent=[12, -12; 38, 12]);
          BondLib.Bonds.Bond B3 annotation (extent=[-12, 12; 12, 36], rotation=
                90);
          BondLib.Passive.R R1(R=R) annotation (extent=[-10, 36; 10, 56],
              rotation=90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -14; -38, 14]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -14; 64, 14]);
        equation 
          connect(B1.BondCon2, J1p3_1.BondCon1) annotation (points=[-12,0; -12,
                0],                    style(color=8));
          connect(J1p3_1.BondCon2, B2.BondCon1) annotation (points=[12, 0;
                12.26, 0], style(color=8));
          connect(B3.BondCon1, J1p3_1.BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(B3.BondCon2, R1.BondCon1) annotation (points=[7.34764e-016,36; 
                -6.12303e-016,36],
              style(color=8));
          connect(El2BG1.BondCon1, B1.BondCon1) annotation (points=[-38,
                1.77636e-015; -38,1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2, BG2El1.BondCon1) annotation (points=[38,0; 38,
                1.77636e-015], style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end Resistor;
        
        model HeatingResistor "Electrical resistor with heat generation" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Resistance R_ref=1 
            "Resistance at temperature T_ref";
          parameter Modelica.SIunits.Temperature T_ref=300 
            "Reference temperature";
          parameter Real alpha(unit="1/K") = 0 
            "Temperature coefficient of resistance";
          Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort annotation (
              extent=[-10,-90; 10,-110],   rotation=-90);
          annotation (Icon(
              Text(extent=[-142,60; 143,118],  string="%name"),
              Line(points=[-90,0; -70,0]),
              Line(points=[70,0; 90,0]),
              Rectangle(extent=[-70,30; 70,-30],   style(
                  color=3,
                  fillColor=7,
                  fillPattern=1)),
              Line(points=[0,-30; 0,-91],   style(color=42)),
              Line(points=[-52,-50; 48,50],   style(color=73, fillColor=73)),
              Polygon(points=[40,52; 50,42; 54,56; 40,52],     style(color=73,
                    fillColor=73))), Diagram);
          Junctions.J1p3 J1p3_1         annotation (extent=[4,58; 28,82]);
          Bonds.Bond B1         annotation (extent=[-22,58; 4,82]);
          Bonds.Bond B2         annotation (extent=[28,58; 54,82]);
          Bonds.Bond B3         annotation (extent=[4,34; 28,58],     rotation=
                270);
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -46,56; -22,84]);
          Interfaces.BG2El BG2El1                           annotation (extent=[54,
                56; 80,84]);
          Interfaces.BG2Heat BG2Heat1 
            annotation (extent=[2,-80; 30,-54], rotation=-90);
          Bonds.eBond B4 annotation (extent=[2,-12; 30,10], rotation=-90);
          Thermal.mRS mRS1 annotation (extent=[4,10; 28,34], rotation=-90);
          Junctions.J0p3 J0p3_1 
            annotation (extent=[6,-32; 26,-12], rotation=-90);
          Bonds.eBond B5 annotation (extent=[2,-54; 30,-32], rotation=-90);
          Bonds.fBond B6 annotation (extent=[-14,-32; 6,-12], rotation=180);
          Modelica.Blocks.Math.Gain Gain1(k=R_ref) 
            annotation (extent=[-12,14; 0,30]);
          Modelica.Blocks.Math.Add Add1 annotation (extent=[-36,12; -20,32]);
          Modelica.Blocks.Math.Gain Gain2(k=alpha) 
            annotation (extent=[-58,-4; -46,12]);
          Modelica.Blocks.Sources.Constant Constant1 
            annotation (extent=[-60,28; -46,44]);
          Modelica.Blocks.Math.Add Add2(k2=-1) 
            annotation (extent=[-44,-38; -60,-18]);
          Modelica.Blocks.Sources.Constant Constant2(k=T_ref) 
            annotation (extent=[-16,-54; -30,-38]);
          BondLib.Sensors.De De1 annotation (extent=[-14,-32; -34,-12]);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[4,70; 4,70],
                                       style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[28,70; 
                28.26,70], style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-22,70; 
                -21.74,70],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[54,70; 54,
                70],           style(color=8));
          connect(B3.BondCon2, mRS1.BondCon1) annotation (points=[16,34; 16,34],
              style(color=8, rgbcolor={192,192,192}));
          connect(J0p3_1.BondCon1, B4.eBondCon1) annotation (points=[16,-12; 16,
                -12], style(color=8, rgbcolor={192,192,192}));
          connect(J0p3_1.BondCon2, B5.fBondCon1) annotation (points=[16,-32; 16,
                -32], style(color=8, rgbcolor={192,192,192}));
          connect(BG2Heat1.BondCon1, B5.eBondCon1) annotation (points=[16,-54;
                16,-54], style(color=8, rgbcolor={192,192,192}));
          connect(B6.eBondCon1, J0p3_1.BondCon3) annotation (points=[6,-22; 6,
                -22], style(color=8, rgbcolor={192,192,192}));
          if cardinality(heatPort) == 0 then
            heatPort.T = T_ref;
          end if;
          connect(J1p3_1.BondCon3, B3.BondCon1) annotation (points=[16,58; 16,
                57.88; 16,57.76; 16,57.76], style(color=8, rgbcolor={192,192,
                  192}));
          connect(B4.fBondCon1, mRS1.BondCon2) annotation (points=[16,10; 16,10],
              style(color=8, rgbcolor={192,192,192}));
          connect(BG2Heat1.port_b, heatPort) annotation (points=[16,-80; 16,-86;
                0,-86; 0,-100], style(color=42, rgbcolor={191,0,0}));
          connect(Gain1.y, mRS1.InPort1) annotation (points=[0.6,22; 5.2,22],
              style(color=74, rgbcolor={0,0,127}));
          connect(Add1.y, Gain1.u) annotation (points=[-19.2,22; -13.2,22],
              style(color=74, rgbcolor={0,0,127}));
          connect(Gain2.y, Add1.u2) annotation (points=[-45.4,4; -42,4; -42,16;
                -37.6,16], style(color=74, rgbcolor={0,0,127}));
          connect(Constant1.y, Add1.u1) annotation (points=[-45.3,36; -42,36;
                -42,28; -37.6,28], style(color=74, rgbcolor={0,0,127}));
          connect(Constant2.y, Add2.u2) annotation (points=[-30.7,-46; -36,-46; 
                -36,-34; -42.4,-34], style(color=74, rgbcolor={0,0,127}));
          connect(Add2.y, Gain2.u) annotation (points=[-60.8,-28; -70,-28; -70,
                4; -59.2,4], style(color=74, rgbcolor={0,0,127}));
          connect(De1.BondCon1, B6.fBondCon1) annotation (points=[-14,-22; -14,
                -22], style(color=8, rgbcolor={192,192,192}));
          connect(De1.OutPort1, Add2.u1) annotation (points=[-35,-22; -42.4,-22],
              style(color=74, rgbcolor={0,0,127}));
          connect(El2BG1.p, p) annotation (points=[-46,70; -88,70; -88,0; -100,
                0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[80,70; 88,70; 88,0; 100,0],
              style(color=3, rgbcolor={0,0,255}));
        end HeatingResistor;
        
        model Conductor "Linear conductor of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Conductance G=1 "Conductance";
          annotation (
            Icon(
              Text(extent=[-100, 40; 100, 98], string="%name"),
              Line(points=[-90, 0; -70, 0]),
              Rectangle(extent=[-70, 30; 70, -30]),
              Line(points=[70, 0; 90, 0]),
              Text(
                extent=[-100, -38; 100, -100],
                string="G=%G",
                style(color=0, pattern=0))),
            Diagram,
            Documentation(info="<html>
The ideal linear conductor is built in bondgraphic technology from a bond graph <b>R</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the resistor in its environment. <p>

<hr>

<pre>
Parameters:

 G:  Conductance (default value = 1 Mho)
</pre>

</html>
"));
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, 12; 12, -12]);
          BondLib.Bonds.Bond B1 annotation (extent=[-38, -12; -12, 12]);
          BondLib.Bonds.Bond B2 annotation (extent=[12, -12; 38, 12]);
          BondLib.Bonds.Bond B3 annotation (extent=[-12, 12; 12, 36], rotation=
                90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -14; -38, 14]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -14; 64, 14]);
          Passive.G G1(G=G) annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(B1.BondCon2, J1p3_1.BondCon1) annotation (points=[-12, 0; -12,
                  0], style(color=8));
          connect(J1p3_1.BondCon2, B2.BondCon1) annotation (points=[12, 0;
                12.26, 0], style(color=8));
          connect(B3.BondCon1, J1p3_1.BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(El2BG1.BondCon1, B1.BondCon1) annotation (points=[-38,
                1.77636e-015; -38,1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2, BG2El1.BondCon1) annotation (points=[38,0; 38,
                1.77636e-015],
                    style(color=8));
          connect(B3.BondCon2, G1.BondCon1) annotation (points=[7.34764e-016,36; 
                -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end Conductor;
        
        model Capacitor "Linear capacitor of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Capacitance C=1 "Capacitance";
          parameter Real u0=0 "Initial voltage across capacitor";
          annotation (
            Icon(
              Line(points=[14, 0; 90, 0]),
              Line(points=[14, 28; 14, -28], style(thickness=2)),
              Line(points=[-14, 28; -14, -28], style(thickness=2)),
              Line(points=[-90, 0; -14, 0]),
              Text(extent=[-100, 40; 100, 100], string="%name"),
              Text(
                extent=[-100, -40; 100, -100],
                string="C=%C",
                style(color=0))),
            Diagram,
            Documentation(info="<html>
The ideal linear capacitor is built in bondgraphic technology from a bond graph <b>C</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the capacitor in its environment. <p>

<hr>

<pre>
Parameters:

 C:  Capacitance (default value = 1 Farad)
</pre>
</html>
"));
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, 12; 12, -12]);
          BondLib.Bonds.Bond B1 annotation (extent=[-38, -12; -12, 12]);
          BondLib.Bonds.Bond B2 annotation (extent=[12, -12; 38, 12]);
          BondLib.Bonds.Bond B3 annotation (extent=[-12, 12; 12, 36], rotation=
                90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -14; -38, 14]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -14; 64, 14]);
          BondLib.Passive.C C1(C=C, e(start=u0)) annotation (extent=[-12, 36;
                12, 60], rotation=90);
        equation 
          connect(B1.BondCon2, J1p3_1.BondCon1) annotation (points=[-12, 0; -12,
                  0], style(color=8));
          connect(J1p3_1.BondCon2, B2.BondCon1) annotation (points=[12, 0;
                12.26, 0], style(color=8));
          connect(B3.BondCon1, J1p3_1.BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(El2BG1.BondCon1, B1.BondCon1) annotation (points=[-38,
                1.77636e-015; -38,1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2, BG2El1.BondCon1) annotation (points=[38,0; 38,
                1.77636e-015],
                    style(color=8));
          connect(B3.BondCon2, C1.BondCon1) annotation (points=[7.34764e-016,36; 
                -7.34764e-016,36],
              style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end Capacitor;
        
        model Inductor "Linear inductor of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Inductance L=1 "Inductance";
          parameter Real i0=0 "Initial current across inductor";
          annotation (
            Icon(
              Line(points=[-90, 0; -60, 0]),
              Ellipse(extent=[-60, -15; -30, 15]),
              Ellipse(extent=[-30, -15; 0, 15]),
              Ellipse(extent=[0, -15; 30, 15]),
              Ellipse(extent=[30, -15; 60, 15]),
              Line(points=[60, 0; 90, 0]),
              Text(extent=[-100, 40; 100, 100], string="%name"),
              Text(
                extent=[-100, -40; 100, -100],
                string="L=%L",
                style(color=0)),
              Rectangle(extent=[-60, -28; 60, 0], style(color=7, fillColor=7))),
            Diagram,
            Documentation(info="<html>
The ideal linear inductor is built in bondgraphic technology from a bond graph <b>I</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the inductor in its environment. <p>

<hr>

<pre>
Parameters:

 L:  Inductance (default value = 1 Henry)
</pre>
</html>
"));
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, 12; 12, -12]);
          BondLib.Bonds.Bond B1 annotation (extent=[-38, -12; -12, 12]);
          BondLib.Bonds.Bond B2 annotation (extent=[12, -12; 38, 12]);
          BondLib.Bonds.Bond B3 annotation (extent=[-12, 12; 12, 36], rotation=
                90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -14; -38, 14]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -14; 64, 14]);
          BondLib.Passive.I L1(I=L, f(start=i0)) annotation (extent=[-12, 36;
                12, 60], rotation=90);
        equation 
          connect(B1.BondCon2, J1p3_1.BondCon1) annotation (points=[-12, 0; -12,
                  0], style(color=8));
          connect(J1p3_1.BondCon2, B2.BondCon1) annotation (points=[12, 0;
                12.26, 0], style(color=8));
          connect(B3.BondCon1, J1p3_1.BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(El2BG1.BondCon1, B1.BondCon1) annotation (points=[-38,
                1.77636e-015; -38,1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2, BG2El1.BondCon1) annotation (points=[38,0; 38,
                1.77636e-015],
                    style(color=8));
          connect(L1.BondCon1, B3.BondCon2) annotation (points=[-7.34764e-016,
                36; 7.34764e-016,36],
              style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -78,
                1.77636e-015; -78,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end Inductor;
        annotation (Icon(
            Rectangle(extent=[-100, -100; 80, 50], style(fillColor=30,
                  fillPattern=1)),
            Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50],
                style(fillColor=30, fillPattern=1)),
            Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70],
                style(fillColor=30, fillPattern=1)),
            Text(
              extent=[-85, 35; 65, -85],
              string="Library",
              style(color=3)),
            Text(
              extent=[-120, 114; 120, 65],
              string="%name",
              style(color=1))), Documentation(info="<html>
This package offers a partial reimplementation of the basic package of the standard analog electrical Modelica library using bond graph technology.
</html>
"));
        model Transformer "Transformer of analog electrical library" 
          extends Interfaces.TwoPort;
          parameter Modelica.SIunits.Inductance L1=1 "Primary inductance";
          parameter Modelica.SIunits.Inductance L2=1 "Secondary inductance";
          parameter Modelica.SIunits.Inductance M=1 "Coupling inductance";
          annotation (
            Icon(
              Ellipse(extent=[-45, -50; -20, -25]),
              Ellipse(extent=[-45, -25; -20, 0]),
              Ellipse(extent=[-45, 0; -20, 25]),
              Ellipse(extent=[-45, 25; -20, 50]),
              Rectangle(extent=[-72, -60; -33, 60], style(color=7, fillColor=7)),
              Line(points=[-90, 50; -32, 50]),
              Line(points=[-90, -50; -32, -50]),
              Ellipse(extent=[20, -50; 45, -25]),
              Ellipse(extent=[20, -25; 45, 0]),
              Ellipse(extent=[20, 0; 45, 25]),
              Ellipse(extent=[20, 25; 45, 50]),
              Rectangle(extent=[33, -60; 72, 60], style(color=7, fillColor=7)),
              Line(points=[32, 50; 90, 50]),
              Line(points=[32, -50; 90, -50]),
              Text(extent=[-89, 18; -60, -10], string="L1"),
              Text(extent=[64, 18; 90, -10], string="L2"),
              Text(extent=[-18, -70; 20, -98], string="M"),
              Text(extent=[-100, 118; 100, 60], string="%name")),
            Diagram(
              Text(
                extent=[-38, 26; -28, 18],
                string="v1a",
                style(color=9)),
              Text(
                extent=[-38, -14; -28, -22],
                style(color=9),
                string="v1b"),
              Text(
                extent=[-26, 8; -16, 0],
                style(color=9),
                string="v1"),
              Text(
                extent=[-54, 26; -44, 18],
                style(color=9),
                string="i1"),
              Text(
                extent=[-24, -4; -16, -12],
                style(color=9),
                string="i1"),
              Text(
                extent=[-54, -16; -44, -24],
                style(color=9),
                string="i1"),
              Text(
                extent=[42, -14; 52, -22],
                style(color=9),
                string="v2b"),
              Text(
                extent=[42, 26; 52, 18],
                style(color=9),
                string="v2a"),
              Text(
                extent=[16, -2; 28, -10],
                style(color=9),
                string="v2"),
              Text(
                extent=[14, 12; 26, 4],
                style(color=9),
                string="i2"),
              Text(
                extent=[26, 24; 36, 16],
                style(color=9),
                string="i2"),
              Text(
                extent=[26, -16; 36, -24],
                style(color=9),
                string="i2")),
            Documentation(info="<html>
The real transformer is built in bondgraphic technology from a bond graph <b>IF</b> element.  A-causal bonds must be used here, because the causality depends on the embedding of the inductive field in its environment. <p>

<hr>

<pre>
Parameters:

 L1:  Primary inductance (default value = 1 Henry)

 L2:  Secondary inductance (default value = 1 Henry)

 M:   Coupling inductance (default value = 1 Henry)
</pre> <p>

<hr> <p>

Equations: <p>

<b>Det = L1*L2 - M^2</b> <br>
<b>Linv1 = L2/Det</b> <br>
<b>Linv2 = L1/Det</b> <br>
<b>Minv = -M/Det</b> <p>
<b>der(f1) = Linv1*e1 + Minv*e2</b> <br>
<b>der(f2) = Minv*e1 + Linv2*e2</b>
</html>
"));
          BondLib.Passive.IF TF1(
            I1=L1,
            I2=L2,
            I12=M) annotation (extent=[-10, -10; 10, 10]);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-70, 40; -50, 60]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [-50, -60; -70, -40]);
          BondLib.Bonds.Bond B1 annotation (extent=[-30, -10; -10, 10]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-50, -10; -30, 10],
                rotation=90);
          BondLib.Bonds.Bond B2 annotation (extent=[-50, 10; -30, 30], rotation=
               -90);
          BondLib.Bonds.Bond B3 annotation (extent=[-50, -30; -30, -10],
              rotation=-90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG2 annotation (extent=
                [70, 40; 50, 60]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El2 annotation (extent=
                [50, -60; 70, -40]);
          BondLib.Bonds.Bond B4 annotation (extent=[10, -10; 30, 10], rotation=
                180);
          BondLib.Junctions.J1p3 J1p3_2 annotation (extent=[50, -10; 30, 10],
              rotation=90);
          BondLib.Bonds.Bond B5 annotation (extent=[30, 10; 50, 30], rotation=-
                90);
          BondLib.Bonds.Bond B6 annotation (extent=[30, -30; 50, -10], rotation=
               -90);
        equation 
          connect(J1p3_1.BondCon3, B1.BondCon1) annotation (points=[-30,
                -6.12303e-016; -30,-6.12303e-016; -30,0; -29.8,0],
                      style(color=8));
          connect(B2.BondCon2, J1p3_1.BondCon2) annotation (points=[-40, 10; -
                40, 10], style(color=8));
          connect(J1p3_1.BondCon1, B3.BondCon1) annotation (points=[-40, -10; -
                40, -10.2], style(color=8));
          connect(El2BG1.BondCon1, B2.BondCon1) annotation (points=[-50,50; -40,
                50; -40,29.8],    style(color=8));
          connect(BG2El1.BondCon1, B3.BondCon2) annotation (points=[-50, -50; -
                40, -50; -40, -30], style(color=8));
          connect(B1.BondCon2, TF1.BondCon1) annotation (points=[-10, 0; -10, 0],
                   style(color=8));
          connect(B5.BondCon2, J1p3_2.BondCon2) annotation (points=[40, 10; 40,
                  10], style(color=8));
          connect(J1p3_2.BondCon1, B6.BondCon1) annotation (points=[40, -10; 40,
                  -10.2], style(color=8));
          connect(El2BG2.BondCon1, B5.BondCon1) annotation (points=[50,50; 40,
                50; 40,29.8],  style(color=8));
          connect(BG2El2.BondCon1, B6.BondCon2) annotation (points=[50, -50; 40,
                  -50; 40, -30], style(color=8));
          connect(B4.BondCon1, J1p3_2.BondCon3) annotation (points=[29.8,
                -1.20011e-015; 29.85,-1.20011e-015; 29.85,-1.81241e-015; 29.9,
                -1.81241e-015; 29.9,-6.12303e-016; 30,-6.12303e-016],
                      style(color=8));
          connect(B4.BondCon2, TF1.BondCon2) annotation (points=[10,
                1.22461e-015; 10,0],
                style(color=8));
          connect(El2BG1.p, p1) annotation (points=[-70,50; -100,50], style(
                color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n1) annotation (points=[-70,-50; -100,-50], style(
                color=3, rgbcolor={0,0,255}));
          connect(El2BG2.p, p2) annotation (points=[70,50; 100,50], style(color=
                 3, rgbcolor={0,0,255}));
          connect(BG2El2.n, n2) annotation (points=[70,-50; 100,-50], style(
                color=3, rgbcolor={0,0,255}));
        end Transformer;
        
        model Gyrator "Real gyrator of analog electrical library" 
          extends Interfaces.TwoPort;
          parameter Modelica.SIunits.Conductance G1=1 
            "Gyration forward conductance";
          parameter Modelica.SIunits.Conductance G2=1 
            "Gyration backward conductance";
          annotation (
            Diagram(
              Ellipse(extent=[-62, 52; -58, 48], style(fillColor=77)),
              Ellipse(extent=[58, 52; 62, 48], style(fillColor=77)),
              Ellipse(extent=[-82, -48; -78, -52], style(fillColor=77)),
              Ellipse(extent=[78, -48; 82, -52], style(fillColor=77))),
            Documentation(info="<html>
The real gyrator is a macro element, built from two <b>VCC</b> elements.  The <b>VCC</b> elements are internally built in bondgraphic technology. <p>

<hr>

<pre>
Parameters:

 G1:  Gyration forward conductance (default value = 1 Amp/Volt)

 G2:  Gyration backward conductance (default value = 1 Amp/Volt)

</pre> <p>

<hr> <p>

Equations: <p>

<b>i1 = G*v2</b> <br>
<b>i2 = -G*v1</b>
</html>
"),         Icon(
              Rectangle(extent=[-60, 60; 60, -60]),
              Line(points=[-90, 50; -60, 50]),
              Line(points=[-90, -50; -60, -50]),
              Line(points=[60, 50; 90, 50]),
              Line(points=[60, -50; 90, -50]),
              Text(extent=[-100, 118; 100, 57], string="%name"),
              Line(points=[-40, 30; 40, 30]),
              Line(points=[-20, -20; 20, -20]),
              Polygon(points=[30, 34; 40, 30; 30, 26; 30, 34], style(fillColor=
                      3, fillPattern=1)),
              Polygon(points=[-26, -19; -16, -15; -16, -23; -26, -19], style(
                    fillColor=3, fillPattern=1)),
              Line(points=[-5, 10; -10, -10], style(thickness=2)),
              Line(points=[9, 10; 4, -9], style(thickness=2)),
              Line(points=[-14, 9; 16, 10], style(thickness=2)),
              Text(extent=[-29, 59; 30, 30], string="G1"),
              Text(extent=[-29, -29; 29, -58], string="G2")),
            Coordsys(extent=[-100, -100; 100, 100]));
          BondLib.Electrical.Analog.Basic.VCC VCC1(transConductance=G1) 
            annotation (extent=[-40, 8; 40, 88]);
          BondLib.Electrical.Analog.Basic.VCC VCC2(transConductance=G2) 
            annotation (extent=[44, -90; -36, -10]);
        equation 
          connect(VCC1.p1, p1) annotation (points=[-40,68; -60,68; -60,50; -100,
                50], style(color=3, rgbcolor={0,0,255}));
          connect(VCC1.n1, n1) annotation (points=[-40,28; -80,28; -80,-50;
                -100,-50], style(color=3, rgbcolor={0,0,255}));
          connect(VCC1.p2, p2) annotation (points=[40,68; 60,68; 60,50; 100,50],
              style(color=3, rgbcolor={0,0,255}));
          connect(VCC1.n2, n2) annotation (points=[40,28; 80,28; 80,-50; 100,
                -50], style(color=3, rgbcolor={0,0,255}));
          connect(VCC1.p1, VCC2.p2) annotation (points=[-40,68; -60,68; -60,-30;
                -36,-30], style(color=3, rgbcolor={0,0,255}));
          connect(VCC1.n1, VCC2.n2) annotation (points=[-40,28; -80,28; -80,-70;
                -36,-70], style(color=3, rgbcolor={0,0,255}));
          connect(VCC1.p2, VCC2.p1) annotation (points=[40,68; 60,68; 60,-30;
                44,-30], style(color=3, rgbcolor={0,0,255}));
          connect(VCC1.n2, VCC2.n1) annotation (points=[40,28; 80,28; 80,-70;
                44,-70], style(color=3, rgbcolor={0,0,255}));
        end Gyrator;
        
        model EMF "Bondgraphic electromotorical force element" 
          parameter Real k(final unit="N.m/A") = 1 "Transformation coefficient";
          Modelica.SIunits.Voltage v "Voltage drop between the two pins";
          Modelica.SIunits.Current i "Current flowing from pin p to pin n";
          Modelica.SIunits.AngularVelocity w "Angular velocity of flange_b";
          Modelica.Electrical.Analog.Interfaces.PositivePin p 
            annotation (extent=[-10, 90; 10, 110]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n 
            annotation (extent=[-10, -110; 10, -90]);
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b 
            annotation (extent=[90, -10; 110, 10]);
          annotation (
            Icon(
              Line(points=[0, 90; 0, 40]),
              Rectangle(extent=[40, 10; 90, -10], style(
                  gradient=2,
                  fillColor=8,
                  fillPattern=1)),
              Ellipse(extent=[-40, 40; 40, -40]),
              Line(points=[0, -90; 0, -40]),
              Text(extent=[20, -40; 100, -100], string="%name"),
              Text(
                extent=[30, 100; 119, 40],
                string="k=%k",
                style(color=9))),
            Documentation(info="<html>
EMF transforms electrical energy into rotational mechanical energy.  It is used as basic building block of an electrical motor. The mechanical connector flange_b can be connected to elements of the Modelica.Mechanics.Rotational library. flange_b.tau is the cut-torque, flange_b.phi is the angle at the rotational connection.
</html>
"),         Diagram(
              Text(
                extent=[-18, 24; -8, 16],
                string="v1a",
                style(color=9)),
              Text(
                extent=[-18, -14; -8, -22],
                style(color=9),
                string="v1b"),
              Text(
                extent=[-6, 8; 4, 0],
                style(color=9),
                string="v1"),
              Text(
                extent=[-34, 24; -24, 16],
                style(color=9),
                string="i1"),
              Text(
                extent=[-4, -4; 4, -12],
                style(color=9),
                string="i1"),
              Text(
                extent=[-34, -16; -24, -24],
                style(color=9),
                string="i1"),
              Text(
                extent=[30, -2; 48, -10],
                style(color=9),
                string="omega"),
              Text(
                extent=[32, 8; 44, 0],
                style(color=9),
                string="tau")));
          BondLib.Passive.GY GY1(r=k) annotation (extent=[10, -10; 30, 10]);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-10, 50; 10, 70], rotation=-90);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [10, -70; -10, -50], rotation=270);
          BondLib.Bonds.Bond B1 annotation (extent=[-10, -10; 10, 10]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-30, -10; -10, 10],
                rotation=90);
          BondLib.Bonds.Bond B2 annotation (extent=[-30, 10; -10, 30], rotation=
               -90);
          BondLib.Bonds.Bond B3 annotation (extent=[-30, -30; -10, -10],
              rotation=-90);
          BondLib.Bonds.Bond B4 annotation (extent=[30, -10; 50, 10]);
          BondLib.Electrical.Analog.Interfaces.BG2Rot BG2Rot1 annotation (
              extent=[50,-10; 70,10]);
        equation 
          v = p.v - n.v;
          i = p.i;
          w = GY1.f2;
          connect(J1p3_1.BondCon3, B1.BondCon1) annotation (points=[-10,
                -6.12303e-016; -9.8,0], style(color=8));
          connect(B2.BondCon2, J1p3_1.BondCon2) annotation (points=[-20, 10; -
                20, 10], style(color=8));
          connect(J1p3_1.BondCon1, B3.BondCon1) annotation (points=[-20, -10; -
                20, -10.2], style(color=8));
          connect(B1.BondCon2, GY1.BondCon1) annotation (points=[10, 0; 10, 0],
                style(color=8));
          connect(GY1.BondCon2, B4.BondCon1) annotation (points=[30, 0; 30.2, 0],
                   style(color=8));
          connect(El2BG1.BondCon1, B2.BondCon1) annotation (points=[
                6.12303e-016,50; 6.12303e-016,40; -20,40; -20,29.8],
                                       style(color=8));
          connect(BG2El1.BondCon1, B3.BondCon2) annotation (points=[
                -1.83691e-015,-50; -1.83691e-015,-40; -20,-40; -20,-30],
                                          style(color=8));
          connect(B4.BondCon2, BG2Rot1.BondCon1) annotation (points=[50,0; 50,0],
              style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-6.12303e-016,70; 0,70; 0,
                100], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[1.83691e-015,-70; 0,-70; 0,
                -100], style(color=3, rgbcolor={0,0,255}));
          connect(BG2Rot1.flange_b, flange_b) annotation (points=[70,0; 100,0],
              style(color=0, rgbcolor={0,0,0}));
        end EMF;
        
        model VCV "Linear voltage-controlled voltage source" 
          extends Interfaces.TwoPort;
          parameter Real gain=1 "Voltage gain";
          annotation (
            Icon(
              Rectangle(extent=[-70, 70; 70, -70], style(fillColor=7)),
              Text(extent=[-99, -59; 100, -109], string="%name"),
              Line(points=[-90, 50; -30, 50]),
              Line(points=[-30, -50; -90, -50]),
              Ellipse(extent=[10, 20; 50, -20]),
              Line(points=[-20, 60; 20, 60]),
              Polygon(points=[20, 60; 10, 63; 10, 57; 20, 60], style(fillColor=
                      3, fillPattern=1)),
              Line(points=[30, 50; 30, -50]),
              Line(points=[30, 50; 90, 50]),
              Line(points=[30, -50; 90, -50])),
            Diagram(
              Text(
                extent=[-68, 26; -58, 18],
                string="v1a",
                style(color=9)),
              Text(
                extent=[-82, 26; -72, 18],
                style(color=9),
                string="i1"),
              Text(
                extent=[-82, -16; -72, -24],
                style(color=9),
                string="i1"),
              Text(
                extent=[-56, -4; -44, -12],
                style(color=9),
                string="i1=0"),
              Text(
                extent=[-68, -14; -58, -22],
                style(color=9),
                string="v1b"),
              Text(
                extent=[-56, 8; -46, 0],
                style(color=9),
                string="v1"),
              Text(
                extent=[42, 8; 54, 0],
                style(color=9),
                string="v2"),
              Text(
                extent=[44, -4; 56, -12],
                style(color=9),
                string="i2"),
              Text(
                extent=[72, 24; 84, 16],
                style(color=9),
                string="i2"),
              Text(
                extent=[72, -16; 84, -24],
                style(color=9),
                string="i2"),
              Text(
                extent=[58, 22; 68, 14],
                style(color=9),
                string="v2a"),
              Text(
                extent=[58, -18; 68, -26],
                style(color=9),
                string="v2b")),
            Documentation(info="<html>
The linear voltage-controlled voltage source is built in bondgraphic technology using an effort detector and a modulated effort source.  A-causal bonds must partially be used here, because the causality of the output port depends on the embedding of the <b>VCV</b> element in its environment. <p>

<hr>

<pre>
Parameters:

 gain:  Voltage gain (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>v2 = gain*v1</b> <br>
<b>i1 = 0</b>
</html>
"));
          Modelica.Blocks.Math.Gain Gain1(k=gain)   annotation (extent=[-8, -10;
                  12, 10]);
          BondLib.Sensors.De De1 annotation (extent=[-40, -10; -20, 10]);
          BondLib.Bonds.fBond B3 annotation (extent=[-60, -10; -40, 10]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-80, -10; -60, 10],
                rotation=90);
          BondLib.Bonds.fBond B1 annotation (extent=[-80, 10; -60, 30],
              rotation=-90);
          BondLib.Bonds.eBond B2 annotation (extent=[-80, -30; -60, -10],
              rotation=-90);
          BondLib.Sources.mSe mSe1 annotation (extent=[40, -10; 20, 10]);
          BondLib.Bonds.fBond B4 annotation (extent=[40, -10; 60, 10]);
          BondLib.Junctions.J1p3 J1p3_2 annotation (extent=[80, -10; 60, 10],
              rotation=90);
          BondLib.Bonds.Bond B6 annotation (extent=[60, -30; 80, -10], rotation=
               90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-80, 40; -60, 60]);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG2 annotation (extent=
                [80, 40; 60, 60]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [60, -60; 80, -40]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El2 annotation (extent=
                [-60, -60; -80, -40]);
          BondLib.Bonds.Bond B5 annotation (extent=[60, 10; 80, 30], rotation=
                90);
        equation 
          connect(De1.OutPort1,Gain1.u)       annotation (points=[-19,0; -10,0],
                    style(color=3));
          connect(B3.fBondCon1, De1.BondCon1) annotation (points=[-40, 0; -40,
                0], style(color=8));
          connect(J1p3_1.BondCon3, B3.eBondCon1) annotation (points=[-60,
                -6.12303e-016; -60,0],
                        style(color=8));
          connect(B1.fBondCon1, J1p3_1.BondCon2) annotation (points=[-70, 10; -
                70, 10], style(color=8));
          connect(J1p3_1.BondCon1, B2.fBondCon1) annotation (points=[-70, -10;
                -70, -10], style(color=8));
          connect(Gain1.y,       mSe1.InPort1) annotation (points=[13,0; 21,0],
                   style(color=3));
          connect(mSe1.BondCon1, B4.eBondCon1) annotation (points=[40, 0; 40, 0],
                   style(color=8));
          connect(B4.fBondCon1, J1p3_2.BondCon3) annotation (points=[60,0; 60,
                -6.12303e-016],
                      style(color=8));
          connect(El2BG1.BondCon1, B1.eBondCon1) annotation (points=[-60, 50; -
                50, 50; -50, 30; -70, 30], style(color=8));
          connect(BG2El2.BondCon1, B2.eBondCon1) annotation (points=[-60, -50;
                -50, -50; -50, -30; -70, -30], style(color=8));
          connect(B5.BondCon1, J1p3_2.BondCon2) annotation (points=[70, 10.2;
                70, 10], style(color=8));
          connect(B6.BondCon2, J1p3_2.BondCon1) annotation (points=[70, -10; 70,
                  -10], style(color=8));
          connect(El2BG2.BondCon1, B5.BondCon2) annotation (points=[60, 50; 50,
                  50; 50, 30; 70, 30], style(color=8));
          connect(BG2El1.BondCon1, B6.BondCon1) annotation (points=[60,-50; 50,
                -50; 50,-29.8; 70,-29.8], style(color=8));
          connect(El2BG1.p, p1) annotation (points=[-80,50; -100,50], style(
                color=3, rgbcolor={0,0,255}));
          connect(BG2El2.n, n1) annotation (points=[-80,-50; -100,-50], style(
                color=3, rgbcolor={0,0,255}));
          connect(El2BG2.p, p2) annotation (points=[80,50; 100,50], style(color=
                 3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n2) annotation (points=[80,-50; 100,-50], style(
                color=3, rgbcolor={0,0,255}));
        end VCV;
        
        model VCC "Linear voltage-controlled current source" 
          extends Interfaces.TwoPort;
          parameter Modelica.SIunits.Conductance transConductance=1 
            "Transconductance";
          annotation (
            Icon(
              Rectangle(extent=[-70, 70; 70, -70], style(fillColor=7)),
              Text(extent=[-99, -60; 100, -109], string="%name"),
              Line(points=[-90, 50; -30, 50]),
              Line(points=[-30, -50; -90, -50]),
              Ellipse(extent=[10, 20; 50, -20]),
              Line(points=[-20, 60; 20, 60]),
              Polygon(points=[20, 60; 10, 63; 10, 57; 20, 60], style(fillColor=
                      3, fillPattern=1)),
              Line(points=[90, 50; 30, 50; 30, 20]),
              Line(points=[91, -50; 30, -50; 30, -20]),
              Line(points=[10, 0; 50, 0])),
            Diagram(
              Text(
                extent=[-68, 26; -58, 18],
                string="v1a",
                style(color=9)),
              Text(
                extent=[-82, 26; -72, 18],
                style(color=9),
                string="i1"),
              Text(
                extent=[-82, -16; -72, -24],
                style(color=9),
                string="i1"),
              Text(
                extent=[-56, -4; -44, -12],
                style(color=9),
                string="i1=0"),
              Text(
                extent=[-68, -14; -58, -22],
                style(color=9),
                string="v1b"),
              Text(
                extent=[-56, 8; -46, 0],
                style(color=9),
                string="v1"),
              Text(
                extent=[42, 8; 54, 0],
                style(color=9),
                string="v2"),
              Text(
                extent=[44, -4; 56, -12],
                style(color=9),
                string="i2"),
              Text(
                extent=[72, 24; 84, 16],
                style(color=9),
                string="i2"),
              Text(
                extent=[72, -16; 84, -24],
                style(color=9),
                string="i2"),
              Text(
                extent=[58, 22; 68, 14],
                style(color=9),
                string="v2a"),
              Text(
                extent=[58, -18; 68, -26],
                style(color=9),
                string="v2b")),
            Documentation(info="<html>
The linear voltage-controlled current source is built in bondgraphic technology using an effort detector and a modulated flow source.  The causalities of all bonds are fixed. <p>

<hr>

<pre>
Parameters:

 transConductance:  Transconductance (default value = 1 Amp/Volt)
</pre> <p>

<hr> <p>

Equations: <p>

<b>i2 = transConductance*v1</b> <br>
<b>i1 = 0</b>
</html>
"));
          Modelica.Blocks.Math.Gain Gain1(k=transConductance)   annotation (
              extent=[-8, -10; 12, 10]);
          BondLib.Sensors.De De1 annotation (extent=[-40, -10; -20, 10]);
          BondLib.Bonds.fBond B1 annotation (extent=[-60, -10; -40, 10]);
          BondLib.Bonds.fBond B2 annotation (extent=[-80, 10; -60, 30],
              rotation=-90);
          BondLib.Bonds.eBond B3 annotation (extent=[-80, -30; -60, -10],
              rotation=-90);
          BondLib.Junctions.J1p3 J1p3_2 annotation (extent=[80, -10; 60, 10],
              rotation=90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-80, 40; -60, 60]);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG2 annotation (extent=
                [80, 40; 60, 60]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [60, -60; 80, -40]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El2 annotation (extent=
                [-60, -60; -80, -40]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-80, -10; -60, 10],
                rotation=90);
          BondLib.Sources.mSf mSf1 annotation (extent=[40, -10; 20, 10]);
          BondLib.Bonds.eBond B4 annotation (extent=[40, -10; 60, 10]);
          BondLib.Bonds.eBond B6 annotation (extent=[60, 10; 80, 30], rotation=
                90);
          BondLib.Bonds.fBond B5 annotation (extent=[60, -30; 80, -10],
              rotation=90);
        equation 
          connect(De1.OutPort1,Gain1.u)       annotation (points=[-19,0; -10,0],
                    style(color=3));
          connect(B1.fBondCon1, De1.BondCon1) annotation (points=[-40, 0; -40,
                0], style(color=8));
          connect(J1p3_1.BondCon3, B1.eBondCon1) annotation (points=[-60,
                -6.12303e-016; -60,0],
                        style(color=8));
          connect(J1p3_1.BondCon2, B2.fBondCon1) annotation (points=[-70, 10; -
                70, 10], style(color=8));
          connect(J1p3_1.BondCon1, B3.fBondCon1) annotation (points=[-70, -10;
                -70, -10], style(color=8));
          connect(Gain1.y,       mSf1.InPort1) annotation (points=[13,0; 21,0],
                   style(color=3));
          connect(El2BG1.BondCon1, B2.eBondCon1) annotation (points=[-60, 50; -
                50, 50; -50, 30; -70, 30], style(color=8));
          connect(BG2El2.BondCon1, B3.eBondCon1) annotation (points=[-60, -50;
                -50, -50; -50, -30; -70, -30], style(color=8));
          connect(B4.fBondCon1, mSf1.BondCon1) annotation (points=[40, 0; 40, 0],
                   style(color=8));
          connect(B4.eBondCon1, J1p3_2.BondCon3) annotation (points=[60,0; 60,
                -6.12303e-016],
                      style(color=8));
          connect(B6.fBondCon1, J1p3_2.BondCon2) annotation (points=[70, 10; 70,
                  10], style(color=8));
          connect(El2BG2.BondCon1, B6.eBondCon1) annotation (points=[60, 50; 50,
                  50; 50, 30; 70, 30], style(color=8));
          connect(J1p3_2.BondCon1, B5.fBondCon1) annotation (points=[70, -10;
                70, -10], style(color=8));
          connect(BG2El1.BondCon1, B5.eBondCon1) annotation (points=[60, -50;
                50, -50; 50, -30; 70, -30], style(color=8));
          connect(El2BG1.p, p1) annotation (points=[-80,50; -100,50], style(
                color=3, rgbcolor={0,0,255}));
          connect(BG2El2.n, n1) annotation (points=[-80,-50; -100,-50], style(
                color=3, rgbcolor={0,0,255}));
          connect(El2BG2.p, p2) annotation (points=[80,50; 100,50], style(color=
                 3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n2) annotation (points=[80,-50; 100,-50], style(
                color=3, rgbcolor={0,0,255}));
        end VCC;
        
        model CCV "Linear current-controlled voltage source" 
          extends Interfaces.TwoPort;
          parameter Modelica.SIunits.Resistance transResistance=1 
            "Transresistance";
          annotation (
            Icon(
              Rectangle(extent=[-70, 70; 70, -70], style(fillColor=7)),
              Text(extent=[-99, -60; 100, -110], string="%name"),
              Ellipse(extent=[10, 20; 50, -20]),
              Line(points=[-20, 60; 20, 60]),
              Polygon(points=[20, 60; 10, 63; 10, 57; 20, 60], style(fillColor=
                      3, fillPattern=1)),
              Line(points=[30, 50; 30, -50]),
              Line(points=[30, 50; 90, 50]),
              Line(points=[30, -50; 90, -50])),
            Diagram(
              Text(
                extent=[-68, 26; -58, 18],
                string="v1a",
                style(color=9)),
              Text(
                extent=[-82, 26; -72, 18],
                style(color=9),
                string="i1"),
              Text(
                extent=[-82, -16; -72, -24],
                style(color=9),
                string="i1"),
              Text(
                extent=[-56, -4; -44, -12],
                style(color=9),
                string="i1"),
              Text(
                extent=[-68, -14; -58, -22],
                style(color=9),
                string="v1b"),
              Text(
                extent=[-58, 12; -46, 2],
                style(color=9),
                string="v1=0"),
              Text(
                extent=[42, 8; 54, 0],
                style(color=9),
                string="v2"),
              Text(
                extent=[44, -4; 56, -12],
                style(color=9),
                string="i2"),
              Text(
                extent=[72, 24; 84, 16],
                style(color=9),
                string="i2"),
              Text(
                extent=[72, -16; 84, -24],
                style(color=9),
                string="i2"),
              Text(
                extent=[58, 22; 68, 14],
                style(color=9),
                string="v2a"),
              Text(
                extent=[58, -18; 68, -26],
                style(color=9),
                string="v2b")),
            Documentation(info="<html>
The linear current-controlled voltage source is built in bondgraphic technology using a flow detector and a modulated effort source.  A-causal bonds must partially be used here, because the causality of the input and output ports depend on the embedding of the <b>CCV</b> element in its environment. <p>

<hr>

<pre>
Parameters:

 transResistance:  Transresistance (default value = 1 Volt/Amp)
</pre> <p>

<hr> <p>

Equations: <p>

<b>v2 = transResistance*i1</b> <br>
<b>v1 = 0</b>
</html>
"));
          Modelica.Blocks.Math.Gain Gain1(k=transResistance)   annotation (
              extent=[-8, -10; 12, 10]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-80, -10; -60, 10],
                rotation=90);
          BondLib.Sources.mSe mSe1 annotation (extent=[40, -10; 20, 10]);
          BondLib.Bonds.fBond B4 annotation (extent=[40, -10; 60, 10]);
          BondLib.Junctions.J1p3 J1p3_2 annotation (extent=[80, -10; 60, 10],
              rotation=90);
          BondLib.Bonds.Bond B5 annotation (extent=[60, -30; 80, -10], rotation=
               90);
          BondLib.Bonds.Bond B6 annotation (extent=[60, 10; 80, 30], rotation=
                90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-80, 40; -60, 60]);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG2 annotation (extent=
                [80, 40; 60, 60]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [60, -60; 80, -40]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El2 annotation (extent=
                [-60, -60; -80, -40]);
          BondLib.Sensors.Df Df1 annotation (extent=[-40, -10; -20, 10]);
          BondLib.Bonds.Bond B1 annotation (extent=[-80, 10; -60, 30], rotation=
               270);
          BondLib.Bonds.Bond B2 annotation (extent=[-80, -30; -60, -10],
              rotation=270);
          BondLib.Bonds.eBond B3 annotation (extent=[-60, -10; -40, 10]);
        equation 
          connect(Gain1.y,       mSe1.InPort1) annotation (points=[13, 0; 21, 0],
                   style(color=3));
          connect(mSe1.BondCon1, B4.eBondCon1) annotation (points=[40, 0; 40, 0],
                   style(color=8));
          connect(B4.fBondCon1, J1p3_2.BondCon3) annotation (points=[60,0; 60,
                -6.12303e-016],
                      style(color=8));
          connect(B5.BondCon2, J1p3_2.BondCon1) annotation (points=[70, -10; 70,
                  -10], style(color=8));
          connect(J1p3_2.BondCon2, B6.BondCon1) annotation (points=[70,10; 70,
                10.2], style(color=8));
          connect(Df1.OutPort1,Gain1.u)       annotation (points=[-19,0; -10,0],
                    style(color=3));
          connect(B3.eBondCon1, Df1.BondCon1) annotation (points=[-40, 0; -40,
                0], style(color=8));
          connect(J1p3_1.BondCon3, B3.fBondCon1) annotation (points=[-60,
                -6.12303e-016; -60,0],
                        style(color=8));
          connect(B1.BondCon2, J1p3_1.BondCon2) annotation (points=[-70, 10; -
                70, 10], style(color=8));
          connect(J1p3_1.BondCon1, B2.BondCon1) annotation (points=[-70, -10; -
                70, -10.2], style(color=8));
          connect(El2BG1.BondCon1, B1.BondCon1) annotation (points=[-60,50; -50,
                50; -50,29.8; -70,29.8],   style(color=8));
          connect(BG2El2.BondCon1, B2.BondCon2) annotation (points=[-60, -50; -
                50, -50; -50, -30; -70, -30], style(color=8));
          connect(El2BG2.BondCon1, B6.BondCon2) annotation (points=[60, 50; 50,
                  50; 50, 30; 70, 30], style(color=8));
          connect(BG2El1.BondCon1, B5.BondCon1) annotation (points=[60,-50; 50,
                -50; 50,-29.8; 70,-29.8], style(color=8));
          connect(El2BG1.p, p1) annotation (points=[-80,50; -100,50], style(
                color=3, rgbcolor={0,0,255}));
          connect(BG2El2.n, n1) annotation (points=[-80,-50; -100,-50], style(
                color=3, rgbcolor={0,0,255}));
          connect(El2BG2.p, p2) annotation (points=[80,50; 100,50], style(color=
                 3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n2) annotation (points=[80,-50; 100,-50], style(
                color=3, rgbcolor={0,0,255}));
        end CCV;
        
        model CCC "Linear current-controlled current source" 
          extends Interfaces.TwoPort;
          parameter Real gain=1 "Current gain";
          annotation (
            Icon(
              Rectangle(extent=[-70, 70; 70, -70], style(fillColor=7)),
              Text(extent=[-100, -60; 101, -111], string="%name"),
              Ellipse(extent=[10, 20; 50, -20]),
              Line(points=[-20, 60; 20, 60]),
              Polygon(points=[20, 60; 10, 63; 10, 57; 20, 60], style(fillColor=
                      3, fillPattern=1)),
              Line(points=[90, 50; 30, 50; 30, 20]),
              Line(points=[91, -50; 30, -50; 30, -20]),
              Line(points=[10, 0; 50, 0]),
              Line(points=[-30, 50; -30, -50]),
              Line(points=[-30, 50; -90, 50]),
              Line(points=[-30, -50; -90, -50])),
            Diagram(
              Text(
                extent=[-68, 26; -58, 18],
                string="v1a",
                style(color=9)),
              Text(
                extent=[-56, -4; -44, -12],
                style(color=9),
                string="i1"),
              Text(
                extent=[-68, -14; -58, -22],
                style(color=9),
                string="v1b"),
              Text(
                extent=[-58, 12; -46, 2],
                style(color=9),
                string="v1=0"),
              Text(
                extent=[42, 8; 54, 0],
                style(color=9),
                string="v2"),
              Text(
                extent=[44, -4; 56, -12],
                style(color=9),
                string="i2"),
              Text(
                extent=[72, 24; 84, 16],
                style(color=9),
                string="i2"),
              Text(
                extent=[72, -16; 84, -24],
                style(color=9),
                string="i2"),
              Text(
                extent=[58, 22; 68, 14],
                style(color=9),
                string="v2a"),
              Text(
                extent=[58, -18; 68, -26],
                style(color=9),
                string="v2b")),
            Documentation(info="<html>
The linear current-controlled current source is built in bondgraphic technology using a flow detector and a modulated flow source.  A-causal bonds must partially be used here, because the causality of the input port depends on the embedding of the <b>CCC</b> element in its environment. <p>

<hr>

<pre>
Parameters:

 gain:  Current gain (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>i2 = gain*i1</b> <br>
<b>v1 = 0</b>
</html>
"));
          Modelica.Blocks.Math.Gain Gain1(k=gain)   annotation (extent=[-8, -10;
                  12, 10]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-80, -10; -60, 10],
                rotation=90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-80, 40; -60, 60]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [-60, -60; -80, -40]);
          BondLib.Sensors.Df Df1 annotation (extent=[-40, -10; -20, 10]);
          BondLib.Bonds.Bond B1 annotation (extent=[-80, 10; -60, 30], rotation=
               270);
          BondLib.Bonds.Bond B2 annotation (extent=[-80, -30; -60, -10],
              rotation=270);
          BondLib.Bonds.eBond B3 annotation (extent=[-60, -10; -40, 10]);
          BondLib.Junctions.J1p3 J1p3_2 annotation (extent=[80, -10; 60, 10],
              rotation=90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG2 annotation (extent=
                [80, 40; 60, 60]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El2 annotation (extent=
                [60, -60; 80, -40]);
          BondLib.Sources.mSf mSf1 annotation (extent=[40, -10; 20, 10]);
          BondLib.Bonds.eBond B4 annotation (extent=[40, -10; 60, 10]);
          BondLib.Bonds.eBond B6 annotation (extent=[60, 10; 80, 30], rotation=
                90);
          BondLib.Bonds.fBond B5 annotation (extent=[60, -30; 80, -10],
              rotation=90);
        equation 
          connect(Df1.OutPort1,Gain1.u)       annotation (points=[-19,0; -10,0],
                    style(color=3));
          connect(B3.eBondCon1, Df1.BondCon1) annotation (points=[-40, 0; -40,
                0], style(color=8));
          connect(J1p3_1.BondCon3, B3.fBondCon1) annotation (points=[-60,
                -6.12303e-016; -60,0],
                        style(color=8));
          connect(B1.BondCon2, J1p3_1.BondCon2) annotation (points=[-70, 10; -
                70, 10], style(color=8));
          connect(J1p3_1.BondCon1, B2.BondCon1) annotation (points=[-70, -10; -
                70, -10.2], style(color=8));
          connect(El2BG1.BondCon1, B1.BondCon1) annotation (points=[-60,50; -50,
                50; -50,29.8; -70,29.8],   style(color=8));
          connect(BG2El1.BondCon1, B2.BondCon2) annotation (points=[-60, -50; -
                50, -50; -50, -30; -70, -30], style(color=8));
          connect(mSf1.InPort1,Gain1.y)        annotation (points=[21,0; 13,0],
                   style(color=3));
          connect(B4.fBondCon1, mSf1.BondCon1) annotation (points=[40, 0; 40, 0],
                   style(color=8));
          connect(B6.fBondCon1, J1p3_2.BondCon2) annotation (points=[70, 10; 70,
                  10], style(color=8));
          connect(El2BG2.BondCon1, B6.eBondCon1) annotation (points=[60, 50; 50,
                  50; 50, 30; 70, 30], style(color=8));
          connect(B5.fBondCon1, J1p3_2.BondCon1) annotation (points=[70, -10;
                70, -10], style(color=8));
          connect(BG2El2.BondCon1, B5.eBondCon1) annotation (points=[60, -50;
                50, -50; 50, -30; 70, -30], style(color=8));
          connect(J1p3_2.BondCon3, B4.eBondCon1) annotation (points=[60,
                -6.12303e-016; 60,0],
                      style(color=8));
          connect(El2BG1.p, p1) annotation (points=[-80,50; -100,50], style(
                color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n1) annotation (points=[-80,-50; -100,-50], style(
                color=3, rgbcolor={0,0,255}));
          connect(El2BG2.p, p2) annotation (points=[80,50; 100,50], style(color=
                 3, rgbcolor={0,0,255}));
          connect(BG2El2.n, n2) annotation (points=[80,-50; 100,-50], style(
                color=3, rgbcolor={0,0,255}));
        end CCC;
        
        model VariableResistor "Modulated linear electrical resistor" 
          extends Interfaces.ModOnePort;
          annotation (
            Icon(
              Text(extent=[-144,-100; 148,-40],   string="%name"),
              Line(points=[-90,0; -70,0]),
              Rectangle(extent=[-70,30; 70,-30],   style(
                  color=3,
                  fillColor=7,
                  fillPattern=1)),
              Line(points=[70,0; 90,0]),
              Line(points=[0,80; 0,30],   style(color=73))),
            Diagram,
            Documentation(info="<html>
The modulated resistor is built in bondgraphic technology from a bond graph <b>mR</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the resistor in its environment. <p>

<hr>

<pre>
Potential variables:

 R:  Resistance (modulation input signal)
</pre>
</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[-38,-12; -12,12]);
          Bonds.Bond B2         annotation (extent=[12,-12; 38,12]);
          Bonds.Bond B3         annotation (extent=[-12,12; 12,36],   rotation=
                90);
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Passive.mR mR1 annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,0; -12,
                0],                    style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,0; 12.26,
                0],        style(color=8));
          connect(B3.BondCon1,J1p3_1. BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,
                1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,0; 38,
                1.77636e-015], style(color=8));
          connect(mR1.BondCon1, B3.BondCon2) annotation (points=[-7.34764e-016,
                36; 7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(u, mR1.InPort1) annotation (points=[0,90; 0,74.4; 0,58.8; 
                6.61287e-016,58.8], style(color=74, rgbcolor={0,0,127}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 81,
                1.77636e-015; 81,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end VariableResistor;
        
        model VariableConductor "Modulated linear electrical conductor" 
          extends Interfaces.ModOnePort;
          annotation (
            Icon(
              Text(extent=[-144,-100; 148,-40],   string="%name"),
              Line(points=[-90,0; -70,0]),
              Rectangle(extent=[-70,30; 70,-30],   style(
                  color=3,
                  fillColor=7,
                  fillPattern=1)),
              Line(points=[70,0; 90,0]),
              Line(points=[0,80; 0,30],   style(color=73))),
            Diagram,
            Documentation(info="<html>
The modulated conductor is built in bondgraphic technology from a bond graph <b>mG</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the conductor in its environment. <p>

<hr>

<pre>
Potential variables:

 G:  Conductance (modulation input signal)
</pre>
</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[-38,-12; -12,12]);
          Bonds.Bond B2         annotation (extent=[12,-12; 38,12]);
          Bonds.Bond B3         annotation (extent=[-12,12; 12,36],   rotation=
                90);
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Passive.mG mG1 annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,0; -12,
                0],                    style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,0; 12.26,
                0],        style(color=8));
          connect(B3.BondCon1,J1p3_1. BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,
                1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,0; 38,
                1.77636e-015], style(color=8));
          connect(B3.BondCon2, mG1.BondCon1) annotation (points=[7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(mG1.InPort1, u) annotation (points=[6.61287e-016,58.8; 
                6.61287e-016,69.4; 0,69.4; 0,90], style(color=74, rgbcolor={0,0,
                  127}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 81,
                1.77636e-015; 81,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end VariableConductor;
        
        model VariableCapacitor "Modulated linear electrical capacitor" 
          extends Interfaces.ModOnePort;
          annotation (
            Icon(
              Text(extent=[-134,-96; 136,-36],    string="%name"),
              Line(points=[-90,0; -14,0]),
              Line(points=[14,0; 90,0]),
              Line(points=[0,80; 0,28],   style(color=73)),
              Line(points=[-14,28; -14,-28],   style(thickness=2)),
              Line(points=[14,28; 14,-28],   style(thickness=2))),
            Diagram,
            Documentation(info="<html>
The modulated capacitor is built in bondgraphic technology from a bond graph <b>mC</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the capacitor in its environment. <p>

<hr>

<pre>
Potential variables:

 C:  Capacitance (modulation input signal)
</pre>
</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[-38,-12; -12,12]);
          Bonds.Bond B2         annotation (extent=[12,-12; 38,12]);
          Bonds.Bond B3         annotation (extent=[-12,12; 12,36],   rotation=
                90);
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Passive.mC mC1 annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,0; -12,
                0],                    style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,0; 12.26,
                0],        style(color=8));
          connect(B3.BondCon1,J1p3_1. BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,
                1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,0; 38,
                1.77636e-015], style(color=8));
          connect(B3.BondCon2, mC1.BondCon1) annotation (points=[7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(mC1.InPort1, u) annotation (points=[6.61287e-016,58.8; 
                6.61287e-016,69.4; 0,69.4; 0,90], style(color=74, rgbcolor={0,0,
                  127}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end VariableCapacitor;
        
        model VariableInductor "Modulated linear electrical inductor" 
          extends Interfaces.ModOnePort;
          annotation (
            Icon(
              Text(extent=[-136,-94; 138,-34],    string="%name"),
              Line(points=[-90,0; -60,0]),
              Line(points=[60,0; 90,0]),
              Line(points=[0,80; 0,6],   style(color=73)),
              Ellipse(extent=[-60,-15; -30,15]),
              Ellipse(extent=[-30,-15; 0,15]),
              Ellipse(extent=[0,-15; 30,15]),
              Ellipse(extent=[30,-15; 60,15]),
              Rectangle(extent=[-60,-30; 60,0],   style(color=7, fillColor=7))),
            Diagram,
            Documentation(info="<html>
The modulated inductor is built in bondgraphic technology from a bond graph <b>mI</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the inductor in its environment. <p>

<hr>

<pre>
Potential variables:

 I:  Inductance (modulation input signal)
</pre>
</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[-38,-12; -12,12]);
          Bonds.Bond B2         annotation (extent=[12,-12; 38,12]);
          Bonds.Bond B3         annotation (extent=[-12,12; 12,36],   rotation=
                90);
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Passive.mI mI1 annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,0; -12,
                0],                    style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,0; 12.26,
                0],        style(color=8));
          connect(B3.BondCon1,J1p3_1. BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,
                1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,0; 38,
                1.77636e-015], style(color=8));
          connect(B3.BondCon2, mI1.BondCon1) annotation (points=[7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(mI1.InPort1, u) annotation (points=[6.61287e-016,58.8; 
                6.61287e-016,69.4; 0,69.4; 0,90], style(color=74, rgbcolor={0,0,
                  127}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end VariableInductor;
      end Basic;
      
      package Ideal "Idealized analog electrical elements" 
        annotation (Icon(
            Rectangle(extent=[-100, -100; 80, 50], style(fillColor=30,
                  fillPattern=1)),
            Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50],
                style(fillColor=30, fillPattern=1)),
            Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70],
                style(fillColor=30, fillPattern=1)),
            Text(
              extent=[-85, 35; 65, -85],
              string="Library",
              style(color=3)),
            Text(
              extent=[-118, 114; 122, 65],
              string="%name",
              style(color=1))));
        
        model IdealCommutingSwitch 
          "Ideal leaking two-way switch of analog electrical library" 
        public 
          Modelica.Electrical.Analog.Interfaces.PositivePin p 
                                   annotation (extent=[-110,-10; -90,10]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n2 
                                    annotation (extent=[90,-10; 110,10]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n1 
                                    annotation (extent=[90,40; 110,60]);
          Modelica.Blocks.Interfaces.BooleanInput control 
            "true => p--n2 connected, false => p--n1 connected" annotation (extent=[
                -20,80; 20,120], rotation=-90);
          annotation (
            Icon(
              Ellipse(extent=[-44,4; -36,-4]),
              Text(extent=[-80,0; -60,22],   string="p"),
              Text(extent=[60,50; 80,72],   string="n1"),
              Text(extent=[60,0; 80,22],   string="n2"),
              Line(points=[-90,0; -44,0]),
              Line(points=[-37,2; 40,50]),
              Line(points=[40,50; 90,50]),
              Line(points=[40,0; 90,0]),
              Text(extent=[-100,-70; 100,-100],   string="%name"),
              Line(points=[0,25; 0,80], style(color=5, rgbcolor={255,0,255}))),
            Diagram,
            Documentation(info="<html>
The ideal leaking electrical commuting switch is built in bondgraphic technology from two bond graph <b>Sw2</b> elements with rversed logic.  A-causal bonds must be used here, because the causality depends on the embedding of the switches in their environment.  Leaking switches have been used to ensure that the switches will not lead to a division by zero in either switch position, irrespective of the circuit topology. <p>

The logic is such that the top switch is considered <b>open</b> and the bottom switch is considered <b>closed</b>, when the Boolean control signal assumes a value of <b>true</b>. <p>

<hr>

<pre>
Parameters:

 Ron:    Leakage resistance in <b>on</b> state (default value = 1e-5 Ohm)

 Goff:   Leakage conductance in <b>off</b> state (default value = 1e-5 Mho)
</pre>
</html>
"));
          parameter Modelica.SIunits.Resistance Ron(final min=0) = 1.E-5 
            "Closed switch resistance";
          parameter Modelica.SIunits.Conductance Goff(final min=0) = 1.E-5 
            "Opened switch conductance";
          Junctions.J1p3 J1p3_1         annotation (extent=[-10,20; 10,0]);
          Bonds.Bond B2         annotation (extent=[-30,-2; -10,22]);
          Bonds.Bond B3         annotation (extent=[10,-2; 30,22]);
          Bonds.Bond B4         annotation (extent=[-12,20; 12,40],   rotation=
                90);
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -84,-14; -60,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[58,
                36; 84,64]);
          Switches.Sw2 Sw1(        Ron=Ron, Goff=Goff) annotation (extent=[-14,
                40; 14,70],    rotation=90);
          Interfaces.BG2El BG2El2                           annotation (extent=[58,
                -14; 84,14]);
          Junctions.J1p3 J1p3_2         annotation (extent=[-10,-20; 10,0]);
          Junctions.J0p3 J0p3_1 
            annotation (extent=[-40,-10; -20,10], rotation=-90);
          Bonds.Bond B1         annotation (extent=[-60,-12; -40,12]);
          Bonds.Bond B5         annotation (extent=[-30,-22; -10,2]);
          Bonds.Bond B6         annotation (extent=[10,-22; 30,2]);
          Bonds.Bond B7         annotation (extent=[-10,-40; 10,-20], rotation=
                -90);
          Switches.Sw2 Sw2(        Ron=Ron, Goff=Goff) annotation (extent=[-14,
                -70; 14,-40],  rotation=270);
          Modelica.Blocks.Logical.Not Not1 
            annotation (extent=[-34,-90; -14,-70]);
        equation 
          connect(B2.BondCon2,J1p3_1. BondCon1) annotation (points=[-10,10; -10,
                10],  style(color=8));
          connect(J1p3_1.BondCon2,B3. BondCon1) annotation (points=[10,10; 10.2,
                10],       style(color=8));
          connect(B4.BondCon1,J1p3_1. BondCon3) annotation (points=[
                -7.20069e-016,20.2; -7.20069e-016,20.12; 0,20.12; 0,20],
                       style(color=8));
          connect(Sw1.BondCon1,B4. BondCon2) annotation (points=[9.19132e-016,
                40; 7.34764e-016,40],
                style(color=8));
          connect(J0p3_1.BondCon1, B2.BondCon1) annotation (points=[-30,10;
                -29.8,10], style(color=8, rgbcolor={192,192,192}));
          connect(B1.BondCon2, J0p3_1.BondCon3) annotation (points=[-40,0; -44,
                0; -44,-6.12303e-016; -40,-6.12303e-016], style(color=8,
                rgbcolor={192,192,192}));
          connect(El2BG1.BondCon1, B1.BondCon1) annotation (points=[-60,
                1.77636e-015; -62,1.77636e-015; -64,0; -59.8,0], style(color=8,
                rgbcolor={192,192,192}));
          connect(B3.BondCon2, BG2El1.BondCon1) annotation (points=[30,10; 40,
                10; 40,50; 58,50], style(color=8, rgbcolor={192,192,192}));
          connect(J0p3_1.BondCon2, B5.BondCon1) annotation (points=[-30,-10;
                -29.8,-10], style(color=8, rgbcolor={192,192,192}));
          connect(B5.BondCon2, J1p3_2.BondCon1) annotation (points=[-10,-10;
                -10,-10], style(color=8, rgbcolor={192,192,192}));
          connect(J1p3_2.BondCon2, B6.BondCon1) annotation (points=[10,-10;
                10.2,-10], style(color=8, rgbcolor={192,192,192}));
          connect(B6.BondCon2, BG2El2.BondCon1) annotation (points=[30,-10; 50,
                -10; 50,1.77636e-015; 58,1.77636e-015], style(color=8, rgbcolor=
                 {192,192,192}));
          connect(B7.BondCon1, J1p3_2.BondCon3) annotation (points=[
                -6.00057e-016,-20.2; -6.00057e-016,-25.12; 0,-25.12; 0,-20],
              style(color=8, rgbcolor={192,192,192}));
          connect(Sw2.BondCon1, B7.BondCon2) annotation (points=[4.34803e-015,
                -40; 6.12303e-016,-40], style(color=8, rgbcolor={192,192,192}));
          connect(Sw1.BooleanInPort1, control) annotation (points=[2.54786e-015,
                68.5; 2.54786e-015,74.25; 0,74.25; 0,100], style(color=5,
                rgbcolor={255,0,255}));
          connect(Not1.y, Sw2.BooleanInPort1) annotation (points=[-13,-80; 
                -5.38149e-016,-80; -5.38149e-016,-68.5], style(color=5,
                rgbcolor={255,0,255}));
          connect(Not1.u, control) annotation (points=[-36,-80; -50,-80; -50,74;
                0,74; 0,100], style(color=5, rgbcolor={255,0,255}));
          connect(El2BG1.p, p) annotation (points=[-84,1.77636e-015; -94,
                1.77636e-015; -94,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El2.n, n2) annotation (points=[84,1.77636e-015; 90,
                1.77636e-015; 90,0; 100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n1) annotation (points=[84,50; 100,50], style(color=
                 3, rgbcolor={0,0,255}));
        end IdealCommutingSwitch;
        
        model IdealIntermediateSwitch "Ideal intermediate switch" 
          parameter Modelica.SIunits.Resistance Ron(final min=0) = 1.E-5 
            "Closed switch resistance";
          parameter Modelica.SIunits.Conductance Goff(final min=0) = 1.E-5 
            "Opened switch conductance";
        public 
          Modelica.Electrical.Analog.Interfaces.PositivePin p1 
                                    annotation (extent=[-110,40; -90,60]);
          Modelica.Electrical.Analog.Interfaces.PositivePin p2 
                                    annotation (extent=[-110,-10; -90,10]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n1 
                                    annotation (extent=[90,40; 110,60]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n2 
                                    annotation (extent=[90,-10; 110,10]);
          Modelica.Blocks.Interfaces.BooleanInput control 
            "true => p1--n2, p2--n1 connected, otherwise p1--n1, p2--n2  connected"
            annotation (extent=[-20,80; 20,120],rotation=-90);
          annotation (
            Icon(
              Ellipse(extent=[-4,30; 4,22]),
              Text(extent=[-80,50; -60,72],   string="p1"),
              Text(extent=[-80,0; -60,22],   string="p2"),
              Text(extent=[60,50; 80,72],   string="n1"),
              Text(extent=[60,0; 80,22],   string="n2"),
              Line(points=[-90,0; -42,0]),
              Line(points=[-90,50; -42,50]),
              Line(points=[-42,0; 42,50]),
              Line(points=[-42,50; 42,0]),
              Line(points=[42,50; 90,50]),
              Line(points=[0,90; 0,25], style(color=5, rgbcolor={255,0,255})),
              Line(points=[42,0; 90,0]),
              Text(extent=[-100,-56; 100,-86],    string="%name")),
            Diagram(
              Ellipse(extent=[58,52; 62,48], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=3,
                  rgbfillColor={0,0,255})),
              Ellipse(extent=[78,2; 82,-2], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=3,
                  rgbfillColor={0,0,255})),
              Ellipse(extent=[-2,2; 2,-2], style(
                  color=5,
                  rgbcolor={255,0,255},
                  fillColor=5,
                  rgbfillColor={255,0,255}))),
            Documentation(info="<html>
The ideal leaking electrical intermediate switch is built as a macro element from two two-way switches. <p>

The logic is such that the two switches are connected in parallel, when the Boolean control signal assumes a value of <b>true</b>.  The are connected over the cross, when the control signal assumes a value of <b>false</b>. <p>

<hr>

<pre>
Parameters:

 Ron:    Leakage resistance in <b>on</b> state (default value = 1e-5 Ohm)

 Goff:   Leakage conductance in <b>off</b> state (default value = 1e-5 Mho)
</pre>
</html>
"));
          IdealCommutingSwitch IdealCommutingSwitch1(Ron=Ron, Goff=Goff) 
            annotation (extent=[-20,60; 20,20]);
          IdealCommutingSwitch IdealCommutingSwitch2 
            annotation (extent=[-20,-60; 20,-20]);
        equation 
          connect(IdealCommutingSwitch2.control, control) annotation (points=[0,
                -20; 0,0; -40,0; -40,70; 0,70; 0,100], style(color=5, rgbcolor=
                  {255,0,255}));
          connect(IdealCommutingSwitch1.control, IdealCommutingSwitch2.control) 
            annotation (points=[0,20; 0,-20], style(color=5, rgbcolor={255,0,
                  255}));
          connect(IdealCommutingSwitch1.p, p1) annotation (points=[-20,40; -60,
                40; -60,50; -100,50], style(color=3, rgbcolor={0,0,255}));
          connect(IdealCommutingSwitch2.p, p2) annotation (points=[-20,-40; -60,
                -40; -60,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(n1, IdealCommutingSwitch2.n1) annotation (points=[100,50; 60,
                50; 60,-30; 20,-30], style(color=3, rgbcolor={0,0,255}));
          connect(n2, IdealCommutingSwitch1.n1) annotation (points=[100,0; 40,0;
                40,30; 20,30], style(color=3, rgbcolor={0,0,255}));
          connect(IdealCommutingSwitch1.n2, n1) annotation (points=[20,40; 40,
                40; 40,50; 100,50], style(color=3, rgbcolor={0,0,255}));
          connect(IdealCommutingSwitch2.n2, n2) annotation (points=[20,-40; 80,
                -40; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end IdealIntermediateSwitch;
        
        model ControlledIdealCommutingSwitch "Controlled ideal two-way switch" 
          parameter Modelica.SIunits.Voltage level=0.5 "Switch level";
          parameter Modelica.SIunits.Resistance Ron(final min=0) = 1.E-5 
            "Closed switch resistance";
          parameter Modelica.SIunits.Conductance Goff(final min=0) = 1.E-5 
            "Opened switch conductance";
        public 
          Modelica.Electrical.Analog.Interfaces.PositivePin p 
                                   annotation (extent=[-110,-10; -90,10]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n2 
                                    annotation (extent=[90,-10; 110,10]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n1 
                                    annotation (extent=[90,40; 110,60]);
          Modelica.Electrical.Analog.Interfaces.Pin control 
            "Control pin: if control.v > level p--n2 connected, otherwise p--n1 connected"
             annotation (extent=[-10,90; 10,110],   rotation=90);
          annotation (
            Icon(
              Ellipse(extent=[-44,4; -36,-4]),
              Text(extent=[-80,0; -60,22],   string="p"),
              Text(extent=[60,50; 80,72],   string="n1"),
              Text(extent=[60,0; 80,22],   string="n2"),
              Line(points=[-90,0; -44,0]),
              Line(points=[-37,2; 40,50]),
              Line(points=[40,50; 90,50]),
              Line(points=[0,90; 0,25]),
              Line(points=[40,0; 90,0])),
            Diagram(Ellipse(extent=[-82,2; -78,-2], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1)), Ellipse(extent=[-2,82; 2,78], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1))),
            Documentation(info="<html>
The ideal leaking controlled electrical commuting switch is built as a macro element from an ideal controlled opening switch and an ideal controlled closing switch. <p>

The logic is such that the top switch is considered <b>open</b> and the bottom switch is considered <b>closed</b>, when the real-valued control signal assumes a value larger than a threshold value, called <b>level</b>. <p>

<hr>

<pre>
Parameters:

 Ron:    Leakage resistance in <b>on</b> state (default value = 1e-5 Ohm)

 Goff:   Leakage conductance in <b>off</b> state (default value = 1e-5 Mho)
</pre>
</html>
"));
          ControlledIdealOpeningSwitch ControlledIdealOpeningSwitch1(
            level=level,
            Ron=Ron,
            Goff=Goff) 
            annotation (extent=[-20,20; 20,60]);
          ControlledIdealClosingSwitch ControlledIdealClosingSwitch1(
            level=level,
            Ron=Ron,
            Goff=Goff) 
            annotation (extent=[-20,-60; 20,-20]);
        equation 
          connect(ControlledIdealClosingSwitch1.control, control) annotation (
              points=[0,-20; 0,10; 40,10; 40,80; 0,80; 0,100], style(color=3,
                rgbcolor={0,0,255}));
          connect(ControlledIdealOpeningSwitch1.control, control) annotation (
              points=[0,60; 0,100], style(color=3, rgbcolor={0,0,255}));
          connect(ControlledIdealOpeningSwitch1.n, n1) annotation (points=[20,
                40; 60,40; 60,50; 100,50], style(color=3, rgbcolor={0,0,255}));
          connect(ControlledIdealClosingSwitch1.n, n2) annotation (points=[20,
                -40; 60,-40; 60,0; 100,0], style(color=3, rgbcolor={0,0,255}));
          connect(ControlledIdealOpeningSwitch1.p, p) annotation (points=[-20,
                40; -80,40; -80,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(ControlledIdealClosingSwitch1.p, p) annotation (points=[-20,
                -40; -80,-40; -80,0; -100,0], style(color=3, rgbcolor={0,0,255}));
        end ControlledIdealCommutingSwitch;
        
        model ControlledIdealIntermediateSwitch 
          "Controlled ideal intermediate switch" 
          parameter Modelica.SIunits.Voltage level=0.5 "Switch level";
          parameter Modelica.SIunits.Resistance Ron(final min=0) = 1.E-5 
            "Closed switch resistance";
          parameter Modelica.SIunits.Conductance Goff(final min=0) = 1.E-5 
            "Opened switch conductance";
        public 
          Modelica.Electrical.Analog.Interfaces.PositivePin p1 
                                    annotation (extent=[-110,40; -90,60]);
          Modelica.Electrical.Analog.Interfaces.PositivePin p2 
                                    annotation (extent=[-110,-10; -90,10]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n1 
                                    annotation (extent=[90,40; 110,60]);
          Modelica.Electrical.Analog.Interfaces.NegativePin n2 
                                    annotation (extent=[90,-10; 110,10]);
          Modelica.Electrical.Analog.Interfaces.Pin control "Control pin: if control.v > level p1--n2, p2--n1 connected,
         otherwise p1--n1, p2--n2  connected"       annotation (extent=[-10,90;
                10,110],
                      rotation=90);
          annotation (
            Icon(
              Ellipse(extent=[-4,30; 4,22]),
              Text(extent=[-80,50; -60,72],   string="p1"),
              Text(extent=[-80,0; -60,22],   string="p2"),
              Text(extent=[60,50; 80,72],   string="n1"),
              Text(extent=[60,0; 80,22],   string="n2"),
              Line(points=[-90,0; -40,0]),
              Line(points=[-90,50; -39,50]),
              Line(points=[-40,0; 40,50]),
              Line(points=[-40,50; 40,0]),
              Line(points=[40,50; 90,50]),
              Line(points=[0,90; 0,25]),
              Line(points=[40,0; 90,0]),
              Text(extent=[-100,-54; 100,-84],    string="%name")),
            Diagram(
              Ellipse(extent=[78,2; 82,-2], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=3,
                  rgbfillColor={0,0,255})),
              Ellipse(extent=[58,52; 62,48], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=3,
                  rgbfillColor={0,0,255})),
              Ellipse(extent=[-2,2; 2,-2], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=3,
                  rgbfillColor={0,0,255}))),
            Documentation(info="<html>
The ideal leaking controlled electrical intermediate switch is built as a macro element from two controlled two-way switches. <p>

The logic is such that the two switches are connected in parallel, when the Boolean control signal assumes a value of <b>true</b>.  The are connected over the cross, when the control signal assumes a value of <b>false</b>. <p>

<hr>

<pre>
Parameters:

 Ron:    Leakage resistance in <b>on</b> state (default value = 1e-5 Ohm)

 Goff:   Leakage conductance in <b>off</b> state (default value = 1e-5 Mho)
</pre>
</html>
"));
          ControlledIdealCommutingSwitch ControlledIdealCommutingSwitch1(
            level=level,
            Ron=Ron,
            Goff=Goff) 
            annotation (extent=[-20,60; 20,20]);
          ControlledIdealCommutingSwitch ControlledIdealCommutingSwitch2(
            level=level,
            Ron=Ron,
            Goff=Goff) 
            annotation (extent=[-20,-60; 20,-20]);
        equation 
          connect(control, ControlledIdealCommutingSwitch2.control) annotation (
             points=[0,100; 0,70; -40,70; -40,0; 0,0; 0,-20], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(ControlledIdealCommutingSwitch1.control,
            ControlledIdealCommutingSwitch2.control) annotation (points=[0,20;
                0,-20], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(ControlledIdealCommutingSwitch1.p, p1) annotation (points=[
                -20,40; -60,40; -60,50; -100,50], style(color=3, rgbcolor={0,0,
                  255}));
          connect(ControlledIdealCommutingSwitch2.p, p2) annotation (points=[
                -20,-40; -60,-40; -60,0; -100,0], style(color=3, rgbcolor={0,0,
                  255}));
          connect(ControlledIdealCommutingSwitch1.n2, n1) annotation (points=[
                20,40; 40,40; 40,50; 100,50], style(color=3, rgbcolor={0,0,255}));
          connect(ControlledIdealCommutingSwitch1.n1, n2) annotation (points=[
                20,30; 40,30; 40,0; 100,0], style(color=3, rgbcolor={0,0,255}));
          connect(ControlledIdealCommutingSwitch2.n1, n1) annotation (points=[
                20,-30; 60,-30; 60,50; 100,50], style(color=3, rgbcolor={0,0,
                  255}));
          connect(ControlledIdealCommutingSwitch2.n2, n2) annotation (points=[
                20,-40; 80,-40; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end ControlledIdealIntermediateSwitch;
        
        model IdealDiode "Ideal leaking diode of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Resistance Ron(final min=0) = 1.E-5 
            "Closed switch resistance";
          parameter Modelica.SIunits.Conductance Goff(final min=0) = 1.E-5 
            "Opened switch conductance";
          parameter Modelica.SIunits.Voltage Vknee(final min=0) = 0 
            "Forward threshold voltage";
          annotation (
            Icon(
              Polygon(points=[30, 0; -30, 40; -30, -40; 30, 0], style(
                  color=3,
                  gradient=0,
                  fillColor=7)),
              Line(points=[-90, 0; 40, 0]),
              Line(points=[40, 0; 90, 0]),
              Line(points=[30, 40; 30, -40], style(color=3)),
              Text(extent=[-102, 94; 98, 64], string="%name")),
            Diagram,
            Documentation(info="<html>
The ideal leaking electrical diode is built in bondgraphic technology from a bond graph <b>D2</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the diode in its environment.  A leaking diode has been used to ensure that the diode will not lead to a division by zero in either switch position, irrespective of the circuit topology. <p>

<hr>

<pre>
Parameters:

 Ron:     Leakage resistance in <b>on</b> state (default value = 1e-5 Ohm)

 Goff:    Leakage conductance in <b>off</b> state (default value = 1e-5 Mho)

 Vknee:   Forward threshold voltage (default = 0 Volt)
</pre>
</html>
"));
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, 12; 12, -12]);
          BondLib.Bonds.Bond B1 annotation (extent=[-38, -12; -12, 12]);
          BondLib.Bonds.Bond B2 annotation (extent=[12, -12; 38, 12]);
          BondLib.Bonds.Bond B3 annotation (extent=[-12, 12; 12, 36], rotation=
                90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -14; -38, 14]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -14; 64, 14]);
          BondLib.Switches.D2 D1(Ron=Ron, Goff=Goff,
            e0=Vknee)                                annotation (extent=[-16,
                36; 16, 68], rotation=90);
        equation 
          connect(B1.BondCon2, J1p3_1.BondCon1) annotation (points=[-12, 0; -12,
                  0], style(color=8));
          connect(J1p3_1.BondCon2, B2.BondCon1) annotation (points=[12, 0;
                12.26, 0], style(color=8));
          connect(B3.BondCon1, J1p3_1.BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(El2BG1.BondCon1, B1.BondCon1) annotation (points=[-38,
                1.77636e-015; -38,1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2, BG2El1.BondCon1) annotation (points=[38,0; 38,
                1.77636e-015],
                    style(color=8));
          connect(D1.BondCon1, B3.BondCon2) annotation (points=[-9.79685e-016,
                36; 7.34764e-016,36],
              style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -78,
                1.77636e-015; -78,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end IdealDiode;
        
        model IdealZenerDiode 
          "Ideal leaking Zener diode of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Resistance Ron(final min=0) = 1.E-5 
            "Closed switch resistance";
          parameter Modelica.SIunits.Resistance Raval(final min=0) = 1.E-5 
            "Avalanche switch resistance";
          parameter Modelica.SIunits.Conductance Goff(final min=0) = 1.E-5 
            "Opened switch conductance";
          parameter Modelica.SIunits.Voltage v0(final min=0) = 1 
            "Avalanche breakdown voltage";
          annotation (
            Icon(
              Polygon(points=[-20,0; 30,40; 30,-40; -20,0],     style(
                  color=3,
                  gradient=0,
                  fillColor=7)),
              Line(points=[-90,0; 40,0]),
              Line(points=[40,0; 90,0]),
              Line(points=[-20,40; -20,-40], style(color=3)),
              Text(extent=[-102,94; 98,64],   string="%name"),
              Line(points=[-20,-40; 0,-60],  style(color=3)),
              Line(points=[-40,60; -20,40],  style(color=3)),
              Text(extent=[-58,-62; 60,-96], string="v0=%v0")),
            Diagram,
            Documentation(info="<html>
The ideal leaking electrical Zener diode is built in bondgraphic technology from a bond graph <b>Z2</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the diode in its environment.  A leaking diode has been used to ensure that the diode will not lead to a division by zero in either switch position, irrespective of the circuit topology. <p>

Zener diodes are always used as reversed diodes.  Thus, the positive and negative pins have been reversed in the model. <p>

<hr>

<pre>
Parameters:

 Ron:    Leakage resistance in <b>on</b> state (default value = 1e-5 Ohm)

 Goff:   Leakage conductance in <b>off</b> state (default value = 1e-5 Mho)

 Raval:  Leakage resistance in <b>breakdown</b> state (default value = 1e-5 Ohm)

 v0:     Avalanche breakdown voltage (default = 1 Volt)
</pre>
</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[-38,-12; -12,12]);
          Bonds.Bond B2         annotation (extent=[12,-12; 38,12]);
          Bonds.Bond B3         annotation (extent=[-12,12; 12,36],   rotation=
                90);
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Switches.Z2 Z1(
            Ron=Ron,
            Raval=Raval,
            Goff=Goff,
            e0=v0) annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,0; -12,
                0],   style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,0; 12.26,
                0],        style(color=8));
          connect(B3.BondCon1,J1p3_1. BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,
                1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,0; 38,
                1.77636e-015],
                    style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 81,
                1.77636e-015; 81,0; 100,0], style(color=3, rgbcolor={0,0,255}));
          connect(B3.BondCon2, Z1.BondCon1) annotation (points=[7.34764e-016,36; 
                -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
        end IdealZenerDiode;
        
        model IdealTunnelDiode 
          "Ideal leaking tunnel diode of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Resistance R1(final min=0) = 1.E-5 
            "First closed switch resistance";
          parameter Modelica.SIunits.Resistance R2(final min=0) = 1.E-5 
            "Second closed switch resistance";
          parameter Modelica.SIunits.Resistance R3(final min=0) = 1.E-5 
            "Third closed switch resistance";
          parameter Modelica.SIunits.Conductance G0(final min=0) = 1.E-5 
            "Opened switch conductance";
          parameter Modelica.SIunits.Voltage em1(final min=0) = 1 
            "First knee voltage";
          parameter Modelica.SIunits.Voltage em2(final min=em1) = 2 
            "Second knee voltage";
          parameter Modelica.SIunits.Voltage em3(final min=em2) = 3 
            "Third knee voltage";
          parameter Modelica.SIunits.Voltage e0(final min=em3) = 4 
            "Fourth knee voltage";
          parameter Modelica.SIunits.Current fm(final min=0) = 1 
            "Bottom intermediate current";
          parameter Modelica.SIunits.Current f0(final min=fm) = 2 
            "Top intermediate current";
          annotation (
            Icon(
              Polygon(points=[30,0; -30,40; -30,-40; 30,0],     style(
                  color=3,
                  gradient=0,
                  fillColor=7)),
              Line(points=[-90,0; 40,0]),
              Line(points=[40,0; 90,0]),
              Line(points=[30,40; 30,-40],   style(color=3)),
              Text(extent=[-102,94; 98,64],   string="%name"),
              Line(points=[10,60; 30,40],    style(color=3)),
              Line(points=[30,-40; 10,-60],  style(color=3))),
            Diagram,
            Documentation(info="<html>
The ideal leaking electrical tunnel diode is built in bondgraphic technology from a bond graph <b>T2</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the diode in its environment.  A leaking diode has been used to ensure that the diode will not lead to a division by zero in either switch position, irrespective of the circuit topology. <p>

<hr>

<pre>
Parameters:

 G0:    Leakage conductance in blocking state (default value = 1e-5 Mho)

 R1:    Leakage resistance in first conducting state (default value = 1e-5 Ohm)

 R2:    Leakage resistance in second conducting state (default value = 1e-5 Ohm)

 R3:    Leakage resistance in final conducting state (default value = 1e-5 Ohm)

 em1:   First knee voltage (default value = 1 Volt)

 em2:   Second knee voltage (default value = 2 Volt)

 em3:   Third knee voltage (default value = 3 Volt)

 e0:    Fourth knee voltage (default value = 4 Volt)

 fm:    Bottom intermediate current (default value = 1 Amp)

 f0:    Top intermediate current (default value = 2 Amp)
</pre>
</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[-38,-12; -12,12]);
          Bonds.Bond B2         annotation (extent=[12,-12; 38,12]);
          Bonds.Bond B3         annotation (extent=[-12,12; 12,36],   rotation=
                90);
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Switches.T2 T1(
            G0=G0,
            R1=R1,
            R2=R2,
            R3=R3,
            em1=em1,
            em2=em2,
            em3=em3,
            e0=e0,
            fm=fm,
            f0=f0) annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,0; -12,
                0],   style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,0; 12.26,
                0],        style(color=8));
          connect(B3.BondCon1,J1p3_1. BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,
                1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,0; 38,
                1.77636e-015],
                    style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 82,
                1.77636e-015; 82,0; 100,0], style(color=3, rgbcolor={0,0,255}));
          connect(B3.BondCon2, T1.BondCon1) annotation (points=[7.34764e-016,36; 
                -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
        end IdealTunnelDiode;
        
        model IdealTransformer 
          "Ideal linear transformer of analog electrical library" 
          extends Interfaces.TwoPort;
          parameter Real n=1 "Turns ratio";
          annotation (
            Icon(
              Ellipse(extent=[-45, -50; -20, -25]),
              Ellipse(extent=[-45, -25; -20, 0]),
              Ellipse(extent=[-45, 0; -20, 25]),
              Ellipse(extent=[-45, 25; -20, 50]),
              Rectangle(extent=[-72, -60; -33, 60], style(color=7, fillColor=7)),
              Line(points=[-90, 50; -32, 50]),
              Line(points=[-90, -50; -32, -50]),
              Ellipse(extent=[20, -50; 45, -25]),
              Ellipse(extent=[20, -25; 45, 0]),
              Ellipse(extent=[20, 0; 45, 25]),
              Ellipse(extent=[20, 25; 45, 50]),
              Rectangle(extent=[33, -60; 72, 60], style(color=7, fillColor=7)),
              Line(points=[32, 50; 90, 50]),
              Line(points=[32, -50; 90, -50]),
              Text(extent=[-100, -68; 100, -88], string="n=%n"),
              Text(extent=[-100, 92; 100, 72], string="%name")),
            Diagram(
              Text(
                extent=[-38, 26; -28, 18],
                string="v1a",
                style(color=9)),
              Text(
                extent=[-38, -14; -28, -22],
                style(color=9),
                string="v1b"),
              Text(
                extent=[42, -14; 52, -22],
                style(color=9),
                string="v2b"),
              Text(
                extent=[42, 26; 52, 18],
                style(color=9),
                string="v2a"),
              Text(
                extent=[-26, 8; -16, 0],
                style(color=9),
                string="v1"),
              Text(
                extent=[12, 8; 24, 0],
                style(color=9),
                string="-v2"),
              Text(
                extent=[-54, 26; -44, 18],
                style(color=9),
                string="i1"),
              Text(
                extent=[-24, -4; -16, -12],
                style(color=9),
                string="i1"),
              Text(
                extent=[-54, -16; -44, -24],
                style(color=9),
                string="i1"),
              Text(
                extent=[14, -4; 26, -12],
                style(color=9),
                string="i2"),
              Text(
                extent=[26, 24; 36, 16],
                style(color=9),
                string="i2"),
              Text(
                extent=[26, -16; 36, -24],
                style(color=9),
                string="i2")),
            Documentation(info="<html>
The ideal transformer is built in bondgraphic technology from a bond graph <b>TF</b> elements.  A-causal bonds must be used here, because the causality depends on the embedding of the transformer in its environment. <p>

<hr>

<pre>
Parameters:

 n:  Transformation constant (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>v1 = -n*v2</b> <br>
<b>i2 = n*11</b>
</html>
"));
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-70, 40; -50, 60]);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG2 annotation (extent=
                [70, 40; 50, 60]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [50, -60; 70, -40]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El2 annotation (extent=
                [-50, -60; -70, -40]);
          BondLib.Passive.TF TF1(m=n) annotation (extent=[-10, -10; 10, 10]);
          BondLib.Bonds.Bond B1 annotation (extent=[-30, -10; -10, 10]);
          BondLib.Bonds.Bond B2 annotation (extent=[10, -10; 30, 10]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-50, -10; -30, 10],
                rotation=90);
          BondLib.Junctions.J1p3 J1p3_2 annotation (extent=[50, -10; 30, 10],
              rotation=90);
          BondLib.Bonds.Bond B3 annotation (extent=[-50, 10; -30, 30], rotation=
               -90);
          BondLib.Bonds.Bond B4 annotation (extent=[-50, -30; -30, -10],
              rotation=-90);
          BondLib.Bonds.Bond B5 annotation (extent=[30, 10; 50, 30], rotation=-
                90);
          BondLib.Bonds.Bond B6 annotation (extent=[30, -30; 50, -10], rotation=
               -90);
        equation 
          connect(B1.BondCon2, TF1.BondCon1) annotation (points=[-10, 0; -10, 0],
                   style(color=8));
          connect(TF1.BondCon2, B2.BondCon1) annotation (points=[10, 0; 10.2, 0],
                   style(color=8));
          connect(J1p3_1.BondCon3, B1.BondCon1) annotation (points=[-30,
                -6.12303e-016; -30,-6.12303e-016; -30,0; -29.8,0],
                      style(color=8));
          connect(B2.BondCon2, J1p3_2.BondCon3) annotation (points=[30,0; 30,
                -6.12303e-016],
                    style(color=8));
          connect(B3.BondCon2, J1p3_1.BondCon2) annotation (points=[-40, 10; -
                40, 10], style(color=8));
          connect(B5.BondCon2, J1p3_2.BondCon2) annotation (points=[40, 10; 40,
                  10], style(color=8));
          connect(J1p3_2.BondCon1, B6.BondCon1) annotation (points=[40, -10; 40,
                  -10.2], style(color=8));
          connect(J1p3_1.BondCon1, B4.BondCon1) annotation (points=[-40, -10; -
                40, -10.2], style(color=8));
          connect(El2BG1.BondCon1, B3.BondCon1) annotation (points=[-50,50; -40,
                50; -40,29.8],    style(color=8));
          connect(BG2El2.BondCon1, B4.BondCon2) annotation (points=[-50, -50; -
                40, -50; -40, -30], style(color=8));
          connect(El2BG2.BondCon1, B5.BondCon1) annotation (points=[50,50; 40,
                50; 40,29.8],  style(color=8));
          connect(BG2El1.BondCon1, B6.BondCon2) annotation (points=[50, -50; 40,
                  -50; 40, -30], style(color=8));
          connect(El2BG1.p, p1) annotation (points=[-70,50; -100,50], style(
                color=3, rgbcolor={0,0,255}));
          connect(BG2El2.n, n1) annotation (points=[-70,-50; -100,-50], style(
                color=3, rgbcolor={0,0,255}));
          connect(El2BG2.p, p2) annotation (points=[70,50; 100,50], style(color=
                 3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n2) annotation (points=[70,-50; 100,-50], style(
                color=3, rgbcolor={0,0,255}));
        end IdealTransformer;
        
        model IdealGyrator "Ideal linear gyrator of analog electrical library" 
          extends Interfaces.TwoPort;
          parameter Modelica.SIunits.Conductance G=1 "Gyration conductance";
          annotation (
            Icon(
              Ellipse(extent=[-70, -30; -10, 30]),
              Rectangle(extent=[-80, -40; -41, 40], style(
                  color=7,
                  pattern=1,
                  thickness=1,
                  arrow=0,
                  fillColor=7)),
              Line(points=[-90, 50; -40, 50; -40, -50; -90, -50]),
              Text(extent=[-100, 98; 100, 68], string="%name"),
              Line(points=[-30, 60; 20, 60]),
              Polygon(points=[20, 63; 30, 60; 20, 57; 20, 63], style(
                  pattern=1,
                  thickness=1,
                  arrow=0,
                  fillColor=3,
                  fillPattern=1)),
              Ellipse(extent=[10, -30; 70, 30]),
              Rectangle(extent=[80, -40; 40, 40], style(
                  color=7,
                  pattern=1,
                  thickness=1,
                  arrow=0,
                  fillColor=7)),
              Line(points=[90, 50; 40, 50; 40, -50; 90, -50])),
            Diagram(
              Text(
                extent=[-38, 26; -28, 18],
                string="v1a",
                style(color=9)),
              Text(
                extent=[-38, -14; -28, -22],
                style(color=9),
                string="v1b"),
              Text(
                extent=[-26, 8; -16, 0],
                style(color=9),
                string="v1"),
              Text(
                extent=[-54, 26; -44, 18],
                style(color=9),
                string="i1"),
              Text(
                extent=[-24, -4; -16, -12],
                style(color=9),
                string="i1"),
              Text(
                extent=[-54, -16; -44, -24],
                style(color=9),
                string="i1"),
              Text(
                extent=[42, -14; 52, -22],
                style(color=9),
                string="v2b"),
              Text(
                extent=[42, 26; 52, 18],
                style(color=9),
                string="v2a"),
              Text(
                extent=[14, -4; 26, -12],
                style(color=9),
                string="i2"),
              Text(
                extent=[26, 24; 36, 16],
                style(color=9),
                string="i2"),
              Text(
                extent=[26, -16; 36, -24],
                style(color=9),
                string="i2"),
              Text(
                extent=[12, 8; 24, 0],
                style(color=9),
                string="-v2")),
            Documentation(info="<html>
The ideal gyrator is built in bondgraphic technology from a bond graph <b>GY</b> elements.  A-causal bonds must be used here, because the causality depends on the embedding of the gyrator in its environment. <p>

<hr>

<pre>
Parameters:

 r:  Gyration constant (default value = 1)
</pre> <p>

<hr> <p>

Equations: <p>

<b>v1 = r*i2</b> <br>
<b>v2 = -r*i1</b>
</html>
"));
          BondLib.Passive.GY GY1(r=-G) annotation (extent=[-10, -10; 10, 10]);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-70, 40; -50, 60]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [-50, -60; -70, -40]);
          BondLib.Bonds.Bond B1 annotation (extent=[-30, -10; -10, 10]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-50, -10; -30, 10],
                rotation=90);
          BondLib.Bonds.Bond B2 annotation (extent=[-50, 10; -30, 30], rotation=
               -90);
          BondLib.Bonds.Bond B3 annotation (extent=[-50, -30; -30, -10],
              rotation=-90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG2 annotation (extent=
                [70, 40; 50, 60]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El2 annotation (extent=
                [50, -60; 70, -40]);
          BondLib.Bonds.Bond B4 annotation (extent=[10, -10; 30, 10]);
          BondLib.Junctions.J1p3 J1p3_2 annotation (extent=[50, -10; 30, 10],
              rotation=90);
          BondLib.Bonds.Bond B5 annotation (extent=[30, 10; 50, 30], rotation=-
                90);
          BondLib.Bonds.Bond B6 annotation (extent=[30, -30; 50, -10], rotation=
               -90);
        equation 
          connect(J1p3_1.BondCon3, B1.BondCon1) annotation (points=[-30,
                -6.12303e-016; -30,-6.12303e-016; -30,0; -29.8,0],
                      style(color=8));
          connect(B2.BondCon2, J1p3_1.BondCon2) annotation (points=[-40, 10; -
                40, 10], style(color=8));
          connect(J1p3_1.BondCon1, B3.BondCon1) annotation (points=[-40, -10; -
                40, -10.2], style(color=8));
          connect(El2BG1.BondCon1, B2.BondCon1) annotation (points=[-50,50; -40,
                50; -40,29.8],    style(color=8));
          connect(BG2El1.BondCon1, B3.BondCon2) annotation (points=[-50, -50; -
                40, -50; -40, -30], style(color=8));
          connect(B1.BondCon2, GY1.BondCon1) annotation (points=[-10, 0; -10, 0],
                   style(color=8));
          connect(B4.BondCon2, J1p3_2.BondCon3) annotation (points=[30,0; 30,
                -6.12303e-016],
                    style(color=8));
          connect(B5.BondCon2, J1p3_2.BondCon2) annotation (points=[40, 10; 40,
                  10], style(color=8));
          connect(J1p3_2.BondCon1, B6.BondCon1) annotation (points=[40, -10; 40,
                  -10.2], style(color=8));
          connect(El2BG2.BondCon1, B5.BondCon1) annotation (points=[50,50; 40,
                50; 40,29.8],  style(color=8));
          connect(BG2El2.BondCon1, B6.BondCon2) annotation (points=[50, -50; 40,
                  -50; 40, -30], style(color=8));
          connect(GY1.BondCon2, B4.BondCon1) annotation (points=[10, 0; 10.2, 0],
                   style(color=8));
          connect(El2BG1.p, p1) annotation (points=[-70,50; -100,50], style(
                color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n1) annotation (points=[-70,-50; -100,-50], style(
                color=3, rgbcolor={0,0,255}));
          connect(El2BG2.p, p2) annotation (points=[70,50; 100,50], style(color=
                 3, rgbcolor={0,0,255}));
          connect(BG2El2.n, n2) annotation (points=[70,-50; 100,-50], style(
                color=3, rgbcolor={0,0,255}));
        end IdealGyrator;
        
        model Idle "Open circuit of analog electrical library" 
          extends Interfaces.OnePort;
          annotation (
            Icon(
              Rectangle(extent=[-60, 60; 60, -60]),
              Line(points=[-90, 0; -40, 0]),
              Line(points=[89, 0; 40, 0]),
              Text(extent=[-100, 98; 100, 68], string="%name")),
            Diagram,
            Documentation(info="<html>
The open circuit element sets the current in the branch equal to zero.  This is accomplished using a flow source with zero flow.
</html>
"));
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, 12; 12, -12]);
          BondLib.Bonds.Bond B1 annotation (extent=[12, -12; 38, 12], rotation=
                180);
          BondLib.Bonds.Bond B2 annotation (extent=[-38, -12; -12, 12],
              rotation=180);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -14; -38, 14]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -14; 64, 14]);
          BondLib.Sources.Sf Sf1(f0=0) annotation (extent=[-12, 36; 12, 62],
              rotation=90);
          BondLib.Bonds.eBond B3 annotation (extent=[-12, 12; 12, 36], rotation=
               -90);
        equation 
          connect(BG2El1.BondCon1, B1.BondCon1) annotation (points=[38,
                1.77636e-015; 38,1.77636e-015; 38,-1.44014e-015; 37.74,
                -1.44014e-015], style(color=8));
          connect(J1p3_1.BondCon2, B1.BondCon2) annotation (points=[12,0; 12,
                1.46953e-015], style(color=8));
          connect(El2BG1.BondCon1, B2.BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                                 style(color=8));
          connect(J1p3_1.BondCon1, B2.BondCon1) annotation (points=[-12,0; -12,
                -7.20069e-016; -12,-1.44014e-015; -12.26,-1.44014e-015],
                                  style(color=8));
          connect(B3.fBondCon1, Sf1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36],
                              style(color=8));
          connect(B3.eBondCon1, J1p3_1.BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],   style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end Idle;
        
        model Short "Short circuit of analog electrical library" 
          extends Interfaces.OnePort;
          annotation (
            Icon(
              Rectangle(extent=[-60, 60; 60, -60]),
              Line(points=[91, 0; -90, 0]),
              Text(extent=[-100, 98; 100, 68], string="%name")),
            Diagram,
            Documentation(info="<html>
The closed circuit element sets the voltage in the branch equal to zero.  This is accomplished using an effort source with zero effort.
</html>
"));
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, 12; 12, -12]);
          BondLib.Bonds.Bond B1 annotation (extent=[12, -12; 38, 12], rotation=
                180);
          BondLib.Bonds.Bond B2 annotation (extent=[-38, -12; -12, 12],
              rotation=180);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -14; -38, 14]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -14; 64, 14]);
          BondLib.Sources.Se Se1(e0=0) annotation (extent=[-14, 36; 14, 64],
              rotation=90);
          BondLib.Bonds.fBond B3 annotation (extent=[-12, 12; 12, 36], rotation=
               -90);
        equation 
          connect(BG2El1.BondCon1, B1.BondCon1) annotation (points=[38,
                1.77636e-015; 38,1.77636e-015; 38,-1.44014e-015; 37.74,
                -1.44014e-015],
                    style(color=8));
          connect(J1p3_1.BondCon2, B1.BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(El2BG1.BondCon1, B2.BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1, B2.BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(B3.eBondCon1, Se1.BondCon1) annotation (points=[-7.34764e-016,
                36; 9.19132e-016,36],
                              style(color=8));
          connect(B3.fBondCon1, J1p3_1.BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],   style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 81,
                1.77636e-015; 81,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end Short;
        
        model IdealOpeningSwitch 
          "Ideal leaking switch of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Resistance Ron(final min=0) = 1.E-5 
            "Closed switch resistance";
          parameter Modelica.SIunits.Conductance Goff(final min=0) = 1.E-5 
            "Opened switch conductance";
        public 
          Modelica.Blocks.Interfaces.BooleanInput control(start=false) 
            "true/false opened/closed switch"                     annotation (
              extent=[-10, 80; 10, 100], rotation=-90);
          annotation (
            Diagram,
            Icon(
              Ellipse(extent=[-44, 4; -36, -4]),
              Line(points=[-90, 0; -44, 0]),
              Line(points=[-37, 2; 40, 50]),
              Line(points=[40, 0; 90, 0]),
              Text(extent=[-100, -48; 100, -78], string="%name"),
              Line(points=[0, 80; 0, 26], style(color=83)),
              Line(points=[40,0; 40,20], style(color=3, rgbcolor={0,0,255}))),
            Documentation(info="<html>
The ideal leaking electrical opening switch is built in bondgraphic technology from a bond graph <b>Sw2</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the switch in its environment.  A leaking switch has been used to ensure that the switch will not lead to a division by zero in either switch position, irrespective of the circuit topology. <p>

The logic is such that the switch is considered <b>open</b>, when the Boolean control signal assumes a value of <b>true</b>. <p>

<hr>

<pre>
Parameters:

 Ron:    Leakage resistance in <b>on</b> state (default value = 1e-5 Ohm)

 Goff:   Leakage conductance in <b>off</b> state (default value = 1e-5 Mho)
</pre>
</html>
"));
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, 12; 12, -12]);
          BondLib.Bonds.Bond B1 annotation (extent=[-38, -12; -12, 12]);
          BondLib.Bonds.Bond B2 annotation (extent=[12, -12; 38, 12]);
          BondLib.Bonds.Bond B3 annotation (extent=[-12, 12; 12, 36], rotation=
                90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -14; -38, 14]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -14; 64, 14]);
          BondLib.Switches.Sw2 Sw1(Ron=Ron, Goff=Goff) annotation (extent=[-14,
                  36; 14, 66], rotation=90);
        equation 
          connect(B1.BondCon2, J1p3_1.BondCon1) annotation (points=[-12, 0; -12,
                  0], style(color=8));
          connect(J1p3_1.BondCon2, B2.BondCon1) annotation (points=[12, 0;
                12.26, 0], style(color=8));
          connect(B3.BondCon1, J1p3_1.BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(El2BG1.BondCon1, B1.BondCon1) annotation (points=[-38,
                1.77636e-015; -38,1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2, BG2El1.BondCon1) annotation (points=[38,0; 38,
                1.77636e-015],
                    style(color=8));
          connect(Sw1.BondCon1, B3.BondCon2) annotation (points=[9.19132e-016,
                36; 7.34764e-016,36],
                style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -82,
                1.77636e-015; -82,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
          connect(Sw1.BooleanInPort1, control) annotation (points=[2.54786e-015,
                64.5; 2.54786e-015,73.25; 0,73.25; 0,90], style(color=5,
                rgbcolor={255,0,255}));
        end IdealOpeningSwitch;
        
        model IdealClosingSwitch 
          "Ideal leaking switch of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Resistance Ron(final min=0) = 1.E-5 
            "Closed switch resistance";
          parameter Modelica.SIunits.Conductance Goff(final min=0) = 1.E-5 
            "Opened switch conductance";
        public 
          Modelica.Blocks.Interfaces.BooleanInput control(start=false) 
            "true/false opened/closed switch"                     annotation (
              extent=[-10, 80; 10, 100], rotation=-90);
          annotation (
            Diagram,
            Icon(
              Ellipse(extent=[-44, 4; -36, -4]),
              Line(points=[-90, 0; -44, 0]),
              Line(points=[-37, 2; 40, 50]),
              Line(points=[40, 0; 90, 0]),
              Text(extent=[-100, -48; 100, -78], string="%name"),
              Line(points=[0, 80; 0, 26], style(color=83))),
            Documentation(info="<html>
The ideal leaking electrical closing switch is built in bondgraphic technology from a bond graph <b>Sw2</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the switch in its environment.  A leaking switch has been used to ensure that the switch will not lead to a division by zero in either switch position, irrespective of the circuit topology. <p>

The logic is such that the switch is considered <b>closed</b>, when the Boolean control signal assumes a value of <b>true</b>. <p>

<hr>

<pre>
Parameters:

 Ron:    Leakage resistance in <b>on</b> state (default value = 1e-5 Ohm)

 Goff:   Leakage conductance in <b>off</b> state (default value = 1e-5 Mho)
</pre>
</html>
"));
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12,-8; 12,-32]);
          BondLib.Bonds.Bond B1 annotation (extent=[-38,-32; -12,-8]);
          BondLib.Bonds.Bond B2 annotation (extent=[12,-32; 38,-8]);
          BondLib.Bonds.Bond B3 annotation (extent=[-12,-8; 12,16],   rotation=
                90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=[
                -62,-34; -38,-6]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=[38,
                -34; 64,-6]);
          BondLib.Switches.Sw2 Sw1(Ron=Ron, Goff=Goff) annotation (extent=[-14,
                16; 14,46],    rotation=90);
          Modelica.Blocks.Logical.Not Not1 
            annotation (extent=[-10,50; 10,70], rotation=-90);
        equation 
          connect(B1.BondCon2, J1p3_1.BondCon1) annotation (points=[-12,-20;
                -12,-20],
                      style(color=8));
          connect(J1p3_1.BondCon2, B2.BondCon1) annotation (points=[12,-20;
                12.26,-20],style(color=8));
          connect(B3.BondCon1, J1p3_1.BondCon3) annotation (points=[
                -7.20069e-016,-7.76; -7.20069e-016,12.12; 0,12.12; 0,-8],
                       style(color=8));
          connect(El2BG1.BondCon1, B1.BondCon1) annotation (points=[-38,-20;
                -37.74,-20],
                      style(color=8));
          connect(B2.BondCon2, BG2El1.BondCon1) annotation (points=[38,-20; 38,
                -20],
                    style(color=8));
          connect(Sw1.BondCon1, B3.BondCon2) annotation (points=[9.19132e-016,
                16; 7.34764e-016,16],
                style(color=8));
          connect(Sw1.BooleanInPort1, Not1.y) annotation (points=[2.54786e-015,
                44.5; 2.54786e-015,47.25; 6.73533e-016,47.25; 6.73533e-016,49],
              style(color=5, rgbcolor={255,0,255}));
          connect(Not1.u, control) annotation (points=[-7.34764e-016,72; 0,72; 
                0,90], style(color=5, rgbcolor={255,0,255}));
          connect(El2BG1.p, p) annotation (points=[-62,-20; -80,-20; -80,0;
                -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,-20; 80,-20; 80,0; 100,0],
              style(color=3, rgbcolor={0,0,255}));
        end IdealClosingSwitch;
        
        model ControlledIdealOpeningSwitch 
          "Controlled ideal leaking switch of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Voltage level=0.5 "Switch level";
          parameter Modelica.SIunits.Resistance Ron(final min=0) = 1.E-5 
            "Closed switch resistance";
          parameter Modelica.SIunits.Conductance Goff(final min=0) = 1.E-5 
            "Opened switch conductance";
          Modelica.Electrical.Analog.Interfaces.PositivePin control 
            annotation (extent=[-10, 90; 10, 110]);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-10, 60; 10, 80], rotation=-90);
          annotation (
            Diagram,
            Icon(
              Ellipse(extent=[-44, 4; -36, -4]),
              Line(points=[-90, 0; -44, 0]),
              Line(points=[-37, 2; 40, 50]),
              Line(points=[40, 0; 90, 0]),
              Line(points=[0, 90; 0, 25]),
              Text(extent=[-100, -44; 100, -74], string="%name"),
              Line(points=[40,0; 40,20], style(color=3, rgbcolor={0,0,255}))),
            Documentation(info="<html>
The controlled ideal leaking opening electrical switch is built in bondgraphic technology from a bond graph <b>Sw2</b> element, a 1-junction, and three bonds.  In addition, an effort detector senses the potential of the control input.  If that signal is larger than a threshold, called <i>level</i>, the switch is open.  Otherwise, it is closed.  This element is an idealized version of a transistor switch. <p>

A-causal bonds must mostly be used here, because the causality depends on the embedding of the switch in its environment.  A leaking switch has been used to ensure that the switch will not lead to a division by zero in either switch position, irrespective of the circuit topology. <p>

<hr>

<pre>
Parameters:

 level:   Potential threshold for switch control (default value = 0.5 Volt)

 Ron:     Leakage resistance in <b>on</b> state (default value = 1e-5 Ohm)

 Goff:    Leakage conductance in <b>off</b> state (default value = 1e-5 Mho)
</pre>
</html>
"));
          BondLib.Bonds.fBond B4 annotation (extent=[-10, 40; 10, 60], rotation=
               -90);
          BondLib.Sensors.De De1 annotation (extent=[-10, 20; 10, 40], rotation=
               -90);
          BondLib.Bonds.Bond B1 annotation (extent=[-38, -92; -12, -68]);
          BondLib.Bonds.Bond B2 annotation (extent=[12, -92; 38, -68]);
          BondLib.Bonds.Bond B3 annotation (extent=[-12, -68; 12, -44],
              rotation=90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG2 annotation (extent=
                [-62, -94; -38, -66]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -94; 64, -66]);
          BondLib.Switches.Sw2 Sw1(Ron=Ron, Goff=Goff) annotation (extent=[-14,
                  -44; 14, -14], rotation=90);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, -68; 12, -92]);
          Modelica.Blocks.Logical.GreaterThreshold GreaterThreshold1(threshold=level) 
            annotation (extent=[-10,-10; 10,10], rotation=-90);
        equation 
          connect(El2BG1.BondCon1, B4.eBondCon1) annotation (points=[
                6.12303e-016,60; -6.12303e-016,60],
                     style(color=8));
          connect(B4.fBondCon1, De1.BondCon1) annotation (points=[6.12303e-016,
                40; -6.12303e-016,40],
                style(color=8));
          connect(Sw1.BondCon1, B3.BondCon2) annotation (points=[9.19132e-016,
                -44; 7.34764e-016,-44],  style(color=8));
          connect(J1p3_1.BondCon3, B3.BondCon1) annotation (points=[0,-68; 0,
                -67.88; 0,-67.76; -7.20069e-016,-67.76],
                         style(color=8));
          connect(B2.BondCon1, J1p3_1.BondCon2) annotation (points=[12.26,-80;
                12,-80],style(color=8));
          connect(B1.BondCon2, J1p3_1.BondCon1) annotation (points=[-12, -80; -
                12, -80], style(color=8));
          connect(El2BG2.BondCon1, B1.BondCon1) annotation (points=[-38,-80;
                -37.74,-80],
                          style(color=8));
          connect(B2.BondCon2, BG2El1.BondCon1) annotation (points=[38, -80; 38,
                  -80], style(color=8));
          connect(GreaterThreshold1.y, Sw1.BooleanInPort1) annotation (points=[
                6.73533e-016,-11; 6.73533e-016,-9.5; 2.54786e-015,-9.5; 
                2.54786e-015,-15.5], style(color=5, rgbcolor={255,0,255}));
          connect(De1.OutPort1, GreaterThreshold1.u) annotation (points=[
                6.73533e-016,19; 6.73533e-016,14.5; -7.34764e-016,14.5; 
                -7.34764e-016,12], style(color=74, rgbcolor={0,0,127}));
          connect(El2BG2.p, p) annotation (points=[-62,-80; -80,-80; -80,0;
                -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,-80; 80,-80; 80,0; 100,0],
              style(color=3, rgbcolor={0,0,255}));
          connect(El2BG1.p, control) annotation (points=[-6.12303e-016,80; 
                -6.12303e-016,88; 0,88; 0,100], style(color=3, rgbcolor={0,0,
                  255}));
        end ControlledIdealOpeningSwitch;
        
        model ControlledIdealClosingSwitch 
          "Controlled ideal leaking switch of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Voltage level=0.5 "Switch level";
          parameter Modelica.SIunits.Resistance Ron(final min=0) = 1.E-5 
            "Closed switch resistance";
          parameter Modelica.SIunits.Conductance Goff(final min=0) = 1.E-5 
            "Opened switch conductance";
          Modelica.Electrical.Analog.Interfaces.PositivePin control 
            annotation (extent=[-10, 90; 10, 110]);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-10, 60; 10, 80], rotation=-90);
          annotation (
            Diagram,
            Icon(
              Ellipse(extent=[-44, 4; -36, -4]),
              Line(points=[-90, 0; -44, 0]),
              Line(points=[-37, 2; 40, 50]),
              Line(points=[40, 0; 90, 0]),
              Line(points=[0, 90; 0, 25]),
              Text(extent=[-100, -44; 100, -74], string="%name")),
            Documentation(info="<html>
The controlled ideal leaking closing electrical switch is built in bondgraphic technology from a bond graph <b>Sw2</b> element, a 1-junction, and three bonds.  In addition, an effort detector senses the potential of the control input.  If that signal is smaller than a threshold, called <i>level</i>, the switch is open.  Otherwise, it is closed.  This element is an idealized version of a transistor switch. <p>

A-causal bonds must mostly be used here, because the causality depends on the embedding of the switch in its environment.  A leaking switch has been used to ensure that the switch will not lead to a division by zero in either switch position, irrespective of the circuit topology. <p>

<hr>

<pre>
Parameters:

 level:   Potential threshold for switch control (default value = 0.5 Volt)

 Ron:     Leakage resistance in <b>on</b> state (default value = 1e-5 Ohm)

 Goff:    Leakage conductance in <b>off</b> state (default value = 1e-5 Mho)
</pre>
</html>
"));
          BondLib.Bonds.fBond B4 annotation (extent=[-10, 40; 10, 60], rotation=
               -90);
          BondLib.Sensors.De De1 annotation (extent=[-10, 20; 10, 40], rotation=
               -90);
          Modelica.Blocks.Logical.LessThreshold LessThan1(    threshold=level) 
            annotation (extent=[-10, -8; 10, 12], rotation=-90);
          BondLib.Bonds.Bond B1 annotation (extent=[-38, -92; -12, -68]);
          BondLib.Bonds.Bond B2 annotation (extent=[12, -92; 38, -68]);
          BondLib.Bonds.Bond B3 annotation (extent=[-12, -68; 12, -44],
              rotation=90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG2 annotation (extent=
                [-62, -94; -38, -66]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -94; 64, -66]);
          BondLib.Switches.Sw2 Sw1(Ron=Ron, Goff=Goff) annotation (extent=[-14,
                  -44; 14, -14], rotation=90);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, -68; 12, -92]);
        equation 
          connect(El2BG1.BondCon1, B4.eBondCon1) annotation (points=[
                6.12303e-016,60; -6.12303e-016,60],
                     style(color=8));
          connect(B4.fBondCon1, De1.BondCon1) annotation (points=[6.12303e-016,
                40; -6.12303e-016,40],
                style(color=8));
          connect(De1.OutPort1,LessThan1.u)       annotation (points=[
                6.73533e-016,19; 6.73533e-016,17.75; -6.12308e-017,17.75; 
                -6.12308e-017,16.5; -7.34764e-016,16.5; -7.34764e-016,14],
                       style(color=3));
          connect(Sw1.BondCon1, B3.BondCon2) annotation (points=[9.19132e-016,
                -44; 7.34764e-016,-44],  style(color=8));
          connect(LessThan1.y,       Sw1.BooleanInPort1) annotation (points=[
                6.73533e-016,-9; 6.73533e-016,-10.625; 3.22139e-015,-10.625; 
                3.22139e-015,-12.25; 2.54786e-015,-12.25; 2.54786e-015,-15.5],
                                 style(color=5));
          connect(J1p3_1.BondCon3, B3.BondCon1) annotation (points=[0,-68; 0,
                -67.88; 0,-67.76; -7.20069e-016,-67.76],
                         style(color=8));
          connect(B2.BondCon1, J1p3_1.BondCon2) annotation (points=[12.26,-80;
                12,-80],style(color=8));
          connect(B1.BondCon2, J1p3_1.BondCon1) annotation (points=[-12, -80; -
                12, -80], style(color=8));
          connect(El2BG2.BondCon1, B1.BondCon1) annotation (points=[-38,-80;
                -37.74,-80],
                          style(color=8));
          connect(B2.BondCon2, BG2El1.BondCon1) annotation (points=[38, -80; 38,
                  -80], style(color=8));
          connect(El2BG2.p, p) annotation (points=[-62,-80; -80,-80; -80,0;
                -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,-80; 80,-80; 80,0; 100,0],
              style(color=3, rgbcolor={0,0,255}));
          connect(El2BG1.p, control) annotation (points=[-6.12303e-016,80; 0,80; 
                0,100], style(color=3, rgbcolor={0,0,255}));
        end ControlledIdealClosingSwitch;
      end Ideal;
      
      package Semiconductors 
        "Semiconductor models of the analog electrical library" 
        model Diode "Real diode of the analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Current Ids=1.e-6 "Saturation current";
          parameter Modelica.SIunits.Voltage Vt=0.04 
            "Thermal voltage equivalent of temperature (kT/qn)";
          parameter Real Maxexp(final min=Modelica.Constants.small) = 15 
            "Max. exponent for linear continuation";
          parameter Modelica.SIunits.Resistance R=1.e8 
            "Parallel Ohmic leakage resistance";
          annotation (
            Icon(
              Polygon(points=[30,0; -30,40; -30,-40; 30,0],     style(
                  color=3,
                  gradient=0,
                  fillColor=7)),
              Line(points=[-90,0; 40,0]),
              Line(points=[40,0; 90,0]),
              Line(points=[30,40; 30,-40],   style(color=3)),
              Text(extent=[-100,100; 100,70],   string="%name"),
              Text(
                extent=[-98,-58; 102,-100],
                string="Vt=%Vt",
                style(color=0))),
            Diagram,
            Documentation(info="<html>
The real electrical diode is built in bondgraphic technology from a bond graph <b>Dreal</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the diode in its environment. <p>

<hr>

<pre>
Parameters:

 Ids:     Saturation current (default value = 1e-6 Amp)

 Vt:      Thermal voltage (default value = 0.04 Volt)

 Maxexp:  Maximum exponent (default value = 15)

 R:       Parallel Ohmic leakage resistance (default value = 1e8 Ohm)
</pre>
</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[-38,-12; -12,12]);
          Bonds.Bond B2         annotation (extent=[12,-12; 38,12]);
          Bonds.Bond B3         annotation (extent=[-12,12; 12,36],   rotation=
                90);
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          BondLib.Semiconductors.Dreal D1(
            Ids=Ids,
            Vt=Vt,
            Maxexp=Maxexp,
            R=R) annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,0; -12,
                0],   style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,0; 12.26,
                0],        style(color=8));
          connect(B3.BondCon1,J1p3_1. BondCon3) annotation (points=[
                -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                       style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,
                1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,0; 38,
                1.77636e-015],
                    style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
          connect(B3.BondCon2, D1.BondCon1) annotation (points=[7.34764e-016,36; 
                -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
        end Diode;
        
        model NPN "NPN bipolar Ebers-Moll transistor" 
          parameter Real Bf=50 "Forward beta coefficient";
          parameter Real Br=0.1 "Reverse beta coefficient";
          parameter Modelica.SIunits.Current Is=1.e-16 
            "Transport saturation current";
          parameter Modelica.SIunits.InversePotential Vak=0.02 
            "Inverse early voltage";
          parameter Modelica.SIunits.Time Tauf=0.12e-9 
            "Ideal forward transit time";
          parameter Modelica.SIunits.Time Taur=5e-9 
            "Ideal reverse transit time";
          parameter Modelica.SIunits.Capacitance Ccs=1e-12 
            "Collector-substrate capacitance";
          parameter Modelica.SIunits.Capacitance Cje=0.4e-12 
            "Base-emitter zero bias depletion capacitance";
          parameter Modelica.SIunits.Capacitance Cjc=0.5e-12 
            "Base-collector zero bias depletion capacitance";
          parameter Modelica.SIunits.Voltage Phie=0.8 
            "Base-emitter diffusion voltage";
          parameter Real Me=0.4 "Base-emitter gradation exponent";
          parameter Modelica.SIunits.Voltage Phic=0.8 
            "Base-collector diffusion voltage";
          parameter Real Mc=0.333 "Base-collector gradation exponent";
          parameter Modelica.SIunits.Conductance Gbc=1e-15 
            "Base-collector leakage conductance";
          parameter Modelica.SIunits.Conductance Gbe=1e-15 
            "Base-emitter leakage conductance";
          parameter Modelica.SIunits.Voltage Vt=0.02585 "Thermal voltage";
          parameter Real EMin=-100 
            "if x < EMin, the exp(x) function is linearized";
          parameter Real EMax=40 
            "if x > EMax, the exp(x) function is linearized";
        public 
          Modelica.Electrical.Analog.Interfaces.Pin C "Collector" annotation (extent=[90,
                40; 110,60]);
          Modelica.Electrical.Analog.Interfaces.Pin B "Base" annotation (extent=[
                -90,-10; -110,10]);
          Modelica.Electrical.Analog.Interfaces.Pin E "Emitter" annotation (extent=[90,
                -40; 110,-60]);
          annotation (
            Icon(
              Text(extent=[-110,74; 94,100],    string="%name"),
              Line(points=[-10,40; -10,-40]),
              Line(points=[-10,0; -90,0]),
              Line(points=[91,50; 30,50]),
              Line(points=[30,50; -10,10]),
              Line(points=[-10,-10; 30,-50]),
              Line(points=[30,-50; 91,-50]),
              Polygon(points=[30,-50; 24,-36; 16,-44; 30,-50],     style(fillColor=3,
                      fillPattern=1))),
            Diagram(
              Ellipse(extent=[-42,2; -38,-2], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=3,
                  rgbfillColor={0,0,255})),
              Ellipse(extent=[-2,2; 2,-2], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=3,
                  rgbfillColor={0,0,255})),
              Ellipse(extent=[26,-84; 30,-88], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1)),
              Ellipse(extent=[-96,-32; -92,-36], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1)),
              Text(
                extent=[14,50; 28,42],
                string="ibc",
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1)),
              Text(
                extent=[-100,-24; -86,-32],
                string="ibc",
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1)),
              Text(
                extent=[86,14; 100,6],
                string="ibc",
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1)),
              Text(
                extent=[86,2; 100,-6],
                string="ibe",
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1)),
              Text(
                extent=[-88,-52; -74,-60],
                string="ibe",
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1)),
              Text(
                extent=[14,-30; 28,-38],
                string="ibe",
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1)),
              Text(
                extent=[-68,50; -54,42],
                string="vbc",
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1)),
              Text(
                extent=[70,-14; 84,-22],
                string="vbc",
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1)),
              Ellipse(extent=[-2,82; 2,78], style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1)),
              Ellipse(extent=[-2,-78; 2,-82], style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1)),
              Ellipse(extent=[38,52; 42,48], style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1)),
              Ellipse(extent=[38,-48; 42,-52], style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1))),
            Documentation(info="<html>
The NPN element of the analog electrical library built on bond graph technology implements the Ebers-Moll model of a NPN bipolar transistor.  The substrate is not shown on the icon layer, as it is assumed grounded. The transistor is assumed to be vertically diffused, as the substrate is connected to the collector, rather than to the base. <p>

<hr>

<pre>
Parameters:

 Bf:    Forward beta coefficient (default value = 50)

 Br:    Reverse beta coefficient (default value = 0.1)

 Is:    Transport saturation current (default value = 1e-16 Amp)

 Vak:   Inverse early voltage (default value = 0.02 /Volt)

 Tauf:  Ideal forward transit time (default value = 0.12e-9 sec)

 Taur:  Ideal reverse transit time (default value = 5e-9 sec)

 Ccs:   Collector-substrate capacitance (default value = 1e-12 F)

 Cje:   Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 Cjc:   Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 Phie:  Base-emitter diffusion voltage (default value = 0.8 Volt)

 Me:    Base-emitter gradation exponent (default value = 0.4)

 Phic:  Base-collector diffusion voltage (default value = 0.8 Volt)

 Mc:    Base-collector gradation exponent (default value = 0.333)

 Gbc:   Base-collector leakage conductance (default value = 1e-15 Mho)

 Gbe:   Base-emitter leakage conductance (default value = 1e-15 Mho)

 Vt:    Thermal voltage (default value = 0.02585 Volt)

 EMin:  Minimum exponent (default value = -100)

 EMax:  Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

References: <p>

Vlach, J. and K. Singal (1983), <I>Computer methods for circuit analysis and design</I>, Van Nostrand Reinhold, New York,
on page 317 ff.
</html>
"));
          Utilities.JunctionCapacitor Cbc(
            Is=Is,
            Tau=Taur,
            Cj=Cjc,
            Phi=Phic,
            M=Mc,
            Gb=Gbc,
            Vt=Vt,
            EMin=EMin,
            EMax=EMax) annotation (extent=[-20,60; 20,20], rotation=-90);
          Utilities.JunctionCapacitor Cbe(
            Is=Is,
            Vt=Vt,
            EMin=EMin,
            EMax=EMax,
            Tau=Tauf,
            Cj=Cje,
            Phi=Phie,
            M=Me,
            Gb=Gbe) annotation (extent=[-20,-60; 20,-20], rotation=-90);
          Sensors.VoltageSensor Vbc 
            annotation (extent=[-60,60; -20,20], rotation=-90);
          Sources.SignalCurrent IB0 
            annotation (extent=[-20,-60; -60,-20], rotation=-90);
          Sources.SignalCurrent IC0 
            annotation (extent=[20,-20; 60,20], rotation=-90);
          BondLib.Semiconductors.Utilities.IC0 IC0_1(
            Bf=Bf,
            Br=Br,
            Vak=Vak) annotation (extent=[80,-10; 60,10]);
          BondLib.Semiconductors.Utilities.IB0 IB0_1(Bf=Bf, Br=Br) 
            annotation (extent=[-80,-50; -60,-30]);
          BondLib.Electrical.Analog.Basic.Capacitor Ccs1(C=Ccs) 
            annotation (extent=[40,66; 68,94]);
          BondLib.Electrical.Analog.Basic.Ground Gnd1 
            annotation (extent=[74,70; 94,90], rotation=90);
        equation 
          connect(IC0_1.y, IC0.InPort1) annotation (points=[59,0; 58.5,0; 58.5,
                7.34764e-016; 52,7.34764e-016], style(color=74, rgbcolor={0,0,
                  127}));
          connect(IB0_1.y, IB0.InPort1) annotation (points=[-59,-40; -52,-40],
              style(color=74, rgbcolor={0,0,127}));
          connect(Ccs1.n, Gnd1.p)    annotation (points=[68,80; 74,80], style(
                color=3, rgbcolor={0,0,255}));
          connect(IC0.p, Ccs1.p) annotation (points=[40,20; 40,80],
              style(color=3, rgbcolor={0,0,255}));
          connect(IB0.p, B) annotation (points=[-40,-20; -40,0; -100,0], style(
                color=3, rgbcolor={0,0,255}));
          connect(IC0.p, C) annotation (points=[40,20; 40,50; 100,50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(IB0.n, Cbe.n) annotation (points=[-40,-60; -40,-80; 
                1.22461e-015,-80; 1.22461e-015,-60], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(IC0.n, Cbe.n) annotation (points=[40,-20; 40,-80; 
                1.22461e-015,-80; 1.22461e-015,-60], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(IC0.n, E) annotation (points=[40,-20; 40,-50; 100,-50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(IB0_1.u2, IC0_1.u2) annotation (points=[-82,-46; -88,-46; -88,
                -86; 110,-86; 110,-6; 82,-6], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(IB0_1.u1, IC0_1.u1) annotation (points=[-82,-34; -94,-34; -94,
                -92; 116,-92; 116,6; 82,6], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Cbc.y, IB0_1.u1) annotation (points=[20,40; 28,40; 28,88;
                -110,88; -110,-34; -82,-34], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Cbe.y, IB0_1.u2) annotation (points=[20,-40; 28,-40; 28,-86;
                -88,-86; -88,-46; -82,-46], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Vbc.V, IC0_1.u3) annotation (points=[-60,40; -116,40; -116,
                -98; 70,-98; 70,-10], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=74,
              rgbfillColor={0,0,156},
              fillPattern=1));
          connect(Vbc.p, B) annotation (points=[-40,20; -40,0; -100,0], style(
                color=3, rgbcolor={0,0,255}));
          connect(Vbc.n, Ccs1.p) annotation (points=[-40,60; -40,80; 40,80],
              style(color=3, rgbcolor={0,0,255}));
          connect(Cbe.p, B) annotation (points=[-1.22461e-015,-20; 
                -1.22461e-015,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(Cbc.p, B) annotation (points=[-1.22461e-015,20; 0,20; 0,0; 
                -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(Cbc.n, Ccs1.p) annotation (points=[1.22461e-015,60; 
                1.22461e-015,80; 40,80], style(color=3, rgbcolor={0,0,255}));
        end NPN;
        
        model PNP "PNP bipolar Ebers-Moll transistor" 
          parameter Real Bf=50 "Forward beta coefficient";
          parameter Real Br=0.1 "Reverse beta coefficient";
          parameter Modelica.SIunits.Current Is=1.e-16 
            "Transport saturation current";
          parameter Modelica.SIunits.InversePotential Vak=0.02 
            "Inverse early voltage";
          parameter Modelica.SIunits.Time Tauf=0.12e-9 
            "Ideal forward transit time";
          parameter Modelica.SIunits.Time Taur=5e-9 
            "Ideal reverse transit time";
          parameter Modelica.SIunits.Capacitance Ccs=1e-12 
            "Collector-substrate capacitance";
          parameter Modelica.SIunits.Capacitance Cje=0.4e-12 
            "Base-emitter zero bias depletion capacitance";
          parameter Modelica.SIunits.Capacitance Cjc=0.5e-12 
            "Base-collector zero bias depletion capacitance";
          parameter Modelica.SIunits.Voltage Phie=0.8 
            "Base-emitter diffusion voltage";
          parameter Real Me=0.4 "Base-emitter gradation exponent";
          parameter Modelica.SIunits.Voltage Phic=0.8 
            "Base-collector diffusion voltage";
          parameter Real Mc=0.333 "Base-collector gradation exponent";
          parameter Modelica.SIunits.Conductance Gbc=1e-15 
            "Base-collector leakage conductance";
          parameter Modelica.SIunits.Conductance Gbe=1e-15 
            "Base-emitter leakage conductance";
          parameter Modelica.SIunits.Voltage Vt=0.02585 "Thermal voltage";
          parameter Real EMin=-100 
            "if x < EMin, the exp(x) function is linearized";
          parameter Real EMax=40 
            "if x > EMax, the exp(x) function is linearized";
        public 
          Modelica.Electrical.Analog.Interfaces.Pin C "Collector" annotation (extent=[90,
                40; 110,60]);
          Modelica.Electrical.Analog.Interfaces.Pin B "Base" annotation (extent=[
                -90,-10; -110,10]);
          Modelica.Electrical.Analog.Interfaces.Pin E "Emitter" annotation (extent=[90,
                -40; 110,-60]);
          annotation (
            Icon(
              Text(extent=[-114,76; 100,100],   string="%name"),
              Line(points=[-10,40; -10,-40]),
              Line(points=[-10,0; -90,0]),
              Line(points=[91,50; 30,50]),
              Line(points=[30,50; -10,10]),
              Line(points=[-10,-10; 30,-50]),
              Line(points=[30,-50; 91,-50]),
              Polygon(points=[-10,-10; 5,-17; -3,-25; -10,-10],     style(fillColor=
                      3, fillPattern=1))),
            Diagram(
              Ellipse(extent=[-42,2; -38,-2], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=3,
                  rgbfillColor={0,0,255})),
              Ellipse(extent=[-2,2; 2,-2], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=3,
                  rgbfillColor={0,0,255})),
              Ellipse(extent=[26,-84; 30,-88], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1)),
              Ellipse(extent=[-96,-32; -92,-36], style(
                  color=3,
                  rgbcolor={0,0,255},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1)),
              Text(
                extent=[14,50; 28,42],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1),
                string="icb"),
              Text(
                extent=[-100,-24; -86,-32],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1),
                string="icb"),
              Text(
                extent=[86,14; 100,6],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1),
                string="icb"),
              Text(
                extent=[86,2; 100,-6],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1),
                string="ieb"),
              Text(
                extent=[-88,-52; -74,-60],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1),
                string="ieb"),
              Text(
                extent=[14,-30; 28,-38],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1),
                string="ieb"),
              Text(
                extent=[-68,50; -54,42],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1),
                string="vcb"),
              Text(
                extent=[70,-14; 84,-22],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=74,
                  rgbfillColor={0,0,156},
                  fillPattern=1),
                string="vcb"),
              Ellipse(extent=[-2,82; 2,78], style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1)),
              Ellipse(extent=[-2,-78; 2,-82], style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1)),
              Ellipse(extent=[38,52; 42,48], style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1)),
              Ellipse(extent=[38,-48; 42,-52], style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1))),
            Documentation(info="<html>
The PNP element of the analog electrical library built on bond graph technology implements the Ebers-Moll model of a PNP bipolar transistor.  The substrate is not shown on the icon layer, as it is assumed grounded. The transistor is assumed to be vertically diffused, as the substrate is connected to the collector, rather than to the base. <p>

<hr>

<pre>
Parameters:

 Bf:    Forward beta coefficient (default value = 50)

 Br:    Reverse beta coefficient (default value = 0.1)

 Is:    Transport saturation current (default value = 1e-16 Amp)

 Vak:   Inverse early voltage (default value = 0.02 /Volt)

 Tauf:  Ideal forward transit time (default value = 0.12e-9 sec)

 Taur:  Ideal reverse transit time (default value = 5e-9 sec)

 Ccs:   Collector-substrate capacitance (default value = 1e-12 F)

 Cje:   Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 Cjc:   Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 Phie:  Base-emitter diffusion voltage (default value = 0.8 Volt)

 Me:    Base-emitter gradation exponent (default value = 0.4)

 Phic:  Base-collector diffusion voltage (default value = 0.8 Volt)

 Mc:    Base-collector gradation exponent (default value = 0.333)

 Gbc:   Base-collector leakage conductance (default value = 1e-15 Mho)

 Gbe:   Base-emitter leakage conductance (default value = 1e-15 Mho)

 Vt:    Thermal voltage (default value = 0.02585 Volt)

 EMin:  Minimum exponent (default value = -100)

 EMax:  Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

References: <p>

Vlach, J. and K. Singal (1983), <I>Computer methods for circuit analysis and design</I>, Van Nostrand Reinhold, New York,
on page 317 ff.
</html>
"));
          Utilities.JunctionCapacitor Ccb(
            Is=Is,
            Tau=Taur,
            Cj=Cjc,
            Phi=Phic,
            M=Mc,
            Gb=Gbc,
            Vt=Vt,
            EMin=EMin,
            EMax=EMax) annotation (extent=[-20,20; 20,60], rotation=-90);
          Utilities.JunctionCapacitor Ceb(
            Is=Is,
            Vt=Vt,
            EMin=EMin,
            EMax=EMax,
            Tau=Tauf,
            Cj=Cje,
            Phi=Phie,
            M=Me,
            Gb=Gbe) annotation (extent=[-20,-20; 20,-60], rotation=-90);
          Sensors.VoltageSensor Vcb 
            annotation (extent=[-60,20; -20,60], rotation=-90);
          Sources.SignalCurrent IB0 
            annotation (extent=[-20,-20; -60,-60], rotation=-90);
          Sources.SignalCurrent IC0 
            annotation (extent=[20,20; 60,-20], rotation=-90);
          BondLib.Semiconductors.Utilities.IC0 IC0_1(
            Bf=Bf,
            Br=Br,
            Vak=Vak) annotation (extent=[80,-10; 60,10]);
          BondLib.Semiconductors.Utilities.IB0 IB0_1(Bf=Bf, Br=Br) 
            annotation (extent=[-80,-50; -60,-30]);
          BondLib.Electrical.Analog.Basic.Capacitor Ccs1(C=Ccs) 
            annotation (extent=[40,66; 68,94]);
          BondLib.Electrical.Analog.Basic.Ground Gnd1 
            annotation (extent=[74,70; 94,90], rotation=90);
        equation 
          connect(IC0_1.y,IC0. InPort1) annotation (points=[59,0; 55.5,0; 55.5,
                -7.34764e-016; 52,-7.34764e-016],
                                                style(color=74, rgbcolor={0,0,
                  127}));
          connect(IB0_1.y,IB0. InPort1) annotation (points=[-59,-40; -52,-40],
              style(color=74, rgbcolor={0,0,127}));
          connect(Ccs1.n,Gnd1. p)    annotation (points=[68,80; 74,80], style(
                color=3, rgbcolor={0,0,255}));
          connect(IB0_1.u2,IC0_1. u2) annotation (points=[-82,-46; -88,-46; -88,
                -86; 110,-86; 110,-6; 82,-6], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(IB0_1.u1,IC0_1. u1) annotation (points=[-82,-34; -94,-34; -94,
                -92; 116,-92; 116,6; 82,6], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Ccb.y,IB0_1. u1) annotation (points=[20,40; 28,40; 28,88;
                -110,88; -110,-34; -82,-34], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Ceb.y,IB0_1. u2) annotation (points=[20,-40; 28,-40; 28,-86;
                -88,-86; -88,-46; -82,-46], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Vcb.V,IC0_1. u3) annotation (points=[-60,40; -116,40; -116,
                -98; 70,-98; 70,-10], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=74,
              rgbfillColor={0,0,156},
              fillPattern=1));
          connect(IC0.n, Ccs1.p) annotation (points=[40,20; 40,80], style(color=
                 3, rgbcolor={0,0,255}));
          connect(IC0.n, C) annotation (points=[40,20; 40,50; 100,50], style(
                color=3, rgbcolor={0,0,255}));
          connect(IC0.p, E) annotation (points=[40,-20; 40,-50; 100,-50], style(
                color=3, rgbcolor={0,0,255}));
          connect(IB0.n, B) annotation (points=[-40,-20; -40,0; -100,0], style(
                color=3, rgbcolor={0,0,255}));
          connect(IB0.p, Ceb.p) annotation (points=[-40,-60; -40,-80; 
                -1.22461e-015,-80; -1.22461e-015,-60], style(color=3, rgbcolor=
                  {0,0,255}));
          connect(Ccb.p, Ccs1.p) annotation (points=[-1.22461e-015,60; 0,60; 0,
                80; 40,80], style(color=3, rgbcolor={0,0,255}));
          connect(Ccb.n, B) annotation (points=[1.22461e-015,20; 1.22461e-015,0; 
                -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(Vcb.n, B) annotation (points=[-40,20; -40,0; -100,0], style(
                color=3, rgbcolor={0,0,255}));
          connect(Vcb.p, Ccs1.p) annotation (points=[-40,60; -40,80; 40,80],
              style(color=3, rgbcolor={0,0,255}));
          connect(Ceb.n, B) annotation (points=[1.22461e-015,-20; 1.22461e-015,
                0; -100,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Ceb.p, IC0.p) annotation (points=[-1.22461e-015,-60; 0,-60; 0,
                -80; 40,-80; 40,-20], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
        end PNP;
        
        model HeatingDiode 
          "Real heating diode of the analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Current Ids=1.e-6 "Saturation current";
          parameter Real EG=1.11 "activation energy";
          parameter Real N=1 "Emission coefficient";
          parameter Modelica.SIunits.Temperature TNOM=300.15 
            "Nominal temperature";
          parameter Real XTI=3 "Temperature exponent of saturation current";
          parameter Real Maxexp(final min=Modelica.Constants.small) = 15 
            "Max. exponent for linear continuation";
          parameter Modelica.SIunits.Resistance R=1.e8 
            "Parallel Ohmic resistance";
          Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort(T(start=
                  300.15)) 
            annotation (extent=[-10,-90; 10,-110],   rotation=-90);
          annotation (
            Icon(
              Polygon(points=[30,0; -30,40; -30,-40; 30,0],     style(
                  color=3,
                  gradient=0,
                  fillColor=1,
                  fillPattern=0)),
              Line(points=[30,40; 30,-40],   style(color=3)),
              Line(points=[0,-20; 0,-91],   style(color=42)),
              Line(points=[-90,0; 90,0], style(color=3, rgbcolor={0,0,255})),
              Text(extent=[-140,109; 145,59],   string="%name")),
            Diagram,
            Documentation(info="<html>
The real electrical heating diode is built in bondgraphic technology from a bond graph <b>DSreal</b> element.  A-causal bonds must be used here, because the causality depends on the embedding of the diode in its environment. <p>

<hr>

<pre>
Parameters:

 Ids:     Saturation current (default value = 1e-6 Amp)

 Maxexp:  Maximum exponent (default value = 15)

 R:       Parallel Ohmic leakage resistance (default value = 1e8 Ohm)

 EG:      Activation energy (default value = 1.11 J)

 N:       Emission coefficient (default value = 1)

 TNOM:    Nominal temperature (default value = 300.15 K)

 XTI:     Temperature exponent of saturation current (default value = 3)
</pre>
</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,28; 12,52]);
          Bonds.Bond B1         annotation (extent=[-38,28; -12,52]);
          Bonds.Bond B2         annotation (extent=[12,28; 38,52]);
          Bonds.Bond B3         annotation (extent=[-12,4; 12,28],    rotation=
                270);
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,26; -38,54]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                26; 64,54]);
          Thermal.DSreal D1(
            Ids=Ids,
            EG=EG,
            N=N,
            TNOM=TNOM,
            XTI=XTI,
            Maxexp=Maxexp,
            R=R) annotation (extent=[-12,-20; 12,4], rotation=-90);
          Interfaces.BG2Heat BG2Heat1 
            annotation (extent=[-12,-68; 12,-44], rotation=-90);
          Bonds.eBond B4 annotation (extent=[-12,-44; 12,-20], rotation=-90);
        equation 
          assert( heatPort.T > 0,"temperature must be positive");
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,40; -12,
                40],  style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,40;
                12.26,40], style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,40;
                -37.74,40],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,40; 38,
                40],style(color=8));
          connect(BG2Heat1.port_b, heatPort) annotation (points=[7.34764e-016,
                -68; 7.34764e-016,-80; 0,-78; 0,-100], style(color=42, rgbcolor=
                 {191,0,0}));
          connect(El2BG1.p, p) annotation (points=[-62,40; -80,40; -80,0; -100,
                0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,40; 80,40; 80,0; 100,0],
              style(color=3, rgbcolor={0,0,255}));
          connect(D1.BondCon2, B4.fBondCon1) annotation (points=[7.34764e-016,
                -20; 7.34764e-016,-24; 0,-20; -7.34764e-016,-20],
              style(color=8, rgbcolor={192,192,192}));
          connect(B4.eBondCon1, BG2Heat1.BondCon1) annotation (points=[
                7.34764e-016,-44; -7.34764e-016,-44], style(color=8, rgbcolor={
                  192,192,192}));
          connect(J1p3_1.BondCon3, B3.BondCon1) annotation (points=[0,28; 0,
                27.76; 2.16021e-015,27.76], style(color=8, rgbcolor={192,192,
                  192}));
          connect(B3.BondCon2, D1.BondCon1) annotation (points=[-2.20429e-015,4; 
                -7.34764e-016,4], style(color=8, rgbcolor={192,192,192}));
        end HeatingDiode;
        
        package Utilities 
          "Utilities for semiconductor models of analog electrical library" 
          annotation (Icon(
              Rectangle(extent=[-100,-100; 80,50], style(
                  color=42,
                  rgbcolor={127,0,0},
                  fillColor=30,
                  rgbfillColor={235,235,235},
                  fillPattern=1)),
              Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50], style(
                  color=42,
                  rgbcolor={127,0,0},
                  fillColor=30,
                  rgbfillColor={235,235,235},
                  fillPattern=1)),
              Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70], style(
                  color=42,
                  rgbcolor={127,0,0},
                  fillColor=30,
                  rgbfillColor={235,235,235},
                  fillPattern=1)),
              Text(
                extent=[-85,35; 65,-85],
                string="Library",
                style(color=42, rgbcolor={127,0,0})),
              Text(
                extent=[-120,122; 120,73],
                string="%name",
                style(color=1))), Documentation(info="<html>
This package contains some utility models used inside some of the semiconductor models of the analog electrical library built from bond graph technology.
</html>
"));
          model VariableCapacitor2 "Modulated linear electrical capacitor" 
            extends Interfaces.ModOnePort;
            annotation (
              Icon(
                Line(points=[-90,0; -14,0]),
                Line(points=[14,0; 90,0]),
                Line(points=[0,80; 0,28],   style(color=73)),
                Line(points=[-14,28; -14,-28],   style(thickness=2)),
                Line(points=[14,28; 14,-28],   style(thickness=2)),
                Text(extent=[-134,-96; 136,-36],    string="%name")),
              Diagram,
              Documentation(info="<html>
This modulated capacitor is built in bondgraphic technology from a bond graph <b>mC2</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the capacitor in its environment. <p>

It is not recommended to use this model.  The regular <b>VariableCapacitor</b> model should be used always.  For this reason, this model has been hidden inside the Utilities package.  However, since the Ebers-Moll bipolar transistor models make use of this model, it had to be constructed. <p>

<hr>

<pre>
Potential variables:

 C:  Capacitance (modulation input signal)
</pre>
</html>
"));
            Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
            Bonds.Bond B1         annotation (extent=[-38,-12; -12,12]);
            Bonds.Bond B2         annotation (extent=[12,-12; 38,12]);
            Bonds.Bond B3         annotation (extent=[-12,12; 12,36],   rotation=
                  90);
            Interfaces.El2BG El2BG1                           annotation (extent=[
                  -62,-14; -38,14]);
            Interfaces.BG2El BG2El1                           annotation (extent=[38,
                  -14; 64,14]);
            BondLib.Semiconductors.Utilities.mC2 mC1 
              annotation (extent=[-12,36; 12,60], rotation=90);
          equation 
            connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,0;
                  -12,0],                style(color=8));
            connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,0;
                  12.26,0],  style(color=8));
            connect(B3.BondCon1,J1p3_1. BondCon3) annotation (points=[
                  -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                         style(color=8));
            connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,
                  1.77636e-015; -38,0; -37.74,0],
                        style(color=8));
            connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,0; 38,
                  1.77636e-015], style(color=8));
            connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                  1.77636e-015; -79,0; -100,0], style(color=3, rgbcolor={0,0,
                    255}));
            connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                  1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
            connect(B3.BondCon2, mC1.BondCon1) annotation (points=[7.34764e-016,
                  36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
            connect(u, mC1.InPort1) annotation (points=[0,90; 0,58.8; 
                  6.61287e-016,58.8], style(color=74, rgbcolor={0,0,127}));
          end VariableCapacitor2;
          
          model JunctionDiode "Junction diode of the analog electrical library" 
            extends Interfaces.OnePort;
            parameter Modelica.SIunits.Current Is=1.e-16 
              "Transport saturation current";
            parameter Modelica.SIunits.Voltage Vt=0.02585 
              "Voltage equivalent of temperature (kT/qn)";
            parameter Real EMin=-100 
              "if x < EMin, the exp(x) function is linearized";
            parameter Real EMax=40 
              "if x > EMax, the exp(x) function is linearized";
            annotation (
              Icon(
                Polygon(points=[30,0; -30,40; -30,-40; 30,0],     style(
                    color=3,
                    gradient=0,
                    fillColor=7)),
                Line(points=[-90,0; -30,0]),
                Line(points=[30,0; 90,0]),
                Line(points=[30,40; 30,-40],   style(color=3)),
                Text(extent=[-100,100; 100,70],   string="%name"),
                Text(
                  extent=[-24,12; 8,-16],
                  string="J",
                  style(color=3, rgbcolor={0,0,255}))),
              Diagram,
              Documentation(info="<html>
The junction diode is built in bondgraphic technology from a bond graph <b>Dj</b> element, a 1-junction, and three bonds.  A-causal bonds must be used here, because the causality depends on the embedding of the diode in its environment. <p>

The junction diode model is a simple diode with an exponential characteristic. The diode formula essentially is: <p>

<b>f = Is*(exp(e/Vt) - 1)</b> <p>

However, if the exponent <b>e/Vt</b> reaches either an upper limit <b>EMax</b> or a lower limit <b>Emin</b>, the diode characterisic is linearly continued to avoid overflow or underflow, respectively. <p>

<hr>

<pre>
Parameters:

 Is:    Transport saturation current (default value = 1e-16 Amp)

 Vt:    Thermal voltage (default value = 0.02585 Volt)

 EMin:  Minimum exponent (default value = -100)

 EMax:  Maximum exponent (default value = 40)
</pre>
</html>
"));
            Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
            Bonds.Bond B1         annotation (extent=[-38,-12; -12,12]);
            Bonds.Bond B2         annotation (extent=[12,-12; 38,12]);
            Bonds.Bond B3         annotation (extent=[-12,12; 12,36],   rotation=
                  90);
            Interfaces.El2BG El2BG1                           annotation (extent=[
                  -62,-14; -38,14]);
            Interfaces.BG2El BG2El1                           annotation (extent=[38,
                  -14; 64,14]);
            BondLib.Semiconductors.Utilities.Dj D1(
              Is=Is,
              Vt=Vt,
              EMin=EMin,
              EMax=EMax) annotation (extent=[-12,36; 12,60], rotation=90);
          equation 
            connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,0;
                  -12,0],
                        style(color=8));
            connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,0;
                  12.26,0],  style(color=8));
            connect(B3.BondCon1,J1p3_1. BondCon3) annotation (points=[
                  -7.20069e-016,12.24; -7.20069e-016,12.12; 0,12.12; 0,12],
                         style(color=8));
            connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,
                  1.77636e-015; -38,0; -37.74,0],
                        style(color=8));
            connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,0; 38,
                  1.77636e-015],
                      style(color=8));
            connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                  1.77636e-015; -80,0; -100,0], style(color=3, rgbcolor={0,0,
                    255}));
            connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                  1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
            connect(B3.BondCon2, D1.BondCon1) annotation (points=[7.34764e-016,
                  36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          end JunctionDiode;
          
          model JunctionCapacitor "Non-linear electrical junction capacitor" 
            extends Interfaces.OnePort;
            parameter Modelica.SIunits.Current Is=1.e-16 
              "Transport saturation current";
            parameter Modelica.SIunits.Time Tau=5e-9 "Ideal transit time";
            parameter Modelica.SIunits.Capacitance Cj=0.5e-12 
              "Zero bias depletion capacitance";
            parameter Modelica.SIunits.Voltage Phi=0.8 "Diffusion voltage";
            parameter Real M=0.333 "Gradation exponent";
            parameter Modelica.SIunits.Conductance Gb=1e-15 
              "Leakage conductance";
            parameter Modelica.SIunits.Voltage Vt=0.02585 "Thermal voltage";
            parameter Real EMin=-100 
              "if x < EMin, the exp(x) function is linearized";
            parameter Real EMax=40 
              "if x > EMax, the exp(x) function is linearized";
            Modelica.Blocks.Interfaces.RealOutput y 
              annotation (extent=[-10,90; 10,110],   rotation=90);
            annotation (
              Icon(
                Line(points=[-90,0; -14,0]),
                Line(points=[14,0; 90,0]),
                Line(points=[-14,28; -14,-28],   style(thickness=2)),
                Line(points=[14,28; 14,-28],   style(thickness=2)),
                Text(extent=[-100,-88; 96,-32],     string="%name"),
                Line(points=[0,90; 0,28],   style(color=74, rgbcolor={0,0,156}))),
              Diagram,
              Documentation(info="<html>
Junction capacitances are used in semiconductor technology to model the charge accumulated in the vicinity of a pn-junction. <p>

The model also computes the diodic current through the junction and puts it out as an output signal. <p>

<hr>

<pre>
Parameters:

 Is:    Transport saturation current (default value = 1e-16 Amp)

 Tau:   Ideal transit time (default value = 5e-9 sec)

 Cj:    Zero bias depletion capacitance (default value = 0.5e-12 F)

 Phi:   Diffusion voltage (default value = 0.8 Volt)

 M:     Gradation exponent (default value = 0.333)

 Gb:    Leakage conductance (default value = 1e-15 Mho)

 Vt:    Thermal voltage (default value = 0.02585 Volt)

 EMin:  Minimum exponent (default value = -100)

 EMax:  Maximum exponent (default value = 40)
</pre>
</html>
"));
            
            VariableCapacitor2 VariableCapacitor1 
              annotation (extent=[-70,12; -90,-12], rotation=90);
            BondLib.Semiconductors.Utilities.nlC nlC1(
              Is=Is,
              Tau=Tau,
              Phi=Phi,
              Cj=Cj,
              M=M,
              Vt=Vt,
              EMin=EMin,
              EMax=EMax) annotation (extent=[-44,-10; -64,10],
                                                             rotation=0);
            BondLib.Electrical.Analog.Sensors.VoltageSensor Vbi 
              annotation (extent=[-36,-12; -10,12], rotation=-90);
            BondLib.Electrical.Analog.Basic.VCV VCV1 
              annotation (extent=[26,22; 0,-22],  rotation=-180);
            BondLib.Electrical.Analog.Sensors.CurrentSensor Id 
              annotation (extent=[32,40; 52,20],     rotation=0);
            BondLib.Electrical.Analog.Basic.Conductor Conductor1(G=Gb) 
              annotation (extent=[70,-20; 90,20], rotation=-90);
            BondLib.Electrical.Analog.Semiconductors.Utilities.JunctionDiode 
              JunctionDiode1(
              Is=Is,
              Vt=Vt,
              EMin=EMin,
              EMax=EMax) annotation (extent=[50,-20; 70,20], rotation=-90);
            Basic.Ground Gnd1    annotation (extent=[50,-50; 70,-30]);
          equation 
            connect(nlC1.y, VariableCapacitor1.u) annotation (points=[-65,0; 
                  -61,0; -61,-6.61287e-016; -71,-6.61287e-016], style(color=74,
                  rgbcolor={0,0,127}));
            connect(Vbi.V, nlC1.u) annotation (points=[-36,-7.34764e-016; -24,
                  -7.34764e-016; -22,0; -42,0], style(color=74, rgbcolor={0,0,
                    127}));
            connect(VariableCapacitor1.p, Vbi.p) annotation (points=[-80,12;
                  -80,30; -23,30; -23,12], style(color=3, rgbcolor={0,0,255}));
            connect(VCV1.p1, Vbi.p) annotation (points=[0,11; 0,30; -23,30; -23,
                  12], style(color=3, rgbcolor={0,0,255}));
            connect(VariableCapacitor1.n, Vbi.n) annotation (points=[-80,-12;
                  -80,-30; -23,-30; -23,-12], style(color=3, rgbcolor={0,0,255}));
            connect(VCV1.n1, Vbi.n) annotation (points=[0,-11; 0,-30; -23,-30; 
                  -23,-12], style(color=3, rgbcolor={0,0,255}));
            connect(Id.p, VCV1.p2) annotation (points=[32,30; 26,30; 26,11],
                style(color=3, rgbcolor={0,0,255}));
            connect(Id.n, JunctionDiode1.p) annotation (points=[52,30; 60,30;
                  60,20], style(color=3, rgbcolor={0,0,255}));
            connect(Conductor1.p, Id.n) annotation (points=[80,20; 80,30; 52,30],
                style(color=3, rgbcolor={0,0,255}));
            connect(Id.I, y) annotation (points=[42,40; 42,60; 0,60; 0,100],
                style(color=74, rgbcolor={0,0,127}));
            connect(VCV1.n2, Gnd1.p)    annotation (points=[26,-11; 26,-30; 60,
                  -30], style(color=3, rgbcolor={0,0,255}));
            connect(JunctionDiode1.n, Gnd1.p)    annotation (points=[60,-20; 60,
                  -30], style(color=3, rgbcolor={0,0,255}));
            connect(Conductor1.n, Gnd1.p)    annotation (points=[80,-20; 80,-30;
                  60,-30], style(color=3, rgbcolor={0,0,255}));
            connect(p, VariableCapacitor1.p) annotation (points=[-100,0; -92,0;
                  -92,30; -80,30; -80,12], style(color=3, rgbcolor={0,0,255}));
            connect(n, VariableCapacitor1.n) annotation (points=[100,0; 90,0;
                  90,-60; -80,-60; -80,-12], style(color=3, rgbcolor={0,0,255}));
          end JunctionCapacitor;
        end Utilities;
      end Semiconductors;
      
      package Sensors "Sensors of analog electrical library" 
        annotation (Icon(
            Rectangle(extent=[-100,-100; 80,50],   style(fillColor=30,
                  fillPattern=1)),
            Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50],
                style(fillColor=30, fillPattern=1)),
            Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70],
                style(fillColor=30, fillPattern=1)),
            Text(
              extent=[-85,35; 65,-85],
              string="Library",
              style(color=3)),
            Text(
              extent=[-118,114; 122,65],
              string="%name",
              style(color=1))), Documentation(info="<html>
This package offers a reimplementation of the sensors package of the standard analog electrical Modelica library using bond graph technology.
</html>
"));
        model PotentialSensor "Sensor of electrical potential" 
          Modelica.Electrical.Analog.Interfaces.PositivePin p 
            "pin to be measured"                        annotation (extent=[
                -110,-10; -90,10]);
          annotation (
            Icon(
              Ellipse(extent=[-70,70; 70,-70],   style(color=0, fillColor=7)),
              Line(points=[0,70; 0,40],   style(color=0)),
              Line(points=[22.9,32.8; 40.2,57.3],   style(color=0)),
              Line(points=[-22.9,32.8; -40.2,57.3],   style(color=0)),
              Line(points=[37.6,13.7; 65.8,23.9],   style(color=0)),
              Line(points=[-37.6,13.7; -65.8,23.9],   style(color=0)),
              Line(points=[0,0; 9.02,28.6],   style(color=0)),
              Polygon(points=[-0.48,31.6; 18,26; 18,57.2; -0.48,31.6],     style(
                  color=0,
                  fillColor=0,
                  fillPattern=1)),
              Ellipse(extent=[-5,5; 5,-5],   style(
                  color=0,
                  gradient=0,
                  fillColor=0,
                  fillPattern=1)),
                 Text(
                extent=[-29,-11; 30,-70],
                string="V",
                style(color=0)),
              Line(points=[-70,0; -90,0],   style(color=0)),
              Line(points=[100,0; 70,0]),
              Text(extent=[-150,72; 150,112],   string="%name")),
            Diagram,
            Documentation(info="<html>
Sensor of electrical potential built in bond graph technology using an effort sensor.
</html>
"));
          Interfaces.El2BG El2BG1 annotation (extent=[-60,-20; -20,20]);
          Bonds.fBond B1 annotation (extent=[-20,-20; 20,20]);
          BondLib.Sensors.De De1 annotation (extent=[20,-20; 60,20]);
          Modelica.Blocks.Interfaces.RealOutput phi 
            annotation (extent=[100,-10; 120,10]);
        equation 
          connect(El2BG1.BondCon1, B1.eBondCon1) annotation (points=[-20,0; -20,
                0], style(color=8, rgbcolor={192,192,192}));
          connect(De1.BondCon1, B1.fBondCon1) annotation (points=[20,0; 20,0],
              style(color=8, rgbcolor={192,192,192}));
          connect(De1.OutPort1, phi) annotation (points=[62,0; 110,0], style(
                color=74, rgbcolor={0,0,127}));
          connect(El2BG1.p, p) annotation (points=[-60,0; -100,0], style(color=
                  3, rgbcolor={0,0,255}));
        end PotentialSensor;
        
        model VoltageSensor "Sensor of electrical voltage" 
          extends Interfaces.OnePort;
          annotation (
            Icon(
              Ellipse(extent=[-70,70; 70,-70],   style(color=0, fillColor=7)),
              Line(points=[0,70; 0,40],   style(color=0)),
              Line(points=[22.9,32.8; 40.2,57.3],   style(color=0)),
              Line(points=[-22.9,32.8; -40.2,57.3],   style(color=0)),
              Line(points=[37.6,13.7; 65.8,23.9],   style(color=0)),
              Line(points=[-37.6,13.7; -65.8,23.9],   style(color=0)),
              Line(points=[0,0; 9.02,28.6],   style(color=0)),
              Polygon(points=[-0.48,31.6; 18,26; 18,57.2; -0.48,31.6],     style(
                  color=0,
                  fillColor=0,
                  fillPattern=1)),
              Ellipse(extent=[-5,5; 5,-5],   style(
                  color=0,
                  gradient=0,
                  fillColor=0,
                  fillPattern=1)),
                 Text(
                extent=[-29,-11; 30,-70],
                string="V",
                style(color=0)),
              Line(points=[-70,0; -90,0],   style(color=0)),
              Line(points=[70,0; 90,0],   style(color=0)),
              Line(points=[0,-90; 0,-70]),
              Text(extent=[-150,72; 150,112],   string="%name")),
            Diagram,
            Documentation(info="<html>
Sensor of electrical voltage built in bond graph technology using an effort sensor.
</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,-12; 12,12]);
          Bonds.Bond B1         annotation (extent=[-38,-12; -12,12]);
          Bonds.Bond B2         annotation (extent=[12,-12; 38,12]);
          Bonds.Bond B3         annotation (extent=[-12,-36; 12,-12], rotation=
                270);
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          BondLib.Sensors.De De1 
            annotation (extent=[-12,-60; 12,-36], rotation=-90);
          Modelica.Blocks.Interfaces.RealOutput V 
            annotation (extent=[-10,-110; 10,-90], rotation=-90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,0; -12,
                0],                    style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,0; 12.26,
                0],        style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,
                1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,0; 38,
                1.77636e-015], style(color=8));
          connect(B3.BondCon1, J1p3_1.BondCon3) annotation (points=[
                2.16021e-015,-12.24; 2.16021e-015,-18.12; 0,-18.12; 0,-12],
              style(color=8, rgbcolor={192,192,192}));
          connect(De1.BondCon1, B3.BondCon2) annotation (points=[-7.34764e-016,
                -36; -2.20429e-015,-36], style(color=8, rgbcolor={192,192,192}));
          connect(De1.OutPort1, V) annotation (points=[8.0824e-016,-61.2; 
                8.0824e-016,-74.6; 0,-74.6; 0,-100],
                                         style(color=74, rgbcolor={0,0,127}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end VoltageSensor;
        
        model CurrentSensor "Sensor of electrical current" 
          extends Interfaces.OnePort;
          annotation (
            Icon(
              Ellipse(extent=[-70,70; 70,-70],   style(color=0, fillColor=7)),
              Line(points=[0,70; 0,40],   style(color=0)),
              Line(points=[22.9,32.8; 40.2,57.3],   style(color=0)),
              Line(points=[-22.9,32.8; -40.2,57.3],   style(color=0)),
              Line(points=[37.6,13.7; 65.8,23.9],   style(color=0)),
              Line(points=[-37.6,13.7; -65.8,23.9],   style(color=0)),
              Line(points=[0,0; 9.02,28.6],   style(color=0)),
              Polygon(points=[-0.48,31.6; 18,26; 18,57.2; -0.48,31.6],     style(
                  color=0,
                  fillColor=0,
                  fillPattern=1)),
              Ellipse(extent=[-5,5; 5,-5],   style(
                  color=0,
                  gradient=0,
                  fillColor=0,
                  fillPattern=1)),
                 Text(
                extent=[-29,-11; 30,-70],
                string="A",
                style(color=0)),
              Text(extent=[-150,72; 150,112],   string="%name"),
              Line(points=[70,0; 90,0],   style(color=0)),
              Line(points=[0,-90; 0,-70]),
              Line(points=[-70,0; -90,0],   style(color=0))),
            Diagram,
            Documentation(info="<html>
Sensor of electrical current built in bond graph technology using a flow sensor.
</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,-12; 12,12]);
          Bonds.Bond B1         annotation (extent=[-38,-12; -12,12]);
          Bonds.Bond B2         annotation (extent=[12,-12; 38,12]);
          Bonds.Bond B3         annotation (extent=[-12,-36; 12,-12], rotation=
                270);
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          BondLib.Sensors.Df Df1 
            annotation (extent=[-12,-60; 12,-36], rotation=-90);
          Modelica.Blocks.Interfaces.RealOutput I 
            annotation (extent=[-10,-110; 10,-90], rotation=-90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,0; -12,
                0],                    style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,0; 12.26,
                0],        style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,
                1.77636e-015; -38,0; -37.74,0],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,0; 38,
                1.77636e-015], style(color=8));
          connect(B3.BondCon1, J1p3_1.BondCon3) annotation (points=[
                2.16021e-015,-12.24; 2.16021e-015,-18.12; 0,-18.12; 0,-12],
              style(color=8, rgbcolor={192,192,192}));
          connect(Df1.BondCon1, B3.BondCon2) annotation (points=[-7.34764e-016,
                -36; -2.20429e-015,-36], style(color=8, rgbcolor={192,192,192}));
          connect(Df1.OutPort1, I) annotation (points=[8.0824e-016,-61.2; 
                8.0824e-016,-74.6; 0,-74.6; 0,-100],
                                         style(color=74, rgbcolor={0,0,127}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 81,
                1.77636e-015; 81,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end CurrentSensor;
      end Sensors;
      
      package Sources "Sources of analog electrical library" 
        annotation (Icon(
            Rectangle(extent=[-100, -100; 80, 50], style(fillColor=30,
                  fillPattern=1)),
            Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50],
                style(fillColor=30, fillPattern=1)),
            Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70],
                style(fillColor=30, fillPattern=1)),
            Text(
              extent=[-85, 35; 65, -85],
              string="Library",
              style(color=3)),
            Text(
              extent=[-118, 114; 122, 65],
              string="%name",
              style(color=1))), Documentation(info="<html>
This package offers a reimplementation of the sources package of the standard analog electrical Modelica library using bond graph technology.
</html>
"));
        model SignalVoltage 
          "Modulated voltage source of analog electrical library" 
          extends Interfaces.OnePort;
          annotation (
            Icon(
              Line(points=[-90, 0; -50, 0]),
              Line(points=[-50, 0; 50, 0]),
              Line(points=[50, 0; 90, 0]),
              Ellipse(extent=[-50, 50; 50, -50], style(fillColor=7)),
              Text(extent=[-100, -100; 100, -60], string="%name")),
            Diagram,
            Documentation(info="<html>
The modulated voltage source is built in bondgraphic technology from a bond graph <b>mSe</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the voltage source in its environment.
</html>
"));
          Modelica.Blocks.Interfaces.RealInput InPort1 
                                                    annotation (extent=[-10, 70;
                  10, 50], rotation=90);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -34; -38, -6]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -34; 64, -6]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, -8; 12, -32]);
          BondLib.Bonds.Bond B1 annotation (extent=[12, -32; 38, -8], rotation=
                180);
          BondLib.Bonds.Bond B2 annotation (extent=[-38, -32; -12, -8],
              rotation=180);
          BondLib.Sources.mSe V1 annotation (extent=[-12, 16; 12, 40], rotation=
               90);
          BondLib.Bonds.fBond B3 annotation (extent=[-12, -8; 12, 16], rotation=
               -90);
        equation 
          connect(J1p3_1.BondCon2, B1.BondCon2) annotation (points=[12, -20; 12,
                  -20], style(color=8));
          connect(BG2El1.BondCon1, B1.BondCon1) annotation (points=[38,-20;
                37.74,-20],
                        style(color=8));
          connect(El2BG1.BondCon1, B2.BondCon2) annotation (points=[-38, -20; -
                38, -20], style(color=8));
          connect(J1p3_1.BondCon1, B2.BondCon1) annotation (points=[-12,-20;
                -12.26,-20],
                          style(color=8));
          connect(V1.InPort1, InPort1) annotation (points=[6.61287e-016,38.8; 
                6.61287e-016,54.4; 0,54.4; 0,60],                         style(
               color=3));
          connect(B3.eBondCon1, V1.BondCon1) annotation (points=[-7.34764e-016,
                16; -7.34764e-016,16],
                              style(color=8));
          connect(B3.fBondCon1, J1p3_1.BondCon3) annotation (points=[
                7.34764e-016,-8; 0,-8],   style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,-20; -80,-20; -80,0;
                -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,-20; 80,-20; 80,0; 100,0],
              style(color=3, rgbcolor={0,0,255}));
        end SignalVoltage;
        
        model ConstantVoltage 
          "Constant voltage source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Voltage V=1 "Value of constant voltage";
          annotation (
            Icon(
              Line(points=[-90, 0; -10, 0]),
              Line(points=[-10, 60; -10, -60]),
              Line(points=[0, 30; 0, -30]),
              Line(points=[0, 0; 90, 0]),
              Text(extent=[-100, -100; 100, -60], string="%name=%V")),
            Diagram,
            Documentation(info="<html>
The constant voltage source is built in bondgraphic technology from a bond graph <b>Se</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the voltage source in its environment. <p>

<hr>

<pre>
Parameters:

 V:  Constant source voltage (default value = 1 Volt)
</pre>

</html>
"));
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -14; -38, 14]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -14; 64, 14]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, 12; 12, -12]);
          BondLib.Bonds.Bond B1 annotation (extent=[12, -12; 38, 12], rotation=
                180);
          BondLib.Bonds.Bond B2 annotation (extent=[-38, -12; -12, 12],
              rotation=180);
          BondLib.Bonds.fBond B3 annotation (extent=[-12, 12; 12, 36], rotation=
               -90);
          BondLib.Sources.Se V1(e0=V) annotation (extent=[-12, 36; 12, 60],
              rotation=90);
        equation 
          connect(J1p3_1.BondCon2, B1.BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1, B1.BondCon1) annotation (points=[38,
                1.77636e-015; 38,1.77636e-015; 38,-1.44014e-015; 37.74,
                -1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1, B2.BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1, B2.BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(B3.fBondCon1, J1p3_1.BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],
                     style(color=8));
          connect(B3.eBondCon1, V1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36],
                style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end ConstantVoltage;
        
        model StepVoltage "Step voltage source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Voltage V=1 "Height of step";
          parameter Modelica.SIunits.Voltage offset=0 "Voltage offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Text(extent=[-150,74; 150,114], string="%name"),
              Line(points=[-90,0; 90,0], style(color=0, rgbcolor={0,0,0})),
                 Line(points=[-70,-70; 0,-70; 0,70; 69,70],     style(color=8))),
            Diagram,
            Documentation(info="<html>
The step voltage source is built in bondgraphic technology from a bond graph <b>stepSe</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the voltage source in its environment. <p>

<hr>

<pre>
Parameters:

 V:          Height of source voltage step (default value = 1 Volt)

 offset:     Offset of step to be generated (default value = 0 Volt)

 startTime:  Start time of step to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.fBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.stepSe V1(
            e0=V,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(B3.fBondCon1,J1p3_1. BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],
                     style(color=8));
          connect(B3.eBondCon1, V1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end StepVoltage;
        
        model RampVoltage "Ramp voltage source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Voltage V=1 "Height of ramp";
          parameter Modelica.SIunits.Time duration=2 "Duration of ramp";
          parameter Modelica.SIunits.Voltage offset=0 "Voltage offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Text(extent=[-150,68; 150,108], string="%name"),
              Line(points=[-90,0; 90,0], style(color=0, rgbcolor={0,0,0})),
                 Line(points=[-80,-60; -50,-60; 50,60; 80,60],     style(color=8))),
            Diagram,
            Documentation(info="<html>
The ramp voltage source is built in bondgraphic technology from a bond graph <b>rampSe</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the voltage source in its environment. <p>

<hr>

<pre>
Parameters:

 V:          Height of source voltage ramp (default value = 1 Volt)

 duration:   Duration of source voltage ramp (default value = 2 sec)

 offset:     Offset of ramp to be generated (default value = 0 Volt)

 startTime:  Start time of ramp to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.fBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.rampSe V1(
            e0=V,
            duration=duration,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(B3.fBondCon1,J1p3_1. BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],
                     style(color=8));
          connect(B3.eBondCon1, V1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -78,
                1.77636e-015; -78,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end RampVoltage;
        
        model SineVoltage 
          "Sinusoidal voltage source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Voltage V=1 "Amplitude of sine wave";
          parameter Modelica.SIunits.Angle phase=0 "Phase of sine wave";
          parameter Modelica.SIunits.Frequency freqHz=1 
            "Frequency of sine wave";
          parameter Modelica.SIunits.Voltage offset=0 "Voltage offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50, 50; 50, -50], style(color=3, fillColor=7)),
              Line(points=[-90, 0; -50, 0]),
              Line(points=[50, 0; 90, 0]),
              Line(points=[-50, 0; 50, 0]),
              Line(points=[-70, 0; -60.2, 29.9; -53.8, 46.5; -48.2, 58.1; -43.3,
                      65.2; -38.3, 69.2; -33.4, 69.8; -28.5, 67; -23.6, 61; -
                    18.6, 52; -13, 38.6; -5.98, 18.6; 8.79, -26.9; 15.1, -44;
                    20.8, -56.2; 25.7, -64; 30.6, -68.6; 35.5, -70; 40.5, -67.9;
                      45.4, -62.5; 50.3, -54.1; 55.9, -41.3; 63, -21.7; 70, 0],
                    style(color=8)),
              Text(extent=[-100, -100; 100, -60], string="%name=%V")),
            Diagram,
            Documentation(info="<html>
The sinusoidal voltage source is built in bondgraphic technology from a bond graph <b>sinSe</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the voltage source in its environment. <p>

<hr>

<pre>
Parameters:

 V:          Amplitude of source voltage (default value = 1 Volt)

 phase:      Phase of sine wave to be generated (default value = 0 rad)

 freqHz:     Frequency of sine wave to be generated (default value = 1 Hz)

 offset:     Offset of sine wave to be generated (default value = 0 Volt)

 startTime:  Start time of sine wave to be generated (default value = 0 sec)
</pre>
</html>
"));
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -14; -38, 14]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -14; 64, 14]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, 12; 12, -12]);
          BondLib.Bonds.Bond B1 annotation (extent=[12, -12; 38, 12], rotation=
                180);
          BondLib.Bonds.Bond B2 annotation (extent=[-38, -12; -12, 12],
              rotation=180);
          BondLib.Bonds.fBond B3 annotation (extent=[-12, 12; 12, 36], rotation=
               -90);
          BondLib.Sources.sinSe V1(
            e0=V,
            phase=phase,
            freqHz=freqHz,
            offset=offset,
            startTime=startTime) annotation (extent=[-12, 36; 12, 60], rotation=
               90);
        equation 
          connect(J1p3_1.BondCon2, B1.BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1, B1.BondCon1) annotation (points=[38,
                1.77636e-015; 38,1.77636e-015; 38,-1.44014e-015; 37.74,
                -1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1, B2.BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1, B2.BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(B3.fBondCon1, J1p3_1.BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],
                     style(color=8));
          connect(B3.eBondCon1, V1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36],
                style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 82,
                1.77636e-015; 82,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end SineVoltage;
        
        model ExpSineVoltage 
          "Damped sinusoidal voltage source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Voltage V=1 "Amplitude of sine wave";
          parameter Modelica.SIunits.Angle phase=0 "Phase of sine wave";
          parameter Modelica.SIunits.Frequency freqHz=2 
            "Frequency of sine wave";
          parameter Modelica.SIunits.Damping damping=1 
            "Damping coefficient of sine wave";
          parameter Modelica.SIunits.Voltage offset=0 "Voltage offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Text(extent=[-144,70; 156,110], string="%name"),
              Line(points=[-90,0; 90,0], style(color=0, rgbcolor={0,0,0})),
                 Line(points=[-80,-14; -75.2,18.3; -72,36.3; -68.7,50.5; -65.5,
                    60.2; -62.3,65.3; -59.1,65.6; -55.9,61.3; -52.7,53.1; -48.6,
                    38.2; -43,11.8; -35,-27.9; -30.2,-47.7; -26.1,-59.9; -22.1,
                    -67.2; -18.1,-69.3; -14.1,-66.5; -10.1,-59.3; -5.23,-46.1;
                    8.44,-0.3; 13.3,12.4; 18.1,20.8; 22.1,24; 26.9,23.2; 31.8,
                    17.8; 38.2,5.4; 51.1,-24.5; 57.5,-35.2; 63.1,-39.9; 68.7,
                    -39.9; 75.2,-34.5; 80,-27.8],  style(color=8))),
            Diagram,
            Documentation(info="<html>
The damped sinusoidal voltage source is built in bondgraphic technology from a bond graph <b>expsinSe</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the voltage source in its environment. <p>

<hr>

<pre>
Parameters:

 V:          Amplitude of source voltage (default value = 1 Volt)

 phase:      Phase of damped sine wave to be generated (default value = 0 rad)

 freqHz:     Frequency of damped sine wave to be generated (default value = 2 Hz)

 damping:    Damping coefficient of damped sine wave to be generated (default value = 1 Hz)

 offset:     Offset of sine wave to be generated (default value = 0 Volt)

 startTime:  Start time of sine wave to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.fBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.expsinSe V1(
            e0=V,
            phase=phase,
            freqHz=freqHz,
            damping=damping,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(B3.fBondCon1,J1p3_1. BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],
                     style(color=8));
          connect(B3.eBondCon1, V1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end ExpSineVoltage;
        
        model ExponentialsVoltage 
          "Step response voltage source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Voltage V=1 "Amplitude of sine wave";
          parameter Modelica.SIunits.Time riseTime(min=0) = 0.5 "Rise time";
          parameter Modelica.SIunits.Time riseTimeConst(min=Modelica.Constants.small) = 0.1 
            "Rise time constant";
          parameter Modelica.SIunits.Time fallTimeConst(min=Modelica.Constants.small) = riseTimeConst 
            "Fall time constant";
          parameter Modelica.SIunits.Voltage offset=0 "Voltage offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Text(extent=[-150,72; 150,112], string="%name"),
              Line(points=[-90,0; 90,0], style(color=0, rgbcolor={0,0,0})),
                 Line(points=[-76,-59; -73.2,-44.3; -70.3,-31.1; -66.8,-16.6;
                    -63.3,-4; -59.7,6.92; -55.5,18.18; -51.3,27.7; -46.3,37;
                    -40.6,45.5; -34.3,53.1; -27.2,59.6; -18.7,65.3; -8.1,70.2;
                    -6,71; -3.88,58.5; -1.05,43.7; 1.78,30.8; 4.606,19.45; 8.14,
                    7.3; 11.68,-3; 15.9,-13.2; 20.2,-21.6; 25.1,-29.5; 30.8,
                    -36.4; 37.1,-42.3; 44.9,-47.5; 54.8,-51.8; 64,-54.4],    style(
                    color=8))),
            Diagram,
            Documentation(info="<html>
The step response voltage source is built in bondgraphic technology from a bond graph <b>expSe</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the voltage source in its environment. <p>

<hr>

<pre>
Parameters:

 V:              Height of step response source voltage after infinite time (default value = 1 Volt)

 riseTime:       Rise time of step response to be generated (default value = 0.5 sec)

 riseTimeConst:  Rise time constant of step response to be generated (default value = 0.1)

 fallTimeConst:  Fall time constant of step response to be generated (default value = riseTimeConst)

 offset:         Offset of step response to be generated (default value = 0 Volt)

 startTime:      Start time of step response to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.fBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.expSe V1(
            riseTime=riseTime,
            riseTimeConst=riseTimeConst,
            fallTimeConst=fallTimeConst,
            offset=offset,
            startTime=startTime,
            e0=V) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(B3.fBondCon1,J1p3_1. BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],
                     style(color=8));
          connect(V1.BondCon1, B3.eBondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end ExponentialsVoltage;
        
        model PulseVoltage "Pulse voltage source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Voltage V=1 "Amplitude of pulse";
          parameter Real width(
            final min=Modelica.Constants.small,
            final max=100) = 50 "Width of pulse in % of period";
          parameter Modelica.SIunits.Time period(final min=Modelica.Constants.small) = 1 
            "Time for one period";
          parameter Modelica.SIunits.Voltage offset=0 "Voltage offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Text(extent=[-150,72; 150,112], string="%name"),
              Line(points=[-90,0; 90,0], style(color=0, rgbcolor={0,0,0})),
                 Line(points=[-70,-70; -40,-70; -40,70; 0,70; 0,-70; 40,-70; 41,
                    70; 80,70],    style(color=8))),
            Diagram,
            Documentation(info="<html>
The pulse voltage source is built in bondgraphic technology from a bond graph <b>pulseSe</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the voltage source in its environment. <p>

<hr>

<pre>
Parameters:

 V:          Amplitude of source voltage pulse (default value = 1 Volt)

 width:      Percentage of period in on state (default value = 50%)

 period:     Length of period of pulse to be generated (default value = 1 sec)

 offset:     Offset of pulse to be generated (default value = 0 Volt)

 startTime:  Start time of pulse to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.fBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.pulseSe V1(
            width=width,
            period=period,
            offset=offset,
            startTime=startTime,
            e0=V) annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(B3.fBondCon1,J1p3_1. BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],
                     style(color=8));
          connect(B3.eBondCon1, V1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 79,
                1.77636e-015; 79,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end PulseVoltage;
        
        model SawToothVoltage 
          "Saw tooth voltage source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Voltage V=1 "Amplitude of saw tooth";
          parameter Modelica.SIunits.Time period(final min=Modelica.Constants.small) = 1 
            "Time for one period";
          parameter Modelica.SIunits.Voltage offset=0 "Voltage offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Text(extent=[-150,72; 150,112], string="%name"),
              Line(points=[-90,0; 90,0], style(color=0, rgbcolor={0,0,0})),
                 Line(points=[-70,-71; -50,-71; 10,70; 10,-71; 70,70; 70,-71],
                  style(color=8))),
            Diagram,
            Documentation(info="<html>
The saw tooth voltage source is built in bondgraphic technology from a bond graph <b>sawSe</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the voltage source in its environment. <p>

<hr>

<pre>
Parameters:

 V:          Amplitude of source voltage saw tooth (default value = 1 Volt)

 period:     Length of period of saw tooth to be generated (default value = 1 sec)

 offset:     Offset of saw tooth to be generated (default value = 0 Volt)

 startTime:  Start time of saw tooth to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.fBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.sawSe V1(
            e0=V,
            period=period,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(B3.fBondCon1,J1p3_1. BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],
                     style(color=8));
          connect(B3.eBondCon1, V1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end SawToothVoltage;
        
        model TrapezoidVoltage 
          "Trapezoidal voltage source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Voltage V=1 "Amplitude of saw tooth";
          parameter Modelica.SIunits.Time rising(final min=0) = 0 
            "Rising duration of trapezoid";
          parameter Modelica.SIunits.Time width(final min=0) = 0.5 
            "Width duration of trapezoid";
          parameter Modelica.SIunits.Time falling(final min=0) = 0 
            "Falling duration of trapezoid";
          parameter Modelica.SIunits.Time period(final min=Modelica.Constants.small) = 1 
            "Time for one period";
          parameter Integer nperiod=-1 
            "Number of periods (< 0 means infinite number of periods)";
          parameter Modelica.SIunits.Voltage offset=0 "Voltage offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Text(extent=[-150,72; 150,112], string="%name"),
              Line(points=[-90,0; 90,0], style(color=0, rgbcolor={0,0,0})),
                 Line(points=[-81,-70; -60,-70; -30,70; 1,70; 30,-70; 51,-70;
                    80,70],  style(color=8))),
            Diagram,
            Documentation(info="<html>
The trapezoidal voltage source is built in bondgraphic technology from a bond graph <b>trapSe</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the voltage source in its environment. <p>

<hr>

<pre>
Parameters:

 V:          Amplitude of source voltage trapezoid (default value = 1 Volt)

 rising:     Length of rising time of trapezoid to be generated (default value = 0 sec)

 width :     Length of on state of trapezoid to be generated (default value = 0.5 sec)

 falling:    Length of falling time of trapezoid to be generated (default value = 0 sec)

 period:     Length of period of trapezoid to be generated (default value = 1 sec)

 nperiod:    Number of periods of trapezoid to be generated
             an infinite number of periods is being generated if nperiod &lt; 0 (default value = -1)

 offset:     Offset of trapezoid to be generated (default value = 0 Volt)

 startTime:  Start time of trapezoid to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.fBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.trapSe V1(
            e0=V,
            rising=rising,
            width=width,
            falling=falling,
            period=period,
            nperiod=nperiod,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(B3.fBondCon1,J1p3_1. BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],
                     style(color=8));
          connect(B3.eBondCon1, V1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end TrapezoidVoltage;
        
        model TableVoltage 
          "Tabular voltage source of analog electrical library" 
          parameter Real table[:, :]=[0, 0; 1, 1; 2, 4] 
            "Table matrix (time = first column, voltage = second column)";
          parameter Modelica.SIunits.Voltage offset=0 "Voltage offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          extends Interfaces.OnePort;
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Text(extent=[-150,72; 150,112], string="%name"),
              Line(points=[-90,0; 90,0], style(color=0, rgbcolor={0,0,0})),
                 Line(points=[-66,-46; -66,74; 34,74; 34,-46; -66,-46; -66,-16;
                    34,-16; 34,14; -66,14; -66,44; 34,44; 34,74; -16,74; -16,
                    -47],style(color=8))),
            Diagram,
            Documentation(info="<html>
The tabular voltage source is built in bondgraphic technology from a bond graph <b>tableSe</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the voltage source in its environment. <p>

<hr>

<pre>
Parameters:

 table:      Two-dimensional table with supporting values (default value = [0, 0; 1, 1; 2, 4])

 offset:     Offset of time function to be generated (default value = 0 Volt)

 startTime:  Start time of time function to be generated (default value = 0 sec)
</pre> <p>

<hr> <p>

The model generates a voltage source by <b>linear interpolation</b> in
a table. The time points and voltage values are stored in a matrix
<b>table[i,j]</b>, where the first column table[:,1] contains the
time points, and the second column contains the voltage to be interpolated.
The table interpolation has the following proporties: <p>

<ul>
<li>The time points need to be <b>monotonically increasing</b>.
<li><b>Discontinuities</b> are allowed, by providing the same
    time point twice in the table.
<li>Values <b>outside</b> of the table range, are computed by
    <b>extrapolation</b> through the last or first two points of the
    table.
<li>If the table has only <b>one row</b>, no interpolation is performed and
    the voltage value is just returned independantly of the
    actual time instant, i.e., this is a constant voltage source.
<li>Via parameters <b>startTime</b> and <b>offset</b> the curve defined
    by the table can be shifted both in time and in the voltage.
<li>The table is implemented in a numerically sound way by
    generating <b>time events</b> at interval boundaries,
    in order to not integrate over a discontinuous or not differentiable
    points.
</ul> <p>

<hr> <p>

<b>Example:</b> <p>

<pre>
   table = [0  0
            1  0
            1  1
            2  4
            3  9
            4 16]
If, e.g., time = 1.0, the voltage v =  0.0 (before event), 1.0 (after event)
    e.g., time = 1.5, the voltage v =  2.5,
    e.g., time = 2.0, the voltage v =  4.0,
    e.g., time = 5.0, the voltage v = 23.0 (i.e. extrapolation).
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.fBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.tableSe V1(
            table=table,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(B3.fBondCon1,J1p3_1. BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],
                     style(color=8));
          connect(B3.eBondCon1, V1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 81,
                1.77636e-015; 81,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end TableVoltage;
        
        model SignalCurrent 
          "Modulated current source of analog electrical library" 
          extends Interfaces.OnePort;
          annotation (
            Icon(
              Ellipse(extent=[-50, 50; 50, -50], style(fillColor=7)),
              Line(points=[-90, 0; -50, 0]),
              Line(points=[0, -50; 0, 50]),
              Line(points=[50, 0; 90, 0]),
              Text(extent=[-100, -100; 100, -60], string="%name")),
            Diagram,
            Documentation(info="<html>
The modulated current source is built in bondgraphic technology from a bond graph <b>mSf</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the current source in its environment.
</html>
"));
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=[
                -62,-34; -38,-6]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=[38,
                -34; 64,-6]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12,-8; 12,-32]);
          BondLib.Bonds.Bond B1 annotation (extent=[12,-32; 38,-8],   rotation=
                180);
          BondLib.Bonds.Bond B2 annotation (extent=[-38,-32; -12,-8],
              rotation=180);
          Modelica.Blocks.Interfaces.RealInput InPort1 
                                                    annotation (extent=[-10, 50;
                  10, 70], rotation=-90);
          BondLib.Sources.mSf I1 annotation (extent=[-12,16; 12,40],   rotation=
               90);
          BondLib.Bonds.eBond B3 annotation (extent=[-12,-8; 12,16],   rotation=
               -90);
        equation 
          connect(J1p3_1.BondCon2, B1.BondCon2) annotation (points=[12,-20; 12,
                -20],   style(color=8));
          connect(BG2El1.BondCon1, B1.BondCon1) annotation (points=[38,-20;
                37.74,-20],
                        style(color=8));
          connect(El2BG1.BondCon1, B2.BondCon2) annotation (points=[-38,-20;
                -38,-20], style(color=8));
          connect(J1p3_1.BondCon1, B2.BondCon1) annotation (points=[-12,-20;
                -12.26,-20],
                          style(color=8));
          connect(B3.eBondCon1, J1p3_1.BondCon3) annotation (points=[
                7.34764e-016,-8; 0,-8],   style(color=8));
          connect(B3.fBondCon1, I1.BondCon1) annotation (points=[-7.34764e-016,
                16; -7.34764e-016,16],
                              style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,-20; -80,-20; -80,0;
                -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,-20; 80,-20; 80,0; 100,0],
              style(color=3, rgbcolor={0,0,255}));
          connect(I1.InPort1, InPort1) annotation (points=[6.61287e-016,38.8; 
                6.61287e-016,34.4; 0,34.4; 0,60], style(color=74, rgbcolor={0,0,
                  127}));
        end SignalCurrent;
        
        model ConstantCurrent 
          "Constant current source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Current I=1 "Value of constant current";
          annotation (
            Icon(
              Line(points=[-90, 0; -50, 0]),
              Ellipse(extent=[-50, 50; 50, -50], style(color=3, fillColor=7)),
              Line(points=[0, -50; 0, 50]),
              Line(points=[50, 0; 90, 0]),
              Text(extent=[-100, -100; 100, -60], string="%name=%I")),
            Diagram,
            Documentation(info="<html>
The constant current source is built in bondgraphic technology from a bond graph <b>Sf</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the current source in its environment. <p>

<hr>

<pre>
Parameters:

 I:  Constant source current (default value = 1 Amp)
</pre>

</html>
"));
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -14; -38, 14]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -14; 64, 14]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, 12; 12, -12]);
          BondLib.Bonds.Bond B1 annotation (extent=[12, -12; 38, 12], rotation=
                180);
          BondLib.Bonds.Bond B2 annotation (extent=[-38, -12; -12, 12],
              rotation=180);
          BondLib.Bonds.eBond B3 annotation (extent=[-12, 12; 12, 36], rotation=
               -90);
          BondLib.Sources.Sf I1(f0=I) annotation (extent=[-12, 36; 12, 60],
              rotation=90);
        equation 
          connect(J1p3_1.BondCon2, B1.BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1, B1.BondCon1) annotation (points=[38,
                1.77636e-015; 38,1.77636e-015; 38,-1.44014e-015; 37.74,
                -1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1, B2.BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1, B2.BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(B3.eBondCon1, J1p3_1.BondCon3) annotation (points=[
                7.34764e-016,12; 0,12],
                     style(color=8));
          connect(B3.fBondCon1, I1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36],
                style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end ConstantCurrent;
        
        model StepCurrent "Step current source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Current I=1 "Height of step";
          parameter Modelica.SIunits.Current offset=0 "Current offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Line(points=[-90,0; -50,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[50,0; 90,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[0,-50; 0,50],   style(color=0, rgbcolor={0,0,0})),
              Text(extent=[-150,114; 150,74],   string="%name"),
                 Line(points=[-86,-70; -13,-70; -14,70; 57,70],     style(color=8))),
            Diagram,
            Documentation(info="<html>
The step current source is built in bondgraphic technology from a bond graph <b>stepSf</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the current source in its environment. <p>

<hr>

<pre>
Parameters:

 V:          Height of step current (default value = 1 Amp)

 offset:     Offset of step to be generated (default value = 0 Amp)

 startTime:  Start time of step to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.eBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.stepSf I1(
            f0=I,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(J1p3_1.BondCon3,B3. eBondCon1) annotation (points=[0,12; 
                7.34764e-016,12],
                     style(color=8));
          connect(B3.fBondCon1, I1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 79,
                1.77636e-015; 79,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end StepCurrent;
        
        model RampCurrent "Ramp current source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Current I=1 "Height of ramp";
          parameter Modelica.SIunits.Time duration=2 "Duration of ramp";
          parameter Modelica.SIunits.Current offset=0 "Current offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Line(points=[-90,0; -50,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[50,0; 90,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[0,-50; 0,50],   style(color=0, rgbcolor={0,0,0})),
              Text(extent=[-152,110; 148,70],   string="%name"),
                 Line(points=[-80,-60; -50,-60; 50,60; 80,60],     style(color=8))),
            Diagram,
            Documentation(info="<html>
The ramp current source is built in bondgraphic technology from a bond graph <b>rampSf</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the current source in its environment. <p>

<hr>

<pre>
Parameters:

 I:          Height of source current ramp (default value = 1 Amp)

 duration:   Duration of source current ramp (default value = 2 sec)

 offset:     Offset of ramp to be generated (default value = 0 Amp)

 startTime:  Start time of ramp to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.eBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.rampSf I1(
            f0=I,
            duration=duration,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(J1p3_1.BondCon3,B3. eBondCon1) annotation (points=[0,12; 
                7.34764e-016,12],
                     style(color=8));
          connect(B3.fBondCon1, I1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end RampCurrent;
        
        model SineCurrent 
          "Sinusoidal current source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Current I=1 "Amplitude of sine wave";
          parameter Modelica.SIunits.Angle phase=0 "Phase of sine wave";
          parameter Modelica.SIunits.Frequency freqHz=1 
            "Frequency of sine wave";
          parameter Modelica.SIunits.Current offset=0 "Current offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50, 50; 50, -50], style(color=3, fillColor=7)),
              Line(points=[-90, 0; -50, 0]),
              Line(points=[50, 0; 90, 0]),
              Line(points=[0, -50; 0, 50]),
              Line(points=[-70, 0; -60.2, 29.9; -53.8, 46.5; -48.2, 58.1; -43.3,
                      65.2; -38.3, 69.2; -33.4, 69.8; -28.5, 67; -23.6, 61; -
                    18.6, 52; -13, 38.6; -5.98, 18.6; 8.79, -26.9; 15.1, -44;
                    20.8, -56.2; 25.7, -64; 30.6, -68.6; 35.5, -70; 40.5, -67.9;
                      45.4, -62.5; 50.3, -54.1; 55.9, -41.3; 63, -21.7; 70, 0],
                    style(color=8)),
              Text(extent=[-100, -100; 100, -60], string="%name=%I")),
            Diagram,
            Documentation(info="<html>
The sinusoidal current source is built in bondgraphic technology from a bond graph <b>sinSf</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the current source in its environment. <p>

<hr>

<pre>
Parameters:

 V:          Amplitude of source current (default value = 1 Amp)

 phase:      Phase of sine wave to be generated (default value = 0 rad)

 freqHz:     Frequency of sine wave to be generated (default value = 1 Hz)

 offset:     Offset of sine wave to be generated (default value = 0 Amp)

 startTime:  Start time of sine wave to be generated (default value = 0 sec)
</pre>
</html>
"));
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=
                [-62, -14; -38, 14]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=
                [38, -14; 64, 14]);
          BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-12, 12; 12, -12]);
          BondLib.Bonds.Bond B1 annotation (extent=[12, -12; 38, 12], rotation=
                180);
          BondLib.Bonds.Bond B2 annotation (extent=[-38, -12; -12, 12],
              rotation=180);
          BondLib.Bonds.eBond B3 annotation (extent=[-12, 12; 12, 36], rotation=
               -90);
          BondLib.Sources.sinSf I1(
            f0=I,
            phase=phase,
            freqHz=freqHz,
            offset=offset,
            startTime=startTime) annotation (extent=[-12, 36; 12, 60], rotation=
               90);
        equation 
          connect(J1p3_1.BondCon2, B1.BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1, B1.BondCon1) annotation (points=[38,
                1.77636e-015; 38,1.77636e-015; 38,-1.44014e-015; 37.74,
                -1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1, B2.BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1, B2.BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(J1p3_1.BondCon3, B3.eBondCon1) annotation (points=[0,12; 
                7.34764e-016,12],
                     style(color=8));
          connect(B3.fBondCon1, I1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36],
                style(color=8));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end SineCurrent;
        
        model ExpSineCurrent 
          "Damped sinusoidal current source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Current I=1 "Amplitude of sine wave";
          parameter Modelica.SIunits.Angle phase=0 "Phase of sine wave";
          parameter Modelica.SIunits.Frequency freqHz=2 
            "Frequency of sine wave";
          parameter Modelica.SIunits.Damping damping=1 
            "Damping coefficient of sine wave";
          parameter Modelica.SIunits.Current offset=0 "Current offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Line(points=[-90,0; -50,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[50,0; 90,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[0,-50; 0,50],   style(color=0, rgbcolor={0,0,0})),
              Text(extent=[-144,112; 156,72],   string="%name"),
                 Line(points=[-80,-14; -75.2,18.3; -72,36.3; -68.7,50.5; -65.5,
                    60.2; -62.3,65.3; -59.1,65.6; -55.9,61.3; -52.7,53.1; -48.6,
                    38.2; -43,11.8; -35,-27.9; -30.2,-47.7; -26.1,-59.9; -22.1,
                    -67.2; -18.1,-69.3; -14.1,-66.5; -10.1,-59.3; -5.23,-46.1;
                    8.44,-0.3; 13.3,12.4; 18.1,20.8; 22.1,24; 26.9,23.2; 31.8,
                    17.8; 38.2,5.4; 51.1,-24.5; 57.5,-35.2; 63.1,-39.9; 68.7,
                    -39.9; 75.2,-34.5; 80,-27.8],  style(color=8))),
            Diagram,
            Documentation(info="<html>
The damped sinusoidal current source is built in bondgraphic technology from a bond graph <b>expsinSf</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the current source in its environment. <p>

<hr>

<pre>
Parameters:

 I:          Amplitude of source current (default value = 1 Amp)

 phase:      Phase of damped sine wave to be generated (default value = 0 rad)

 freqHz:     Frequency of damped sine wave to be generated (default value = 2 Hz)

 damping:    Damping coefficient of damped sine wave to be generated (default value = 1 Hz)

 offset:     Offset of sine wave to be generated (default value = 0 Amp)

 startTime:  Start time of sine wave to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.eBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.expsinSf I1(
            f0=I,
            phase=phase,
            freqHz=freqHz,
            damping=damping,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(J1p3_1.BondCon3,B3. eBondCon1) annotation (points=[0,12; 
                7.34764e-016,12],
                     style(color=8));
          connect(B3.fBondCon1, I1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 81,
                1.77636e-015; 81,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end ExpSineCurrent;
        
        model ExponentialsCurrent 
          "Step response current source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Current I=1 "Amplitude of sine wave";
          parameter Modelica.SIunits.Time riseTime(min=0) = 0.5 "Rise time";
          parameter Modelica.SIunits.Time riseTimeConst(min=Modelica.Constants.small) = 0.1 
            "Rise time constant";
          parameter Modelica.SIunits.Time fallTimeConst(min=Modelica.Constants.small) = riseTimeConst 
            "Fall time constant";
          parameter Modelica.SIunits.Current offset=0 "Current offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Line(points=[-90,0; -50,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[50,0; 90,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[0,-50; 0,50],   style(color=0, rgbcolor={0,0,0})),
              Text(extent=[-150,112; 150,72],   string="%name"),
                 Line(points=[-76,-59; -73.2,-44.3; -70.3,-31.1; -66.8,-16.6;
                    -63.3,-4; -59.7,6.92; -55.5,18.18; -51.3,27.7; -46.3,37;
                    -40.6,45.5; -34.3,53.1; -27.2,59.6; -18.7,65.3; -8.1,70.2;
                    -6,71; -3.88,58.5; -1.05,43.7; 1.78,30.8; 4.606,19.45; 8.14,
                    7.3; 11.68,-3; 15.9,-13.2; 20.2,-21.6; 25.1,-29.5; 30.8,
                    -36.4; 37.1,-42.3; 44.9,-47.5; 54.8,-51.8; 64,-54.4],    style(
                    color=8))),
            Diagram,
            Documentation(info="<html>
The step response current source is built in bondgraphic technology from a bond graph <b>expSe</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the current source in its environment. <p>

<hr>

<pre>
Parameters:

 I:              Height of step response source current after infinite time (default value = 1 Amp)

 riseTime:       Rise time of step response to be generated (default value = 0.5 sec)

 riseTimeConst:  Rise time constant of step response to be generated (default value = 0.1)

 fallTimeConst:  Fall time constant of step response to be generated (default value = riseTimeConst)

 offset:         Offset of step response to be generated (default value = 0 Amp)

 startTime:      Start time of step response to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.eBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.expSf I1(
            riseTime=riseTime,
            riseTimeConst=riseTimeConst,
            fallTimeConst=fallTimeConst,
            offset=offset,
            startTime=startTime,
            f0=I) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(J1p3_1.BondCon3,B3. eBondCon1) annotation (points=[0,12; 
                7.34764e-016,12],
                     style(color=8));
          connect(B3.fBondCon1, I1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -81,
                1.77636e-015; -81,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end ExponentialsCurrent;
        
        model PulseCurrent "Pulse current source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Current I=1 "Amplitude of pulse";
          parameter Real width(
            final min=Modelica.Constants.small,
            final max=100) = 50 "Width of pulse in % of period";
          parameter Modelica.SIunits.Time period(final min=Modelica.Constants.small) = 1 
            "Time for one period";
          parameter Modelica.SIunits.Current offset=0 "Current offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Line(points=[-90,0; -50,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[50,0; 90,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[0,-50; 0,50],   style(color=0, rgbcolor={0,0,0})),
              Text(extent=[-150,112; 150,72],   string="%name"),
                 Line(points=[-68,-70; -38,-70; -38,70; 2,70; 2,-70; 42,-70; 42,
                    70; 82,70],    style(color=8))),
            Diagram,
            Documentation(info="<html>
The pulse current source is built in bondgraphic technology from a bond graph <b>pulseSf</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the current source in its environment. <p>

<hr>

<pre>
Parameters:

 I:          Amplitude of source current pulse (default value = 1 Amp)

 width:      Percentage of period in on state (default value = 50%)

 period:     Length of period of pulse to be generated (default value = 1 sec)

 offset:     Offset of pulse to be generated (default value = 0 Amp)

 startTime:  Start time of pulse to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.eBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.pulseSf I1(
            f0=I,
            width=width,
            period=period,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(J1p3_1.BondCon3,B3. eBondCon1) annotation (points=[0,12; 
                7.34764e-016,12],
                     style(color=8));
          connect(B3.fBondCon1, I1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 82,
                1.77636e-015; 82,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end PulseCurrent;
        
        model SawToothCurrent 
          "Saw tooth current source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Current I=1 "Amplitude of saw tooth";
          parameter Modelica.SIunits.Time period(final min=Modelica.Constants.small) = 1 
            "Time for one period";
          parameter Modelica.SIunits.Current offset=0 "Current offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Line(points=[-90,0; -50,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[50,0; 90,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[0,-50; 0,50],   style(color=0, rgbcolor={0,0,0})),
              Text(extent=[-150,112; 150,72],   string="%name"),
                 Line(points=[-76,-71; -56,-71; 4,70; 4,-71; 64,70; 64,-71],
                  style(color=8))),
            Diagram,
            Documentation(info="<html>
The saw tooth current source is built in bondgraphic technology from a bond graph <b>sawSf</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the current source in its environment. <p>

<hr>

<pre>
Parameters:

 I:          Amplitude of source current saw tooth (default value = 1 Amp)

 period:     Length of period of saw tooth to be generated (default value = 1 sec)

 offset:     Offset of saw tooth to be generated (default value = 0 Amp)

 startTime:  Start time of saw tooth to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.eBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.sawSf I1(
            f0=I,
            period=period,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(J1p3_1.BondCon3,B3. eBondCon1) annotation (points=[0,12; 
                7.34764e-016,12],
                     style(color=8));
          connect(B3.fBondCon1, I1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -79,
                1.77636e-015; -79,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end SawToothCurrent;
        
        model TrapezoidCurrent 
          "Trapezoidal current source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Modelica.SIunits.Current I=1 "Amplitude of saw tooth";
          parameter Modelica.SIunits.Time rising(final min=0) = 0 
            "Rising duration of trapezoid";
          parameter Modelica.SIunits.Time width(final min=0) = 0.5 
            "Width duration of trapezoid";
          parameter Modelica.SIunits.Time falling(final min=0) = 0 
            "Falling duration of trapezoid";
          parameter Modelica.SIunits.Time period(final min=Modelica.Constants.small) = 1 
            "Time for one period";
          parameter Integer nperiod=-1 
            "Number of periods (< 0 means infinite number of periods)";
          parameter Modelica.SIunits.Current offset=0 "Current offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Line(points=[-90,0; -50,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[50,0; 90,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[0,-50; 0,50],   style(color=0, rgbcolor={0,0,0})),
              Text(extent=[-150,112; 150,72],   string="%name"),
                 Line(points=[-81,-70; -60,-70; -30,70; 1,70; 30,-70; 51,-70;
                    80,70],  style(color=8))),
            Diagram,
            Documentation(info="<html>
The trapezoidal current source is built in bondgraphic technology from a bond graph <b>trapSf</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the current source in its environment. <p>

<hr>

<pre>
Parameters:

 I:          Amplitude of source current trapezoid (default value = 1 Amp)

 rising:     Length of rising time of trapezoid to be generated (default value = 0 sec)

 width :     Length of on state of trapezoid to be generated (default value = 0.5 sec)

 falling:    Length of falling time of trapezoid to be generated (default value = 0 sec)

 period:     Length of period of trapezoid to be generated (default value = 1 sec)

 nperiod:    Number of periods of trapezoid to be generated
             an infinite number of periods is being generated if nperiod &lt; 0 (default value = -1)

 offset:     Offset of trapezoid to be generated (default value = 0 Amp)

 startTime:  Start time of trapezoid to be generated (default value = 0 sec)
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.eBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.trapSf I1(
            f0=I,
            rising=rising,
            width=width,
            falling=falling,
            period=period,
            nperiod=nperiod,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(J1p3_1.BondCon3,B3. eBondCon1) annotation (points=[0,12; 
                7.34764e-016,12],
                     style(color=8));
          connect(B3.fBondCon1, I1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 81,
                1.77636e-015; 81,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end TrapezoidCurrent;
        
        model TableCurrent 
          "Tabular current source of analog electrical library" 
          extends Interfaces.OnePort;
          parameter Real table[:, :]=[0, 0; 1, 1; 2, 4] 
            "Table matrix (time = first column, current = second column)";
          parameter Modelica.SIunits.Current offset=0 "Current offset";
          parameter Modelica.SIunits.Time startTime=0 "Time offset";
          annotation (
            Icon(
              Ellipse(extent=[-50,50; 50,-50],   style(
                  color=0,
                  rgbcolor={0,0,0},
                  fillColor=7,
                  rgbfillColor={255,255,255})),
              Line(points=[-90,0; -50,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[50,0; 90,0],   style(color=0, rgbcolor={0,0,0})),
              Line(points=[0,-50; 0,50],   style(color=0, rgbcolor={0,0,0})),
              Text(extent=[-150,112; 150,72],   string="%name"),
                 Line(points=[-68,-44; -68,76; 32,76; 32,-44; -68,-44; -68,-14;
                    32,-14; 32,16; -68,16; -68,46; 32,46; 32,76; -18,76; -18,
                    -45],style(color=8))),
            Diagram,
            Documentation(info="<html>
The tabular current source is built in bondgraphic technology from a bond graph <b>tableSf</b> element, a 1-junction, and three bonds.  A-causal bonds must be used except at the source, because the causality depends on the embedding of the current source in its environment. <p>

<hr>

<pre>
Parameters:

 table:      Two-dimensional table with supporting values (default value = [0, 0; 1, 1; 2, 4])

 offset:     Offset of time function to be generated (default value = 0 Volt)

 startTime:  Start time of time function to be generated (default value = 0 sec)
</pre> <p>

<hr> <p>

The model generates a current source by <b>linear interpolation</b> in
a table. The time points and current values are stored in a matrix
<b>table[i,j]</b>, where the first column table[:,1] contains the
time points, and the second column contains the current to be interpolated.
The table interpolation has the following proporties: <p>

<ul>
<li>The time points need to be <b>monotonically increasing</b>.
<li><b>Discontinuities</b> are allowed, by providing the same
    time point twice in the table.
<li>Values <b>outside</b> of the table range, are computed by
    <b>extrapolation</b> through the last or first two points of the
    table.
<li>If the table has only <b>one row</b>, no interpolation is performed and
    the voltage value is just returned independantly of the
    actual time instant, i.e., this is a constant voltage source.
<li>Via parameters <b>startTime</b> and <b>offset</b> the curve defined
    by the table can be shifted both in time and in the voltage.
<li>The table is implemented in a numerically sound way by
    generating <b>time events</b> at interval boundaries,
    in order to not integrate over a discontinuous or not differentiable
    points.
</ul> <p>

<hr> <p>

<b>Example:</b> <p>

<pre>
   table = [0  0
            1  0
            1  1
            2  4
            3  9
            4 16]
If, e.g., time = 1.0, the current i =  0.0 (before event), 1.0 (after event)
    e.g., time = 1.5, the current i =  2.5,
    e.g., time = 2.0, the current i =  4.0,
    e.g., time = 5.0, the current i = 23.0 (i.e. extrapolation).
</pre>
</html>
"));
          Interfaces.El2BG El2BG1                           annotation (extent=[
                -62,-14; -38,14]);
          Interfaces.BG2El BG2El1                           annotation (extent=[38,
                -14; 64,14]);
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,12; 12,-12]);
          Bonds.Bond B1         annotation (extent=[12,-12; 38,12],   rotation=
                180);
          Bonds.Bond B2         annotation (extent=[-38,-12; -12,12],
              rotation=180);
          Bonds.eBond B3         annotation (extent=[-12,12; 12,36],   rotation=
               -90);
          BondLib.Sources.tableSf I1(
            table=table,
            offset=offset,
            startTime=startTime) 
            annotation (extent=[-12,36; 12,60], rotation=90);
        equation 
          connect(J1p3_1.BondCon2,B1. BondCon2) annotation (points=[12,0; 12,
                1.46953e-015],
                    style(color=8));
          connect(BG2El1.BondCon1,B1. BondCon1) annotation (points=[38,
                1.77636e-015; 38,-1.44014e-015; 37.74,-1.44014e-015],
                    style(color=8));
          connect(El2BG1.BondCon1,B2. BondCon2) annotation (points=[-38,
                1.77636e-015; -38,1.46953e-015],
                      style(color=8));
          connect(J1p3_1.BondCon1,B2. BondCon1) annotation (points=[-12,0; 
                -12.13,0; -12.13,-1.44014e-015; -12.26,-1.44014e-015],
                      style(color=8));
          connect(J1p3_1.BondCon3,B3. eBondCon1) annotation (points=[0,12; 
                7.34764e-016,12],
                     style(color=8));
          connect(B3.fBondCon1, I1.BondCon1) annotation (points=[-7.34764e-016,
                36; -7.34764e-016,36], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,1.77636e-015; -80,
                1.77636e-015; -80,0; -100,0],
                                style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,1.77636e-015; 80,
                1.77636e-015; 80,0; 100,0], style(color=3, rgbcolor={0,0,255}));
        end TableCurrent;
      end Sources;
      
      package Spice "Spice-style models of electronic circuits" 
        annotation (Icon(
            Rectangle(extent=[-100,-100; 80,50],   style(fillColor=30,
                  fillPattern=1)),
            Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50],
                style(fillColor=30, fillPattern=1)),
            Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70],
                style(fillColor=30, fillPattern=1)),
            Text(
              extent=[-85,35; 65,-85],
              string="Library",
              style(color=3)),
            Text(
              extent=[-118,114; 122,65],
              string="%name",
              style(color=1))), Documentation(info="<html>
This package contains Spice-style models of electronic circuit elements.
</html>
"));
        package Interfaces "Common interfaces of Spice-style models" 
          annotation (Icon(
              Text(
                extent=[-118,112; 122,63],
                string="%name",
                style(color=1)),
              Rectangle(extent=[-100,-100; 80,50],   style(
                  color=58,
                  fillColor=30,
                  fillPattern=1)),
              Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50],
                  style(
                  color=58,
                  fillColor=30,
                  fillPattern=1)),
              Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70],
                  style(
                  color=58,
                  fillColor=30,
                  fillPattern=1)),
              Text(
                extent=[-85,35; 65,-85],
                string="Library",
                style(color=58))), Documentation(info="<html>
This package contains common interfaces of Spice-style electronic circuit element models.
</html>
"));
          partial model SpiceTwoPort "TwoPort interface for Spice-style models" 
            extends BondLib.Electrical.Analog.Interfaces.OnePort;
            parameter Modelica.SIunits.Temperature Tnom=300.15 
              "Reference temperature";
            Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort(T(start=
                    300.15)) 
              annotation (extent=[-10,-90; 10,-110],   rotation=-90);
            annotation (Icon(
                Text(extent=[-40,86; 40,56],   string="%name")), Documentation(
                  info="<html>
All Spice-style OnePorts must have an additional HeatPort, even capacitors and inductors.  The reason is that they need the current circuit temperature, which they import through the HeatPort.
</html>
"));
          end SpiceTwoPort;
        end Interfaces;
        
        model R "Spice-style resistor of the analog electrical library" 
          extends Interfaces.SpiceTwoPort;
          parameter Modelica.SIunits.Resistance R=1 
            "Resistance at reference temperature";
          parameter Real TR1=0 "Linear temperature coefficient [Ohm/degree]";
          parameter Real TR2=0 
            "Quadratic temperature coefficient [Ohm/(degree*degree)]";
          parameter Real Area=1 "Relative area occupied by resistor";
          annotation (Icon(
              Rectangle(extent=[-70,30; 70,-30],   style(
                  color=3,
                  fillColor=7,
                  fillPattern=1)),
              Line(points=[-90,0; -70,0]),
              Line(points=[70,0; 90,0]),
              Line(points=[0,-30; 0,-91],   style(color=42)),
              Text(
                extent=[-100,-32; 100,-94],
                string="R=%R",
                style(color=0))),                              Diagram,
            Documentation(info="<html>
The Spice-style resistor has a reference resistance value computed at the reference temperature, <b>Tnom</b>, and for a relative area of <b>Area=1</b>.  It changes its value as a function of the circuit temperature and the relative area occupied by the resistor. <p>

<hr> <p>

<pre>
Parameters:

 R:     Reference resistance (default value = 1 Ohm)

 Tnom:  Reference temperature (default value = 300.15 <sup>o</sup>K)

 TR1:   Linear temperature variation coefficient (default value = 0 Ohm/<sup>o</sup>K)

 TR2:   Quadratic temperature variation coefficient (default value = 0 Ohm/<sup>o</sup>K<sup>2</sup>)

 Area:  Relative area occupied by resistor (default value = 1)
</pre> <p>
</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,28; 12,52]);
          Bonds.Bond B1         annotation (extent=[-38,28; -12,52]);
          Bonds.Bond B2         annotation (extent=[12,28; 38,52]);
          Bonds.Bond B3         annotation (extent=[-12,4; 12,28],    rotation=
                270);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=[
                -62,26; -38,54]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=[38,
                26; 64,54]);
          BondLib.Electrical.Analog.Interfaces.BG2Heat BG2Heat1 
            annotation (extent=[-12,-80; 12,-56], rotation=-90);
          BondLib.Bonds.eBond B4 
                         annotation (extent=[-12,-56; 12,-32], rotation=-90);
          BondLib.Spice.RS R1(
            Tnom=Tnom,
            R=R,
            TR1=TR1,
            TR2=TR2,
            Area=Area) annotation (extent=[-12,-32; 12,4], rotation=-90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,40; -12,
                40],  style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,40;
                12.26,40], style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,40;
                -37.74,40],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,40; 38,
                40],style(color=8));
          connect(B4.eBondCon1,BG2Heat1. BondCon1) annotation (points=[
                7.34764e-016,-56; -7.34764e-016,-56], style(color=8, rgbcolor={
                  192,192,192}));
          connect(J1p3_1.BondCon3, B3.BondCon1) annotation (points=[0,28; 0,
                27.76; 2.16021e-015,27.76], style(color=8, rgbcolor={192,192,
                  192}));
          connect(B3.BondCon2, R1.BondCon1)  annotation (points=[-2.20429e-015,
                4; -7.34764e-016,4], style(color=8, rgbcolor={192,192,192}));
          connect(R1.BondCon2, B4.fBondCon1)  annotation (points=[7.34764e-016,
                -32; -7.34764e-016,-32], style(color=8, rgbcolor={192,192,192}));
          connect(El2BG1.p, p) annotation (points=[-62,40; -80,40; -80,0; -100,
                0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,40; 80,40; 80,0; 100,0],
              style(color=3, rgbcolor={0,0,255}));
          connect(BG2Heat1.port_b, heatPort) annotation (points=[7.34764e-016,
                -80; 7.34764e-016,-82; 0,-80; 0,-100], style(color=42, rgbcolor=
                 {191,0,0}));
        end R;
        
        model C "Spice-style capacitor of the analog electrical library" 
          extends Interfaces.SpiceTwoPort;
          parameter Modelica.SIunits.Capacitance C=1 
            "Capacitance at reference temperature";
          parameter Real TC1=0 "Linear temperature coefficient [F/degree]";
          parameter Real TC2=0 
            "Quadratic temperature coefficient [F/(degree*degree)]";
          parameter Real Area=1 "Relative area occupied by capacitor";
          annotation (
            Icon(
              Line(points=[14,0; 90,0]),
              Line(points=[14,28; 14,-28],   style(thickness=2)),
              Line(points=[-14,28; -14,-28],   style(thickness=2)),
              Line(points=[-90,0; -14,0]),
              Line(points=[0,-28; 0,-91],   style(color=42)),
              Text(
                extent=[-100,-34; 100,-94],
                string="C=%C",
                style(color=0))),
            Diagram,
            Documentation(info="<html>
The Spice-style capacitor has a reference capacitance value computed at the reference temperature, <b>Tnom</b>, and for a relative area of <b>Area=1</b>.  It changes its value as a function of the circuit temperature and the relative area occupied by the capacitor. <p>

<hr> <p>

<pre>
Parameters:

 C:     Reference capacitance (default value = 1 F)

 Tnom:  Reference temperature (default value = 300.15 <sup>o</sup>K)

 TC1:   Linear temperature variation coefficient (default value = 0 F/<sup>o</sup>K)

 TC2:   Quadratic temperature variation coefficient (default value = 0 F/<sup>o</sup>K<sup>2</sup>)

 Area:  Relative area occupied by capacitor (default value = 1)
</pre> <p>
</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,28; 12,52]);
          Bonds.Bond B1         annotation (extent=[-38,28; -12,52]);
          Bonds.Bond B2         annotation (extent=[12,28; 38,52]);
          Bonds.Bond B3         annotation (extent=[-12,4; 12,28],    rotation=
                270);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=[
                -62,26; -38,54]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=[38,
                26; 64,54]);
          BondLib.Electrical.Analog.Interfaces.BG2Heat BG2Heat1 
            annotation (extent=[-12,-80; 12,-56], rotation=-90);
          BondLib.Bonds.eBond B4 
                         annotation (extent=[-12,-56; 12,-32], rotation=-90);
          BondLib.Spice.CS C1(
            Tnom=Tnom,
            C=C,
            TC1=TC1,
            TC2=TC2,
            Area=Area) annotation (extent=[-12,-32; 12,4], rotation=-90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,40; -12,
                40],  style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,40;
                12.26,40], style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,40;
                -37.74,40],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,40; 38,
                40],style(color=8));
          connect(B4.eBondCon1,BG2Heat1. BondCon1) annotation (points=[
                7.34764e-016,-56; -7.34764e-016,-56], style(color=8, rgbcolor={
                  192,192,192}));
          connect(J1p3_1.BondCon3,B3. BondCon1) annotation (points=[0,28; 0,
                27.76; 2.16021e-015,27.76], style(color=8, rgbcolor={192,192,
                  192}));
          connect(El2BG1.p, p) annotation (points=[-62,40; -80,40; -80,0; -100,
                0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,40; 80,40; 80,0; 100,0],
              style(color=3, rgbcolor={0,0,255}));
          connect(BG2Heat1.port_b, heatPort) annotation (points=[7.34764e-016,
                -80; 7.34764e-016,-85; 0,-85; 0,-100], style(color=42, rgbcolor=
                 {191,0,0}));
          connect(B3.BondCon2, C1.BondCon1) annotation (points=[-2.20429e-015,4; 
                -2.20429e-015,-1; -7.34764e-016,-1; -7.34764e-016,4], style(
                color=8, rgbcolor={192,192,192}));
          connect(C1.BondCon2, B4.fBondCon1) annotation (points=[7.34764e-016,
                -32; -7.34764e-016,-32], style(color=8, rgbcolor={192,192,192}));
        end C;
        
        model L "Spice-style inductor of the analog electrical library" 
          extends Interfaces.SpiceTwoPort;
          parameter Modelica.SIunits.Inductance L=1 
            "Inductance at reference temperature";
          parameter Real TL1=0 "Linear temperature coefficient [H/degree]";
          parameter Real TL2=0 
            "Quadratic temperature coefficient [H/(degree*degree)]";
          annotation (
            Icon(
              Line(points=[-90,0; -60,0]),
              Ellipse(extent=[-60,-15; -30,15]),
              Ellipse(extent=[-30,-15; 0,15]),
              Ellipse(extent=[0,-15; 30,15]),
              Ellipse(extent=[30,-15; 60,15]),
              Line(points=[60,0; 90,0]),
              Rectangle(extent=[-60,-28; 60,0],   style(color=7, fillColor=7)),
              Line(points=[0,0; 0,-91],     style(color=42)),
              Text(
                extent=[-100,-30; 100,-90],
                string="L=%L",
                style(color=0))),
            Diagram,
            Documentation(info="<html>
The Spice-style inductor has a reference inductance value computed at the reference temperature, <b>Tnom</b>.  It changes its value as a function of the circuit temperature. <p>

<hr> <p>

<pre>
Parameters:

 L:     Reference inductance (default value = 1 H)

 Tnom:  Reference temperature (default value = 300.15 <sup>o</sup>K)

 TL1:   Linear temperature variation coefficient (default value = 0 H/<sup>o</sup>K)

 TL2:   Quadratic temperature variation coefficient (default value = 0 H/<sup>o</sup>K<sup>2</sup>)
</pre> <p>

</html>
"));
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,28; 12,52]);
          Bonds.Bond B1         annotation (extent=[-38,28; -12,52]);
          Bonds.Bond B2         annotation (extent=[12,28; 38,52]);
          Bonds.Bond B3         annotation (extent=[-12,4; 12,28],    rotation=
                270);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=[
                -62,26; -38,54]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=[38,
                26; 64,54]);
          BondLib.Electrical.Analog.Interfaces.BG2Heat BG2Heat1 
            annotation (extent=[-12,-80; 12,-56], rotation=-90);
          BondLib.Bonds.eBond B4 
                         annotation (extent=[-12,-56; 12,-32], rotation=-90);
          BondLib.Spice.LS L1(
            Tnom=Tnom,
            L=L,
            TL1=TL1,
            TL2=TL2) annotation (extent=[-12,-32; 12,4], rotation=-90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,40; -12,
                40],  style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,40;
                12.26,40], style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,40;
                -37.74,40],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,40; 38,
                40],style(color=8));
          connect(B4.eBondCon1,BG2Heat1. BondCon1) annotation (points=[
                7.34764e-016,-56; -7.34764e-016,-56], style(color=8, rgbcolor={
                  192,192,192}));
          connect(J1p3_1.BondCon3,B3. BondCon1) annotation (points=[0,28; 0,
                27.76; 2.16021e-015,27.76], style(color=8, rgbcolor={192,192,
                  192}));
          connect(El2BG1.p, p) annotation (points=[-62,40; -80,40; -80,0; -100,
                0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,40; 80,40; 80,0; 100,0],
              style(color=3, rgbcolor={0,0,255}));
          connect(BG2Heat1.port_b, heatPort) annotation (points=[7.34764e-016,
                -80; 7.34764e-016,-85; 0,-85; 0,-100], style(color=42, rgbcolor=
                 {191,0,0}));
          connect(B3.BondCon2, L1.BondCon1) annotation (points=[-2.20429e-015,4; 
                -7.34764e-016,4], style(color=8, rgbcolor={192,192,192}));
          connect(L1.BondCon2, B4.fBondCon1) annotation (points=[7.34764e-016,
                -32; -7.34764e-016,-32], style(color=8, rgbcolor={192,192,192}));
        end L;
        
        model D "Spice-style diode of the analog electrical library" 
          extends Interfaces.SpiceTwoPort;
          parameter Modelica.SIunits.Current IS=1e-16 
            "Saturation current at reference temperature";
          parameter Modelica.SIunits.Voltage EG=1.16 
            "Activation energy at reference temperature";
          parameter Real N=1 "Emission coefficient";
          parameter Real XTI=3 "Temperature exponent of saturation current";
          parameter Real Area=1 "Relative area occupied by diode";
          parameter Real EMin=-100 
            "if x < EMin, the exp(x) function is linearized";
          parameter Real EMax=40 
            "if x > EMax, the exp(x) function is linearized";
          Junctions.J1p3 J1p3_1         annotation (extent=[-12,28; 12,52]);
          Bonds.Bond B1         annotation (extent=[-38,28; -12,52]);
          Bonds.Bond B2         annotation (extent=[12,28; 38,52]);
          Bonds.Bond B3         annotation (extent=[-12,4; 12,28],    rotation=
                270);
          BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=[
                -62,26; -38,54]);
          BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=[38,
                26; 64,54]);
          BondLib.Electrical.Analog.Interfaces.BG2Heat BG2Heat1 
            annotation (extent=[-12,-80; 12,-56], rotation=-90);
          BondLib.Bonds.eBond B4 
                         annotation (extent=[-12,-56; 12,-32], rotation=-90);
          BondLib.Spice.DS D1(
            Tnom=Tnom,
            IS=IS,
            EG=EG,
            N=N,
            XTI=XTI,
            Area=Area,
            EMin=EMin,
            EMax=EMax) annotation (extent=[-10,-32; 10,4], rotation=-90);
        equation 
          connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,40; -12,
                40],  style(color=8));
          connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,40;
                12.26,40], style(color=8));
          connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,40;
                -37.74,40],
                      style(color=8));
          connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,40; 38,
                40],style(color=8));
          connect(B4.eBondCon1,BG2Heat1. BondCon1) annotation (points=[
                7.34764e-016,-56; -7.34764e-016,-56], style(color=8, rgbcolor={
                  192,192,192}));
          connect(J1p3_1.BondCon3,B3. BondCon1) annotation (points=[0,28; 0,
                27.76; 2.16021e-015,27.76], style(color=8, rgbcolor={192,192,
                  192}));
          annotation (
            Diagram,
            Icon(
              Polygon(points=[30,0; -30,40; -30,-40; 30,0],     style(
                  color=3,
                  gradient=0,
                  fillColor=7)),
              Line(points=[-90,0; 40,0]),
              Line(points=[40,0; 90,0]),
              Line(points=[30,40; 30,-40],   style(color=3)),
              Line(points=[0,-20; 0,-91],   style(color=42))),
            Documentation(info="<html>
The Spice-style diode has a reference characteristic computed at the reference temperature, <b>Tnom</b>, and for a relative area of <b>Area=1</b>.  The characteristic changes its parameter value as a function of the circuit temperature and the relative area occupied by the diode. <p>

<hr> <p>

<pre>
Parameters:

 Tnom:    Reference temperature (default value = 300.15 K)

 IS:      Saturation current at reference temperature (default value = 1e-6 Amp)

 EG:      Activation energy at reference temperature (default value = 1.16 Volt)

 N:       Emission coefficient (default value = 1)

 XTI:     Temperature exponent of saturation current (default value = 3)

 Area:    Relative area occupied by the diode (default value = 1)

 EMin:    if x < EMin, the exp(x) function is linearized (default value = -100)

 EMax:    if x > EMax, the exp(x) function is linearized (default value = 40)
</pre> <p>
</html>
"));
          connect(El2BG1.p, p) annotation (points=[-62,40; -80,40; -80,0; -100,
                0], style(color=3, rgbcolor={0,0,255}));
          connect(BG2El1.n, n) annotation (points=[64,40; 80,40; 80,0; 100,0],
              style(color=3, rgbcolor={0,0,255}));
          connect(D1.BondCon1, B3.BondCon2) annotation (points=[-6.12303e-016,4; 
                -2.20429e-015,4], style(color=8, rgbcolor={192,192,192}));
          connect(D1.BondCon2, B4.fBondCon1) annotation (points=[6.12303e-016,
                -32; -7.34764e-016,-32], style(color=8, rgbcolor={192,192,192}));
          connect(BG2Heat1.port_b, heatPort) annotation (points=[7.34764e-016,
                -80; 0,-80; 0,-100], style(color=42, rgbcolor={191,0,0}));
        end D;
        
        model Qnl "Spice-style laterally diffused NPN bipolar transistor" 
          /* DC model parameters */
          parameter Real BF=50 
            "Forward beta coefficient at reference temperature";
          parameter Real BR=0.1 
            "Reverse beta coefficient at reference temperature";
          parameter Modelica.SIunits.Current IS=1e-16 
            "Saturation current at reference temperature";
          parameter Modelica.SIunits.Current ISS=1e-16 
            "Saturation current of substrate diode at reference temperature";
          parameter Real NF=1 "Forward emission coefficient";
          parameter Real NR=1 "Reverse emission coefficient";
          parameter Real NS=1 "Emission coefficient of substrate diode";
          parameter Modelica.SIunits.Conductance GminDC=1e-15 
            "Leakage conductance";
          
          /* Low current beta degradation effect parameters */
          parameter Modelica.SIunits.Current ISC=1e-16 
            "Collector saturation current at reference temperature";
          parameter Modelica.SIunits.Current ISE=1e-16 
            "Emitter saturation current at reference temperature";
          parameter Real NC=2 "Collector beta degradation coefficient";
          parameter Real NE=1.5 "Emitter beta degradation coefficient";
          
          /* Base width modulation parameters */
          parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
          parameter Modelica.SIunits.Voltage VAR=9e30 "Reverse early voltage";
          
          /* High current beta degradation effect parameters */
          parameter Modelica.SIunits.Current IKF=9e30 
            "Forward junction beta degradation current";
          parameter Modelica.SIunits.Current IKR=9e30 
            "Reverse junction beta degradation current";
          
          /* Parasitic Resistor Parameters */
          parameter Modelica.SIunits.Current IRB=0 
            "Parasitic base resistor current";
          parameter Modelica.SIunits.Resistance RB=0 
            "Parasitic base resistance value";
          parameter Modelica.SIunits.Resistance RBM=0 
            "Parasitic modified base resistance value";
          parameter Modelica.SIunits.Resistance RC=0 
            "Parasitic collector resistance value";
          parameter Modelica.SIunits.Resistance RE=0 
            "Parasitic emitter resistance value";
          
          /* Junction capacitor parameters */
          parameter Modelica.SIunits.Capacitance CJC=0.5e-12 
            "Base-collector zero bias depletion capacitance at reference temperature";
          parameter Real MJC=0.333 "Base-collector gradation exponent";
          parameter Modelica.SIunits.Voltage VJC=0.8 
            "Base-collector diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJE=0.4e-12 
            "Base-emitter zero bias depletion capacitance at reference temperature";
          parameter Real MJE=0.4 "Base-emitter gradation exponent";
          parameter Modelica.SIunits.Voltage VJE=0.8 
            "Base-emitter diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJS=0.4e-12 
            "Substrate zero bias depletion capacitance at reference temperature";
          parameter Real MJS=0.4 "Substrate gradation exponent";
          parameter Modelica.SIunits.Voltage VJS=0.8 
            "Substrate diffusion voltage at reference temperature";
          parameter Real XCJC=1 
            "Portion of depletion capacitance considered inside base-collector junction";
          
          /* Transit time parameters */
          parameter Modelica.SIunits.Time TF=0.12e-9 
            "Ideal forward transit time";
          parameter Modelica.SIunits.Time TR=5e-9 "Ideal reverse transit time";
          
          /* Temperature compensation and area parameters */
          parameter Real TRB1=0 
            "Linear temperature coefficient of base resistance [Ohm/degree]";
          parameter Real TRB2=0 
            "Quadratic temperature coefficient of base resistance [Ohm/(degree*degree)]";
          parameter Real TRM1=0 
            "Linear temperature coefficient of modified base resistance [Ohm/degree]";
          parameter Real TRM2=0 
            "Quadratic temperature coefficient of modified base resistance [Ohm/(degree*degree)]";
          parameter Real TRC1=0 
            "Linear temperature coefficient of collector resistance [Ohm/degree]";
          parameter Real TRC2=0 
            "Quadratic temperature coefficient of collector resistance [Ohm/(degree*degree)]";
          parameter Real TRE1=0 
            "Linear temperature coefficient of emitter resistance [Ohm/degree]";
          parameter Real TRE2=0 
            "Quadratic temperature coefficient of emitter resistance [Ohm/(degree*degree)]";
          parameter Modelica.SIunits.Temperature Tnom=300.15 
            "Reference temperature";
          parameter Real XTI=3 "Temperature exponent of saturation current";
          parameter Real XTB=0 "Temperature ratio exponent";
          parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
          parameter Real Area=1 "Relative area occupied by device";
          
          /* Substrate parameters */
          parameter Modelica.SIunits.Voltage VS=0 "Substrate potential";
          
          /* Numerical parameters */
          parameter Real EMin=-100 
            "if x < EMin, the exp(x) function is linearized";
          parameter Real EMax=40 
            "if x > EMax, the exp(x) function is linearized";
          Modelica.Electrical.Analog.Interfaces.Pin B "Base" annotation (extent=[
                -90,-10; -110,10]);
        public 
          Modelica.Electrical.Analog.Interfaces.Pin C "Collector" annotation (extent=[90,
                40; 110,60]);
          Modelica.Electrical.Analog.Interfaces.Pin E "Emitter" annotation (extent=[90,
                -40; 110,-60]);
          Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort(T(start=
                  300.15)) 
            annotation (extent=[-10,-90; 10,-110],   rotation=-90);
          Utilities.Qni Qni1(
            BF=BF,
            BR=BR,
            IS=IS,
            NF=NF,
            NR=NR,
            GminDC=GminDC,
            ISC=ISC,
            ISE=ISE,
            NC=NC,
            NE=NE,
            VAF=VAF,
            VAR=VAR,
            IKF=IKF,
            IKR=IKR) annotation (extent=[-20,-20; 20,20]);
          annotation (
            Diagram(
              Text(
                extent=[32,8; 42,0],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1),
                string="qb"),
              Text(
                extent=[-60,20; -50,12],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1),
                string="qb"),
              Ellipse(extent=[-2,-58; 2,-62], style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=42,
                  rgbfillColor={188,0,0},
                  fillPattern=1))),
            Icon(
              Line(points=[-10,40; -10,-40]),
              Line(points=[-10,0; -90,0]),
              Line(points=[91,50; 30,50]),
              Line(points=[30,50; -10,10]),
              Line(points=[-10,-10; 30,-50]),
              Line(points=[30,-50; 91,-50]),
              Polygon(points=[30,-50; 24,-36; 16,-44; 30,-50],     style(fillColor=3,
                      fillPattern=1)),
              Line(points=[0,-40; 0,-91],   style(color=42)),
            Text(
              extent=[12,30; 120,-34],
              string="%Area x",
              style(color=3, rgbcolor={0,0,255})),
              Text(extent=[-100,68; 100,94],    string="%name")),
            Documentation(info="<html>
The <b>Qnl</b> element of the Spice analog electrical library implements a full-fledges Spice-stye model of the laterally diffused NPN bipolar transistor [1-3]. The model contains a <b>Qni</b> model implementing the inner parts of the NPN transistor up to the internal nodes. <p>

<hr>

<pre>
<b>DC Model Parameters:</b>

 BF:      Forward beta coefficient (default value = 50)

 BR:      Reverse beta coefficient (default value = 0.1)

 IS:      Transport saturation current (default value = 1e-16 Amp)

 ISS:     Transport saturation current of substrate diode (default value = 1e-16 Amp)

 NF:      Forward emission coefficient (default value = 1)

 NR:      Reverse emission coefficient (default value = 1)

 NS:      Emission coefficient of substrate diode (default value = 1)

 GminDC:  Junction leakage conductance (default value = 1e-15 Mho)


<b>Low Current Beta Degradation Effect Parameters:</b>

 ISC:     Collector saturation current at reference temperature (default value = 1e-16 Amp)

 ISE:     Emitter saturation current at reference temperature (default value = 1e-16 Amp)

 NC:      Collector beta degradation coefficient (default value = 2)

 NE:      Emitter beta degradation coefficient (default value = 1.5)


<b>Base Width Modulation Parameters:</b>
  
 VAF:     Forward early voltage (default value = 9e30 Volt)

 VAR:     Reverse early voltage (default value = 9e30 Volt)


<b>High Current Beta Degradation Effect Parameters:</b>

 IKF:     Forward junction beta degradation current (default value = 9e30 Amp)

 IKR:     Reverse junction beta degradation current (default value = 9e30 Amp)


<b>Parasitic Resistor Parameters:</b>

 IRB:     Parasitic base resistor current (default value = 0 Amp)

 RB:      Parasitic base resistance value (default value = 0 Ohm)

 RBM:     Parasitic modified base resistance value (default value = 0 Ohm)

 RC:      Parasitic collector resistance value (default value = 0 Ohm)

 RE:      Parasitic emitter resistance value (default value = 0 Ohm)


<b>Junction Capacitor Parameters:</b>

 CJC:     Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 MJC:     Base-collector gradation exponent (default value = 0.333)

 VJC:     Base-collector diffusion voltage (default value = 0.8 Volt)

 CJE:     Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 MJE:     Base-emitter gradation exponent (default value = 0.4)

 VJE:     Base-emitter diffusion voltage (default value = 0.8 Volt)

 CJS:     Substrate zero bias depletion capacitance (default value = 0.4e-12 F)

 MJS:     Substrate gradation exponent (default value = 0.4)

 VJS:     Substrate diffusion voltage (default value = 0.8 Volt)

 XCJC:    Portion of depletion capacitance considered inside base-collector junction (default value = 1)


<b>Transit Time Parameters:</b>

 TF:      Ideal forward transit time (default value = 0.12e-9 sec)

 TR:      Ideal reverse transit time (default value = 5e-9 sec)


<b>Temperature Compensation and Area Parameters:</b>

 TRB1:    Linear temperature coefficient of base resistance (default value = 0 Ohm/degree)

 TRB2:    Quadratic temperature coefficient of base resistance (default value = 0 Ohm/(degree*degree))

 TRM1:    Linear temperature coefficient of modified base resistance (default value = 0 Ohm/degree)

 TRM2:    Quadratic temperature coefficient of modified base resistance (default value = 0 Ohm/(degree*degree))

 TRC1:    Linear temperature coefficient of collector resistance (default value = 0 Ohm/degree)

 TRC2:    Quadratic temperature coefficient of collector resistance (default value = 0 Ohm/(degree*degree))

 TRE1:    Linear temperature coefficient of emitter resistance (default value = 0 Ohm/degree)

 TRE2:    Quadratic temperature coefficient of emitter resistance (default value = 0 Ohm/(degree*degree))

 Tnom:    Reference temperature (default value = 300.15 <sup>o</sup>K)

 XTI:     Temperature exponent of saturation current (default value = 3)

 XTB:     Temperature ratio exponent (default value = 0)

 EG:      Activation energy (default value = 1.16 Volt)

 Area:    Relative area occupied by device (default value = 1)


<b>Substrate parameters:</b>

 VS:      Substrate potential (default value = 0 Volt)

  
<b>Numerical Parameters:</b>

 EMin:    Minimum exponent (default value = -100)

 EMax:    Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li>Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York.
<li>Hild, D.R. and F.E. Cellier (1994), \"Object-oriented electronic circuit modeling using Dymola,\"
    <i>Proc. OOS'94, SCS Object Oriented Simulation Conference</i>, Tempe, AZ, pp.68-75.
<li>Hild, D.R. (1993), <i>Circuit Modeling in Dymola</i>, MS Thesis, Dept. of Electr. &amp; Comp. Engr.,
    University of Arizona, Tucson.
<li>Schweisguth, M.C. and F.E. Cellier (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/BJT.pdf\">A
    bond graph model of the bipolar junction transistor</a>,\" <i>Proc. SCS Intl. Conf. on Bond Graph Modeling</i>,
    San Francisco, CA, pp.344-349.
<li>Schweisguth, M.C. (1997), <a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/schweisguth_ms.pdf\"><i>Semiconductor
    Modeling with Bondgraphs</i></a>, MS Thesis, Dept. of Electr. &amp; Comp. Engr., University of Arizona, Tucson.
</ol> 
</html>
"));
          Utilities.Rb RB1(
            Tnom=Tnom,
            RB=RB,
            RBM=RBM,
            IRB=IRB,
            TRB1=TRB1,
            TRB2=TRB2,
            TRM1=TRM1,
            TRM2=TRM2,
            Area=Area) annotation (extent=[-80,-10; -40,10]);
          R RC1(
            Tnom=Tnom,
            R=RC,
            TR1=TRC1,
            TR2=TRC2,
            Area=Area) annotation (extent=[40,40; 80,60]);
          R RE1(
            Tnom=Tnom,
            Area=Area,
            R=RE,
            TR1=TRE1,
            TR2=TRE2) annotation (extent=[40,-60; 80,-40]);
          Utilities.Cbx Cbx1(
            Tnom=Tnom,
            EG=EG,
            VJ=VJC,
            CJ=CJC,
            XCJ=XCJC,
            MJ=MJC,
            Area=Area) annotation (extent=[-50,40; -10,60]);
          Utilities.Dj Dbs(
            Tnom=Tnom,
            IS=ISS,
            EG=EG,
            N=NS,
            XTI=XTI,
            VJ=VJS,
            CJ=CJS,
            XCJ=1,
            MJ=MJS,
            Tau=0,
            GminDC=GminDC,
            Area=Area,
            BE=false,
            EMin=EMin,
            EMax=EMax) annotation (extent=[-10,-80; -30,-40], rotation=-90);
          Sources.ConstantVoltage VS1(V=VS) 
            annotation (extent=[-30,-90; -70,-70]);
          Basic.Ground Gnd1 annotation (extent=[-76,-96; -64,-86]);
        Modelica.Blocks.Sources.Constant C01(k=0) 
          annotation (extent=[-60,-46; -48,-34]);
        Modelica.Blocks.Sources.Constant qb1(k=1) 
          annotation (extent=[-60,-66; -48,-54]);
        equation 
          connect(Qni1.heatPort, heatPort) annotation (points=[0,-20; 0,-100],
              style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RC1.n, C) annotation (points=[80,50; 100,50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Qni1.Cint, RC1.p) annotation (points=[20,10; 20,50; 40,50],
              style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RE1.n, E) annotation (points=[80,-50; 100,-50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Qni1.Eint, RE1.p) annotation (points=[20,-10; 20,-50; 40,-50],
              style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RE1.heatPort, heatPort) annotation (points=[60,-60; 0,-60; 0,
                -100], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RC1.heatPort, heatPort) annotation (points=[60,40; 60,-20; 0,
                -20; 0,-100], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RB1.heatPort, Qni1.heatPort) annotation (points=[-60,-10; -60,
                -20; 0,-20], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Cbx1.n, RC1.p) annotation (points=[-10,50; 40,50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Cbx1.p, RB1.p) annotation (points=[-50,50; -80,50; -80,0],
              style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RB1.n, Qni1.Bint) annotation (points=[-40,0; -20,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RB1.p, B) annotation (points=[-80,0; -100,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Cbx1.heatPort, Qni1.heatPort) annotation (points=[-30,40; -30,
                -20; 0,-20], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Qni1.qb, RB1.qb) annotation (points=[22,0; 30,0; 30,30; -60,
                30; -60,10], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Qni1.Bint, Dbs.p) annotation (points=[-20,0; -20,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(VS1.p, Dbs.n) annotation (points=[-30,-80; -20,-80], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Gnd1.p, VS1.n) annotation (points=[-70,-86; -70,-80], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Dbs.heatPort, heatPort) annotation (points=[-10,-60; 0,-60; 0,
                -100], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(qb1.y, Dbs.qb) annotation (points=[-47.4,-60; -40,-60; -40,
                -68; -30,-68], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(C01.y, Dbs.C0) annotation (points=[-47.4,-40; -40,-40; -40,
                -52; -30,-52], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
        end Qnl;
        
        model Qnv "Spice-style vertically diffused NPN bipolar transistor" 
          /* DC model parameters */
          parameter Real BF=50 
            "Forward beta coefficient at reference temperature";
          parameter Real BR=0.1 
            "Reverse beta coefficient at reference temperature";
          parameter Modelica.SIunits.Current IS=1e-16 
            "Saturation current at reference temperature";
          parameter Modelica.SIunits.Current ISS=1e-16 
            "Saturation current of substrate diode at reference temperature";
          parameter Real NF=1 "Forward emission coefficient";
          parameter Real NR=1 "Reverse emission coefficient";
          parameter Real NS=1 "Emission coefficient of substrate diode";
          parameter Modelica.SIunits.Conductance GminDC=1e-15 
            "Leakage conductance";
          
          /* Low current beta degradation effect parameters */
          parameter Modelica.SIunits.Current ISC=1e-16 
            "Collector saturation current at reference temperature";
          parameter Modelica.SIunits.Current ISE=1e-16 
            "Emitter saturation current at reference temperature";
          parameter Real NC=2 "Collector beta degradation coefficient";
          parameter Real NE=1.5 "Emitter beta degradation coefficient";
          
          /* Base width modulation parameters */
          parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
          parameter Modelica.SIunits.Voltage VAR=9e30 "Reverse early voltage";
          
          /* High current beta degradation effect parameters */
          parameter Modelica.SIunits.Current IKF=9e30 
            "Forward junction beta degradation current";
          parameter Modelica.SIunits.Current IKR=9e30 
            "Reverse junction beta degradation current";
          
          /* Parasitic Resistor Parameters */
          parameter Modelica.SIunits.Current IRB=0 
            "Parasitic base resistor current";
          parameter Modelica.SIunits.Resistance RB=0 
            "Parasitic base resistance value";
          parameter Modelica.SIunits.Resistance RBM=0 
            "Parasitic modified base resistance value";
          parameter Modelica.SIunits.Resistance RC=0 
            "Parasitic collector resistance value";
          parameter Modelica.SIunits.Resistance RE=0 
            "Parasitic emitter resistance value";
          
          /* Junction capacitor parameters */
          parameter Modelica.SIunits.Capacitance CJC=0.5e-12 
            "Base-collector zero bias depletion capacitance at reference temperature";
          parameter Real MJC=0.333 "Base-collector gradation exponent";
          parameter Modelica.SIunits.Voltage VJC=0.8 
            "Base-collector diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJE=0.4e-12 
            "Base-emitter zero bias depletion capacitance at reference temperature";
          parameter Real MJE=0.4 "Base-emitter gradation exponent";
          parameter Modelica.SIunits.Voltage VJE=0.8 
            "Base-emitter diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJS=0.4e-12 
            "Substrate zero bias depletion capacitance at reference temperature";
          parameter Real MJS=0.4 "Substrate gradation exponent";
          parameter Modelica.SIunits.Voltage VJS=0.8 
            "Substrate diffusion voltage at reference temperature";
          parameter Real XCJC=1 
            "Portion of depletion capacitance considered inside base-collector junction";
          
          /* Transit time parameters */
          parameter Modelica.SIunits.Time TF=0.12e-9 
            "Ideal forward transit time";
          parameter Modelica.SIunits.Time TR=5e-9 "Ideal reverse transit time";
          
          /* Temperature compensation and area parameters */
          parameter Real TRB1=0 
            "Linear temperature coefficient of base resistance [Ohm/degree]";
          parameter Real TRB2=0 
            "Quadratic temperature coefficient of base resistance [Ohm/(degree*degree)]";
          parameter Real TRM1=0 
            "Linear temperature coefficient of modified base resistance [Ohm/degree]";
          parameter Real TRM2=0 
            "Quadratic temperature coefficient of modified base resistance [Ohm/(degree*degree)]";
          parameter Real TRC1=0 
            "Linear temperature coefficient of collector resistance [Ohm/degree]";
          parameter Real TRC2=0 
            "Quadratic temperature coefficient of collector resistance [Ohm/(degree*degree)]";
          parameter Real TRE1=0 
            "Linear temperature coefficient of emitter resistance [Ohm/degree]";
          parameter Real TRE2=0 
            "Quadratic temperature coefficient of emitter resistance [Ohm/(degree*degree)]";
          parameter Modelica.SIunits.Temperature Tnom=300.15 
            "Reference temperature";
          parameter Real XTI=3 "Temperature exponent of saturation current";
          parameter Real XTB=0 "Temperature ratio exponent";
          parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
          parameter Real Area=1 "Relative area occupied by device";
          
          /* Substrate parameters */
          parameter Modelica.SIunits.Voltage VS=0 "Substrate potential";
          
          /* Numerical parameters */
          parameter Real EMin=-100 
            "if x < EMin, the exp(x) function is linearized";
          parameter Real EMax=40 
            "if x > EMax, the exp(x) function is linearized";
          Modelica.Electrical.Analog.Interfaces.Pin B "Base" annotation (extent=[
                -90,-10; -110,10]);
        public 
          Modelica.Electrical.Analog.Interfaces.Pin C "Collector" annotation (extent=[90,
                40; 110,60]);
          Modelica.Electrical.Analog.Interfaces.Pin E "Emitter" annotation (extent=[90,
                -40; 110,-60]);
          Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort(T(start=
                  300.15)) 
            annotation (extent=[-10,-90; 10,-110],   rotation=-90);
          Utilities.Qni Qni1(
            BF=BF,
            BR=BR,
            IS=IS,
            NF=NF,
            NR=NR,
            GminDC=GminDC,
            ISC=ISC,
            ISE=ISE,
            NC=NC,
            NE=NE,
            VAF=VAF,
            VAR=VAR,
            IKF=IKF,
            IKR=IKR) annotation (extent=[-40,-20; 0,20]);
          Utilities.Rb RB1(
            Tnom=Tnom,
            RB=RB,
            RBM=RBM,
            IRB=IRB,
            TRB1=TRB1,
            TRB2=TRB2,
            TRM1=TRM1,
            TRM2=TRM2,
            Area=Area) annotation (extent=[-88,-10; -48,10]);
          R RC1(
            Tnom=Tnom,
            R=RC,
            TR1=TRC1,
            TR2=TRC2,
            Area=Area) annotation (extent=[40,40; 80,60]);
          R RE1(
            Tnom=Tnom,
            Area=Area,
            R=RE,
            TR1=TRE1,
            TR2=TRE2) annotation (extent=[40,-60; 80,-40]);
          Utilities.Cbx Cbx1(
            Tnom=Tnom,
            EG=EG,
            VJ=VJC,
            CJ=CJC,
            XCJ=XCJC,
            MJ=MJC,
            Area=Area) annotation (extent=[-50,40; -10,60]);
          Utilities.Dj Dsc(
            Tnom=Tnom,
            IS=ISS,
            EG=EG,
            N=NS,
            XTI=XTI,
            VJ=VJS,
            CJ=CJS,
            XCJ=1,
            MJ=MJS,
            Tau=0,
            GminDC=GminDC,
            Area=Area,
            BE=false,
            EMin=EMin,
            EMax=EMax) annotation (extent=[50,-20; 30,20], rotation=90);
          Sources.ConstantVoltage VS1(V=VS) annotation (extent=[50,-30; 90,-10]);
          Basic.Ground Gnd1 annotation (extent=[84,-36; 96,-26]);
        Modelica.Blocks.Sources.Constant C01(k=0) 
          annotation (extent=[80,-6; 68,6]);
        Modelica.Blocks.Sources.Constant qb1(k=1) 
          annotation (extent=[80,14; 68,26]);
          annotation (
            Diagram(Text(
                extent=[2,8; 12,0],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1),
                string="qb"), Text(
                extent=[-68,20; -58,12],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1),
                string="qb")),
            Icon(
              Line(points=[-10,40; -10,-40]),
              Line(points=[-10,0; -90,0]),
              Line(points=[91,50; 30,50]),
              Line(points=[30,50; -10,10]),
              Line(points=[-10,-10; 30,-50]),
              Line(points=[30,-50; 91,-50]),
              Polygon(points=[30,-50; 24,-36; 16,-44; 30,-50],     style(fillColor=3,
                      fillPattern=1)),
              Line(points=[0,-40; 0,-91],   style(color=42)),
            Text(
              extent=[40,30; 82,-28],
              string="%Area x",
              style(color=3, rgbcolor={0,0,255})),
              Text(extent=[-100,68; 100,94],    string="%name")),
            Documentation(info="<html>
The <b>Qnv</b> element of the Spice analog electrical library implements a full-fledges Spice-stye model of the vertically diffused NPN bipolar transistor [1-3]. The model contains a <b>Qni</b> model implementing the inner parts of the NPN transistor up to the internal nodes. <p>

<hr>

<pre>
<b>DC Model Parameters:</b>

 BF:      Forward beta coefficient (default value = 50)

 BR:      Reverse beta coefficient (default value = 0.1)

 IS:      Transport saturation current (default value = 1e-16 Amp)

 ISS:     Transport saturation current of substrate diode (default value = 1e-16 Amp)

 NF:      Forward emission coefficient (default value = 1)

 NR:      Reverse emission coefficient (default value = 1)

 NS:      Emission coefficient of substrate diode (default value = 1)

 GminDC:  Junction leakage conductance (default value = 1e-15 Mho)


<b>Low Current Beta Degradation Effect Parameters:</b>

 ISC:     Collector saturation current at reference temperature (default value = 1e-16 Amp)

 ISE:     Emitter saturation current at reference temperature (default value = 1e-16 Amp)

 NC:      Collector beta degradation coefficient (default value = 2)

 NE:      Emitter beta degradation coefficient (default value = 1.5)


<b>Base Width Modulation Parameters:</b>
  
 VAF:     Forward early voltage (default value = 9e30 Volt)

 VAR:     Reverse early voltage (default value = 9e30 Volt)


<b>High Current Beta Degradation Effect Parameters:</b>

 IKF:     Forward junction beta degradation current (default value = 9e30 Amp)

 IKR:     Reverse junction beta degradation current (default value = 9e30 Amp)


<b>Parasitic Resistor Parameters:</b>

 IRB:     Parasitic base resistor current (default value = 0 Amp)

 RB:      Parasitic base resistance value (default value = 0 Ohm)

 RBM:     Parasitic modified base resistance value (default value = 0 Ohm)

 RC:      Parasitic collector resistance value (default value = 0 Ohm)

 RE:      Parasitic emitter resistance value (default value = 0 Ohm)


<b>Junction Capacitor Parameters:</b>

 CJC:     Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 MJC:     Base-collector gradation exponent (default value = 0.333)

 VJC:     Base-collector diffusion voltage (default value = 0.8 Volt)

 CJE:     Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 MJE:     Base-emitter gradation exponent (default value = 0.4)

 VJE:     Base-emitter diffusion voltage (default value = 0.8 Volt)

 CJS:     Substrate zero bias depletion capacitance (default value = 0.4e-12 F)

 MJS:     Substrate gradation exponent (default value = 0.4)

 VJS:     Substrate diffusion voltage (default value = 0.8 Volt)

 XCJC:    Portion of depletion capacitance considered inside base-collector junction (default value = 1)


<b>Transit Time Parameters:</b>

 TF:      Ideal forward transit time (default value = 0.12e-9 sec)

 TR:      Ideal reverse transit time (default value = 5e-9 sec)


<b>Temperature Compensation and Area Parameters:</b>

 TRB1:    Linear temperature coefficient of base resistance (default value = 0 Ohm/degree)

 TRB2:    Quadratic temperature coefficient of base resistance (default value = 0 Ohm/(degree*degree))

 TRM1:    Linear temperature coefficient of modified base resistance (default value = 0 Ohm/degree)

 TRM2:    Quadratic temperature coefficient of modified base resistance (default value = 0 Ohm/(degree*degree))

 TRC1:    Linear temperature coefficient of collector resistance (default value = 0 Ohm/degree)

 TRC2:    Quadratic temperature coefficient of collector resistance (default value = 0 Ohm/(degree*degree))

 TRE1:    Linear temperature coefficient of emitter resistance (default value = 0 Ohm/degree)

 TRE2:    Quadratic temperature coefficient of emitter resistance (default value = 0 Ohm/(degree*degree))

 Tnom:    Reference temperature (default value = 300.15 <sup>o</sup>K)

 XTI:     Temperature exponent of saturation current (default value = 3)

 XTB:     Temperature ratio exponent (default value = 0)

 EG:      Activation energy (default value = 1.16 Volt)

 Area:    Relative area occupied by device (default value = 1)


<b>Substrate parameters:</b>

 VS:      Substrate potential (default value = 0 Volt)

  
<b>Numerical Parameters:</b>

 EMin:    Minimum exponent (default value = -100)

 EMax:    Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li>Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York.
<li>Hild, D.R. and F.E. Cellier (1994), \"Object-oriented electronic circuit modeling using Dymola,\"
    <i>Proc. OOS'94, SCS Object Oriented Simulation Conference</i>, Tempe, AZ, pp.68-75.
<li>Hild, D.R. (1993), <i>Circuit Modeling in Dymola</i>, MS Thesis, Dept. of Electr. &amp; Comp. Engr.,
    University of Arizona, Tucson.
<li>Schweisguth, M.C. and F.E. Cellier (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/BJT.pdf\">A
    bond graph model of the bipolar junction transistor</a>,\" <i>Proc. SCS Intl. Conf. on Bond Graph Modeling</i>,
    San Francisco, CA, pp.344-349.
<li>Schweisguth, M.C. (1997), <a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/schweisguth_ms.pdf\"><i>Semiconductor
    Modeling with Bondgraphs</i></a>, MS Thesis, Dept. of Electr. &amp; Comp. Engr., University of Arizona, Tucson.
</ol> 
</html>
"));
        equation 
          connect(RC1.n, C) annotation (points=[80,50; 100,50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Qni1.Cint, RC1.p) annotation (points=[0,10; 0,50; 40,50],
              style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RE1.n, E) annotation (points=[80,-50; 100,-50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Qni1.Eint, RE1.p) annotation (points=[0,-10; 0,-50; 40,-50],
              style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RB1.heatPort, Qni1.heatPort) annotation (points=[-68,-10; -68,
                -20; -20,-20], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Cbx1.n, RC1.p) annotation (points=[-10,50; 40,50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Cbx1.p, RB1.p) annotation (points=[-50,50; -88,50; -88,0],
              style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RB1.n, Qni1.Bint) annotation (points=[-48,0; -40,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RB1.p, B) annotation (points=[-88,0; -100,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Cbx1.heatPort, Qni1.heatPort) annotation (points=[-30,40; -30,
                -20; -20,-20], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Qni1.qb, RB1.qb) annotation (points=[2,0; 12,0; 12,30; -68,30;
                -68,10], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Dsc.p, VS1.p) annotation (points=[40,-20; 50,-20], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Dsc.n, RC1.p) annotation (points=[40,20; 40,50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Gnd1.p, VS1.n) annotation (points=[90,-26; 90,-20], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(RC1.heatPort, Dsc.heatPort) annotation (points=[60,40; 30,40; 
                30,-1.22461e-015], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Qni1.heatPort, heatPort) annotation (points=[-20,-20; -20,-60;
                0,-60; 0,-100], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(RE1.heatPort, heatPort) annotation (points=[60,-60; 0,-60; 0,
                -100], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Dsc.heatPort, heatPort) annotation (points=[30,-1.22461e-015; 
                30,-60; 0,-60; 0,-100], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(C01.y, Dsc.C0) annotation (points=[67.4,0; 60,0; 60,-8; 50,-8],
              style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(qb1.y, Dsc.qb) annotation (points=[67.4,20; 60,20; 60,8; 50,8],
              style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
        end Qnv;
        
        model Qpl "Spice-style laterally diffused PNP bipolar transistor" 
          /* DC model parameters */
          parameter Real BF=50 
            "Forward beta coefficient at reference temperature";
          parameter Real BR=0.1 
            "Reverse beta coefficient at reference temperature";
          parameter Modelica.SIunits.Current IS=1e-16 
            "Saturation current at reference temperature";
          parameter Modelica.SIunits.Current ISS=1e-16 
            "Saturation current of substrate diode at reference temperature";
          parameter Real NF=1 "Forward emission coefficient";
          parameter Real NR=1 "Reverse emission coefficient";
          parameter Real NS=1 "Emission coefficient of substrate diode";
          parameter Modelica.SIunits.Conductance GminDC=1e-15 
            "Leakage conductance";
          
          /* Low current beta degradation effect parameters */
          parameter Modelica.SIunits.Current ISC=1e-16 
            "Collector saturation current at reference temperature";
          parameter Modelica.SIunits.Current ISE=1e-16 
            "Emitter saturation current at reference temperature";
          parameter Real NC=2 "Collector beta degradation coefficient";
          parameter Real NE=1.5 "Emitter beta degradation coefficient";
          
          /* Base width modulation parameters */
          parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
          parameter Modelica.SIunits.Voltage VAR=9e30 "Reverse early voltage";
          
          /* High current beta degradation effect parameters */
          parameter Modelica.SIunits.Current IKF=9e30 
            "Forward junction beta degradation current";
          parameter Modelica.SIunits.Current IKR=9e30 
            "Reverse junction beta degradation current";
          
          /* Parasitic Resistor Parameters */
          parameter Modelica.SIunits.Current IRB=0 
            "Parasitic base resistor current";
          parameter Modelica.SIunits.Resistance RB=0 
            "Parasitic base resistance value";
          parameter Modelica.SIunits.Resistance RBM=0 
            "Parasitic modified base resistance value";
          parameter Modelica.SIunits.Resistance RC=0 
            "Parasitic collector resistance value";
          parameter Modelica.SIunits.Resistance RE=0 
            "Parasitic emitter resistance value";
          
          /* Junction capacitor parameters */
          parameter Modelica.SIunits.Capacitance CJC=0.5e-12 
            "Base-collector zero bias depletion capacitance at reference temperature";
          parameter Real MJC=0.333 "Base-collector gradation exponent";
          parameter Modelica.SIunits.Voltage VJC=0.8 
            "Base-collector diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJE=0.4e-12 
            "Base-emitter zero bias depletion capacitance at reference temperature";
          parameter Real MJE=0.4 "Base-emitter gradation exponent";
          parameter Modelica.SIunits.Voltage VJE=0.8 
            "Base-emitter diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJS=0.4e-12 
            "Substrate zero bias depletion capacitance at reference temperature";
          parameter Real MJS=0.4 "Substrate gradation exponent";
          parameter Modelica.SIunits.Voltage VJS=0.8 
            "Substrate diffusion voltage at reference temperature";
          parameter Real XCJC=1 
            "Portion of depletion capacitance considered inside base-collector junction";
          
          /* Transit time parameters */
          parameter Modelica.SIunits.Time TF=0.12e-9 
            "Ideal forward transit time";
          parameter Modelica.SIunits.Time TR=5e-9 "Ideal reverse transit time";
          
          /* Temperature compensation and area parameters */
          parameter Real TRB1=0 
            "Linear temperature coefficient of base resistance [Ohm/degree]";
          parameter Real TRB2=0 
            "Quadratic temperature coefficient of base resistance [Ohm/(degree*degree)]";
          parameter Real TRM1=0 
            "Linear temperature coefficient of modified base resistance [Ohm/degree]";
          parameter Real TRM2=0 
            "Quadratic temperature coefficient of modified base resistance [Ohm/(degree*degree)]";
          parameter Real TRC1=0 
            "Linear temperature coefficient of collector resistance [Ohm/degree]";
          parameter Real TRC2=0 
            "Quadratic temperature coefficient of collector resistance [Ohm/(degree*degree)]";
          parameter Real TRE1=0 
            "Linear temperature coefficient of emitter resistance [Ohm/degree]";
          parameter Real TRE2=0 
            "Quadratic temperature coefficient of emitter resistance [Ohm/(degree*degree)]";
          parameter Modelica.SIunits.Temperature Tnom=300.15 
            "Reference temperature";
          parameter Real XTI=3 "Temperature exponent of saturation current";
          parameter Real XTB=0 "Temperature ratio exponent";
          parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
          parameter Real Area=1 "Relative area occupied by device";
          
          /* Substrate parameters */
          parameter Modelica.SIunits.Voltage VS=0 "Substrate potential";
          
          /* Numerical parameters */
          parameter Real EMin=-100 
            "if x < EMin, the exp(x) function is linearized";
          parameter Real EMax=40 
            "if x > EMax, the exp(x) function is linearized";
          Modelica.Electrical.Analog.Interfaces.Pin B "Base" annotation (extent=[
                -90,-10; -110,10]);
        public 
          Modelica.Electrical.Analog.Interfaces.Pin C "Collector" annotation (extent=[90,
                40; 110,60]);
          Modelica.Electrical.Analog.Interfaces.Pin E "Emitter" annotation (extent=[90,
                -40; 110,-60]);
          Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort(T(start=
                  300.15)) 
            annotation (extent=[-10,-90; 10,-110],   rotation=-90);
          Utilities.Rb RB1(
            Tnom=Tnom,
            RB=RB,
            RBM=RBM,
            IRB=IRB,
            TRB1=TRB1,
            TRB2=TRB2,
            TRM1=TRM1,
            TRM2=TRM2,
            Area=Area) annotation (extent=[-80,-10; -40,10]);
          R RC1(
            Tnom=Tnom,
            R=RC,
            TR1=TRC1,
            TR2=TRC2,
            Area=Area) annotation (extent=[40,40; 80,60]);
          R RE1(
            Tnom=Tnom,
            Area=Area,
            R=RE,
            TR1=TRE1,
            TR2=TRE2) annotation (extent=[40,-60; 80,-40]);
          Utilities.Cbx Cbx1(
            Tnom=Tnom,
            EG=EG,
            VJ=VJC,
            CJ=CJC,
            XCJ=XCJC,
            MJ=MJC,
            Area=Area) annotation (extent=[-50,40; -10,60]);
          Utilities.Dj Dsb(
            Tnom=Tnom,
            IS=ISS,
            EG=EG,
            N=NS,
            XTI=XTI,
            VJ=VJS,
            CJ=CJS,
            XCJ=1,
            MJ=MJS,
            Tau=0,
            GminDC=GminDC,
            Area=Area,
            BE=false,
            EMin=EMin,
            EMax=EMax) annotation (extent=[-10,-40; -30,-80], rotation=-90);
          Sources.ConstantVoltage VS1(V=VS) 
            annotation (extent=[-30,-90; -70,-70]);
          Basic.Ground Gnd1 annotation (extent=[-76,-96; -64,-86]);
        Modelica.Blocks.Sources.Constant C01(k=0) 
          annotation (extent=[-60,-66; -48,-54]);
        Modelica.Blocks.Sources.Constant qb1(k=1) 
          annotation (extent=[-60,-46; -48,-34]);
          annotation (
            Diagram(
              Text(
                extent=[32,8; 42,0],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1),
                string="qb"),
              Text(
                extent=[-60,20; -50,12],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1),
                string="qb"),
              Ellipse(extent=[-2,-58; 2,-62], style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=42,
                  rgbfillColor={188,0,0},
                  fillPattern=1))),
            Documentation(info="<html>
The <b>Qpl</b> element of the Spice analog electrical library implements a full-fledges Spice-stye model of the laterally diffused PNP bipolar transistor [1-3]. The model contains a <b>Qpi</b> model implementing the inner parts of the PNP transistor up to the internal nodes. <p>

<hr>

<pre>
<b>DC Model Parameters:</b>

 BF:      Forward beta coefficient (default value = 50)

 BR:      Reverse beta coefficient (default value = 0.1)

 IS:      Transport saturation current (default value = 1e-16 Amp)

 ISS:     Transport saturation current of substrate diode (default value = 1e-16 Amp)

 NF:      Forward emission coefficient (default value = 1)

 NR:      Reverse emission coefficient (default value = 1)

 NS:      Emission coefficient of substrate diode (default value = 1)

 GminDC:  Junction leakage conductance (default value = 1e-15 Mho)


<b>Low Current Beta Degradation Effect Parameters:</b>

 ISC:     Collector saturation current at reference temperature (default value = 1e-16 Amp)

 ISE:     Emitter saturation current at reference temperature (default value = 1e-16 Amp)

 NC:      Collector beta degradation coefficient (default value = 2)

 NE:      Emitter beta degradation coefficient (default value = 1.5)


<b>Base Width Modulation Parameters:</b>
  
 VAF:     Forward early voltage (default value = 9e30 Volt)

 VAR:     Reverse early voltage (default value = 9e30 Volt)


<b>High Current Beta Degradation Effect Parameters:</b>

 IKF:     Forward junction beta degradation current (default value = 9e30 Amp)

 IKR:     Reverse junction beta degradation current (default value = 9e30 Amp)


<b>Parasitic Resistor Parameters:</b>

 IRB:     Parasitic base resistor current (default value = 0 Amp)

 RB:      Parasitic base resistance value (default value = 0 Ohm)

 RBM:     Parasitic modified base resistance value (default value = 0 Ohm)

 RC:      Parasitic collector resistance value (default value = 0 Ohm)

 RE:      Parasitic emitter resistance value (default value = 0 Ohm)


<b>Junction Capacitor Parameters:</b>

 CJC:     Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 MJC:     Base-collector gradation exponent (default value = 0.333)

 VJC:     Base-collector diffusion voltage (default value = 0.8 Volt)

 CJE:     Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 MJE:     Base-emitter gradation exponent (default value = 0.4)

 VJE:     Base-emitter diffusion voltage (default value = 0.8 Volt)

 CJS:     Substrate zero bias depletion capacitance (default value = 0.4e-12 F)

 MJS:     Substrate gradation exponent (default value = 0.4)

 VJS:     Substrate diffusion voltage (default value = 0.8 Volt)

 XCJC:    Portion of depletion capacitance considered inside base-collector junction (default value = 1)


<b>Transit Time Parameters:</b>

 TF:      Ideal forward transit time (default value = 0.12e-9 sec)

 TR:      Ideal reverse transit time (default value = 5e-9 sec)


<b>Temperature Compensation and Area Parameters:</b>

 TRB1:    Linear temperature coefficient of base resistance (default value = 0 Ohm/degree)

 TRB2:    Quadratic temperature coefficient of base resistance (default value = 0 Ohm/(degree*degree))

 TRM1:    Linear temperature coefficient of modified base resistance (default value = 0 Ohm/degree)

 TRM2:    Quadratic temperature coefficient of modified base resistance (default value = 0 Ohm/(degree*degree))

 TRC1:    Linear temperature coefficient of collector resistance (default value = 0 Ohm/degree)

 TRC2:    Quadratic temperature coefficient of collector resistance (default value = 0 Ohm/(degree*degree))

 TRE1:    Linear temperature coefficient of emitter resistance (default value = 0 Ohm/degree)

 TRE2:    Quadratic temperature coefficient of emitter resistance (default value = 0 Ohm/(degree*degree))

 Tnom:    Reference temperature (default value = 300.15 <sup>o</sup>K)

 XTI:     Temperature exponent of saturation current (default value = 3)

 XTB:     Temperature ratio exponent (default value = 0)

 EG:      Activation energy (default value = 1.16 Volt)

 Area:    Relative area occupied by device (default value = 1)


<b>Substrate parameters:</b>

 VS:      Substrate potential (default value = 0 Volt)

  
<b>Numerical Parameters:</b>

 EMin:    Minimum exponent (default value = -100)

 EMax:    Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li>Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York.
<li>Hild, D.R. and F.E. Cellier (1994), \"Object-oriented electronic circuit modeling using Dymola,\"
    <i>Proc. OOS'94, SCS Object Oriented Simulation Conference</i>, Tempe, AZ, pp.68-75.
<li>Hild, D.R. (1993), <i>Circuit Modeling in Dymola</i>, MS Thesis, Dept. of Electr. &amp; Comp. Engr.,
    University of Arizona, Tucson.
<li>Schweisguth, M.C. and F.E. Cellier (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/BJT.pdf\">A
    bond graph model of the bipolar junction transistor</a>,\" <i>Proc. SCS Intl. Conf. on Bond Graph Modeling</i>,
    San Francisco, CA, pp.344-349.
<li>Schweisguth, M.C. (1997), <a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/schweisguth_ms.pdf\"><i>Semiconductor
    Modeling with Bondgraphs</i></a>, MS Thesis, Dept. of Electr. &amp; Comp. Engr., University of Arizona, Tucson.
</ol> 
</html>
"),         Icon(
              Line(points=[-10,40; -10,-40]),
              Line(points=[-10,0; -90,0]),
              Line(points=[91,50; 30,50]),
              Line(points=[30,50; -10,10]),
              Line(points=[-10,-10; 30,-50]),
              Line(points=[30,-50; 91,-50]),
              Polygon(points=[-10,-10; 5,-17; -3,-25; -10,-10],     style(fillColor=
                      3, fillPattern=1)),
              Text(extent=[-100,64; 100,100],   string="%name"),
              Line(points=[0,-40; 0,-91],   style(color=42)),
            Text(
              extent=[14,30; 118,-34],
              string="%Area x",
              style(color=3, rgbcolor={0,0,255}))));
          Utilities.Qpi Qpi1 annotation (extent=[-20,-20; 20,20]);
        equation 
          connect(RC1.n, C) annotation (points=[80,50; 100,50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RE1.n, E) annotation (points=[80,-50; 100,-50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RE1.heatPort, heatPort) annotation (points=[60,-60; 0,-60; 0,
                -100], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Cbx1.n, RC1.p) annotation (points=[-10,50; 40,50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Cbx1.p, RB1.p) annotation (points=[-50,50; -80,50; -80,0],
              style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RB1.p, B) annotation (points=[-80,0; -100,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Gnd1.p, VS1.n) annotation (points=[-70,-86; -70,-80], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Dsb.heatPort, heatPort) annotation (points=[-10,-60; 0,-60; 0,
                -100], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Qpi1.heatPort, heatPort) annotation (points=[0,-20; 0,-100],
              style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(RC1.heatPort, Qpi1.heatPort) annotation (points=[60,40; 60,
                -20; 0,-20], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Qpi1.Cint, RC1.p) annotation (points=[20,10; 20,50; 40,50],
              style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Qpi1.Bint, RB1.n) annotation (points=[-20,0; -40,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Dsb.n, Qpi1.Bint) annotation (points=[-20,-40; -20,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Dsb.p, VS1.p) annotation (points=[-20,-80; -30,-80], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(C01.y, Dsb.C0) annotation (points=[-47.4,-60; -40,-60; -40,
                -68; -30,-68], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(qb1.y, Dsb.qb) annotation (points=[-47.4,-40; -40,-40; -40,
                -52; -30,-52], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Qpi1.Eint, RE1.p) annotation (points=[20,-10; 20,-50; 40,-50],
              style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Qpi1.qb, RB1.qb) annotation (points=[22,0; 30,0; 30,30; -60,
                30; -60,10], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Qpi1.heatPort, Cbx1.heatPort) annotation (points=[0,-20; -30,
                -20; -30,40], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Qpi1.heatPort, RB1.heatPort) annotation (points=[0,-20; -60,
                -20; -60,-10], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
        end Qpl;
        
        model Qpv "Spice-style vertically diffused PNP bipolar transistor" 
          /* DC model parameters */
          parameter Real BF=50 
            "Forward beta coefficient at reference temperature";
          parameter Real BR=0.1 
            "Reverse beta coefficient at reference temperature";
          parameter Modelica.SIunits.Current IS=1e-16 
            "Saturation current at reference temperature";
          parameter Modelica.SIunits.Current ISS=1e-16 
            "Saturation current of substrate diode at reference temperature";
          parameter Real NF=1 "Forward emission coefficient";
          parameter Real NR=1 "Reverse emission coefficient";
          parameter Real NS=1 "Emission coefficient of substrate diode";
          parameter Modelica.SIunits.Conductance GminDC=1e-15 
            "Leakage conductance";
          
          /* Low current beta degradation effect parameters */
          parameter Modelica.SIunits.Current ISC=1e-16 
            "Collector saturation current at reference temperature";
          parameter Modelica.SIunits.Current ISE=1e-16 
            "Emitter saturation current at reference temperature";
          parameter Real NC=2 "Collector beta degradation coefficient";
          parameter Real NE=1.5 "Emitter beta degradation coefficient";
          
          /* Base width modulation parameters */
          parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
          parameter Modelica.SIunits.Voltage VAR=9e30 "Reverse early voltage";
          
          /* High current beta degradation effect parameters */
          parameter Modelica.SIunits.Current IKF=9e30 
            "Forward junction beta degradation current";
          parameter Modelica.SIunits.Current IKR=9e30 
            "Reverse junction beta degradation current";
          
          /* Parasitic Resistor Parameters */
          parameter Modelica.SIunits.Current IRB=0 
            "Parasitic base resistor current";
          parameter Modelica.SIunits.Resistance RB=0 
            "Parasitic base resistance value";
          parameter Modelica.SIunits.Resistance RBM=0 
            "Parasitic modified base resistance value";
          parameter Modelica.SIunits.Resistance RC=0 
            "Parasitic collector resistance value";
          parameter Modelica.SIunits.Resistance RE=0 
            "Parasitic emitter resistance value";
          
          /* Junction capacitor parameters */
          parameter Modelica.SIunits.Capacitance CJC=0.5e-12 
            "Base-collector zero bias depletion capacitance at reference temperature";
          parameter Real MJC=0.333 "Base-collector gradation exponent";
          parameter Modelica.SIunits.Voltage VJC=0.8 
            "Base-collector diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJE=0.4e-12 
            "Base-emitter zero bias depletion capacitance at reference temperature";
          parameter Real MJE=0.4 "Base-emitter gradation exponent";
          parameter Modelica.SIunits.Voltage VJE=0.8 
            "Base-emitter diffusion voltage at reference temperature";
          parameter Modelica.SIunits.Capacitance CJS=0.4e-12 
            "Substrate zero bias depletion capacitance at reference temperature";
          parameter Real MJS=0.4 "Substrate gradation exponent";
          parameter Modelica.SIunits.Voltage VJS=0.8 
            "Substrate diffusion voltage at reference temperature";
          parameter Real XCJC=1 
            "Portion of depletion capacitance considered inside base-collector junction";
          
          /* Transit time parameters */
          parameter Modelica.SIunits.Time TF=0.12e-9 
            "Ideal forward transit time";
          parameter Modelica.SIunits.Time TR=5e-9 "Ideal reverse transit time";
          
          /* Temperature compensation and area parameters */
          parameter Real TRB1=0 
            "Linear temperature coefficient of base resistance [Ohm/degree]";
          parameter Real TRB2=0 
            "Quadratic temperature coefficient of base resistance [Ohm/(degree*degree)]";
          parameter Real TRM1=0 
            "Linear temperature coefficient of modified base resistance [Ohm/degree]";
          parameter Real TRM2=0 
            "Quadratic temperature coefficient of modified base resistance [Ohm/(degree*degree)]";
          parameter Real TRC1=0 
            "Linear temperature coefficient of collector resistance [Ohm/degree]";
          parameter Real TRC2=0 
            "Quadratic temperature coefficient of collector resistance [Ohm/(degree*degree)]";
          parameter Real TRE1=0 
            "Linear temperature coefficient of emitter resistance [Ohm/degree]";
          parameter Real TRE2=0 
            "Quadratic temperature coefficient of emitter resistance [Ohm/(degree*degree)]";
          parameter Modelica.SIunits.Temperature Tnom=300.15 
            "Reference temperature";
          parameter Real XTI=3 "Temperature exponent of saturation current";
          parameter Real XTB=0 "Temperature ratio exponent";
          parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
          parameter Real Area=1 "Relative area occupied by device";
          
          /* Substrate parameters */
          parameter Modelica.SIunits.Voltage VS=0 "Substrate potential";
          
          /* Numerical parameters */
          parameter Real EMin=-100 
            "if x < EMin, the exp(x) function is linearized";
          parameter Real EMax=40 
            "if x > EMax, the exp(x) function is linearized";
          Modelica.Electrical.Analog.Interfaces.Pin B "Base" annotation (extent=[
                -90,-10; -110,10]);
        public 
          Modelica.Electrical.Analog.Interfaces.Pin C "Collector" annotation (extent=[90,
                40; 110,60]);
          Modelica.Electrical.Analog.Interfaces.Pin E "Emitter" annotation (extent=[90,
                -40; 110,-60]);
          Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort(T(start=
                  300.15)) 
            annotation (extent=[-10,-90; 10,-110],   rotation=-90);
          Utilities.Rb RB1(
            Tnom=Tnom,
            RB=RB,
            RBM=RBM,
            IRB=IRB,
            TRB1=TRB1,
            TRB2=TRB2,
            TRM1=TRM1,
            TRM2=TRM2,
            Area=Area) annotation (extent=[-88,-10; -48,10]);
          R RC1(
            Tnom=Tnom,
            R=RC,
            TR1=TRC1,
            TR2=TRC2,
            Area=Area) annotation (extent=[40,40; 80,60]);
          R RE1(
            Tnom=Tnom,
            Area=Area,
            R=RE,
            TR1=TRE1,
            TR2=TRE2) annotation (extent=[40,-60; 80,-40]);
          Utilities.Cbx Cbx1(
            Tnom=Tnom,
            EG=EG,
            VJ=VJC,
            CJ=CJC,
            XCJ=XCJC,
            MJ=MJC,
            Area=Area) annotation (extent=[-50,40; -10,60]);
          Utilities.Dj Dcs(
            Tnom=Tnom,
            IS=ISS,
            EG=EG,
            N=NS,
            XTI=XTI,
            VJ=VJS,
            CJ=CJS,
            XCJ=1,
            MJ=MJS,
            Tau=0,
            GminDC=GminDC,
            Area=Area,
            BE=false,
            EMin=EMin,
            EMax=EMax) annotation (extent=[50,20; 30,-20], rotation=90);
          Sources.ConstantVoltage VS1(V=VS) annotation (extent=[50,-30; 90,-10]);
          Basic.Ground Gnd1 annotation (extent=[84,-36; 96,-26]);
        Modelica.Blocks.Sources.Constant C01(k=0) 
          annotation (extent=[80,14; 68,26]);
        Modelica.Blocks.Sources.Constant qb1(k=1) 
          annotation (extent=[80,-6; 68,6]);
          annotation (
            Diagram(Text(
                extent=[2,8; 12,0],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1),
                string="qb"), Text(
                extent=[-68,20; -58,12],
                style(
                  color=10,
                  rgbcolor={95,95,95},
                  fillColor=3,
                  rgbfillColor={0,0,255},
                  fillPattern=1),
                string="qb")),
            Icon(
              Line(points=[-10,40; -10,-40]),
              Line(points=[-10,0; -90,0]),
              Line(points=[91,50; 30,50]),
              Line(points=[30,50; -10,10]),
              Line(points=[-10,-10; 30,-50]),
              Line(points=[30,-50; 91,-50]),
              Polygon(points=[-10,-10; 5,-17; -3,-25; -10,-10],     style(fillColor=
                      3, fillPattern=1)),
              Text(extent=[-100,64; 100,100],   string="%name"),
              Line(points=[0,-40; 0,-91],   style(color=42)),
            Text(
              extent=[40,30; 82,-28],
              string="%Area x",
              style(color=3, rgbcolor={0,0,255}))),
            Documentation(info="<html>
The <b>Qpv</b> element of the Spice analog electrical library implements a full-fledges Spice-stye model of the vertically diffused PNP bipolar transistor [1-3]. The model contains a <b>Qpi</b> model implementing the inner parts of the PNP transistor up to the internal nodes. <p>

<hr>

<pre>
<b>DC Model Parameters:</b>

 BF:      Forward beta coefficient (default value = 50)

 BR:      Reverse beta coefficient (default value = 0.1)

 IS:      Transport saturation current (default value = 1e-16 Amp)

 ISS:     Transport saturation current of substrate diode (default value = 1e-16 Amp)

 NF:      Forward emission coefficient (default value = 1)

 NR:      Reverse emission coefficient (default value = 1)

 NS:      Emission coefficient of substrate diode (default value = 1)

 GminDC:  Junction leakage conductance (default value = 1e-15 Mho)


<b>Low Current Beta Degradation Effect Parameters:</b>

 ISC:     Collector saturation current at reference temperature (default value = 1e-16 Amp)

 ISE:     Emitter saturation current at reference temperature (default value = 1e-16 Amp)

 NC:      Collector beta degradation coefficient (default value = 2)

 NE:      Emitter beta degradation coefficient (default value = 1.5)


<b>Base Width Modulation Parameters:</b>
  
 VAF:     Forward early voltage (default value = 9e30 Volt)

 VAR:     Reverse early voltage (default value = 9e30 Volt)


<b>High Current Beta Degradation Effect Parameters:</b>

 IKF:     Forward junction beta degradation current (default value = 9e30 Amp)

 IKR:     Reverse junction beta degradation current (default value = 9e30 Amp)


<b>Parasitic Resistor Parameters:</b>

 IRB:     Parasitic base resistor current (default value = 0 Amp)

 RB:      Parasitic base resistance value (default value = 0 Ohm)

 RBM:     Parasitic modified base resistance value (default value = 0 Ohm)

 RC:      Parasitic collector resistance value (default value = 0 Ohm)

 RE:      Parasitic emitter resistance value (default value = 0 Ohm)


<b>Junction Capacitor Parameters:</b>

 CJC:     Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 MJC:     Base-collector gradation exponent (default value = 0.333)

 VJC:     Base-collector diffusion voltage (default value = 0.8 Volt)

 CJE:     Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 MJE:     Base-emitter gradation exponent (default value = 0.4)

 VJE:     Base-emitter diffusion voltage (default value = 0.8 Volt)

 CJS:     Substrate zero bias depletion capacitance (default value = 0.4e-12 F)

 MJS:     Substrate gradation exponent (default value = 0.4)

 VJS:     Substrate diffusion voltage (default value = 0.8 Volt)

 XCJC:    Portion of depletion capacitance considered inside base-collector junction (default value = 1)


<b>Transit Time Parameters:</b>

 TF:      Ideal forward transit time (default value = 0.12e-9 sec)

 TR:      Ideal reverse transit time (default value = 5e-9 sec)


<b>Temperature Compensation and Area Parameters:</b>

 TRB1:    Linear temperature coefficient of base resistance (default value = 0 Ohm/degree)

 TRB2:    Quadratic temperature coefficient of base resistance (default value = 0 Ohm/(degree*degree))

 TRM1:    Linear temperature coefficient of modified base resistance (default value = 0 Ohm/degree)

 TRM2:    Quadratic temperature coefficient of modified base resistance (default value = 0 Ohm/(degree*degree))

 TRC1:    Linear temperature coefficient of collector resistance (default value = 0 Ohm/degree)

 TRC2:    Quadratic temperature coefficient of collector resistance (default value = 0 Ohm/(degree*degree))

 TRE1:    Linear temperature coefficient of emitter resistance (default value = 0 Ohm/degree)

 TRE2:    Quadratic temperature coefficient of emitter resistance (default value = 0 Ohm/(degree*degree))

 Tnom:    Reference temperature (default value = 300.15 <sup>o</sup>K)

 XTI:     Temperature exponent of saturation current (default value = 3)

 XTB:     Temperature ratio exponent (default value = 0)

 EG:      Activation energy (default value = 1.16 Volt)

 Area:    Relative area occupied by device (default value = 1)


<b>Substrate parameters:</b>

 VS:      Substrate potential (default value = 0 Volt)

  
<b>Numerical Parameters:</b>

 EMin:    Minimum exponent (default value = -100)

 EMax:    Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li>Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York.
<li>Hild, D.R. and F.E. Cellier (1994), \"Object-oriented electronic circuit modeling using Dymola,\"
    <i>Proc. OOS'94, SCS Object Oriented Simulation Conference</i>, Tempe, AZ, pp.68-75.
<li>Hild, D.R. (1993), <i>Circuit Modeling in Dymola</i>, MS Thesis, Dept. of Electr. &amp; Comp. Engr.,
    University of Arizona, Tucson.
<li>Schweisguth, M.C. and F.E. Cellier (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/BJT.pdf\">A
    bond graph model of the bipolar junction transistor</a>,\" <i>Proc. SCS Intl. Conf. on Bond Graph Modeling</i>,
    San Francisco, CA, pp.344-349.
<li>Schweisguth, M.C. (1997), <a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/schweisguth_ms.pdf\"><i>Semiconductor
    Modeling with Bondgraphs</i></a>, MS Thesis, Dept. of Electr. &amp; Comp. Engr., University of Arizona, Tucson.
</ol> 
</html>
"));
          Utilities.Qpi Qpi1 annotation (extent=[-40,-20; 0,20]);
        equation 
          connect(RC1.n, C) annotation (points=[80,50; 100,50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RE1.n, E) annotation (points=[80,-50; 100,-50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Cbx1.n, RC1.p) annotation (points=[-10,50; 40,50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Cbx1.p, RB1.p) annotation (points=[-50,50; -88,50; -88,0],
              style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(RB1.p, B) annotation (points=[-88,0; -100,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1));
          connect(Gnd1.p, VS1.n) annotation (points=[90,-26; 90,-20], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(RC1.heatPort, Dcs.heatPort) annotation (points=[60,40; 30,40; 
                30,1.22461e-015], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(RE1.heatPort, heatPort) annotation (points=[60,-60; 0,-60; 0,
                -100], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Dcs.heatPort, heatPort) annotation (points=[30,1.22461e-015; 
                30,-60; 0,-60; 0,-100], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Qpi1.Bint, RB1.n) annotation (points=[-40,0; -48,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Qpi1.Cint, RC1.p) annotation (points=[0,10; 0,50; 40,50],
              style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Qpi1.Eint, RE1.p) annotation (points=[0,-10; 0,-50; 40,-50],
              style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Qpi1.qb, RB1.qb) annotation (points=[2,0; 12,0; 12,30; -68,30;
                -68,10], style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Qpi1.heatPort, heatPort) annotation (points=[-20,-20; -20,-60;
                0,-60; 0,-100], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(RB1.heatPort, Qpi1.heatPort) annotation (points=[-68,-10; -68,
                -20; -20,-20], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Cbx1.heatPort, Qpi1.heatPort) annotation (points=[-30,40; -30,
                -20; -20,-20], style(
              color=42,
              rgbcolor={191,0,0},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Dcs.p, RC1.p) annotation (points=[40,20; 40,50], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(Dcs.n, VS1.p) annotation (points=[40,-20; 50,-20], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(C01.y, Dcs.C0) annotation (points=[67.4,20; 60,20; 60,8; 50,8],
              style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
          connect(qb1.y, Dcs.qb) annotation (points=[67.4,0; 60,0; 60,-8; 50,-8],
              style(
              color=74,
              rgbcolor={0,0,127},
              fillColor=42,
              rgbfillColor={188,0,0},
              fillPattern=1));
        end Qpv;
        
        package Utilities "Utility models of Spice circuit element models" 
          annotation (Icon(
              Rectangle(extent=[-100,-100; 80,50], style(
                  color=42,
                  rgbcolor={127,0,0},
                  fillColor=30,
                  rgbfillColor={235,235,235},
                  fillPattern=1)),
              Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50], style(
                  color=42,
                  rgbcolor={127,0,0},
                  fillColor=30,
                  rgbfillColor={235,235,235},
                  fillPattern=1)),
              Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70], style(
                  color=42,
                  rgbcolor={127,0,0},
                  fillColor=30,
                  rgbfillColor={235,235,235},
                  fillPattern=1)),
              Text(
                extent=[-85,35; 65,-85],
                string="Library",
                style(color=42, rgbcolor={127,0,0})),
              Text(
                extent=[-120,122; 120,73],
                string="%name",
                style(color=1))), Documentation(info="<html>
This package contains some utility models used within the Spice-style circuit element models.
</html>
"));
          model Rb 
            "Spice-style bipolar base resistor of the analog electrical library" 
            extends Interfaces.SpiceTwoPort;
            parameter Modelica.SIunits.Resistance RB=0 
              "Resistance at reference temperature";
            parameter Modelica.SIunits.Resistance RBM=0 
              "Modified resistance at reference temperature";
            parameter Modelica.SIunits.Current IRB=0 
              "Reference base current at reference temperature";
            parameter Real TRB1=0 "Linear temperature coefficient [Ohm/degree]";
            parameter Real TRB2=0 
              "Quadratic temperature coefficient [Ohm/(degree*degree)]";
            parameter Real TRM1=0 "Linear temperature coefficient [Ohm/degree]";
            parameter Real TRM2=0 
              "Quadratic temperature coefficient [Ohm/(degree*degree)]";
            parameter Real Area=1 "Relative area occupied by resistor";
            Junctions.J1p3 J1p3_1         annotation (extent=[-12,28; 12,52]);
            Bonds.Bond B1         annotation (extent=[-38,28; -12,52]);
            Bonds.Bond B2         annotation (extent=[12,28; 38,52]);
            Bonds.Bond B3         annotation (extent=[-12,4; 12,28],    rotation=
                  270);
            BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=[
                  -62,26; -38,54]);
            BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=[38,
                  26; 64,54]);
            BondLib.Electrical.Analog.Interfaces.BG2Heat BG2Heat1 
              annotation (extent=[-12,-80; 12,-56], rotation=-90);
            BondLib.Bonds.eBond B4 
                           annotation (extent=[-12,-56; 12,-32], rotation=-90);
            BondLib.Spice.Utilities.RBS Rb1(
              Tnom=Tnom,
              RB=RB,
              RBM=RBM,
              IRB=IRB,
              TRB1=TRB1,
              TRB2=TRB2,
              TRM1=TRM1,
              TRM2=TRM2,
              Area=Area) annotation (extent=[-10,-32; 10,4], rotation=-90);
            Modelica.Blocks.Interfaces.RealInput qb 
              annotation (extent=[-10,90; 10,110], rotation=-90);
          equation 
            connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,40;
                  -12,40],
                        style(color=8));
            connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,40;
                  12.26,40], style(color=8));
            connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,40;
                  -37.74,40],
                        style(color=8));
            connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,40; 38,
                  40],style(color=8));
            connect(B4.eBondCon1,BG2Heat1. BondCon1) annotation (points=[
                  7.34764e-016,-56; -7.34764e-016,-56], style(color=8, rgbcolor={
                    192,192,192}));
            connect(J1p3_1.BondCon3,B3. BondCon1) annotation (points=[0,28; 0,
                  27.76; 2.16021e-015,27.76], style(color=8, rgbcolor={192,192,
                    192}));
            annotation (
              Diagram,
              Icon(
                Rectangle(extent=[-70,30; 70,-30],   style(
                    color=3,
                    fillColor=7,
                    fillPattern=1)),
                Line(points=[-90,0; -70,0]),
                Line(points=[70,0; 90,0]),
                Text(
                  extent=[12,-44; 108,-78],
                  style(color=0),
                  string="R=%RB"),
                Line(points=[0,-30; 0,-91],   style(color=42))),
              Documentation(info="<html>
The base resistor is the most important of the parasitic resistors of a bipolar transistor.  For this reason, Spice models this resistor using a more sophisticated model with additional parameters. <p>

<hr> <p>

<pre>
Parameters:

 RB:    Reference base resistance (default value = 0 Ohm)

 RBM:   Reference modified base resistance (default value = 0 Ohm)

 IRB:   Reference base resistance current (default value = 0 Amp)

 Tnom:  Reference temperature (default value = 300.15 <sup>o</sup>K)

 TRB1:  Linear temperature variation coefficient of RB (default value = 0 Ohm/<sup>o</sup>K)

 TRB2:  Quadratic temperature variation coefficient of RB (default value = 0 Ohm/<sup>o</sup>K<sup>2</sup>)

 TRM1:  Linear temperature variation coefficient of RBM (default value = 0 Ohm/<sup>o</sup>K)

 TRM2:  Quadratic temperature variation coefficient of RBM (default value = 0 Ohm/<sup>o</sup>K<sup>2</sup>)

 Area:  Relative area occupied by resistor (default value = 1)
</pre>
</html>
"));
            connect(El2BG1.p, p) annotation (points=[-62,40; -80,40; -80,0;
                  -100,0], style(color=3, rgbcolor={0,0,255}));
            connect(BG2El1.n, n) annotation (points=[64,40; 80,40; 80,0; 100,0],
                style(color=3, rgbcolor={0,0,255}));
            connect(BG2Heat1.port_b, heatPort) annotation (points=[7.34764e-016,
                  -80; 0,-80; 0,-100], style(color=42, rgbcolor={191,0,0}));
            connect(Rb1.BondCon1, B3.BondCon2) annotation (points=[
                  -6.12303e-016,4; -2.20429e-015,4], style(color=8, rgbcolor={
                    192,192,192}));
            connect(Rb1.BondCon2, B4.fBondCon1) annotation (points=[
                  6.12303e-016,-32; -7.34764e-016,-32], style(color=8, rgbcolor=
                   {192,192,192}));
            connect(Rb1.qb, qb) annotation (points=[10,-14; 20,-14; 20,80; 0,80; 
                  0,100], style(color=74, rgbcolor={0,0,127}));
          end Rb;
          
          model Cj 
            "Spice-style junction capacitor model for bipolar transistors" 
            extends Interfaces.SpiceTwoPort;
            parameter Modelica.SIunits.Current IS=1e-16 
              "Saturation current at reference temperature";
            parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
            parameter Real N=1 "Emission coefficient";
            parameter Real XTI=3 "Temperature exponent of saturation current";
            parameter Modelica.SIunits.Voltage VJ=0.75 
              "Junction diffusion voltage at reference temperature";
            parameter Modelica.SIunits.Capacitance CJ=0.5e-12 
              "Junction zero bias depletion capacitance at reference temperature";
            parameter Real XCJ=1 
              "Portion of depletion capacitance considered inside the junction";
            parameter Real MJ=0.333 "Junction gradation exponent";
            parameter Modelica.SIunits.Time Tau=1e-9 "Ideal transit time";
            parameter Modelica.SIunits.Conductance GminDC=1e-15 
              "Leakage conductance";
            parameter Real Area=1 "Relative area occupied by capacitor";
            parameter Boolean BE=true "True if base-emitter junction";
            Junctions.J1p3 J1p3_1         annotation (extent=[-12,28; 12,52]);
            Bonds.Bond B1         annotation (extent=[-38,28; -12,52]);
            Bonds.Bond B2         annotation (extent=[12,28; 38,52]);
            Bonds.Bond B3         annotation (extent=[-12,4; 12,28],    rotation=
                  270);
            BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=[
                  -62,26; -38,54]);
            BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=[38,
                  26; 64,54]);
            BondLib.Electrical.Analog.Interfaces.BG2Heat BG2Heat1 
              annotation (extent=[-12,-80; 12,-56], rotation=-90);
            BondLib.Bonds.eBond B4 
                           annotation (extent=[-12,-56; 12,-32], rotation=-90);
            BondLib.Spice.Utilities.CjS Cj1(
              Tnom=Tnom,
              IS=IS,
              EG=EG,
              N=N,
              XTI=XTI,
              VJ=VJ,
              CJ=CJ,
              XCJ=XCJ,
              MJ=MJ,
              Tau=Tau,
              GminDC=GminDC,
              Area=Area,
              BE=BE) annotation (extent=[-10,-32; 10,4], rotation=-90);
            Modelica.Blocks.Interfaces.RealInput C0 
              annotation (extent=[-50,90; -30,110], rotation=-90);
            Modelica.Blocks.Interfaces.RealInput qb 
              annotation (extent=[30,90; 50,110], rotation=-90);
          equation 
            connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,40;
                  -12,40],
                        style(color=8));
            connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,40;
                  12.26,40], style(color=8));
            connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,40;
                  -37.74,40],
                        style(color=8));
            connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,40; 38,
                  40],style(color=8));
            connect(B4.eBondCon1,BG2Heat1. BondCon1) annotation (points=[
                  7.34764e-016,-56; -7.34764e-016,-56], style(color=8, rgbcolor={
                    192,192,192}));
            connect(J1p3_1.BondCon3,B3. BondCon1) annotation (points=[0,28; 0,
                  27.76; 2.16021e-015,27.76], style(color=8, rgbcolor={192,192,
                    192}));
            annotation (
              Diagram,
              Icon(
                Line(points=[14,0; 90,0]),
                Line(points=[14,28; 14,-28],   style(thickness=2)),
                Line(points=[-14,28; -14,-28],   style(thickness=2)),
                Line(points=[-90,0; -14,0]),
                Line(points=[0,-28; 0,-91],   style(color=42)),
                Text(
                  extent=[-14,12; 16,-16],
                  style(color=3, rgbcolor={0,0,255}),
                  string="J")),
              Documentation(info="<html>
The Spice-style junction capacitance computes both the depletion capacitance value and the diffusion capacitance value of a junction used in a bipolar transistor.  Different Spice dialects vary in the formulae they use for this purpose.  Many Spice dialects actually don't use a formula for the junction capacitance at all, but rather compute the electric charge stored in the junction directly, which is conceptually cleaner.  However, that approach is computationally cumbersome, as it leads to an awkward algebraic loop [1].  Thus, we chose to compute the junction capacitance, and use a (physically incorrect) approximate non-linear capacitor model (just as in the case of the simpler Ebers-Moll model).  The numerical error should remain small, as the time constants associated with temperature change are much larger than those associated with electrical phenomena. <p>

This particular model uses the space charge formula proposed by van Halen [2].  Since: <p>

<b>f = der(q)</b> <p>

the space charge, <b>q</b>, was symbolically differentiated.  In the differentiation, only electrical signals, i.e., the voltage, <b>e</b>, were considered time-varying.  The temperature gradients were assumed to be negligible.  This produced an equation of the form: <p>

<b>f = C(e)*der(e)</b> <p>

which is the formula that was used to compute the non-linear capacitance <b>C(e)</b> in the model. <p>

<hr>

<pre>
Parameters:

 Is:      Transport saturation current (default value = 1e-16 Amp)

 EG:      Activation energy (default value = 1.16 Volt)

 N:       Emission coefficient (default value = 1)

 XTI:     Temperature exponent of saturation current (default value = 3)

 VJ:      Diffusion voltage (default value = 0.75 Volt)

 CJ:      Zero bias depletion capacitance (default value = 0.5e-12 F)

 XCJ:     Portion of depletion capacitance considered inside the junction (default value = 1)

 MJ:      Gradation exponent (default value = 0.333)

 Tau:     Ideal transit time (default value = 1e-9 sec)

 GminDC:  Leakage conductance (default value = 1e-15 Mho)

 Area:    Relative area occupied by the diode (default value = 1)

 BE:      True if base-emitter junction (default value = true)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York, pp. 224-225.
<li> van Halen, P. (1988), \"A new semiconductor junction diode space charge layer capacitance model,\"
     <i>Proc. IEEE 1988 Bipolar Circuits &amp; Technology Meeting</i>, Minneapolis, MN, pp. 168-171.
</ol>
</html>"));
            connect(El2BG1.p, p) annotation (points=[-62,40; -80,40; -80,0;
                  -100,0], style(color=3, rgbcolor={0,0,255}));
            connect(BG2El1.n, n) annotation (points=[64,40; 80,40; 80,0; 100,0],
                style(color=3, rgbcolor={0,0,255}));
            connect(B3.BondCon2, Cj1.BondCon1) annotation (points=[
                  -2.20429e-015,4; -2.20429e-015,1; -6.12303e-016,1; 
                  -6.12303e-016,4], style(color=8, rgbcolor={192,192,192}));
            connect(Cj1.BondCon2, B4.fBondCon1) annotation (points=[
                  6.12303e-016,-32; -7.34764e-016,-32], style(color=8, rgbcolor=
                   {192,192,192}));
            connect(Cj1.qb, qb) annotation (points=[-10,-6.8; -16,-6.8; -16,-6; 
                  -22,-6; -22,80; 40,80; 40,100], style(color=74, rgbcolor={0,0,
                    127}));
            connect(Cj1.C0, C0) annotation (points=[-10,-21.2; -20,-22; -28,-22;
                  -28,80; -40,80; -40,100], style(color=74, rgbcolor={0,0,127}));
            connect(BG2Heat1.port_b, heatPort) annotation (points=[7.34764e-016,
                  -80; 7.34764e-016,-85; 0,-85; 0,-100], style(color=42,
                  rgbcolor={191,0,0}));
          end Cj;
          
          model Cbx 
            "Spice-style extenral base-collector capacitance model for bipolar transistors" 
            extends Interfaces.SpiceTwoPort;
            parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
            parameter Modelica.SIunits.Voltage VJ=0.75 
              "Junction diffusion voltage at reference temperature";
            parameter Modelica.SIunits.Capacitance CJ=0.5e-12 
              "Junction zero bias depletion capacitance at reference temperature";
            parameter Real XCJ=1 
              "Portion of depletion capacitance considered inside the junction";
            parameter Real MJ=0.333 "Junction gradation exponent";
            parameter Real Area=1 "Relative area occupied by capacitor";
            annotation (
              Icon(
                Line(points=[14,0; 90,0]),
                Line(points=[14,28; 14,-28],   style(thickness=2)),
                Line(points=[-14,28; -14,-28],   style(thickness=2)),
                Line(points=[-90,0; -14,0]),
                Line(points=[0,-28; 0,-91],   style(color=42)),
                Line(points=[0,20; 0,-20], style(pattern=2, thickness=2))),
              Diagram,
              Documentation(info="<html>
The Spice-style external base-collector capacitance computes the external depletion capacitance value of a bipolar transistor. <p>

<hr>

<pre>
Parameters:

 EG:      Activation energy (default value = 1.16 Volt)

 VJ:      Diffusion voltage (default value = 0.75 Volt)

 CJ:      Zero bias depletion capacitance (default value = 0.5e-12 F)

 XCJ:     Portion of depletion capacitance considered inside the junction (default value = 1)

 MJ:      Gradation exponent (default value = 0.333)

 Area:    Relative area occupied by the diode (default value = 1)
</pre>
</html>
"));
            Junctions.J1p3 J1p3_1         annotation (extent=[-12,28; 12,52]);
            Bonds.Bond B1         annotation (extent=[-38,28; -12,52]);
            Bonds.Bond B2         annotation (extent=[12,28; 38,52]);
            Bonds.Bond B3         annotation (extent=[-12,4; 12,28],    rotation=
                  270);
            BondLib.Electrical.Analog.Interfaces.El2BG El2BG1 annotation (extent=[
                  -62,26; -38,54]);
            BondLib.Electrical.Analog.Interfaces.BG2El BG2El1 annotation (extent=[38,
                  26; 64,54]);
            BondLib.Electrical.Analog.Interfaces.BG2Heat BG2Heat1 
              annotation (extent=[-12,-80; 12,-56], rotation=-90);
            BondLib.Bonds.eBond B4 
                           annotation (extent=[-12,-56; 12,-32], rotation=-90);
            BondLib.Spice.Utilities.CbxS Cbx1(
              Tnom=Tnom,
              EG=EG,
              Area=Area,
              VJ=VJ,
              CJ=CJ,
              XCJ=XCJ,
              MJ=MJ) annotation (extent=[-10,-32; 10,4], rotation=-90);
          equation 
            connect(B1.BondCon2,J1p3_1. BondCon1) annotation (points=[-12,40;
                  -12,40],
                        style(color=8));
            connect(J1p3_1.BondCon2,B2. BondCon1) annotation (points=[12,40;
                  12.26,40], style(color=8));
            connect(El2BG1.BondCon1,B1. BondCon1) annotation (points=[-38,40;
                  -37.74,40],
                        style(color=8));
            connect(B2.BondCon2,BG2El1. BondCon1) annotation (points=[38,40; 38,
                  40],style(color=8));
            connect(B4.eBondCon1,BG2Heat1. BondCon1) annotation (points=[
                  7.34764e-016,-56; -7.34764e-016,-56], style(color=8, rgbcolor={
                    192,192,192}));
            connect(J1p3_1.BondCon3,B3. BondCon1) annotation (points=[0,28; 0,
                  27.76; 2.16021e-015,27.76], style(color=8, rgbcolor={192,192,
                    192}));
            connect(El2BG1.p, p) annotation (points=[-62,40; -80,40; -80,0;
                  -100,0], style(color=3, rgbcolor={0,0,255}));
            connect(BG2El1.n, n) annotation (points=[64,40; 80,40; 80,0; 100,0],
                style(color=3, rgbcolor={0,0,255}));
            connect(BG2Heat1.port_b, heatPort) annotation (points=[7.34764e-016,
                  -80; 7.34764e-016,-85; 0,-85; 0,-100], style(color=42,
                  rgbcolor={191,0,0}));
            connect(B3.BondCon2, Cbx1.BondCon1) annotation (points=[
                  -2.20429e-015,4; -6.12303e-016,4], style(color=8, rgbcolor={
                    192,192,192}));
            connect(Cbx1.BondCon2, B4.fBondCon1) annotation (points=[
                  6.12303e-016,-32; -7.34764e-016,-32], style(color=8, rgbcolor=
                   {192,192,192}));
          end Cbx;
          
          model Dj "Spice-style junction diode model for bipolar transistors" 
            extends Interfaces.SpiceTwoPort;
            parameter Modelica.SIunits.Temperature Tnom=300.15 
              "Reference temperature";
            parameter Modelica.SIunits.Current IS=1e-16 
              "Saturation current at reference temperature";
            parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
            parameter Real N=1 "Emission coefficient";
            parameter Real XTI=3 "Temperature exponent of saturation current";
            parameter Modelica.SIunits.Voltage VJ=0.75 
              "Junction diffusion voltage at reference temperature";
            parameter Modelica.SIunits.Capacitance CJ=0.5e-12 
              "Junction zero bias depletion capacitance at reference temperature";
            parameter Real XCJ=1 
              "Portion of depletion capacitance considered inside the junction";
            parameter Real MJ=0.333 "Junction gradation exponent";
            parameter Modelica.SIunits.Time Tau=1e-9 "Ideal transit time";
            parameter Modelica.SIunits.Conductance GminDC=1e-15 
              "Leakage conductance";
            parameter Real Area=1 "Relative area occupied by diode";
            parameter Boolean BE=true "True if base-emitter junction";
            parameter Real EMin=-100 
              "if x < EMin, the exp(x) function is linearized";
            parameter Real EMax=40 
              "if x > EMax, the exp(x) function is linearized";
          Modelica.Blocks.Interfaces.RealOutput id 
            annotation (extent=[-10,90; 10,110], rotation=90);
          Modelica.Blocks.Interfaces.RealInput C0 
            annotation (extent=[-50,90; -30,110],   rotation=270);
          Modelica.Blocks.Interfaces.RealInput qb 
            annotation (extent=[30,90; 50,110],   rotation=270);
            Sensors.CurrentSensor Id1 annotation (extent=[-40,30; -20,10]);
            D D1(
              Tnom=Tnom,
              IS=IS,
              EG=EG,
              N=N,
              XTI=XTI,
              Area=Area,
              EMin=EMin,
              EMax=EMax) annotation (extent=[20,30; 60,50]);
            R R1(
              Tnom=Tnom,
              R=1/GminDC,
              TR1=0,
              TR2=0,
              Area=1) annotation (extent=[20,-10; 60,10]);
            Cj Cj1(
              Tnom=Tnom,
              IS=IS,
              EG=EG,
              N=N,
              XTI=XTI,
              VJ=VJ,
              CJ=CJ,
              XCJ=XCJ,
              MJ=MJ,
              Tau=Tau,
              GminDC=GminDC,
              Area=Area,
              BE=BE) annotation (extent=[-20,-50; 20,-30]);
            annotation (
              Diagram,
              Documentation(info="<html>
The Spice-style junction diode consists of a parallel connection of a regular diode, a highly non-linear junction capacitance, and a leakage conductance. <p>

<hr>

<pre>
Parameters:

 Is:      Transport saturation current (default value = 1e-16 Amp)

 EG:      Activation energy (default value = 1.16 Volt)

 N:       Emission coefficient (default value = 1)

 XTI:     Temperature exponent of saturation current (default value = 3)

 VJ:      Diffusion voltage (default value = 0.75 Volt)

 CJ:      Zero bias depletion capacitance (default value = 0.5e-12 F)

 XCJ:     Portion of depletion capacitance considered inside the junction (default value = 1)

 MJ:      Gradation exponent (default value = 0.333)

 Tau:     Ideal transit time (default value = 1e-9 sec)

 GminDC:  Leakage conductance (default value = 1e-15 Mho)

 Area:    Relative area occupied by the diode (default value = 1)

 BE:      True if base-emitter junction (default value = true)

 EMin:    if x &lt; EMin, the exp(x) function is linearized (default value = -100)

 EMax:    if x &gt; EMax, the exp(x) function is linearized (default value = 40)

</pre>
</html>
"),           Icon(
                Polygon(points=[30,0; -30,40; -30,-40; 30,0],     style(
                    color=3,
                    gradient=0,
                    fillColor=7)),
                Line(points=[-90,0; -30,0]),
                Line(points=[30,0; 90,0]),
                Line(points=[30,40; 30,-40],   style(color=3)),
                Line(points=[0,-20; 0,-91],   style(color=42)),
                Text(
                  extent=[-24,14; 4,-14],
                  style(color=3, rgbcolor={0,0,255}),
                  string="J")));
          equation 
            connect(R1.n, n) annotation (points=[60,0; 100,0], style(color=3,
                  rgbcolor={0,0,255}));
            connect(D1.n, n) annotation (points=[60,40; 80,40; 80,0; 100,0],
                style(color=3, rgbcolor={0,0,255}));
            connect(Cj1.n, n) annotation (points=[20,-40; 80,-40; 80,0; 100,0],
                style(color=3, rgbcolor={0,0,255}));
            connect(Id1.n, D1.p) annotation (points=[-20,20; 0,20; 0,40; 20,40],
                style(color=3, rgbcolor={0,0,255}));
            connect(R1.p, Id1.n) annotation (points=[20,0; 0,0; 0,20; -20,20],
                style(color=3, rgbcolor={0,0,255}));
            connect(Id1.p, p) annotation (points=[-40,20; -60,20; -60,0; -100,0],
                style(color=3, rgbcolor={0,0,255}));
            connect(Cj1.p, p) annotation (points=[-20,-40; -60,-40; -60,0; -100,
                  0], style(color=3, rgbcolor={0,0,255}));
            connect(Id1.I, id) annotation (points=[-30,30; -30,60; 0,60; 0,100],
                style(color=74, rgbcolor={0,0,127}));
            connect(D1.heatPort, heatPort) annotation (points=[40,30; 70,30; 70,
                  -70; 0,-70; 0,-100], style(color=42, rgbcolor={191,0,0}));
            connect(R1.heatPort, heatPort) annotation (points=[40,-10; 70,-10;
                  70,-70; 0,-70; 0,-100], style(color=42, rgbcolor={191,0,0}));
            connect(Cj1.heatPort, heatPort) annotation (points=[0,-50; 0,-100],
                style(color=42, rgbcolor={191,0,0}));
            connect(Cj1.C0, C0) annotation (points=[-8,-30; -8,-20; -80,-20;
                  -80,80; -40,80; -40,100], style(color=74, rgbcolor={0,0,127}));
            connect(Cj1.qb, qb) annotation (points=[8,-30; 8,-20; 88,-20; 88,80;
                  40,80; 40,100], style(color=74, rgbcolor={0,0,127}));
          end Dj;
          
          model Qni 
            "Spice-style NPN transistor model without parasitic resistors and substrate diode" 
            /* DC model parameters */
            parameter Real BF=50 
              "Forward beta coefficient at reference temperature";
            parameter Real BR=0.1 
              "Reverse beta coefficient at reference temperature";
            parameter Modelica.SIunits.Current IS=1e-16 
              "Saturation current at reference temperature";
            parameter Real NF=1 "Forward emission coefficient";
            parameter Real NR=1 "Reverse emission coefficient";
            parameter Modelica.SIunits.Conductance GminDC=1e-15 
              "Leakage conductance";
            
            /* Low current beta degradation effect parameters */
            parameter Modelica.SIunits.Current ISC=1e-16 
              "Collector saturation current at reference temperature";
            parameter Modelica.SIunits.Current ISE=1e-16 
              "Emitter saturation current at reference temperature";
            parameter Real NC=2 "Collector beta degradation coefficient";
            parameter Real NE=1.5 "Emitter beta degradation coefficient";
            
            /* Base width modulation parameters */
            parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
            parameter Modelica.SIunits.Voltage VAR=9e30 "Reverse early voltage";
            
            /* High current beta degradation effect parameters */
            parameter Modelica.SIunits.Current IKF=9e30 
              "Forward junction beta degradation current";
            parameter Modelica.SIunits.Current IKR=9e30 
              "Reverse junction beta degradation current";
            
            /* Junction capacitor parameters */
            parameter Modelica.SIunits.Capacitance CJC=0.5e-12 
              "Base-collector zero bias depletion capacitance at reference temperature";
            parameter Real MJC=0.333 "Base-collector gradation exponent";
            parameter Modelica.SIunits.Voltage VJC=0.8 
              "Base-collector diffusion voltage at reference temperature";
            parameter Modelica.SIunits.Capacitance CJE=0.4e-12 
              "Base-emitter zero bias depletion capacitance at reference temperature";
            parameter Real MJE=0.4 "Base-emitter gradation exponent";
            parameter Modelica.SIunits.Voltage VJE=0.8 
              "Base-emitter diffusion voltage at reference temperature";
            parameter Real XCJC=1 
              "Portion of depletion capacitance considered inside base-collector junction";
            
            /* Transit time parameters */
            parameter Modelica.SIunits.Time TF=0.12e-9 
              "Ideal forward transit time";
            parameter Modelica.SIunits.Time TR=5e-9 
              "Ideal reverse transit time";
            
            /* Temperature compensation and area parameters */
            parameter Modelica.SIunits.Temperature Tnom=300.15 
              "Reference temperature";
            parameter Real XTI=3 "Temperature exponent of saturation current";
            parameter Real XTB=0 "Temperature ratio exponent";
            parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
            parameter Real Area=1 "Relative area occupied by device";
            
            /* Numerical parameters */
            parameter Real EMin=-100 
              "if x < EMin, the exp(x) function is linearized";
            parameter Real EMax=40 
              "if x > EMax, the exp(x) function is linearized";
            Modelica.Electrical.Analog.Interfaces.Pin Bint "Internal base node"
                                                               annotation (extent=[
                  -90,-10; -110,10]);
          public 
            Modelica.Electrical.Analog.Interfaces.Pin Cint 
              "Internal collector node"                             annotation (extent=[90,
                  40; 110,60]);
            annotation (
              Diagram(
                Ellipse(extent=[-12,2; -8,-2], style(
                    color=3,
                    rgbcolor={0,0,255},
                    fillColor=3,
                    rgbfillColor={0,0,255})),
                Text(
                  extent=[-98,78; -86,72],
                  string="vbc",
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1)),
                Text(
                  extent=[-98,70; -86,64],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="ibc"),
                Text(
                  extent=[-98,62; -86,56],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="vbe"),
                Text(
                  extent=[-98,54; -86,48],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="ibe"),
                Text(
                  extent=[-38,78; -26,72],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="IB0"),
                Text(
                  extent=[-38,70; -26,64],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="IC0"),
                Text(
                  extent=[-38,62; -26,56],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="qb"),
                Text(
                  extent=[-38,54; -26,48],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="C0"),
                Text(
                  extent=[-60,22; -48,16],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="Tdev")),
              Icon(
                Line(points=[-10,40; -10,-40]),
                Line(points=[-10,0; -90,0]),
                Line(points=[91,50; 30,50]),
                Line(points=[30,50; -10,10]),
                Line(points=[-10,-10; 30,-50]),
                Line(points=[30,-50; 91,-50]),
                Polygon(points=[30,-50; 24,-36; 16,-44; 30,-50],     style(fillColor=3,
                        fillPattern=1)),
                Text(extent=[-110,74; 94,100],    string="%name"),
                Line(points=[0,-40; 0,-91],   style(color=42))),
              Documentation(info="<html>
The NPN element of the Spice analog electrical library implements a full-fledges Spice-stye model of the NPN bipolar transistor [1-3].  <b>NPNint</b> is a partial model that implements only the internal nodes of the bipolar transistor.  The external parasitic resistances, the external capacitor between base and collector, and the substrate are being added from the outside. <p>

<hr>

<pre>
<b>DC Model Parameters:</b>

 BF:      Forward beta coefficient (default value = 50)

 BR:      Reverse beta coefficient (default value = 0.1)

 IS:      Transport saturation current (default value = 1e-16 Amp)

 NF:      Forward emission coefficient (default value = 1)

 NR:      Reverse emission coefficient (default value = 1)

 GminDC:  Junction leakage conductance (default value = 1e-15 Mho)


<b>Low Current Beta Degradation Effect Parameters:</b>

 ISC:     Collector saturation current at reference temperature (default value = 1e-16 Amp)

 ISE:     Emitter saturation current at reference temperature (default value = 1e-16 Amp)

 NC:      Collector beta degradation coefficient (default value = 2)

 NE:      Emitter beta degradation coefficient (default value = 1.5)


<b>Base Width Modulation Parameters:</b>
  
 VAF:     Forward early voltage (default value = 9e30 Volt)

 VAR:     Reverse early voltage (default value = 9e30 Volt)


<b>High Current Beta Degradation Effect Parameters:</b>

 IKF:     Forward junction beta degradation current (default value = 9e30 Amp)

 IKR:     Reverse junction beta degradation current (default value = 9e30 Amp)


<b>Junction Capacitor Parameters:</b>

 CJC:     Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 MJC:     Base-collector gradation exponent (default value = 0.333)

 VJC:     Base-collector diffusion voltage (default value = 0.8 Volt)

 CJE:     Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 MJE:     Base-emitter gradation exponent (default value = 0.4)

 VJE:     Base-emitter diffusion voltage (default value = 0.8 Volt)

 XCJC:    Portion of depletion capacitance considered inside base-collector junction (default value = 1)


<b>Transit Time Parameters:</b>

 TF:      Ideal forward transit time (default value = 0.12e-9 sec)

 TR:      Ideal reverse transit time (default value = 5e-9 sec)


<b>Temperature Compensation and Area Parameters:</b>

 Tnom:    Reference temperature (default value = 300.15 <sup>o</sup>K)

 XTI:     Temperature exponent of saturation current (default value = 3)

 XTB:     Temperature ratio exponent (default value = 0)

 EG:      Activation energy (default value = 1.16 Volt)

 Area:    Relative area occupied by device (default value = 1)


<b>Numerical Parameters:</b>

 EMin:    Minimum exponent (default value = -100)

 EMax:    Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li>Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York.
<li>Hild, D.R. and F.E. Cellier (1994), \"Object-oriented electronic circuit modeling using Dymola,\"
    <i>Proc. OOS'94, SCS Object Oriented Simulation Conference</i>, Tempe, AZ, pp.68-75.
<li>Hild, D.R. (1993), <i>Circuit Modeling in Dymola</i>, MS Thesis, Dept. of Electr. &amp; Comp. Engr.,
    University of Arizona, Tucson.
<li>Schweisguth, M.C. and F.E. Cellier (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/BJT.pdf\">A
    bond graph model of the bipolar junction transistor</a>,\" <i>Proc. SCS Intl. Conf. on Bond Graph Modeling</i>,
    San Francisco, CA, pp.344-349.
<li>Schweisguth, M.C. (1997), <a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/schweisguth_ms.pdf\"><i>Semiconductor
    Modeling with Bondgraphs</i></a>, MS Thesis, Dept. of Electr. &amp; Comp. Engr., University of Arizona, Tucson.
</ol> 
</html>
"));
            Modelica.Electrical.Analog.Interfaces.Pin Eint 
              "Internal emitter node"                             annotation (extent=[90,
                  -40; 110,-60]);
            Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort(T(start=
                    300.15)) 
              annotation (extent=[-10,-90; 10,-110],   rotation=-90);
            BondLib.Spice.Utilities.BJTvars BJTvars1(
            Tnom=Tnom,
            BF=BF,
            BR=BR,
            TF=TF,
            EG=EG,
            XTI=XTI,
            VAF=VAF,
            VAR=VAR,
            IKF=IKF,
            IKR=IKR,
            ISC=ISC,
            ISE=ISE,
            NC=NC,
            NE=NE,
            XTB=XTB,
            Area=Area) 
            annotation (extent=[-80,40; -40,80]);
            BondLib.Electrical.Analog.Spice.Utilities.Dj Dbc(
              Tnom=Tnom,
              IS=IS,
              EG=EG,
              N=NR,
              XTI=XTI,
              VJ=VJC,
              CJ=CJC,
              XCJ=XCJC,
              MJ=MJC,
              Tau=TR,
              GminDC=GminDC,
              Area=Area,
              BE=false,
              EMin=EMin,
              EMax=EMax) annotation (extent=[10,10; 30,50], rotation=90);
            BondLib.Electrical.Analog.Spice.Utilities.Dj Dbe(
              Tnom=Tnom,
              IS=IS,
              EG=EG,
              XTI=XTI,
              GminDC=GminDC,
              Area=Area,
              EMin=EMin,
              EMax=EMax,
              N=NF,
              VJ=VJE,
              CJ=CJE,
              MJ=MJE,
              Tau=TF,
              BE=true,
              XCJ=1) annotation (extent=[10,-10; 30,-50], rotation=90);
            BondLib.Electrical.Analog.Sources.SignalCurrent IC0 
              annotation (extent=[50,-10; 70,10], rotation=-90);
            BondLib.Electrical.Analog.Sources.SignalCurrent IB0 
              annotation (extent=[-20,-40; 0,-20], rotation=-90);
            BondLib.Electrical.Analog.Sensors.VoltageSensor Vbc 
              annotation (extent=[0,20; -20,40], rotation=90);
            BondLib.Electrical.Analog.Sensors.VoltageSensor Vbe 
              annotation (extent=[-30,-20; -50,-40], rotation=90);
          Modelica.Blocks.Sources.Constant qb1(k=1) 
            annotation (extent=[36,60; 24,72]);
          Modelica.Blocks.Sources.Constant C01(k=0) 
            annotation (extent=[36,80; 24,92]);
            Modelica.Thermal.HeatTransfer.TemperatureSensor Tdev 
              annotation (extent=[-20,-80; -40,-60]);
            Modelica.Blocks.Interfaces.RealOutput qb 
              annotation (extent=[100,-10; 120,10]);
          equation 
            connect(Dbc.p, Dbe.p) annotation (points=[20,10; 20,-10], style(
                  color=3, rgbcolor={0,0,255}));
            connect(Dbc.p, Bint) annotation (points=[20,10; 20,0; -100,0],
                style(color=3, rgbcolor={0,0,255}));
            connect(Dbc.n, Cint) annotation (points=[20,50; 100,50], style(
                  color=3, rgbcolor={0,0,255}));
            connect(Dbe.n, Eint) annotation (points=[20,-50; 100,-50], style(
                  color=3, rgbcolor={0,0,255}));
            connect(IC0.n, Eint) annotation (points=[60,-10; 60,-50; 100,-50],
                style(color=3, rgbcolor={0,0,255}));
            connect(IC0.p, Cint) annotation (points=[60,10; 60,50; 100,50],
                style(color=3, rgbcolor={0,0,255}));
            connect(IB0.n, Dbe.n) annotation (points=[-10,-40; -10,-50; 20,-50],
                style(color=3, rgbcolor={0,0,255}));
            connect(IB0.p, Bint) annotation (points=[-10,-20; -10,0; -100,0],
                style(color=3, rgbcolor={0,0,255}));
            connect(Vbc.p, Bint) annotation (points=[-10,20; -10,0; -100,0],
                style(color=3, rgbcolor={0,0,255}));
            connect(Vbc.n, Dbc.n) annotation (points=[-10,40; -10,50; 20,50],
                style(color=3, rgbcolor={0,0,255}));
            connect(Vbe.n, Dbe.n) annotation (points=[-40,-40; -40,-50; 20,-50],
                style(color=3, rgbcolor={0,0,255}));
            connect(Vbe.p, Bint) annotation (points=[-40,-20; -40,0; -100,0],
                style(color=3, rgbcolor={0,0,255}));
            connect(Dbe.heatPort, heatPort) annotation (points=[30,-30; 30,-70;
                  0,-70; 0,-100], style(color=42, rgbcolor={191,0,0}));
            connect(Dbc.heatPort, Dbe.heatPort) annotation (points=[30,30; 30,
                  -30], style(color=42, rgbcolor={191,0,0}));
            connect(Dbe.id, BJTvars1.ibe) annotation (points=[10,-30; 2,-30; 2,
                  -10; -108,-10; -108,48; -82,48], style(color=74, rgbcolor={0,
                    0,127}));
            connect(Vbe.V, BJTvars1.vbe) annotation (points=[-50,-30; -110,-30;
                  -110,56; -82,56], style(color=74, rgbcolor={0,0,127}));
            connect(Dbc.id, BJTvars1.ibc) annotation (points=[10,30; 2,30; 2,12;
                  -112,12; -112,64; -82,64], style(color=74, rgbcolor={0,0,127}));
            connect(Vbc.V, BJTvars1.vbc) annotation (points=[-20,30; -114,30;
                  -114,72; -82,72], style(color=74, rgbcolor={0,0,127}));
            connect(qb1.y, Dbc.qb) annotation (points=[23.4,66; 6,66; 6,38; 10,
                  38], style(color=74, rgbcolor={0,0,127}));
            connect(C01.y, Dbc.C0) annotation (points=[23.4,86; 4,86; 4,22; 10,
                  22], style(color=74, rgbcolor={0,0,127}));
            connect(BJTvars1.qb, Dbe.qb) annotation (points=[-38,56; -28,56;
                  -28,4; 4,4; 4,-38; 10,-38], style(color=74, rgbcolor={0,0,127}));
            connect(BJTvars1.C0, Dbe.C0) annotation (points=[-38,48; -26,48;
                  -26,6; 6,6; 6,-22; 10,-22], style(color=74, rgbcolor={0,0,127}));
            connect(BJTvars1.ic0, IC0.InPort1) annotation (points=[-38,64; -26,
                  64; -26,98; 74,98; 74,3.67382e-016; 66,3.67382e-016], style(
                  color=74, rgbcolor={0,0,127}));
            connect(BJTvars1.ib0, IB0.InPort1) annotation (points=[-38,72; -28,
                  72; -28,100; 76,100; 76,-60; 0,-60; 0,-30; -4,-30], style(
                  color=74, rgbcolor={0,0,127}));
            connect(Tdev.port, heatPort) annotation (points=[-20,-70; 0,-70; 0,
                  -100], style(
                color=42,
                rgbcolor={191,0,0},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Tdev.T, BJTvars1.Tdev) annotation (points=[-40,-70; -60,-70;
                  -60,38], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(BJTvars1.qb, qb) annotation (points=[-38,56; 80,56; 80,0;
                  110,0], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
          end Qni;
          
          model Qpi 
            "Spice-style PNP transistor model without parasitic resistors and substrate diode" 
            /* DC model parameters */
            parameter Real BF=50 
              "Forward beta coefficient at reference temperature";
            parameter Real BR=0.1 
              "Reverse beta coefficient at reference temperature";
            parameter Modelica.SIunits.Current IS=1e-16 
              "Saturation current at reference temperature";
            parameter Real NF=1 "Forward emission coefficient";
            parameter Real NR=1 "Reverse emission coefficient";
            parameter Modelica.SIunits.Conductance GminDC=1e-15 
              "Leakage conductance";
            
            /* Low current beta degradation effect parameters */
            parameter Modelica.SIunits.Current ISC=1e-16 
              "Collector saturation current at reference temperature";
            parameter Modelica.SIunits.Current ISE=1e-16 
              "Emitter saturation current at reference temperature";
            parameter Real NC=2 "Collector beta degradation coefficient";
            parameter Real NE=1.5 "Emitter beta degradation coefficient";
            
            /* Base width modulation parameters */
            parameter Modelica.SIunits.Voltage VAF=9e30 "Forward early voltage";
            parameter Modelica.SIunits.Voltage VAR=9e30 "Reverse early voltage";
            
            /* High current beta degradation effect parameters */
            parameter Modelica.SIunits.Current IKF=9e30 
              "Forward junction beta degradation current";
            parameter Modelica.SIunits.Current IKR=9e30 
              "Reverse junction beta degradation current";
            
            /* Junction capacitor parameters */
            parameter Modelica.SIunits.Capacitance CJC=0.5e-12 
              "Base-collector zero bias depletion capacitance at reference temperature";
            parameter Real MJC=0.333 "Base-collector gradation exponent";
            parameter Modelica.SIunits.Voltage VJC=0.8 
              "Base-collector diffusion voltage at reference temperature";
            parameter Modelica.SIunits.Capacitance CJE=0.4e-12 
              "Base-emitter zero bias depletion capacitance at reference temperature";
            parameter Real MJE=0.4 "Base-emitter gradation exponent";
            parameter Modelica.SIunits.Voltage VJE=0.8 
              "Base-emitter diffusion voltage at reference temperature";
            parameter Real XCJC=1 
              "Portion of depletion capacitance considered inside base-collector junction";
            
            /* Transit time parameters */
            parameter Modelica.SIunits.Time TF=0.12e-9 
              "Ideal forward transit time";
            parameter Modelica.SIunits.Time TR=5e-9 
              "Ideal reverse transit time";
            
            /* Temperature compensation and area parameters */
            parameter Modelica.SIunits.Temperature Tnom=300.15 
              "Reference temperature";
            parameter Real XTI=3 "Temperature exponent of saturation current";
            parameter Real XTB=0 "Temperature ratio exponent";
            parameter Modelica.SIunits.Voltage EG=1.16 "Activation energy";
            parameter Real Area=1 "Relative area occupied by device";
            
            /* Numerical parameters */
            parameter Real EMin=-100 
              "if x < EMin, the exp(x) function is linearized";
            parameter Real EMax=40 
              "if x > EMax, the exp(x) function is linearized";
            Modelica.Electrical.Analog.Interfaces.Pin Bint "Internal base node"
                                                               annotation (extent=[
                  -90,-10; -110,10]);
          public 
            Modelica.Electrical.Analog.Interfaces.Pin Cint 
              "Internal collector node"                             annotation (extent=[90,
                  40; 110,60]);
            Modelica.Electrical.Analog.Interfaces.Pin Eint 
              "Internal emitter node"                             annotation (extent=[90,
                  -40; 110,-60]);
            Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort(T(start=
                    300.15)) 
              annotation (extent=[-10,-90; 10,-110],   rotation=-90);
            BondLib.Spice.Utilities.BJTvars BJTvars1(
            Tnom=Tnom,
            BF=BF,
            BR=BR,
            TF=TF,
            EG=EG,
            XTI=XTI,
            VAF=VAF,
            VAR=VAR,
            IKF=IKF,
            IKR=IKR,
            ISC=ISC,
            ISE=ISE,
            NC=NC,
            NE=NE,
            XTB=XTB,
            Area=Area) 
            annotation (extent=[-80,40; -40,80]);
            BondLib.Electrical.Analog.Spice.Utilities.Dj Dcb(
              Tnom=Tnom,
              IS=IS,
              EG=EG,
              N=NR,
              XTI=XTI,
              VJ=VJC,
              CJ=CJC,
              XCJ=XCJC,
              MJ=MJC,
              Tau=TR,
              GminDC=GminDC,
              Area=Area,
              BE=false,
              EMin=EMin,
              EMax=EMax) annotation (extent=[10,50; 30,10], rotation=90);
            BondLib.Electrical.Analog.Spice.Utilities.Dj Deb(
              Tnom=Tnom,
              IS=IS,
              EG=EG,
              XTI=XTI,
              GminDC=GminDC,
              Area=Area,
              EMin=EMin,
              EMax=EMax,
              N=NF,
              VJ=VJE,
              CJ=CJE,
              MJ=MJE,
              Tau=TF,
              BE=true,
              XCJ=1) annotation (extent=[10,-50; 30,-10], rotation=90);
            BondLib.Electrical.Analog.Sources.SignalCurrent IC0 
              annotation (extent=[50,10; 70,-10], rotation=-90);
            BondLib.Electrical.Analog.Sources.SignalCurrent IB0 
              annotation (extent=[-20,-20; 0,-40], rotation=-90);
            BondLib.Electrical.Analog.Sensors.VoltageSensor Vcb 
              annotation (extent=[0,40; -20,20], rotation=90);
            BondLib.Electrical.Analog.Sensors.VoltageSensor Veb 
              annotation (extent=[-30,-40; -50,-20], rotation=90);
          Modelica.Blocks.Sources.Constant qb1(k=1) 
            annotation (extent=[36,80; 24,92]);
          Modelica.Blocks.Sources.Constant C01(k=0) 
            annotation (extent=[36,60; 24,72]);
            Modelica.Thermal.HeatTransfer.TemperatureSensor Tdev 
              annotation (extent=[-20,-80; -40,-60]);
            annotation (
              Diagram(
                Ellipse(extent=[-12,2; -8,-2], style(
                    color=3,
                    rgbcolor={0,0,255},
                    fillColor=3,
                    rgbfillColor={0,0,255})),
                Text(
                  extent=[-98,78; -86,72],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="vcb"),
                Text(
                  extent=[-98,70; -86,64],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="icb"),
                Text(
                  extent=[-98,62; -86,56],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="veb"),
                Text(
                  extent=[-98,54; -86,48],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="ieb"),
                Text(
                  extent=[-38,78; -26,72],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="IB0"),
                Text(
                  extent=[-38,70; -26,64],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="IC0"),
                Text(
                  extent=[-38,62; -26,56],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="qb"),
                Text(
                  extent=[-38,54; -26,48],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="C0"),
                Text(
                  extent=[-60,22; -48,16],
                  style(
                    color=10,
                    rgbcolor={95,95,95},
                    fillColor=3,
                    rgbfillColor={0,0,255},
                    fillPattern=1),
                  string="Tdev")),
              Icon(
                Line(points=[-10,40; -10,-40]),
                Line(points=[-10,0; -90,0]),
                Line(points=[91,50; 30,50]),
                Line(points=[30,50; -10,10]),
                Line(points=[-10,-10; 30,-50]),
                Line(points=[30,-50; 91,-50]),
                Polygon(points=[-10,-10; 5,-17; -3,-25; -10,-10],     style(fillColor=
                        3, fillPattern=1)),
                Line(points=[0,-40; 0,-91],   style(color=42))),
              Documentation(info="<html>
The PNP element of the Spice bond graph library implements a full-fledges Spice-stye model of the PNP bipolar transistor [1-3].  <b>PNPint</b> is a partial model that implements only the internal nodes of the bipolar transistor.  The external parasitic resistances, the external capacitor between base and collector, and the substrate are being added from the outside. <p>

<hr>

<pre>
<b>DC Model Parameters:</b>

 BF:      Forward beta coefficient (default value = 50)

 BR:      Reverse beta coefficient (default value = 0.1)

 IS:      Transport saturation current (default value = 1e-16 Amp)

 NF:      Forward emission coefficient (default value = 1)

 NR:      Reverse emission coefficient (default value = 1)

 GminDC:  Junction leakage conductance (default value = 1e-15 Mho)


<b>Low Current Beta Degradation Effect Parameters:</b>

 ISC:     Collector saturation current at reference temperature (default value = 1e-16 Amp)

 ISE:     Emitter saturation current at reference temperature (default value = 1e-16 Amp)

 NC:      Collector beta degradation coefficient (default value = 2)

 NE:      Emitter beta degradation coefficient (default value = 1.5)


<b>Base Width Modulation Parameters:</b>
  
 VAF:     Forward early voltage (default value = 9e30 Volt)

 VAR:     Reverse early voltage (default value = 9e30 Volt)


<b>High Current Beta Degradation Effect Parameters:</b>

 IKF:     Forward junction beta degradation current (default value = 9e30 Amp)

 IKR:     Reverse junction beta degradation current (default value = 9e30 Amp)


<b>Junction Capacitor Parameters:</b>

 CJC:     Base-collector zero bias depletion capacitance (default value = 0.5e-12 F)

 MJC:     Base-collector gradation exponent (default value = 0.333)

 VJC:     Base-collector diffusion voltage (default value = 0.8 Volt)

 CJE:     Base-emitter zero bias depletion capacitance (default value = 0.4e-12 F)

 MJE:     Base-emitter gradation exponent (default value = 0.4)

 VJE:     Base-emitter diffusion voltage (default value = 0.8 Volt)

 XCJC:    Portion of depletion capacitance considered inside base-collector junction (default value = 1)


<b>Transit Time Parameters:</b>

 TF:      Ideal forward transit time (default value = 0.12e-9 sec)

 TR:      Ideal reverse transit time (default value = 5e-9 sec)


<b>Temperature Compensation and Area Parameters:</b>

 Tnom:    Reference temperature (default value = 300.15 <sup>o</sup>K)

 XTI:     Temperature exponent of saturation current (default value = 3)

 XTB:     Temperature ratio exponent (default value = 0)

 EG:      Activation energy (default value = 1.16 Volt)

 Area:    Relative area occupied by device (default value = 1)


<b>Numerical Parameters:</b>

 EMin:    Minimum exponent (default value = -100)

 EMax:    Maximum exponent (default value = 40)
</pre> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li>Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York.
<li>Hild, D.R. and F.E. Cellier (1994), \"Object-oriented electronic circuit modeling using Dymola,\"
    <i>Proc. OOS'94, SCS Object Oriented Simulation Conference</i>, Tempe, AZ, pp.68-75.
<li>Hild, D.R. (1993), <i>Circuit Modeling in Dymola</i>, MS Thesis, Dept. of Electr. &amp; Comp. Engr.,
    University of Arizona, Tucson.
<li>Schweisguth, M.C. and F.E. Cellier (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/BJT.pdf\">A
    bond graph model of the bipolar junction transistor</a>,\" <i>Proc. SCS Intl. Conf. on Bond Graph Modeling</i>,
    San Francisco, CA, pp.344-349.
<li>Schweisguth, M.C. (1997), <a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/schweisguth_ms.pdf\"><i>Semiconductor
    Modeling with Bondgraphs</i></a>, MS Thesis, Dept. of Electr. &amp; Comp. Engr., University of Arizona, Tucson.
</ol> 
</html>
"));
            Modelica.Blocks.Interfaces.RealOutput qb 
              annotation (extent=[100,-10; 120,10]);
          equation 
            connect(Dcb.p, Bint) annotation (points=[20,50; 20,0; -100,0],
                style(color=3, rgbcolor={0,0,255}));
            connect(Deb.heatPort, heatPort) annotation (points=[30,-30; 30,-70;
                  0,-70; 0,-100], style(color=42, rgbcolor={191,0,0}));
            connect(Dcb.heatPort, Deb.heatPort) annotation (points=[30,30; 30,
                  -30], style(color=42, rgbcolor={191,0,0}));
            connect(Deb.id, BJTvars1.ibe) annotation (points=[10,-30; 2,-30; 2,
                  -10; -108,-10; -108,48; -82,48], style(color=74, rgbcolor={0,
                    0,127}));
            connect(Veb.V, BJTvars1.vbe) annotation (points=[-50,-30; -110,-30;
                  -110,56; -82,56], style(color=74, rgbcolor={0,0,127}));
            connect(Dcb.id, BJTvars1.ibc) annotation (points=[10,30; 2,30; 2,12;
                  -112,12; -112,64; -82,64], style(color=74, rgbcolor={0,0,127}));
            connect(Vcb.V, BJTvars1.vbc) annotation (points=[-20,30; -114,30;
                  -114,72; -82,72], style(color=74, rgbcolor={0,0,127}));
            connect(BJTvars1.ic0, IC0.InPort1) annotation (points=[-38,64; -26,
                  64; -26,98; 74,98; 74,-3.67382e-016; 66,-3.67382e-016], style(
                  color=74, rgbcolor={0,0,127}));
            connect(BJTvars1.ib0, IB0.InPort1) annotation (points=[-38,72; -28,
                  72; -28,100; 76,100; 76,-60; 0,-60; 0,-30; -4,-30], style(
                  color=74, rgbcolor={0,0,127}));
            connect(Tdev.port, heatPort) annotation (points=[-20,-70; 0,-70; 0,
                  -100], style(
                color=42,
                rgbcolor={191,0,0},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Tdev.T, BJTvars1.Tdev) annotation (points=[-40,-70; -60,-70;
                  -60,38], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Vcb.n, Bint) annotation (points=[-10,20; -10,0; -100,0],
                style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Veb.n, Bint) annotation (points=[-40,-20; -40,0; -100,0],
                style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(IB0.n, Bint) annotation (points=[-10,-20; -10,0; -100,0],
                style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Deb.p, Eint) annotation (points=[20,-50; 100,-50], style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(IB0.p, Deb.p) annotation (points=[-10,-40; -10,-50; 20,-50],
                style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Veb.p, Deb.p) annotation (points=[-40,-40; -40,-50; 20,-50],
                style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Deb.n, Bint) annotation (points=[20,-10; 20,0; -100,0],
                style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Deb.C0, BJTvars1.C0) annotation (points=[10,-38; 4,-38; 4,4;
                  -28,4; -28,48; -38,48], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Deb.qb, BJTvars1.qb) annotation (points=[10,-22; 6,-22; 6,6;
                  -26,6; -26,56; -38,56], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Dcb.qb, qb1.y) annotation (points=[10,22; 4,22; 4,86; 23.4,
                  86], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Dcb.C0, C01.y) annotation (points=[10,38; 6,38; 6,66; 23.4,
                  66], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Dcb.p, Cint) annotation (points=[20,50; 100,50], style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(Vcb.p, Dcb.p) annotation (points=[-10,40; -10,50; 20,50],
                style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(IC0.n, Cint) annotation (points=[60,10; 60,50; 100,50],
                style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(IC0.p, Eint) annotation (points=[60,-10; 60,-50; 100,-50],
                style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
            connect(BJTvars1.qb, qb) annotation (points=[-38,56; 80,56; 80,0;
                  110,0], style(
                color=74,
                rgbcolor={0,0,127},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1));
          end Qpi;
        end Utilities;
      end Spice;
      
      package Examples 
        "Examples of analog electrical circuits copied from standard library" 
        annotation (Icon(
            Rectangle(extent=[-100,-100; 80,50], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=30,
                rgbfillColor={235,235,235},
                fillPattern=1)),
            Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=30,
                rgbfillColor={235,235,235},
                fillPattern=1)),
            Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=30,
                rgbfillColor={235,235,235},
                fillPattern=1)),
            Text(
              extent=[-118,114; 122,65],
              string="%name",
              style(color=1)),
            Text(
              extent=[-85,63; 65,-57],
              string="Sample",
              style(color=0)),
            Text(
              extent=[-97,15; 78,-106],
              string="Programs",
              style(color=0))), Documentation(info="<html>
This package contains a number of examples copied from the standard analog electrical library, except that each of the modeling elements has been replaced by the corresponding modeling element from the analog electrical library built on bond graph technology.  These models were placed here to verify the correctness of the bond graph library.
</html>
"));
        model CharacteristicIdealDiodes "Characteristic of ideal diodes" 
          annotation (Documentation(info="<html>
<P>
Three examples of ideal diodes are shown:<br><br>
the <b>totally ideal diode</b> (Ideal) with all parameters to be zero <br>
the <b>nearly ideal diode</b> with <i>Ron=0.1</i> and <i>Goff=0.1</i> <br>
the nearly ideal but <b>displaced diode</b> with <i>Vknee=5</i> and <i>Ron=0.1</i> and 
<i>Goff=0.1</i> <br><br>
The resistance and conductance are chosen untypically high since the slopes should
be seen in the graphics.
</P>
<P>
Simulate until T=1 s.
</P>
<P>
Plot in separate windows:<br> <br>
Ideal.i versus Ideal.v <br>
With_Ron_Goff.i versus With_Ron_Goff.v<br>
With_Ron_Goff_Vknee.i versus With_Ron_Goff_Vknee.v<br>
</P>
<p><b>Release Notes:</b></p>
<ul>
<li><i>Mai 7, 2004   </i>
       by Christoph Clauss<br> realized<br>
       </li>
</ul>
</html>
"),         Diagram(Text(extent=[-90,96; 90,42], string=
                  "Characteristic Ideal Diodes")),
            Icon(
              Rectangle(extent=[-100,-100; 80,50],   style(fillColor=7)),
              Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50],      style(
                    fillColor=7)),
              Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70],      style(
                    fillColor=7)),
              Text(
                extent=[-96,3; 77,-49],
                string="Example",
                style(color=3)),
              Text(
                extent=[-120,132; 120,73],
                string="%name",
                style(color=1))));
          Modelica.Electrical.Analog.Basic.Ground Ground1 
          annotation (extent=[-52,-86; -32,-66]);
          Sources.SineVoltage SineVoltage1(V=10, offset=-9) 
            annotation (extent=[-32,4; -52,-16], rotation=90);
          Sources.SineVoltage SineVoltage2(V=10, offset=0) 
            annotation (extent=[-52,44; -72,24], rotation=90);
          Sources.SineVoltage SineVoltage3(V=10, offset=0) 
            annotation (extent=[-12,-36; -32,-56], rotation=90);
          Basic.Resistor R1(R=1e-3) annotation (extent=[58,34; 78,54]);
          Basic.Resistor R2(R=1e-3) annotation (extent=[58,-6; 78,14]);
          Basic.Resistor R3(R=1e-3) annotation (extent=[58,-46; 78,-26]);
          BondLib.Electrical.Analog.Ideal.IdealDiode Ideal(Ron=0, Goff=0) 
            annotation (extent=[-2,34; 18,54]);
          BondLib.Electrical.Analog.Ideal.IdealDiode With_Ron_Goff(Ron=0.1, Goff=
               0.1) annotation (extent=[-2,-6; 18,14]);
          BondLib.Electrical.Analog.Ideal.IdealDiode With_Ron_Goff_Vknee(
            Ron=0.2,
            Goff=0.2,
            Vknee=5) annotation (extent=[-2,-46; 18,-26]);
        equation 
          connect(SineVoltage2.n, Ground1.p) annotation (points=[-62,24; -62,
                -66; -42,-66], style(color=3, rgbcolor={0,0,255}));
          connect(Ideal.p, SineVoltage2.p) annotation (points=[-2,44; -62,44],
              style(color=3, rgbcolor={0,0,255}));
          connect(Ideal.n, R1.p) annotation (points=[18,44; 58,44], style(color=
                 3, rgbcolor={0,0,255}));
          connect(R1.n, R2.n) annotation (points=[78,44; 78,4], style(color=3,
                rgbcolor={0,0,255}));
          connect(SineVoltage1.n, Ground1.p) annotation (points=[-42,-16; -42,
                -66; -42,-66], style(color=3, rgbcolor={0,0,255}));
          connect(SineVoltage1.p, With_Ron_Goff.p) annotation (points=[-42,4;
                -2,4], style(color=3, rgbcolor={0,0,255}));
          connect(With_Ron_Goff.n, R2.p) annotation (points=[18,4; 58,4], style(
                color=3, rgbcolor={0,0,255}));
          connect(R2.n, R3.n) annotation (points=[78,4; 78,-36], style(color=3,
                rgbcolor={0,0,255}));
          connect(SineVoltage3.n, Ground1.p) annotation (points=[-22,-56; -22,
                -66; -42,-66], style(color=3, rgbcolor={0,0,255}));
          connect(SineVoltage3.p, With_Ron_Goff_Vknee.p) annotation (points=[
                -22,-36; -2,-36], style(color=3, rgbcolor={0,0,255}));
          connect(With_Ron_Goff_Vknee.n, R3.p) annotation (points=[18,-36; 58,
                -36], style(color=3, rgbcolor={0,0,255}));
          connect(R3.n, Ground1.p) annotation (points=[78,-36; 78,-66; -42,-66],
              style(color=3, rgbcolor={0,0,255}));
        end CharacteristicIdealDiodes;
        
        model DifferenceAmplifier "Differential amplifier" 
          annotation (
            Icon(
              Rectangle(extent=[-100,-100; 80,50],   style(fillColor=7)),
              Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50],      style(
                    fillColor=7)),
              Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70],      style(
                    fillColor=7)),
              Text(
                extent=[-96,3; 77,-49],
                string="Example",
                style(color=3)),
              Text(
                extent=[-120,132; 120,73],
                string="%name",
                style(color=1))),
            Documentation(info="<html>
<p>
It is a simple NPN transistor amplifier circuit. The voltage difference between R1.p and R3.n is amplified. The output signal is the voltage between R2.n and R4.n. In this example the voltage at V1 is amplified because R3.n is grounded.
<p>
The simulation end time should be set to 1e- 8. Please plot the input voltage V1.v, and the output voltages R2.n.v, and R4.n.v.
<p>
<dl>
<dt>
<b>Reference:</b>
<dd>
Tietze, U.; Schenk, Ch.: Halbleiter-Schaltungstechnik. Springer-Verlag Berlin Heidelberg NewYork 1980, p. 59
<p>
<dt>
<b>Main Authors:</b>
<dd>
<a href=\"http://people.eas.iis.fhg.de/Christoph.Clauss/\">Christoph Clau&szlig;</a>
    &lt;<a href=\"mailto:clauss@eas.iis.fhg.de\">clauss@eas.iis.fhg.de</a>&gt;<br>
    <a href=\"http://people.eas.iis.fhg.de/Andre.Schneider/\">Andr&eacute; Schneider</a>
    &lt;<a href=\"mailto:schneider@eas.iis.fhg.de\">schneider@eas.iis.fhg.de</a>&gt;<br>
    Fraunhofer Institute for Integrated Circuits<br>
    Design Automation Department<br>
    Zeunerstra&szlig;e 38<br>
    D-01069 Dresden<br>
<p>
<dt>
<b>Copyright:</b>
<dd>
Copyright &copy; 1998-2002, Modelica Association and Fraunhofer-Gesellschaft.<br>
<i>The Modelica package is <b>free</b> software; it can be redistributed and/or modified
under the terms of the <b>Modelica license</b>, see the license conditions
and the accompanying <b>disclaimer</b> in the documentation of package
Modelica in file \"Modelica/package.mo\".</i><br>
<p>
</dl>
</html>
"),         Diagram);
          Basic.Ground Gnd1 annotation (extent=[-96,-80; -84,-70]);
          Basic.Ground Gnd2 annotation (extent=[-66,-80; -54,-70]);
          Basic.Ground Gnd3 annotation (extent=[-16,-20; -4,-10]);
          Basic.Ground Gnd4 annotation (extent=[84,-40; 96,-30]);
          Basic.Ground Gnd5 annotation (extent=[54,-80; 66,-70]);
          Basic.Ground Gnd6 annotation (extent=[4,-20; 16,-10]);
          Basic.Ground Gnd7 annotation (extent=[-16,-80; -4,-70]);
          Basic.Ground Gnd8 annotation (extent=[4,-80; 16,-70]);
          Basic.Ground Gnd9 annotation (extent=[74,20; 86,30]);
          Sources.ExpSineVoltage V1(
            V=0.2,
            freqHz=0.2e9,
            damping=0.1e8) annotation (extent=[-100,-60; -80,-40], rotation=-90);
          Basic.Resistor R1(R=0.0001) annotation (extent=[-90,-20; -70,0]);
          Basic.Resistor R2(R=100) 
            annotation (extent=[-50,20; -30,40], rotation=-90);
          Basic.Resistor R3(R=0.0001) annotation (extent=[70,-20; 90,0]);
          Basic.Resistor R4(R=100) 
            annotation (extent=[30,20; 50,40], rotation=-90);
          Basic.Capacitor C1(C=1e-10) 
            annotation (extent=[-70,-60; -50,-40], rotation=-90);
          Basic.Capacitor C2(C=1e-10) 
            annotation (extent=[-30,-14; -10,6], rotation=0);
          Basic.Capacitor C3(C=1e-10) 
            annotation (extent=[50,-60; 70,-40], rotation=-90);
          Basic.Capacitor C4(C=1e-10) 
            annotation (extent=[10,-14; 30,6], rotation=0);
          Basic.Capacitor C5(C=1e-10) 
            annotation (extent=[0,-60; 20,-40], rotation=-90);
          Sources.RampVoltage V2(V=15, duration=1e-9) 
            annotation (extent=[70,40; 90,60], rotation=-90);
          Sources.RampCurrent I1(I=0.16, duration=1e-9) 
            annotation (extent=[-20,-60; 0,-40], rotation=-90);
          Utilities.Transistor Transistor1 annotation (extent=[-60,-20; -40,0]);
          Utilities.Transistor Transistor2 annotation (extent=[60,-20; 40,0]);
        equation 
          connect(Gnd1.p, V1.n) annotation (points=[-90,-70; -90,-60], style(
                color=3, rgbcolor={0,0,255}));
          connect(V1.p, R1.p) annotation (points=[-90,-40; -90,-10], style(
                color=3, rgbcolor={0,0,255}));
          connect(Gnd4.p, R3.n) annotation (points=[90,-30; 90,-10], style(
                color=3, rgbcolor={0,0,255}));
          connect(Gnd2.p, C1.n) annotation (points=[-60,-70; -60,-60], style(
                color=3, rgbcolor={0,0,255}));
          connect(Gnd3.p, C2.n) annotation (points=[-10,-10; -10,-4], style(
                color=3, rgbcolor={0,0,255}));
          connect(Gnd5.p, C3.n) annotation (points=[60,-70; 60,-60], style(
                color=3, rgbcolor={0,0,255}));
          connect(Gnd6.p, C4.p) annotation (points=[10,-10; 10,-4], style(color=
                 3, rgbcolor={0,0,255}));
          connect(Gnd8.p, C5.n) annotation (points=[10,-70; 10,-60], style(
                color=3, rgbcolor={0,0,255}));
          connect(Gnd9.p, V2.n) annotation (points=[80,30; 80,40], style(color=
                  3, rgbcolor={0,0,255}));
          connect(V2.p, R4.p) annotation (points=[80,60; 80,70; 40,70; 40,40],
              style(color=3, rgbcolor={0,0,255}));
          connect(R2.p, V2.p) annotation (points=[-40,40; -40,70; 80,70; 80,60],
              style(color=3, rgbcolor={0,0,255}));
          connect(Gnd7.p, I1.n) annotation (points=[-10,-70; -10,-60], style(
                color=3, rgbcolor={0,0,255}));
          connect(C5.p, I1.p) annotation (points=[10,-40; -10,-40], style(color=
                 3, rgbcolor={0,0,255}));
          connect(R1.n, Transistor1.b) annotation (points=[-70,-10; -60,-10],
              style(color=3, rgbcolor={0,0,255}));
          connect(C1.p, Transistor1.b) annotation (points=[-60,-40; -60,-10],
              style(color=3, rgbcolor={0,0,255}));
          connect(I1.p, Transistor1.e) annotation (points=[-10,-40; -30,-40;
                -30,-16; -40,-16], style(color=3, rgbcolor={0,0,255}));
          connect(C2.p, Transistor1.c) annotation (points=[-30,-4; -40,-4],
              style(color=3, rgbcolor={0,0,255}));
          connect(R2.n, Transistor1.c) annotation (points=[-40,20; -40,-4],
              style(color=3, rgbcolor={0,0,255}));
          connect(C4.n, Transistor2.c) annotation (points=[30,-4; 40,-4], style(
                color=3, rgbcolor={0,0,255}));
          connect(Transistor2.c, R4.n) annotation (points=[40,-4; 40,20], style(
                color=3, rgbcolor={0,0,255}));
          connect(C5.p, Transistor2.e) annotation (points=[10,-40; 30,-40; 30,
                -16; 40,-16], style(color=3, rgbcolor={0,0,255}));
          connect(Transistor2.b, R3.p) annotation (points=[60,-10; 70,-10],
              style(color=3, rgbcolor={0,0,255}));
          connect(C3.p, Transistor2.b) annotation (points=[60,-40; 60,-10],
              style(color=3, rgbcolor={0,0,255}));
        end DifferenceAmplifier;
        
        model HeatingRectifier "Heating rectifier" 
          annotation (
            Icon(
              Rectangle(extent=[-100,-100; 80,50],   style(fillColor=7)),
              Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50],      style(
                    fillColor=7)),
              Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70],      style(
                    fillColor=7)),
              Text(
                extent=[-96,3; 77,-49],
                string="Example",
                style(color=3)),
              Text(
                extent=[-120,132; 120,73],
                string="%name",
                style(color=1))),
            Diagram(        Text(extent=[-74,88; 20,60],   string=
                  "HeatingRectifier")),
            Documentation(info="<html>
<P>
The heating rectifier shows a heat flow always if the electrical capacitor is loaded.
</P>
<P>
Simulate until T=5 s.
</P>
<P>
Plot in separate windows:<br> <br>
SineVoltage1.v  and  Capacitor1.p.v <br>
HeatCapacitor1.port.T and HeatingDiode1.heatPort.T<br>
HeatingDiode1.heatPort.Q_flow<br>
</P>
<p><b>Release Notes:</b></p>
<ul>
<li><i>Mai 6, 2004   </i>
       by Christoph Clauss<br> realized<br>
       </li>
</ul>
</html>
"),       experiment(StopTime=5));
          Modelica.Electrical.Analog.Basic.Ground G 
          annotation (extent=[-60,-14; -40,6]);
          Modelica.Thermal.HeatTransfer.HeatCapacitor HeatCapacitor1(C=1) 
          annotation (extent=[0,-74; 20,-54],    rotation=180);
          Modelica.Thermal.HeatTransfer.ThermalConductor ThermalConductor1(G=10) 
          annotation (extent=[0,-34; 20,-14],  rotation=270);
          Basic.Resistor R annotation (extent=[40,60; 60,80]);
          Basic.Capacitor Capacitor1 annotation (extent=[40,26; 60,46]);
          Sources.SineVoltage SineVoltage1 
            annotation (extent=[-60,16; -40,36], rotation=-90);
          Semiconductors.HeatingDiode HeatingDiode1 
            annotation (extent=[0,26; 20,46]);
        equation 
          connect(ThermalConductor1.port_b,HeatCapacitor1. port) 
                                                               annotation (
            points=[10,-35; 10,-39.75; 10,-39.75; 10,-44.5; 10,-54; 10,-54],
                          style(color=42));
          connect(R.n, Capacitor1.n) annotation (points=[60,70; 60,36], style(
                color=3, rgbcolor={0,0,255}));
          connect(R.p, Capacitor1.p) annotation (points=[40,70; 40,36], style(
                color=3, rgbcolor={0,0,255}));
          connect(Capacitor1.n, G.p) annotation (points=[60,36; 60,6; -50,6],
              style(color=3, rgbcolor={0,0,255}));
          connect(SineVoltage1.n, G.p) annotation (points=[-50,16; -50,6],
              style(color=3, rgbcolor={0,0,255}));
          connect(HeatingDiode1.n, Capacitor1.p) annotation (points=[20,36; 40,
                36], style(color=3, rgbcolor={0,0,255}));
          connect(HeatingDiode1.p, SineVoltage1.p) annotation (points=[0,36;
                -50,36], style(color=3, rgbcolor={0,0,255}));
          connect(HeatingDiode1.heatPort, ThermalConductor1.port_a) annotation (
             points=[10,26; 10,6.5; 10,-13; 10,-13],
                                     style(color=42, rgbcolor={191,0,0}));
        end HeatingRectifier;
        
        model Rectifier "B6 diode bridge" 
          parameter Modelica.SIunits.Voltage VAC=400 "RMS line-to-line";
          parameter Modelica.SIunits.Frequency f=50 "line frequency";
          parameter Modelica.SIunits.Inductance LAC=60E-6 "line inductor";
          parameter Modelica.SIunits.Resistance Ron=1E-3 
            "diode forward resistance";
          parameter Modelica.SIunits.Conductance Goff=1E-3 
            "diode backward conductance";
          parameter Modelica.SIunits.Voltage Vknee=2 "diode threshold voltage";
          parameter Modelica.SIunits.Capacitance CDC=15E-3 "DC capacitance";
          parameter Modelica.SIunits.Current IDC=500 "load current";
          parameter Modelica.SIunits.Voltage vC10 = VAC*sqrt(2)/2;
          parameter Modelica.SIunits.Voltage vC20 = VAC*sqrt(2)/2;
          output Modelica.SIunits.Voltage uDC;
          output Modelica.SIunits.Current iAC[3];
          output Modelica.SIunits.Voltage uAC[3];
          output Modelica.SIunits.Power Losses;
          annotation (
            Icon(
              Rectangle(extent=[-100,-100; 80,50],   style(fillColor=7)),
              Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50],      style(
                    fillColor=7)),
              Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70],      style(
                    fillColor=7)),
              Text(
                extent=[-96,3; 77,-49],
                string="Example",
                style(color=3)),
              Text(
                extent=[-120,132; 120,73],
                string="%name",
                style(color=1))),
            Diagram(
            Text(
              extent=[-82,80; 78,60],
              string="Rectifier",
              style(color=0, rgbcolor={0,0,0})),
            Line(points=[-18,8; -18,-8; -20,-4; -16,-4; -18,-8],   style(
                  color=0, rgbcolor={0,0,0})),
            Line(points=[-32,12; -28,10; -32,8; -32,12],      style(color=0,
                  rgbcolor={0,0,0})),
            Line(points=[30,20; 30,-40; 28,-36; 32,-36; 30,-40],      style(
                  color=0, rgbcolor={0,0,0})),
            Text(
              extent=[-40,6; -24,-2],
              string="iAC",
              style(color=0, rgbcolor={0,0,0})),
            Text(
              extent=[-16,-2; 0,-10],
              string="uAC",
              style(color=0, rgbcolor={0,0,0})),
            Text(
              extent=[20,-26; 36,-34],
              string="uDC",
              style(color=0, rgbcolor={0,0,0}))),
            Documentation(info="<html>
<P>
The rectifier example shows a B6 diode bridge fed by a three phase sinusoidal voltage, loaded by a DC current.<br>
DC capacitors start at ideal no-load voltage, thus making easier initial transient.
</P>
<P>
Simulate until T=0.1 s,<br>
Set communication interval to 1e-5, and<br>
Limit output storage to defined output variables only.<p>

Plot in separate windows:<br><br>
uDC ... DC-voltage<br>
iAC ... AC-currents 1..3<br>
uAC ... AC-voltages 1..3 (distorted)<br>
Try different load currents iDC = 0..approximately 500 A.
</P>
<p>
You may watch Losses (of the whole diode bridge) trying different diode parameters.
</p>
<p><b>Release Notes:</b></p>
<ul>
<li><i>Mai 7, 2004   </i>
       by Anton Haumer<br> realized<br>
       </li>
</ul>
</html>
"),         experiment(StopTime=0.1, Interval=1e-005),
            experimentSetupOutput(
              states=false,
              derivatives=false,
              inputs=false,
              auxiliaries=false));
          Modelica.Blocks.Sources.Constant Constant1(k=IDC) 
          annotation (extent=[98,-20; 78,0],     rotation=0);
          Basic.Ground Ground1 annotation (extent=[42,-88; 62,-68]);
          Basic.Capacitor Capacitor1(C=2*CDC, u0=vC10) 
            annotation (extent=[28,20; 48,40], rotation=-90);
          Basic.Capacitor Capacitor2(C=2*CDC, u0=vC20) 
            annotation (extent=[28,-60; 48,-40], rotation=-90);
          Sources.SignalCurrent SignalCurrent1 
            annotation (extent=[48,-20; 68,0], rotation=-90);
          Sources.SineVoltage SineVoltage1(V=VAC*sqrt(2/3), freqHz=f) 
            annotation (extent=[-92,20; -72,0], rotation=180);
          Sources.SineVoltage SineVoltage2(
            V=VAC*sqrt(2/3),
            freqHz=f,
            phase=-2/3*Modelica.Constants.pi) 
            annotation (extent=[-92,0; -72,-20], rotation=180);
          Sources.SineVoltage SineVoltage3(
            V=VAC*sqrt(2/3),
            freqHz=f,
            phase=-4/3*Modelica.Constants.pi) 
            annotation (extent=[-92,-20; -72,-40], rotation=180);
          Basic.Inductor Inductor1(L=LAC) annotation (extent=[-62,0; -42,20]);
          Basic.Inductor Inductor2(L=LAC) annotation (extent=[-62,-20; -42,0]);
          Basic.Inductor Inductor3(L=LAC) annotation (extent=[-62,-40; -42,-20]);
          Ideal.IdealDiode IdealDiode1(
            Ron=Ron,
            Goff=Goff,
            Vknee=Vknee) annotation (extent=[-32,20; -12,40], rotation=90);
          Ideal.IdealDiode IdealDiode2(
            Ron=Ron,
            Goff=Goff,
            Vknee=Vknee) annotation (extent=[-12,20; 8,40], rotation=90);
          Ideal.IdealDiode IdealDiode3(
            Ron=Ron,
            Goff=Goff,
            Vknee=Vknee) annotation (extent=[8,20; 28,40], rotation=90);
          Ideal.IdealDiode IdealDiode4(
            Ron=Ron,
            Goff=Goff,
            Vknee=Vknee) annotation (extent=[-32,-60; -12,-40], rotation=90);
          Ideal.IdealDiode IdealDiode5(
            Ron=Ron,
            Goff=Goff,
            Vknee=Vknee) annotation (extent=[-12,-60; 8,-40], rotation=90);
          Ideal.IdealDiode IdealDiode6(
            Ron=Ron,
            Goff=Goff,
            Vknee=Vknee) annotation (extent=[8,-60; 28,-40], rotation=90);
        equation 
          uDC = Capacitor1.v + Capacitor2.v;
          iAC = {Inductor1.i,Inductor2.i,Inductor3.i};
          uAC[1] = Inductor1.n.v - Inductor2.n.v;
          uAC[2] = Inductor2.n.v - Inductor3.n.v;
          uAC[3] = Inductor3.n.v - Inductor1.n.v;
          Losses = IdealDiode1.v*IdealDiode1.i + IdealDiode2.v*IdealDiode2.i +
            IdealDiode3.v*IdealDiode3.i + IdealDiode4.v*IdealDiode4.i +
            IdealDiode5.v*IdealDiode5.i + IdealDiode6.v*IdealDiode6.i;
          connect(Constant1.y, SignalCurrent1.InPort1) annotation (points=[77,
                -10; 64,-10], style(color=74, rgbcolor={0,0,127}));
          connect(SineVoltage1.n, SineVoltage2.n) annotation (points=[-92,10; 
                -92,-10], style(color=3, rgbcolor={0,0,255}));
          connect(SineVoltage2.n, SineVoltage3.n) annotation (points=[-92,-10; 
                -92,-30], style(color=3, rgbcolor={0,0,255}));
          connect(SineVoltage1.p, Inductor1.p) annotation (points=[-72,10; -67,
                10; -67,10; -62,10], style(color=3, rgbcolor={0,0,255}));
          connect(SineVoltage2.p, Inductor2.p) annotation (points=[-72,-10; -67,
                -10; -67,-10; -62,-10], style(color=3, rgbcolor={0,0,255}));
          connect(SineVoltage3.p, Inductor3.p) annotation (points=[-72,-30; -62,
                -30], style(color=3, rgbcolor={0,0,255}));
          connect(Inductor1.n, IdealDiode4.n) annotation (points=[-42,10; -22,
                10; -22,-40], style(color=3, rgbcolor={0,0,255}));
          connect(Inductor2.n, IdealDiode5.n) annotation (points=[-42,-10; -2,
                -10; -2,-40], style(color=3, rgbcolor={0,0,255}));
          connect(Inductor3.n, IdealDiode3.p) annotation (points=[-42,-30; 18,
                -30; 18,20], style(color=3, rgbcolor={0,0,255}));
          connect(IdealDiode1.p, IdealDiode4.n) annotation (points=[-22,20; -22,
                -40], style(color=3, rgbcolor={0,0,255}));
          connect(IdealDiode2.p, IdealDiode5.n) annotation (points=[-2,20; -2,5; 
                -2,5; -2,-10; -2,-40; -2,-40], style(color=3, rgbcolor={0,0,255}));
          connect(IdealDiode6.n, IdealDiode3.p) annotation (points=[18,-40; 18,
                20], style(color=3, rgbcolor={0,0,255}));
          connect(IdealDiode1.n, IdealDiode2.n) annotation (points=[-22,40; -2,
                40], style(color=3, rgbcolor={0,0,255}));
          connect(IdealDiode2.n, IdealDiode3.n) annotation (points=[-2,40; 18,
                40], style(color=3, rgbcolor={0,0,255}));
          connect(IdealDiode3.n, Capacitor1.p) annotation (points=[18,40; 38,40],
              style(color=3, rgbcolor={0,0,255}));
          connect(IdealDiode4.p, IdealDiode5.p) annotation (points=[-22,-60; -2,
                -60], style(color=3, rgbcolor={0,0,255}));
          connect(IdealDiode5.p, IdealDiode6.p) annotation (points=[-2,-60; 18,
                -60], style(color=3, rgbcolor={0,0,255}));
          connect(IdealDiode6.p, Capacitor2.n) annotation (points=[18,-60; 38,
                -60], style(color=3, rgbcolor={0,0,255}));
          connect(Capacitor1.n, Capacitor2.p) annotation (points=[38,20; 38,-40],
              style(color=3, rgbcolor={0,0,255}));
          connect(Ground1.p, Capacitor2.p) annotation (points=[52,-68; 52,-30;
                38,-30; 38,-40], style(color=3, rgbcolor={0,0,255}));
          connect(Capacitor1.p, SignalCurrent1.p) annotation (points=[38,40; 58,
                40; 58,0], style(color=3, rgbcolor={0,0,255}));
          connect(Capacitor2.n, SignalCurrent1.n) annotation (points=[38,-60;
                58,-60; 58,-20], style(color=3, rgbcolor={0,0,255}));
        end Rectifier;
        
        model ShowVariableResistor "Simple demo of a VariableResistor model" 
          annotation (
            Icon(
              Rectangle(extent=[-100,-100; 80,50],   style(fillColor=7)),
              Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50],      style(
                    fillColor=7)),
              Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70],      style(
                    fillColor=7)),
              Text(
                extent=[-96,3; 77,-49],
                string="Example",
                style(color=3)),
              Text(
                extent=[-120,132; 120,73],
                string="%name",
                style(color=1))),
            Diagram(Text(
                extent=[-90,106; 90,34],
                style(color=3, rgbcolor={0,0,255}),
                string="Example VariableResistor")),
            Documentation(info="<html>
<P>
It is a simple test circuit for the VariableResistor. The VariableResistor
sould be compared with R2.
</P>
<P>
Simulate until T=1 s.
</P>
<P>
<p><b>Release Notes:</b></p>
<ul>
<li><i>Mai 6, 2004   </i>
       by Teresa Schlegel<br> realized<br>
       </li>
</ul>
</html>
"));
          Modelica.Blocks.Sources.Ramp Ramp1(height=5, offset=2) 
          annotation(extent=[-10,4; 10,24], rotation=270);
          Basic.Ground Ground1 annotation (extent=[-90,-84; -70,-64]);
          Basic.Ground Ground2 annotation (extent=[70,-50; 90,-30]);
          Basic.Resistor R1 annotation (extent=[-60,34; -40,54]);
          Basic.Resistor R2 annotation (extent=[-10,34; 10,54]);
          Basic.Resistor R3 annotation (extent=[30,34; 50,54]);
          Basic.Resistor R4 annotation (extent=[-60,-26; -40,-6]);
          Basic.Resistor R5 annotation (extent=[30,-26; 50,-6]);
          Basic.VariableResistor VariableResistor1 
            annotation (extent=[-10,-26; 10,-6]);
          Sources.SineVoltage SineVoltage1 
            annotation (extent=[-90,-50; -70,-30], rotation=90);
        equation 
          connect(Ramp1.y, VariableResistor1.u) annotation (points=[
                -2.0206e-015,3; -2.0206e-015,-1.5; 0,-1.5; 0,-7], style(color=
                  74, rgbcolor={0,0,127}));
          connect(SineVoltage1.n, R4.p) annotation (points=[-80,-30; -80,-16;
                -60,-16], style(color=3, rgbcolor={0,0,255}));
          connect(R1.p, R4.p) annotation (points=[-60,44; -80,44; -80,-16; -60,
                -16], style(color=3, rgbcolor={0,0,255}));
          connect(R1.n, R2.p) annotation (points=[-40,44; -10,44], style(color=
                  3, rgbcolor={0,0,255}));
          connect(R4.n, VariableResistor1.p) annotation (points=[-40,-16; -10,
                -16], style(color=3, rgbcolor={0,0,255}));
          connect(R2.n, R3.p) annotation (points=[10,44; 30,44], style(color=3,
                rgbcolor={0,0,255}));
          connect(VariableResistor1.n, R5.p) annotation (points=[10,-16; 30,-16],
              style(color=3, rgbcolor={0,0,255}));
          connect(R5.n, R3.n) annotation (points=[50,-16; 80,-16; 80,44; 50,44],
              style(color=3, rgbcolor={0,0,255}));
          connect(Ground2.p, R3.n) annotation (points=[80,-30; 80,44; 50,44],
              style(color=3, rgbcolor={0,0,255}));
          connect(Ground1.p, SineVoltage1.p) annotation (points=[-80,-64; -80,
                -50], style(color=3, rgbcolor={0,0,255}));
        end ShowVariableResistor;
        
        package Utilities 
          "Some utility models used in the examples of the analog electrical library" 
          annotation (Icon(
              Rectangle(extent=[-100,-100; 80,50], style(
                  color=42,
                  rgbcolor={127,0,0},
                  fillColor=30,
                  rgbfillColor={235,235,235},
                  fillPattern=1)),
              Polygon(points=[-100,50; -80,70; 100,70; 80,50; -100,50], style(
                  color=42,
                  rgbcolor={127,0,0},
                  fillColor=30,
                  rgbfillColor={235,235,235},
                  fillPattern=1)),
              Polygon(points=[100,70; 100,-80; 80,-100; 80,50; 100,70], style(
                  color=42,
                  rgbcolor={127,0,0},
                  fillColor=30,
                  rgbfillColor={235,235,235},
                  fillPattern=1)),
              Text(
                extent=[-85,35; 65,-85],
                string="Library",
                style(color=42, rgbcolor={127,0,0})),
              Text(
                extent=[-120,122; 120,73],
                string="%name",
                style(color=1))), Documentation(info="<html>
This package contains some utility models used by some of the examples of the analog electrical library.
</html>
"));
          model Transistor "NPN transistor based amplifier" 
            annotation (
              Documentation(info="<html>
This model presents a simple amplifier built from a single NPN bipolar transistor.
</html>
"),           Icon(
                Rectangle(extent=[-80,80; 80,-80]),
                Line(points=[80,60; 100,60]),
                Line(points=[80,-60; 100,-60]),
                Line(points=[-100,0; -80,0]),
                Line(points=[-60,0; -10,0]),
                Line(points=[-10,40; -10,-40]),
                Line(points=[60,60; 40,60; -10,10]),
                Line(points=[-10,-10; 40,-60; 60,-60])),
              Diagram);
            Modelica.Electrical.Analog.Interfaces.Pin c 
                             annotation (extent=[90,50; 110,70]);
            Modelica.Electrical.Analog.Interfaces.Pin b 
                             annotation (extent=[-110,-10; -90,10]);
            Modelica.Electrical.Analog.Interfaces.Pin e 
                             annotation (extent=[90,-70; 110,-50]);
            Basic.Resistor Rtb(R=0.05) annotation (extent=[-70,-10; -50,10]);
            Basic.Capacitor Ct(C=1e-10) 
              annotation (extent=[-40,-40; -20,-20], rotation=-90);
            Semiconductors.NPN Tr(
              Bf=50,
              Br=0.1,
              Is=1e-16,
              Vak=0.02,
              Tauf=0.12e-9,
              Taur=5e-9,
              Ccs=1e-12,
              Cje=0.4e-12,
              Cjc=0.5e-12,
              Phie=0.8,
              Me=0.4,
              Phic=0.8,
              Mc=0.333,
              Gbc=1e-15,
              Gbe=1e-15,
              Vt=0.02585) 
                         annotation (extent=[-10,-20; 30,20]);
            Basic.Resistor Rtc(R=0.1) annotation (extent=[50,0; 70,20]);
            Basic.Ground Gnd1    annotation (extent=[-40,-80; -20,-60]);
          equation 
            connect(Tr.C, Rtc.p) annotation (points=[30,10; 50,10], style(color=
                   3, rgbcolor={0,0,255}));
            connect(Rtc.n, c) annotation (points=[70,10; 80,10; 80,60; 100,60],
                style(color=3, rgbcolor={0,0,255}));
            connect(Tr.E, e) annotation (points=[30,-10; 80,-10; 80,-60; 100,
                  -60], style(color=3, rgbcolor={0,0,255}));
            connect(Ct.n, Gnd1.p)    annotation (points=[-30,-40; -30,-60],
                style(color=3, rgbcolor={0,0,255}));
            connect(Rtb.n, Tr.B) annotation (points=[-50,0; -10,0], style(color=
                   3, rgbcolor={0,0,255}));
            connect(Ct.p, Tr.B) annotation (points=[-30,-20; -30,0; -10,0],
                style(color=3, rgbcolor={0,0,255}));
            connect(Rtb.p, b) annotation (points=[-70,0; -100,0], style(color=3,
                  rgbcolor={0,0,255}));
          end Transistor;
        end Utilities;
      end Examples;
    end Analog;
  end Electrical;
  
  package Hydraulic "Hydraulic components built from bond graphs" 
    annotation (
      Coordsys(
        extent=[0, 0; 443, 453],
        grid=[2, 2],
        component=[20, 20]),
      Icon(
        Rectangle(extent=[-100, -100; 80, 50], style(
            color=42,
            fillColor=30,
            fillPattern=1)),
        Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50], style(
            color=42,
            fillColor=30,
            fillPattern=1)),
        Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70], style(
            color=42,
            fillColor=30,
            fillPattern=1)),
        Text(
          extent=[-85, 35; 65, -85],
          string="Library",
          style(color=42)),
        Text(
          extent=[-120, 122; 120, 73],
          string="%name",
          style(color=1))),
      Window(
        x=0.02,
        y=0,
        width=0.44,
        height=0.65,
        library=1,
        autolayout=1),
      Documentation(info="<html>
This package contains a collection of components used in hydraulic systems that are built from bond graph technology.  The set of elements is by no means exhaustive.  It currently contains only one type of hydraulic motor together with its servo valve.
</html>"));
    block Modulator "Modulator needed by the servo valve" 
      parameter Real k=1 "Hydraulic Valve Flow Constant";
      parameter Real x0=0 "Mechanical Valve Underlap";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(
          Line(points=[-116, 18; -90, 18], style(color=0)),
          Line(points=[-96, 22; -90, 18; -96, 14], style(color=0)),
          Text(
            extent=[-110, 34; -98, 20],
            string="x",
            style(color=0)),
          Text(
            extent=[4, 70; 16, 62],
            string="x0+x",
            style(color=9)),
          Line(points=[84, 78; 110, 78], style(color=0)),
          Line(points=[104, 82; 110, 78; 104, 74], style(color=0)),
          Line(points=[84, -44; 110, -44], style(color=0)),
          Line(points=[104, -40; 110, -44; 104, -48], style(color=0)),
          Text(
            extent=[76, 94; 118, 82],
            string="k*(x0+x)",
            style(color=0)),
          Text(
            extent=[76, -26; 118, -38],
            string="k*(x0-x)",
            style(color=0)),
          Text(
            extent=[-26, 8; -10, -8],
            string="x0",
            style(color=9))),
        Icon(
          Line(points=[-90, 0; -40, 0]),
          Text(
            extent=[-28, 10; -10, -10],
            string="k",
            style(color=9)),
          Polygon(points=[-40, 40; -40, -40; 20, 0; -40, 40]),
          Line(points=[20, 0; 40, 0; 40, 60; 90, 60]),
          Line(points=[20, 0; 40, 0; 40, -60; 90, -60]),
          Text(
            extent=[80, 100; 120, 62],
            string="+",
            style(color=9)),
          Text(
            extent=[80, -20; 120, -60],
            string="-",
            style(color=9)),
          Text(extent=[-74, 122; 72, 80], string="%name")),
        Documentation(info="<html>
The <b>Modulator</b> block is needed by the servo valve.  Each of the four valve flows, <b>q<sub>1</sub></b>, <b>q<sub>2</sub></b>, <b>q<sub>3</sub></b>, and <b>q<sub>4</sub></b>, is characterized by an underlap, <b>x<sub>0</sub></b>.  Each of the four flows is proportional to either <b>x<sub>0</sub> + x</b> or <b>x<sub>0</sub> - x</b>, depending on the topology.  These two proportionality factors are computed by the <b>Modulator</b> block.  They are used as modulation signals in the four hydraulic conductor models representing the turbulent valve flows.
</html>
"));
      Modelica.Blocks.Interfaces.RealInput InPort1 
                                                annotation (extent=[-110, -10;
            -90, 10]);
      Modelica.Blocks.Interfaces.RealOutput OutPort1 
                                                  annotation (extent=[90, 50;
            110, 70]);
      Modelica.Blocks.Interfaces.RealOutput OutPort2 
                                                  annotation (extent=[90, -70;
            110, -50]);
      Modelica.Blocks.Math.Gain k1(k=k)   annotation (extent=[60, 50; 80, 70]);
      Modelica.Blocks.Math.Add A1 annotation (extent=[-20, 50; 0, 70]);
      Modelica.Blocks.Math.Gain k2(k=k)   annotation (extent=[60, -70; 80, -50]);
      Modelica.Blocks.Math.Add A2(k2=-1) annotation (extent=[-20, -70; 0, -50]);
      Modelica.Blocks.Sources.Constant X0(k=x0)   annotation (extent=[-60, -10;
              -40, 10]);
      Modelica.Blocks.Nonlinear.Limiter L1(uMin=0)   annotation (extent=[20, 50;
              40, 70]);
      Modelica.Blocks.Nonlinear.Limiter L2(uMin=0)   annotation (extent=[20, -
            70; 40, -50]);
    equation 
      connect(InPort1,A1.u1)       annotation (points=[-100,0; -80,0; -80,66;
            -22,66],    style(color=3));
      connect(InPort1,A2.u2)       annotation (points=[-100,0; -80,0; -80,-66;
            -22,-66],    style(color=3));
      connect(X0.y,A1.u2)             annotation (points=[-39,0; -30,0; -30,54;
            -22,54],      style(color=3));
      connect(X0.y,A2.u1)             annotation (points=[-39,0; -30,0; -30,-54;
            -22,-54],       style(color=3));
      connect(A1.y,L1.u)             annotation (points=[1,60; 18,60],   style(
            color=3));
      connect(L1.y,k1.u)             annotation (points=[41,60; 58,60],   style(
           color=3));
      connect(k1.y,       OutPort1) annotation (points=[81,60; 100,60],  style(
            color=3));
      connect(A2.y,L2.u)             annotation (points=[1,-60; 18,-60],
          style(color=3));
      connect(L2.y,k2.u)             annotation (points=[41,-60; 58,-60],
          style(color=3));
      connect(k2.y,       OutPort2) annotation (points=[81,-60; 100,-60],
          style(color=3));
    end Modulator;
    
    model Servo "Servo mechanism built from bond graph technology" 
      extends Modelica.Blocks.Interfaces.SISO;
      parameter Real rs=1 "Servo resistance";
      parameter Real ls=1 "Servo inductance";
      parameter Real bs=1 "Servo damper";
      parameter Real ms=1 "Servo mass";
      parameter Real ks=1 "Servo spring";
      parameter Real psis=1 "Servo induction constant";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram,
        Icon(
          Rectangle(extent=[-100, -100; 100, 100], style(color=3, fillColor=7)),
          Rectangle(extent=[100, 6; -48, -6], style(fillColor=73)),
          Line(points=[12, 14; -16, -14], style(color=41, thickness=2)),
          Line(points=[16, 14; -12, -14], style(color=41, thickness=2)),
          Line(points=[20, 14; -8, -14], style(color=41, thickness=2)),
          Line(points=[24, 14; -4, -14], style(color=41, thickness=2)),
          Line(points=[28, 14; 0, -14], style(color=41, thickness=2)),
          Line(points=[28, 16; -60, 16], style(color=41, thickness=2)),
          Line(points=[28, 16; 28, 14], style(color=41, thickness=2)),
          Line(points=[-16, -14; -60, -14], style(color=41, thickness=2)),
          Ellipse(extent=[-62, 18; -58, 14], style(fillColor=49)),
          Ellipse(extent=[-62, -12; -58, -16], style(fillColor=49)),
          Line(points=[-68, 10; -68, -10]),
          Line(points=[-70, -6; -68, -10; -66, -6]),
          Text(extent=[-78, 4; -68, -4], string="u"),
          Line(points=[-138, 26; -108, 26], style(color=0)),
          Line(points=[-112, 30; -108, 26; -112, 22], style(color=0)),
          Text(
            extent=[-130, 36; -120, 28],
            string="u",
            style(color=0)),
          Line(points=[92, 16; 122, 16], style(color=0)),
          Line(points=[118, 20; 122, 16; 118, 12], style(color=0)),
          Text(
            extent=[102, 26; 112, 18],
            string="x",
            style(color=0)),
          Rectangle(extent=[-34, 20; -16, 12], style(fillColor=49)),
          Text(extent=[-28, 30; -20, 22], string="R"),
          Text(extent=[-10, -18; -2, -26], string="L"),
          Rectangle(extent=[-50, 48; -48, -48], style(fillColor=73)),
          Line(points=[-50, 38; -62, 38], style(thickness=2)),
          Rectangle(extent=[-62, 44; -68, 32], style(pattern=0, fillColor=55)),
          Line(points=[-62, 42; -62, 34], style(thickness=2)),
          Line(points=[-58, 44; -68, 44; -68, 32; -58, 32], style(thickness=2)),
          Line(points=[-68, 38; -100, 38], style(thickness=2)),
          Text(extent=[-68, 54; -60, 46], string="B"),
          Line(points=[-50, -30; -60, -30; -62, -34; -64, -26; -66, -34; -68, -
                26; -70, -34; -72, -30; -100, -30], style(thickness=2)),
          Text(extent=[-70, -36; -62, -44], string="k")),
        Window(
          x=0.45,
          y=0.01,
          width=0.44,
          height=0.65),
        Documentation(info="<html>
The servo mechanism described here has a signal input, the armature voltage, <b>u</b>, and a signal output, the position of the tongue of the servo valve, <b>x</b>. <p>

The input signal is converted to a bond graphic power signal using a modulated effort source.  The spring force is measured in the bond graph using an effort sensor.  It is then converted to the tongue position using the amplifier model of Modelica's block diagram library.
</html>
"));
      Sources.mSe mSe1 annotation (extent=[-70, -10; -90, 10]);
      Bonds.fBond B1 annotation (extent=[-70, -10; -50, 10]);
      Junctions.J1p4 J1p4_1 annotation (extent=[-50, -10; -30, 10]);
      Bonds.eBond B2 annotation (extent=[-50, 10; -30, 30], rotation=90);
      Passive.R Rs(R=rs) annotation (extent=[-50, 30; -30, 50], rotation=90);
      Bonds.fBond B3 annotation (extent=[-50, -30; -30, -10], rotation=-90);
      Passive.I Ls(I=ls) annotation (extent=[-50, -50; -30, -30], rotation=-90);
      Passive.GY GY1(r=psis) annotation (extent=[-10, -10; 10, 10]);
      Bonds.eBond B4 annotation (extent=[-30, -10; -10, 10]);
      Bonds.fBond B5 annotation (extent=[10, -10; 30, 10]);
      Junctions.J1p4 J1p4_2 annotation (extent=[30, -10; 50, 10]);
      Bonds.eBond B6 annotation (extent=[30, 10; 50, 30], rotation=90);
      Passive.R Bs(R=bs) annotation (extent=[30, 30; 50, 50], rotation=90);
      Bonds.fBond B7 annotation (extent=[30, -30; 50, -10], rotation=-90);
      Passive.I Ms(I=ms) annotation (extent=[30, -50; 50, -30], rotation=-90);
      Bonds.eBond B8 annotation (extent=[50, -10; 70, 10]);
      Passive.C Ks(C=1/ks) annotation (extent=[70, -50; 90, -30], rotation=-90);
      Modelica.Blocks.Math.Gain Gain1(k=1/ks)   annotation (extent=[70, 70; 90,
              90]);
      Junctions.J0p3 J0p3_1 annotation (extent=[70, -10; 90, 10], rotation=-90);
      Bonds.eBond B9 annotation (extent=[70, -30; 90, -10], rotation=-90);
      Bonds.fBond B10 annotation (extent=[70, 10; 90, 30], rotation=90);
      Sensors.De De1 annotation (extent=[70, 30; 90, 50], rotation=90);
    equation 
      connect(u,      mSe1.InPort1) annotation (points=[-120,0; -89,0],   style(
           color=3));
      connect(mSe1.BondCon1, B1.eBondCon1) annotation (points=[-70, 0; -70, 0],
            style(color=8));
      connect(B1.fBondCon1, J1p4_1.BondCon1) annotation (points=[-50, 0; -50, 0],
               style(color=8));
      connect(J1p4_1.BondCon4, B2.fBondCon1) annotation (points=[-40, 10; -40,
            10], style(color=8));
      connect(B2.eBondCon1, Rs.BondCon1) annotation (points=[-40, 30; -40, 30],
            style(color=8));
      connect(J1p4_1.BondCon3, B3.eBondCon1) annotation (points=[-40, -10; -40,
              -10], style(color=8));
      connect(B3.fBondCon1, Ls.BondCon1) annotation (points=[-40, -30; -40, -30],
               style(color=8));
      connect(J1p4_1.BondCon2, B4.fBondCon1) annotation (points=[-30, 0; -30, 0],
               style(color=8));
      connect(B4.eBondCon1, GY1.BondCon1) annotation (points=[-10, 0; -10, 0],
          style(color=8));
      connect(GY1.BondCon2, B5.eBondCon1) annotation (points=[10, 0; 10, 0],
          style(color=8));
      connect(B5.fBondCon1, J1p4_2.BondCon1) annotation (points=[30, 0; 30, 0],
            style(color=8));
      connect(J1p4_2.BondCon4, B6.fBondCon1) annotation (points=[40, 10; 40, 10],
               style(color=8));
      connect(B6.eBondCon1, Bs.BondCon1) annotation (points=[40, 30; 40, 30],
          style(color=8));
      connect(J1p4_2.BondCon3, B7.eBondCon1) annotation (points=[40, -10; 40, -
            10], style(color=8));
      connect(B7.fBondCon1, Ms.BondCon1) annotation (points=[40, -30; 40, -30],
            style(color=8));
      connect(J1p4_2.BondCon2, B8.fBondCon1) annotation (points=[50, 0; 50, 0],
            style(color=8));
      connect(Gain1.y,y)              annotation (points=[91,80; 96,80; 96,0;
            110,0],    style(color=3));
      connect(B8.eBondCon1, J0p3_1.BondCon3) annotation (points=[70,0; 70,
            -6.12303e-016],
            style(color=8));
      connect(J0p3_1.BondCon2, B9.fBondCon1) annotation (points=[80, -10; 80, -
            10], style(color=8));
      connect(B9.eBondCon1, Ks.BondCon1) annotation (points=[80, -30; 80, -30],
            style(color=8));
      connect(J0p3_1.BondCon1, B10.eBondCon1) annotation (points=[80, 10; 80,
            10], style(color=8));
      connect(B10.fBondCon1, De1.BondCon1) annotation (points=[80, 30; 80, 30],
            style(color=8));
      connect(De1.OutPort1,Gain1.u)       annotation (points=[80,51; 80,60; 60,
            60; 60,80; 68,80],       style(color=3));
    end Servo;
    
    model Servovalve "Servo valve built from bond graph technology" 
      parameter Real k=1 "Hydraulic Valve Flow Constant";
      parameter Real x0=0 "Mechanical Valve Underlap";
      parameter Real ps=1 "System pressure";
      parameter Real p0=0 "Environmental pressure";
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(
          Line(points=[-108, 14; -88, 14], style(color=0)),
          Text(
            extent=[-104, 24; -94, 14],
            string="x",
            style(color=0)),
          Line(points=[-92, 16; -88, 14; -92, 12], style(color=0)),
          Text(
            extent=[-78, -74; -72, -82],
            string="p1",
            style(color=9)),
          Text(
            extent=[-90, -80; -82, -88],
            string="qL1",
            style(color=9)),
          Text(
            extent=[-62, -60; -56, -68],
            string="p1",
            style(color=9)),
          Text(
            extent=[-62, -48; -56, -56],
            string="q1",
            style(color=9)),
          Text(
            extent=[-22, -60; -14, -70],
            style(color=9),
            string="ps"),
          Text(
            extent=[-22, -48; -16, -56],
            string="q1",
            style(color=9)),
          Text(
            extent=[14, -50; 22, -60],
            style(color=9),
            string="ps"),
          Text(
            extent=[16, -62; 22, -70],
            string="q4",
            style(color=9)),
          Text(
            extent=[56, -52; 62, -60],
            string="p2",
            style(color=9)),
          Text(
            extent=[56, -62; 62, -70],
            string="q4",
            style(color=9)),
          Text(
            extent=[72, -78; 78, -86],
            string="p2",
            style(color=9)),
          Text(
            extent=[82, -80; 90, -88],
            string="qL2",
            style(color=9)),
          Text(
            extent=[-54, -36; -40, -42],
            style(color=9),
            string="ps-p1"),
          Text(
            extent=[-36, -36; -30, -44],
            string="q1",
            style(color=9)),
          Text(
            extent=[2, -32; 10, -42],
            style(color=9),
            string="ps"),
          Text(
            extent=[-18, -32; -4, -42],
            string="q1+q4",
            style(color=9)),
          Text(
            extent=[44, -36; 50, -44],
            string="q4",
            style(color=9)),
          Text(
            extent=[24, -38; 38, -44],
            style(color=9),
            string="ps-p2"),
          Text(
            extent=[-64, 68; -58, 60],
            string="p1",
            style(color=9)),
          Text(
            extent=[-64, 58; -58, 50],
            string="q2",
            style(color=9)),
          Text(
            extent=[-50, 44; -44, 36],
            string="q2",
            style(color=9)),
          Text(
            extent=[-38, 46; -24, 40],
            style(color=9),
            string="p1-p0"),
          Text(
            extent=[-26, 70; -18, 60],
            style(color=9),
            string="p0"),
          Text(
            extent=[-24, 58; -18, 50],
            string="q2",
            style(color=9)),
          Text(
            extent=[2, 48; 10, 38],
            style(color=9),
            string="p0"),
          Text(
            extent=[-18, 48; -4, 38],
            string="q2+q3",
            style(color=9)),
          Text(
            extent=[18, 60; 26, 50],
            style(color=9),
            string="p0"),
          Text(
            extent=[16, 72; 22, 64],
            string="q3",
            style(color=9)),
          Text(
            extent=[30, 44; 36, 36],
            string="q3",
            style(color=9)),
          Text(
            extent=[42, 46; 56, 40],
            style(color=9),
            string="p2-p0"),
          Text(
            extent=[58, 60; 64, 52],
            string="p2",
            style(color=9)),
          Text(
            extent=[58, 72; 64, 64],
            string="q3",
            style(color=9))),
        Icon(
          Polygon(points=[-80, -90; -32, -60; -32, -42; -40, -42; -40, -2; -8,
                -2; -8, -38; 8, -38; 8, -2; 40, -2; 40, -42; 32, -42; 32, -60;
                80, -90; 74, -94; 20, -60; 20, -42; -20, -42; -20, -60; -72, -
                94; -80, -90], style(pattern=0, fillColor=65)),
          Polygon(points=[-56, 66; -56, 38; -40, 38; -40, 2; -8, 2; -8, 38; 8,
                38; 8, 2; 40, 2; 40, 38; 56, 38; 56, 66; 40, 66; 40, 42; 8, 42;
                  8, 66; -8, 66; -8, 42; -40, 42; -40, 66; -56, 66], style(
                pattern=0, fillColor=65)),
          Line(points=[-108, 14; -88, 14], style(color=0)),
          Text(
            extent=[-104, 24; -94, 14],
            string="x",
            style(color=0)),
          Rectangle(extent=[-88, 2; 100, -2], style(fillColor=73)),
          Rectangle(extent=[-8, 38; 8, -38], style(fillColor=73)),
          Rectangle(extent=[-56, 38; -40, -38], style(fillColor=73)),
          Rectangle(extent=[40, 38; 56, -38], style(fillColor=73)),
          Line(points=[-80, 4; -68, 4; -68, 42; -56, 42; -56, 66]),
          Line(points=[-40, 66; -40, 42; -8, 42; -8, 66]),
          Line(points=[8, 66; 8, 42; 40, 42; 40, 66]),
          Line(points=[56, 66; 56, 42; 68, 42; 68, 4; 80, 4]),
          Line(points=[-80, -4; -68, -4; -68, -42; -32, -42; -32, -60; -80, -90]),
          Line(points=[80, -4; 68, -4; 68, -42; 32, -42; 32, -60; 80, -90]),
          Line(points=[-72, -94; -20, -60; -20, -42; 20, -42; 20, -60; 74, -94]),
          Line(points=[-48, 48; -48, 72], style(color=0)),
          Line(points=[48, 48; 48, 72], style(color=0)),
          Line(points=[0, 72; 0, 48], style(color=0)),
          Text(
            extent=[-56, 86; -40, 74],
            string="p0",
            style(color=0)),
          Text(
            extent=[40, 86; 56, 74],
            string="p0",
            style(color=0)),
          Text(
            extent=[-8, 86; 8, 74],
            string="ps",
            style(color=0)),
          Line(points=[-34, 36; -46, 46], style(color=0)),
          Line(points=[-4, 44; -14, 36], style(color=0)),
          Line(points=[4, 44; 14, 36], style(color=0)),
          Line(points=[34, 36; 46, 46], style(color=0)),
          Text(
            extent=[-38, 36; -28, 28],
            string="q2",
            style(color=0)),
          Text(
            extent=[-22, 36; -12, 28],
            string="q1",
            style(color=0)),
          Text(
            extent=[12, 36; 22, 28],
            string="q4",
            style(color=0)),
          Text(
            extent=[28, 36; 38, 28],
            string="q3",
            style(color=0)),
          Line(points=[26, -40; 26, -58], style(color=0)),
          Line(points=[-26, -58; -26, -40], style(color=0)),
          Text(
            extent=[20, -32; 32, -40],
            string="qL2",
            style(color=0)),
          Text(
            extent=[-32, -32; -20, -40],
            string="qL1",
            style(color=0)),
          Line(points=[-50, 68; -48, 72; -46, 68], style(color=0)),
          Line(points=[-2, 52; 0, 48; 2, 52], style(color=0)),
          Line(points=[46, 68; 48, 72; 50, 68], style(color=0)),
          Line(points=[-44, 42; -46, 46; -42, 44], style(color=0)),
          Line(points=[-14, 40; -14, 36; -10, 36], style(color=0)),
          Line(points=[12, 40; 14, 36; 10, 36], style(color=0)),
          Line(points=[42, 44; 46, 46; 44, 42], style(color=0)),
          Line(points=[24, -44; 26, -40; 28, -44], style(color=0)),
          Line(points=[-28, -54; -26, -58; -24, -54], style(color=0)),
          Text(extent=[-80, 132; 80, 84], string="%name"),
          Line(points=[-92, 16; -88, 14; -92, 12], style(color=0)),
          Text(
            extent=[-30, -8; -14, -20],
            string="p1",
            style(color=0)),
          Text(
            extent=[18, -8; 34, -20],
            string="p2",
            style(color=0))),
        Window(
          x=0.45,
          y=0.01,
          width=0.44,
          height=0.65),
        Documentation(info="<html>
The servo valve model described here has a signal input, the position of the tongue, <b>x</b>, and two bondgraphic outputs: the two load flows, <b>q<sub>L1</sub></b> and <b>q<sub>L2</sub></b>.  The bondgraphic interface is designed such that the servo valve can be directly connected to the hydraulic motor without either a set of bonds or a set of junctions in between. <p>

The two chambers of the servo valve are at the pressures <b>p<sub>1</sub></b> and <b>p<sub>2</sub></b>, respectively. <p>

The four valve flows, <b>q<sub>1</sub></b>, <b>q<sub>2</sub></b>, <b>q<sub>3</sub></b>, and <b>q<sub>4</sub></b>, are assumed to be turbulent flows.  The valve flows are modulated by the tongue position.  The modulation of the four hydraulic conductors representing the turbulent flows is computed by the <b>Modulator</b> block.
</html>

"));
      Modelica.Blocks.Interfaces.RealInput InPort1 
                                                annotation (extent=[-108, -10;
            -88, 10]);
      Interfaces.BondCon BondCon1 annotation (extent=[-90, -110; -70, -90]);
      Interfaces.BondCon BondCon2 annotation (extent=[70, -110; 90, -90]);
      Modulator M1(k=k, x0=x0) annotation (extent=[-80, 10; -60, -10]);
      Bonds.eBond B6 annotation (extent=[-90, -90; -70, -70], rotation=-90);
      Junctions.J0p3 J0p3_1 annotation (extent=[-90, -70; -70, -50]);
      Bonds.eBond B2 annotation (extent=[-70, -70; -50, -50], rotation=180);
      Junctions.J1p3 J1p3_1 annotation (extent=[-50, -50; -30, -70]);
      Bonds.fBond B3 annotation (extent=[-30, -70; -10, -50], rotation=180);
      Junctions.J0p3 J0p3_2 annotation (extent=[-10, -50; 10, -70]);
      Bonds.fBond B4 annotation (extent=[10, -70; 30, -50]);
      Junctions.J1p3 J1p3_2 annotation (extent=[30, -50; 50, -70]);
      Bonds.eBond B5 annotation (extent=[50, -70; 70, -50]);
      Bonds.fBond B1 annotation (extent=[70, -90; 90, -70], rotation=90);
      Junctions.J0p3 J0p3_3 annotation (extent=[70, -70; 90, -50]);
      Bonds.fBond B7 annotation (extent=[-50, -50; -30, -30], rotation=90);
      Bonds.fBond B8 annotation (extent=[-10, -50; 10, -30], rotation=-90);
      Bonds.fBond B9 annotation (extent=[30, -50; 50, -30], rotation=90);
      Sources.Se PS(e0=ps) annotation (extent=[-10, -30; 10, -10], rotation=90);
      Passive.HydromG mG1 annotation (extent=[-50, -30; -30, -10], rotation=90);
      Passive.HydromG mG4 annotation (extent=[30, -30; 50, -10], rotation=90);
      Bonds.fBond B15 annotation (extent=[-70, 50; -50, 70]);
      Junctions.J1p3 J1p3_3 annotation (extent=[-50, 50; -30, 70]);
      Bonds.fBond B12 annotation (extent=[-50, 30; -30, 50], rotation=-90);
      Passive.HydromG mG2 annotation (extent=[-50, 10; -30, 30], rotation=-90);
      Bonds.eBond B11 annotation (extent=[-30, 50; -10, 70]);
      Junctions.J0p3 J0p3_4 annotation (extent=[-10, 50; 10, 70]);
      Bonds.eBond B10 annotation (extent=[-10, 30; 10, 50], rotation=-90);
      Sources.Se P0(e0=p0) annotation (extent=[-10, 10; 10, 30], rotation=-90);
      Bonds.eBond B13 annotation (extent=[10, 50; 30, 70], rotation=180);
      Junctions.J1p3 J1p3_4 annotation (extent=[30, 50; 50, 70]);
      Bonds.fBond B14 annotation (extent=[30, 30; 50, 50], rotation=-90);
      Passive.HydromG mG3 annotation (extent=[30, 10; 50, 30], rotation=-90);
      Bonds.fBond B16 annotation (extent=[50, 50; 70, 70], rotation=180);
    equation 
      connect(InPort1, M1.InPort1) annotation (points=[-98,0; -80,0],   style(
            color=3));
      connect(B6.eBondCon1, BondCon1) annotation (points=[-80,-90; -80,-100;
            -80,-100],style(color=8));
      connect(J0p3_1.BondCon3, B6.fBondCon1) annotation (points=[-80, -70; -80,
              -70], style(color=8));
      connect(B2.eBondCon1, J0p3_1.BondCon2) annotation (points=[-70, -60; -70,
              -60], style(color=8));
      connect(J1p3_1.BondCon1, B2.fBondCon1) annotation (points=[-50, -60; -50,
              -60], style(color=8));
      connect(B3.fBondCon1, J1p3_1.BondCon2) annotation (points=[-30, -60; -30,
              -60], style(color=8));
      connect(J0p3_2.BondCon1, B3.eBondCon1) annotation (points=[-10, -60; -10,
              -60], style(color=8));
      connect(J0p3_2.BondCon2, B4.eBondCon1) annotation (points=[10, -60; 10, -
            60], style(color=8));
      connect(B4.fBondCon1, J1p3_2.BondCon1) annotation (points=[30, -60; 30, -
            60], style(color=8));
      connect(J1p3_2.BondCon2, B5.fBondCon1) annotation (points=[50, -60; 50, -
            60], style(color=8));
      connect(BondCon2, B1.eBondCon1) annotation (points=[80,-100; 80,-90],
          style(color=8));
      connect(B1.fBondCon1, J0p3_3.BondCon3) annotation (points=[80, -70; 80, -
            70], style(color=8));
      connect(B5.eBondCon1, J0p3_3.BondCon1) annotation (points=[70, -60; 70, -
            60], style(color=8));
      connect(J1p3_1.BondCon3, B7.eBondCon1) annotation (points=[-40, -50; -40,
              -50], style(color=8));
      connect(B8.fBondCon1, J0p3_2.BondCon3) annotation (points=[6.12303e-016,
            -50; 0,-50],
               style(color=8));
      connect(J1p3_2.BondCon3, B9.eBondCon1) annotation (points=[40, -50; 40, -
            50], style(color=8));
      connect(PS.BondCon1, B8.eBondCon1) annotation (points=[-6.12303e-016,-30; 
            -6.12303e-016,-30],
          style(color=8));
      connect(B7.fBondCon1, mG1.BondCon1) annotation (points=[-40, -30; -40, -
            30], style(color=8));
      connect(M1.OutPort1, mG1.InPort1) annotation (points=[-60,-6; -40,-6; -40,
            -11],     style(color=3));
      connect(B9.fBondCon1, mG4.BondCon1) annotation (points=[40, -30; 40, -30],
            style(color=8));
      connect(J0p3_1.BondCon1, B15.eBondCon1) annotation (points=[-90, -60; -90,
              60; -70, 60], style(color=8));
      connect(B15.fBondCon1, J1p3_3.BondCon1) annotation (points=[-50, 60; -50,
              60], style(color=8));
      connect(J1p3_3.BondCon3, B12.eBondCon1) annotation (points=[-40, 50; -40,
              50], style(color=8));
      connect(B12.fBondCon1, mG2.BondCon1) annotation (points=[-40, 30; -40, 30],
               style(color=8));
      connect(M1.OutPort2, mG2.InPort1) annotation (points=[-60,6; -40,6; -40,
            11],   style(color=3));
      connect(J1p3_3.BondCon2, B11.fBondCon1) annotation (points=[-30, 60; -30,
              60], style(color=8));
      connect(B11.eBondCon1, J0p3_4.BondCon1) annotation (points=[-10, 60; -10,
              60], style(color=8));
      connect(J0p3_4.BondCon3, B10.fBondCon1) annotation (points=[0,50; 
            -6.12303e-016,50],
            style(color=8));
      connect(B10.eBondCon1, P0.BondCon1) annotation (points=[6.12303e-016,30; 
            -6.12303e-016,30],
          style(color=8));
      connect(B13.eBondCon1, J0p3_4.BondCon2) annotation (points=[10, 60; 10,
            60], style(color=8));
      connect(J1p3_4.BondCon1, B13.fBondCon1) annotation (points=[30, 60; 30,
            60], style(color=8));
      connect(J1p3_4.BondCon3, B14.eBondCon1) annotation (points=[40, 50; 40,
            50], style(color=8));
      connect(B14.fBondCon1, mG3.BondCon1) annotation (points=[40, 30; 40, 30],
            style(color=8));
      connect(M1.OutPort2, mG4.InPort1) annotation (points=[-60,6; 0,6; 0,0; 40,
            0; 40,-11],        style(color=3));
      connect(M1.OutPort1, mG3.InPort1) annotation (points=[-60,-6; 20,-6; 20,6;
            40,6; 40,11],        style(color=3));
      connect(B16.fBondCon1, J1p3_4.BondCon2) annotation (points=[50, 60; 50,
            60], style(color=8));
      connect(J0p3_3.BondCon2, B16.eBondCon1) annotation (points=[90, -60; 90,
            60; 70, 60], style(color=8));
    end Servovalve;
    
    model Hydromotor "Hydraulic motor model built from bond graph technology" 
      parameter Real ce=1 "External leakage";
      parameter Real ci=1 "Internal leakage";
      parameter Real c1=1 "Compression coefficient";
      parameter Real psi=1 "Motor induction constant";
      parameter Real rhom=1 "Motor friction constant";
      parameter Real jm=1 "Motor inertia";
      parameter Real ps=1 "Service pressure";
      parameter Real p0=0 "Environment pressure";
      annotation (
        Coordsys(
          extent=[-100, -140; 100, 100],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(
          Text(
            extent=[-40, 36; -28, 28],
            string="p1",
            style(color=9)),
          Text(
            extent=[52, 18; 64, 10],
            string="p2",
            style(color=9)),
          Text(
            extent=[40, -4; 52, -12],
            string="p2",
            style(color=9)),
          Text(
            extent=[-28, 18; -16, 10],
            string="p1",
            style(color=9)),
          Text(
            extent=[-28, 58; -16, 50],
            string="p1",
            style(color=9)),
          Text(
            extent=[12, 58; 24, 50],
            string="p2",
            style(color=9)),
          Text(
            extent=[28, 32; 40, 24],
            string="p2",
            style(color=9)),
          Text(
            extent=[-64, 10; -52, 2],
            string="p1",
            style(color=9)),
          Text(
            extent=[12, 18; 24, 10],
            string="p2",
            style(color=9)),
          Text(
            extent=[-40, -4; -28, -12],
            string="p1",
            style(color=9)),
          Text(
            extent=[0, -4; 12, -12],
            string="pL",
            style(color=9)),
          Text(
            extent=[-12, 72; 0, 64],
            string="pL",
            style(color=9)),
          Text(
            extent=[0, 72; 12, 64],
            string="qi",
            style(color=9)),
          Text(
            extent=[-28, 48; -16, 40],
            string="qi",
            style(color=9)),
          Text(
            extent=[12, 48; 24, 40],
            string="qi",
            style(color=9)),
          Text(
            extent=[-16, -6; -4, -14],
            string="qind",
            style(color=9)),
          Text(
            extent=[-28, 8; -16, 0],
            string="qind",
            style(color=9)),
          Text(
            extent=[12, 8; 24, 0],
            string="qind",
            style(color=9)),
          Text(
            extent=[-16, -44; -4, -52],
            string="wm",
            style(color=9)),
          Text(
            extent=[14, -74; 26, -82],
            string="wm",
            style(color=9)),
          Text(
            extent=[-26, -58; -14, -66],
            string="wm",
            style(color=9)),
          Text(
            extent=[54, 8; 66, 0],
            string="qe2",
            style(color=9)),
          Text(
            extent=[-66, 22; -54, 14],
            string="qe1",
            style(color=9)),
          Text(
            extent=[-56, -4; -44, -12],
            string="qc1",
            style(color=9)),
          Text(
            extent=[24, -4; 36, -12],
            string="qc2",
            style(color=9)),
          Text(
            extent=[12, -60; 24, -68],
            string="Tb",
            style(color=9)),
          Text(
            extent=[-24, -70; -12, -78],
            string="Tj",
            style(color=9)),
          Text(
            extent=[0, -44; 12, -52],
            string="Tm",
            style(color=9)),
          Text(
            extent=[94, 4; 104, -4],
            string="wm",
            style(color=0)),
          Line(points=[92, -4; 112, -4], style(color=0)),
          Line(points=[106, 0; 112, -4; 106, -8], style(color=0)),
          Line(points=[40, 20; 40, 20], style(color=8)),
          Line(points=[30, 10; 30, 10], style(color=8)),
          Line(points=[40, 0; 40, 0], style(color=8)),
          Line(points=[30, 10; 30, 10], style(color=8)),
          Line(points=[40, 20; 40, 20], style(color=8)),
          Line(points=[40, 0; 40, 0], style(color=8)),
          Line(points=[0, -80; 0, -80], style(color=8)),
          Line(points=[0, -60; 0, -60], style(color=8)),
          Line(points=[10, -70; 10, -70], style(color=8)),
          Line(points=[-10, -70; -10, -70], style(color=8)),
          Line(points=[-40, 60; -40, 60], style(color=8)),
          Line(points=[40, 60; 40, 60], style(color=8)),
          Line(points=[0, -60; 0, -60], style(color=8)),
          Line(points=[10, -70; 10, -70], style(color=8)),
          Line(points=[-10, -70; -10, -70], style(color=8))),
        Icon(
          Rectangle(extent=[-80, 40; 80, -80], style(gradient=2, fillColor=41)),
          Polygon(points=[-80, -120; -80, -100; -60, -100; -42, -20; 38, -20;
                60, -100; 80, -100; 80, -120; -80, -120], style(color=0,
                fillColor=0)),
          Rectangle(extent=[-68, 20; 70, -60], style(fillColor=7)),
          Rectangle(extent=[-10, 16; 12, -56], style(fillColor=73)),
          Rectangle(extent=[-68, -16; -80, -24], style(pattern=0, fillColor=7)),
          Rectangle(extent=[80, -16; 68, -24], style(pattern=0, fillColor=7)),
          Rectangle(extent=[94, -18; -86, -22], style(fillColor=73)),
          Rectangle(extent=[-64, 74; -56, 18], style(pattern=0, fillColor=7)),
          Rectangle(extent=[56, 74; 64, 18], style(pattern=0, fillColor=7)),
          Polygon(points=[-64, 86; -64, 20; -68, 20; -68, -16; -80, -16; -80, -
                18; -10, -18; -10, 16; 12, 16; 12, -18; 80, -18; 80, -16; 70, -
                16; 70, 20; 64, 20; 64, 86; 56, 86; 56, 20; -56, 20; -56, 86; -
                64, 86], style(pattern=0, fillColor=65)),
          Polygon(points=[-80, -22; -80, -24; -68, -24; -68, -60; 70, -60; 70,
                -24; 80, -24; 80, -22; 12, -22; 12, -56; -10, -56; -10, -22; -
                80, -22], style(pattern=0, fillColor=65)),
          Line(points=[-64, 86; -64, 20; -68, 20; -68, -16; -80, -16]),
          Line(points=[-80, -24; -68, -24; -68, -60; 70, -60; 70, -24; 80, -24]),
          Line(points=[-56, 80; -56, 20; 56, 20; 56, 80]),
          Line(points=[64, 80; 64, 20; 70, 20; 70, -16; 80, -16]),
          Line(points=[22, 8; 14, 18], style(color=0)),
          Text(
            extent=[20, 10; 30, 2],
            string="qi",
            style(color=0)),
          Line(points=[-12, 18; -20, 10], style(color=0)),
          Text(
            extent=[-28, 10; -18, 2],
            string="qi",
            style(color=0)),
          Line(points=[-58, -8; -66, -16], style(color=0)),
          Line(points=[-66, -12; -66, -16; -62, -16], style(color=0)),
          Text(
            extent=[-60, -8; -48, -16],
            string="qe1",
            style(color=0)),
          Line(points=[58, -8; 68, -16], style(color=0)),
          Line(points=[68, -12; 68, -16; 64, -16], style(color=0)),
          Text(
            extent=[48, -8; 60, -16],
            string="qe2",
            style(color=0)),
          Line(points=[60, 38; 60, 18], style(color=0)),
          Line(points=[-62, 22; -60, 18; -58, 22], style(color=0)),
          Text(
            extent=[54, 18; 66, 10],
            string="qL2",
            style(color=0)),
          Line(points=[-60, 18; -60, 36], style(color=0)),
          Line(points=[58, 34; 60, 38; 62, 34], style(color=0)),
          Text(
            extent=[-66, 18; -54, 10],
            string="qL1",
            style(color=0)),
          Text(extent=[-56, 138; 56, 100], string="%name"),
          Line(points=[92, -4; 112, -4], style(color=0)),
          Line(points=[106, 0; 112, -4; 106, -8], style(color=0)),
          Text(
            extent=[94, 6; 104, -2],
            string="wm",
            style(color=0)),
          Line(points=[-16, 18; -12, 18; -12, 14], style(color=0)),
          Line(points=[22, 12; 22, 8; 18, 8], style(color=0)),
          Polygon(points=[-86, 100; -86, 86; -56, 86; -56, 94; -74, 94; -74,
                100; -86, 100], style(pattern=0, fillColor=65)),
          Polygon(points=[74, 100; 74, 94; 56, 94; 56, 86; 86, 86; 86, 100; 74,
                  100], style(pattern=0, fillColor=65)),
          Line(points=[-64, 86; -86, 86; -86, 100]),
          Line(points=[-56, 80; -56, 94; -74, 94; -74, 100]),
          Line(points=[74, 100; 74, 94; 56, 94; 56, 80]),
          Line(points=[86, 100; 86, 86; 64, 86; 64, 80]),
          Text(
            extent=[-46, -36; -34, -44],
            style(color=0),
            string="p1"),
          Text(
            extent=[36, -36; 48, -44],
            style(color=0),
            string="p2")),
        Window(
          x=0.44,
          y=0.06,
          width=0.47,
          height=0.64),
        Documentation(info="<html>
The hydraulic motor model described here has two bondgraphic inputs: the two load flows, <b>q<sub>L1</sub></b> and <b>q<sub>L2</sub></b>.  It has a signal output: the angular velocity, <b>omega<sub>m</sub></b>, of the motor.  The bondgraphic interface is designed such that the hydraulic motor can be directly connected to the servo valve without either a set of bonds or a set of junctions in between. <p>

The two chambers of the hydraulic motor are at the pressures <b>p<sub>1</sub></b> and <b>p<sub>2</sub></b>, respectively. <p>

The model also contains an internal leakage flow, <b>q<sub>i</sub></b>, and two external leakage flows, <b>q<sub>e1</sub></b> and <b>q<sub>e2</sub></b>.  The leakage flows are assumed to be laminar flows.
</html>

"));
      Interfaces.BondCon BondCon1 annotation (extent=[-90, 90; -70, 110]);
      Interfaces.BondCon BondCon2 annotation (extent=[70, 90; 90, 110]);
      Junctions.J0p3 J0p3_1 annotation (extent=[30, 40; 50, 60], rotation=-90);
      Bonds.eBond B4 annotation (extent=[-50, 20; -30, 40], rotation=-90);
      Bonds.fBond B9 annotation (extent=[50, 0; 70, 20]);
      Passive.R Re2(R=1/ce) annotation (extent=[70, 0; 90, 20]);
      Bonds.fBond B1 annotation (extent=[-30, 40; -10, 60]);
      Junctions.J1p3 J1p3_1 annotation (extent=[-10, 60; 10, 40]);
      Bonds.fBond B3 annotation (extent=[-10, 60; 10, 80], rotation=90);
      Passive.R Ri(R=1/ci) annotation (extent=[-10, 80; 10, 100], rotation=90);
      Bonds.eBond B2 annotation (extent=[10, 40; 30, 60]);
      Junctions.J0p3 J0p3_2 annotation (extent=[-50, 40; -30, 60], rotation=90);
      Bonds.fBond B11 annotation (extent=[30, 20; 50, 40], rotation=90);
      Junctions.J0p4 J0p4_2 annotation (extent=[-50, 0; -30, 20]);
      Bonds.fBond B7 annotation (extent=[-30, 0; -10, 20]);
      Junctions.J1p3 J1p3_2 annotation (extent=[-10, 0; 10, 20]);
      Bonds.eBond B8 annotation (extent=[10, 0; 30, 20]);
      Bonds.fBond B5 annotation (extent=[-70, 0; -50, 20], rotation=180);
      Passive.R Re1(R=1/ce) annotation (extent=[-70, 0; -90, 20]);
      Bonds.eBond B10 annotation (extent=[30, -20; 50, 0], rotation=-90);
      Passive.C C2(C=1/c1, e(start=(ps + p0)/2)) annotation (extent=[30, -40;
            50, -20], rotation=-90);
      Bonds.eBond B6 annotation (extent=[-50, -20; -30, 0], rotation=-90);
      Passive.C C1(C=1/c1, e(start=(ps + p0)/2)) annotation (extent=[-50, -40;
            -30, -20], rotation=-90);
      Bonds.fBond B12 annotation (extent=[-10, -20; 10, 0], rotation=-90);
      Passive.TF TF1(m=1/psi) annotation (extent=[-10, -40; 10, -20], rotation=
            -90);
      Bonds.fBond B13 annotation (extent=[-10, -60; 10, -40], rotation=-90);
      Bonds.eBond B14 annotation (extent=[10, -80; 30, -60]);
      Passive.R Bm(R=rhom) annotation (extent=[30, -80; 50, -60]);
      Bonds.fBond B15 annotation (extent=[-30, -80; -10, -60], rotation=180);
      Passive.I Jm(I=jm) annotation (extent=[-30, -80; -50, -60]);
      Junctions.J0p4 J0p4_1 annotation (extent=[30, 0; 50, 20]);
      Modelica.Blocks.Interfaces.RealOutput OutPort1 
                                                  annotation (extent=[92, -30;
            112, -10]);
      Sensors.Df Df1 annotation (extent=[-10, -120; 10, -100], rotation=-90);
      Bonds.eBond B16 annotation (extent=[-10, -100; 10, -80], rotation=-90);
      Junctions.J1p4 J1p4_1 annotation (extent=[-10, -80; 10, -60]);
    equation 
      connect(J1p3_1.BondCon3, B3.eBondCon1) annotation (points=[0,60; 
            -6.12303e-016,60], style(color=8));
      connect(J0p4_2.BondCon1, B5.eBondCon1) annotation (points=[-50,10; -50,10],
                 style(color=8));
      connect(B5.fBondCon1, Re1.BondCon1) annotation (points=[-70,10; -70,10],
            style(color=8));
      connect(B10.eBondCon1, C2.BondCon1) annotation (points=[40, -20; 40, -20],
            style(color=8));
      connect(J0p4_2.BondCon3, B6.fBondCon1) annotation (points=[-40, 0; -40, 0],
               style(color=8));
      connect(B6.eBondCon1, C1.BondCon1) annotation (points=[-40, -20; -40, -20],
               style(color=8));
      connect(J1p3_2.BondCon3, B12.eBondCon1) annotation (points=[0,0; 
            -6.12303e-016,0],
          style(color=8));
      connect(B12.fBondCon1, TF1.BondCon1) annotation (points=[6.12303e-016,-20; 
            -6.12303e-016,-20], style(color=8));
      connect(TF1.BondCon2, B13.eBondCon1) annotation (points=[6.12303e-016,-40; 
            -6.12303e-016,-40],
                         style(color=8));
      connect(B14.eBondCon1, Bm.BondCon1) annotation (points=[30, -70; 30, -70],
            style(color=8));
      connect(B15.fBondCon1, Jm.BondCon1) annotation (points=[-30, -70; -30, -
            70], style(color=8));
      connect(J0p4_1.BondCon3, B10.fBondCon1) annotation (points=[40, 0; 40, 0],
            style(color=8));
      connect(J0p4_1.BondCon2, B9.eBondCon1) annotation (points=[50, 10; 50, 10],
               style(color=8));
      connect(B9.fBondCon1, Re2.BondCon1) annotation (points=[70, 10; 70, 10],
          style(color=8));
      connect(J0p3_2.BondCon1, B4.fBondCon1) annotation (points=[-40, 40; -40,
            40], style(color=8));
      connect(B4.eBondCon1, J0p4_2.BondCon4) annotation (points=[-40, 20; -40,
            20], style(color=8));
      connect(J0p4_1.BondCon4, B11.eBondCon1) annotation (points=[40, 20; 40,
            20], style(color=8));
      connect(B11.fBondCon1, J0p3_1.BondCon2) annotation (points=[40, 40; 40,
            40], style(color=8));
      connect(J1p3_1.BondCon2, B2.fBondCon1) annotation (points=[10, 50; 10, 50],
               style(color=8));
      connect(B2.eBondCon1, J0p3_1.BondCon3) annotation (points=[30, 50; 30, 50],
               style(color=8));
      connect(J0p3_2.BondCon3, B1.eBondCon1) annotation (points=[-30, 50; -30,
            50], style(color=8));
      connect(B1.fBondCon1, J1p3_1.BondCon1) annotation (points=[-10, 50; -10,
            50], style(color=8));
      connect(J1p3_2.BondCon2, B8.fBondCon1) annotation (points=[10, 10; 10, 10],
               style(color=8));
      connect(B8.eBondCon1, J0p4_1.BondCon1) annotation (points=[30, 10; 30, 10],
               style(color=8));
      connect(J0p4_2.BondCon2, B7.eBondCon1) annotation (points=[-30, 10; -30,
            10], style(color=8));
      connect(B7.fBondCon1, J1p3_2.BondCon1) annotation (points=[-10, 10; -10,
            10], style(color=8));
      connect(B3.fBondCon1, Ri.BondCon1) annotation (points=[6.12303e-016,80; 
            -6.12303e-016,80],
                    style(color=8));
      connect(J0p3_1.BondCon1, BondCon2) annotation (points=[40,60; 40,80; 80,
            80; 80,100],   style(color=8));
      connect(BondCon1, J0p3_2.BondCon2) annotation (points=[-80,100; -80,80;
            -40,80; -40,60],   style(color=8));
      connect(J1p4_1.BondCon1, B15.eBondCon1) annotation (points=[-10, -70; -10,
              -70], style(color=8));
      connect(B13.fBondCon1, J1p4_1.BondCon4) annotation (points=[6.12303e-016,
            -60; 0,-60],
                 style(color=8));
      connect(J1p4_1.BondCon2, B14.fBondCon1) annotation (points=[10, -70; 10,
            -70], style(color=8));
      connect(J1p4_1.BondCon3, B16.fBondCon1) annotation (points=[0,-80; 
            -6.12303e-016,-80], style(color=8));
      connect(B16.eBondCon1, Df1.BondCon1) annotation (points=[6.12303e-016,
            -100; -6.12303e-016,-100],
                           style(color=8));
      connect(Df1.OutPort1, OutPort1) annotation (points=[6.73533e-016,-121; 
            6.73533e-016,-130; 80,-130; 80,-20; 102,-20],
                                       style(color=3));
    end Hydromotor;
  end Hydraulic;
  
  package Examples "Examples of use of bond graph library" 
    annotation (Icon(
        Rectangle(extent=[-100, -100; 80, 50], style(
            color=0,
            fillColor=30,
            fillPattern=1)),
        Polygon(points=[-100, 50; -80, 70; 100, 70; 80, 50; -100, 50], style(
            color=0,
            fillColor=30,
            fillPattern=1)),
        Polygon(points=[100, 70; 100, -80; 80, -100; 80, 50; 100, 70], style(
            color=0,
            fillColor=30,
            fillPattern=1)),
        Text(
          extent=[-85, 71; 65, -49],
          string="Sample",
          style(color=0)),
        Text(
          extent=[-118, 114; 122, 65],
          string="%name",
          style(color=1)),
        Text(
          extent=[-97, 23; 78, -98],
          string="Programs",
          style(color=0))), Documentation(info="<html>
This package contains a number of examples demonstrating the use of the bond graph library: <p>

<ol>
<li> a simple bond graph of an electrical circuit
<li> the same circuit modeled using the electrical library built in bond graph technology
<li> a hydraulic control system
<li> a thermal building model
</ol>
</html>
"));
    model SimpleBondGraph "A simple bond graph of an electrical circuit" 
      constant Real pi=4*Modelica.Math.atan(1);
      annotation (
        Documentation(info="<html>
This is a simple bond graph of an electrical circuit.  The development of the bond graph of this circuit was demonstrated in: <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Cellier, F.E. and A. Nebot (2005), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/modelica2005_cellier.pdf\">The
     Modelica Bond Graph Library</a>,\" <i>Proc. 4<sup>th</sup> Modelica Conference</i>, Hamburg, Germany.
</ol> <p>

<hr> <p>

<b>Experimentation:</b> <p>

Simulate the bond graph during 0.002 seconds. <p>
 
<hr> <p>

<b>Simulation Results:</b> <p>

<img src=\"../Images/BG_Ex1.gif\"> 
</html>
"),     Diagram,
        Coordsys(extent=[-100, -120; 300, 120]),
        Icon(
          Rectangle(extent=[0, 100; 200, -100], style(
              color=0,
              thickness=2,
              fillColor=9)),
          Text(
            extent=[24, 44; 178, 4],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="A simple bond graph"),
          Text(
            extent=[22, 20; 180, -20],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="of an electrical circuit")));
      BondLib.Sources.sinSe U0(e0=10, freqHz=2500/pi) annotation (extent=[-40,
            -20; -80, 20]);
      BondLib.Bonds.fBond B1 annotation (extent=[-40, -20; 0, 20]);
      BondLib.Junctions.J0p3 J0p3_1 annotation (extent=[0, -20; 40, 20]);
      BondLib.Bonds.fBond B2 annotation (extent=[0, -60; 40, -20], rotation=-90);
      BondLib.Passive.I L(I=0.0015, f(start=2)) annotation (extent=[0, -100; 40,
              -60], rotation=-90);
      BondLib.Bonds.fBond B3 annotation (extent=[40, -20; 80, 20]);
      BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[80, 20; 120, -20]);
      BondLib.Bonds.fBond B4 annotation (extent=[80, 20; 120, 60], rotation=90);
      BondLib.Passive.R R1(R=100) annotation (extent=[80, 60; 120, 100],
          rotation=90);
      BondLib.Bonds.eBond B5 annotation (extent=[120, -20; 160, 20]);
      BondLib.Junctions.J0p3 J0p3_2 annotation (extent=[160, -20; 200, 20]);
      BondLib.Bonds.eBond B6 annotation (extent=[160, -60; 200, -20], rotation=
            -90);
      BondLib.Passive.C C1(C=1e-6, e(start=1)) annotation (extent=[160, -100;
            200, -60], rotation=-90);
      BondLib.Bonds.fBond B7 annotation (extent=[200, -20; 240, 20]);
      BondLib.Passive.R R2(R=20) annotation (extent=[240, -20; 280, 20],
          rotation=0);
    equation 
      connect(U0.BondCon1, B1.eBondCon1) annotation (points=[-40, 0; -40, 0],
          style(color=8));
      connect(B1.fBondCon1, J0p3_1.BondCon1) annotation (points=[0, 0; 0, 0],
          style(color=8));
      connect(J0p3_1.BondCon3, B2.eBondCon1) annotation (points=[20,-20; 20,-20],
                 style(color=8));
      connect(B2.fBondCon1, L.BondCon1) annotation (points=[20,-60; 20,-60],
          style(color=8));
      connect(J0p3_1.BondCon2, B3.eBondCon1) annotation (points=[40, 0; 40, 0],
            style(color=8));
      connect(B3.fBondCon1, J1p3_1.BondCon1) annotation (points=[80,0; 80,0],
            style(color=8));
      connect(B4.eBondCon1, J1p3_1.BondCon3) annotation (points=[100,20; 100,20],
                 style(color=8));
      connect(R1.BondCon1, B4.fBondCon1) annotation (points=[100,60; 100,60],
            style(color=8));
      connect(J1p3_1.BondCon2, B5.fBondCon1) annotation (points=[120,0; 120,0],
               style(color=8));
      connect(B5.eBondCon1, J0p3_2.BondCon1) annotation (points=[160,0; 160,0],
               style(color=8));
      connect(J0p3_2.BondCon3, B6.fBondCon1) annotation (points=[180, -20; 180,
              -20], style(color=8));
      connect(B6.eBondCon1, C1.BondCon1) annotation (points=[180, -60; 180, -60],
               style(color=8));
      connect(J0p3_2.BondCon2, B7.eBondCon1) annotation (points=[200,0; 200,0],
               style(color=8));
      connect(B7.fBondCon1, R2.BondCon1) annotation (points=[240,0; 240,0],
          style(color=8));
    end SimpleBondGraph;
    
    model ElectricalCircuit 
      "A simple  electrical circuit built in bond graph technology" 
      constant Real pi=4*Modelica.Math.atan(1);
      BondLib.Electrical.Analog.Sources.SineVoltage U0(V=10, freqHz=2500/pi) 
        annotation (extent=[-80, -20; -40, 20], rotation=-90);
      BondLib.Electrical.Analog.Basic.Resistor R1(R=100) annotation (extent=[-
            40, 20; 0, 60], rotation=-90);
      BondLib.Electrical.Analog.Basic.Resistor R2(R=20) annotation (extent=[0,
            -20; 40, 20], rotation=0);
      BondLib.Electrical.Analog.Basic.Inductor L(L=0.0015, i0=2) annotation (
          extent=[40, 20; 80, 60], rotation=-90);
      BondLib.Electrical.Analog.Basic.Capacitor C(C=1e-6, u0=1) annotation (
          extent=[-40, -60; 0, -20], rotation=-90);
      annotation (
        Coordsys(extent=[-100, -120; 100, 100]),
        Diagram,
        Icon(
          Rectangle(extent=[-100, 89; 100, -111], style(
              color=0,
              thickness=2,
              fillColor=9)),
          Text(
            extent=[-70, 40; 76, 7],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="An electrical circuit"),
          Text(
            extent=[-48, 11; 52, -8],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="built in"),
          Text(
            extent=[-78, 0; 80, -40],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="bond graph technology")),
        Documentation(info="<html>
This is a circuit diagram of a simple electrical circuit.  In fact, it is the same circuit as the one used in the previous example.  The circuit diagram was built using models from the analog electrical library contained within the bond graph library, i.e., each model has built in bond graph technology.  Yet from the outside, the circuit elements are indistinguishable from those in Modelica's standard analog electrical library. <p>

The circuit was elaborated on in: <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Cellier, F.E. and A. Nebot (2005), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/modelica2005_cellier.pdf\">The
     Modelica Bond Graph Library</a>,\" <i>Proc. 4<sup>th</sup> Modelica Conference</i>, Hamburg, Germany.
</ol> <p>

<hr> <p>

<b>Experimentation:</b> <p>

Simulate the bond graph during 0.002 seconds. <p>
 
<hr> <p>

<b>Simulation Results:</b> <p>

<img src=\"../Images/BG_Ex2.gif\"> 
</html>
"));
      BondLib.Electrical.Analog.Basic.Ground G annotation (extent=[-20, -120;
            20, -80]);
    equation 
      connect(U0.p, R1.p) annotation (points=[-60,20; -60,80; -20,80; -20,60],
          style(color=3, rgbcolor={0,0,255}));
      connect(L.p, R1.p) annotation (points=[60,60; 60,80; -20,80; -20,60],
          style(color=3, rgbcolor={0,0,255}));
      connect(U0.n, G.p) annotation (points=[-60,-20; -60,-80; 0,-80], style(
            color=3, rgbcolor={0,0,255}));
      connect(C.n, G.p) annotation (points=[-20,-60; -20,-80; 0,-80], style(
            color=3, rgbcolor={0,0,255}));
      connect(R1.n, C.p) annotation (points=[-20,20; -20,-20], style(color=3,
            rgbcolor={0,0,255}));
      connect(R2.p, C.p) annotation (points=[0,0; -20,0; -20,-20], style(color=
              3, rgbcolor={0,0,255}));
      connect(L.n, G.p) annotation (points=[60,20; 60,-80; 0,-80], style(color=
              3, rgbcolor={0,0,255}));
      connect(R2.n, L.n) annotation (points=[40,0; 60,0; 60,20], style(color=3,
            rgbcolor={0,0,255}));
    end ElectricalCircuit;
    
    package OperationalAmplifierCircuit "Operational amplifier circuit" 
      annotation (
        Icon(
          Rectangle(extent=[-99.85,98.65; 100.15,-101.35],   style(
              color=0,
              thickness=2,
              fillColor=9)),
          Text(
            extent=[-57.85,52.65; 54,24],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="Electronic circuit"),
          Text(
            extent=[-63.85,2.65; 66,-44],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="operational amplifier"),
          Text(
            extent=[-71.7,35.3; 74,4],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="containing an inverter"),
          Text(
            extent=[-45.55,13.95; 38,-16],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="built from an")),
        Diagram(
          Rectangle(extent=[-99.85,100.65; 100.15,-99.35],   style(
              color=0,
              thickness=2,
              fillColor=9)),
          Text(
            extent=[-57.85,54.65; 54,26],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="Electronic circuit"),
          Text(
            extent=[-63.85,4.65; 66,-42],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="operational amplifier"),
          Text(
            extent=[-71.7,37.3; 74,6],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="containing an inverter"),
          Text(
            extent=[-45.55,15.95; 38,-14],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="built from an")),
        Documentation(info="<html>
This package contains an electronic circuit representing an analog inverter built up from a commercial style operational amplifier circuit containing 12 bipolar transistors, 6 NPNs and 6 PNPs. <p>

The design of this model has been described in [1]. <p>

<hr> <p>

<b>Experimentation:</b> <p>

This model uses seconds as time units.  You should simulate the model during 0.0001 seconds.  Plot the input voltage and the output voltage of the inverter together on one plot. <p>

<hr> <p>

<b>Simulation Results:</b> <p>

<img src=\"../Images/BG_Ex6.gif\"> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York, pp. 216 ff.
</ol>
</html>
"));
      model OpAmp "Operational amplifier" 
        annotation (
          Coordsys(extent=[-140,-100; 100,100]),
          Icon(
            Ellipse(extent=[-98,64; -30,-56], style(
                color=3,
                rgbcolor={0,0,255},
                thickness=2)),
            Rectangle(extent=[-54,66; 60,-60], style(
                pattern=0,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Line(points=[60,0; -56,62], style(
                color=3,
                rgbcolor={0,0,255},
                thickness=2,
                fillPattern=1)),
            Line(points=[60,0; -54,-54], style(
                color=3,
                rgbcolor={0,0,255},
                thickness=2,
                fillPattern=1)),
            Line(points=[-94,30; -130,30], style(
                pattern=0,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Line(points=[-92,-30; -130,-30], style(
                pattern=0,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Line(points=[-20,44; -20,90], style(
                pattern=0,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Line(points=[-20,-38; -20,-90], style(
                pattern=0,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Line(points=[60,0; 90,0], style(
                pattern=0,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Text(
              extent=[-96,60; -42,6],
              style(
                pattern=0,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1),
              string="-"),
            Text(
              extent=[-84,-12; -52,-48],
              style(
                pattern=0,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1),
              string="+")),
          Diagram(
            Ellipse(extent=[38,-18; 42,-22], style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255})),
            Ellipse(extent=[38,48; 42,44], style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1)),
            Text(
              extent=[-36,86; -22,80],
              string="Vcc",
              style(
                color=10,
                rgbcolor={95,95,95},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1)),
            Text(
              extent=[-8,-84; 6,-90],
              style(
                color=10,
                rgbcolor={95,95,95},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1),
              string="Vee"),
            Text(
              extent=[-98,14; -82,8],
              style(
                color=10,
                rgbcolor={95,95,95},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1),
              string="-VI"),
            Text(
              extent=[-8,14; 8,8],
              style(
                color=10,
                rgbcolor={95,95,95},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1),
              string="+VI"),
            Text(
              extent=[66,14; 82,8],
              style(
                color=10,
                rgbcolor={95,95,95},
                fillColor=3,
                rgbfillColor={0,0,255},
                fillPattern=1),
              string="VO"),
            Ellipse(extent=[-22,-88; -18,-92], style(
                color=3,
                rgbcolor={0,0,255},
                fillColor=3,
                rgbfillColor={0,0,255}))),
          Documentation(info="<html>
This circuit represents a commercial high-gain operational amplifier built from 12 individual bipolar transistors, six of which are NPN transistors, whereas the other six are PNP transistors. <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York, pp. 216 ff.
</ol>
</html>
"));
        Modelica.Electrical.Analog.Interfaces.Pin vi_n 
          annotation (extent=[-150,20; -130,40]);
        Modelica.Electrical.Analog.Interfaces.Pin vi_p 
          annotation (extent=[-150,-40; -130,-20]);
        Modelica.Electrical.Analog.Interfaces.Pin vo 
          annotation (extent=[90,-10; 110,10]);
        Modelica.Electrical.Analog.Interfaces.Pin vcc 
          annotation (extent=[-30,90; -10,110]);
        Modelica.Electrical.Analog.Interfaces.Pin vee 
          annotation (extent=[-30,-110; -10,-90]);
        Electrical.Analog.Semiconductors.PNP PNP1 
          annotation (extent=[-100,70; -120,50]);
        Electrical.Analog.Basic.Resistor R1(R=1.5e6) 
          annotation (extent=[-130,-60; -110,-40], rotation=-90);
        Electrical.Analog.Semiconductors.PNP PNP2 
          annotation (extent=[-66,70; -46,50]);
        Electrical.Analog.Semiconductors.PNP PNP3 
          annotation (extent=[20,70; 40,50]);
        Electrical.Analog.Basic.Capacitor C1(C=10e-12) 
          annotation (extent=[0,-30; 20,-10]);
        Electrical.Analog.Semiconductors.NPN NPN4 
          annotation (extent=[60,36; 80,56]);
        Electrical.Analog.Semiconductors.NPN NPN5 
          annotation (extent=[20,20; 40,40]);
        Electrical.Analog.Semiconductors.PNP PNP6 
          annotation (extent=[-90,16; -70,-4]);
        Electrical.Analog.Semiconductors.PNP PNP7 
          annotation (extent=[0,16; -20,-4]);
        Electrical.Analog.Semiconductors.NPN NPN8 
          annotation (extent=[20,-10; 40,10]);
        Electrical.Analog.Semiconductors.PNP PNP9 
          annotation (extent=[60,-10; 80,-30]);
        Electrical.Analog.Semiconductors.NPN NPN10 
          annotation (extent=[20,-60; 40,-40]);
        Electrical.Analog.Semiconductors.NPN NPN11 
          annotation (extent=[-50,-80; -70,-60]);
        Electrical.Analog.Semiconductors.NPN NPN12 
          annotation (extent=[-40,-80; -20,-60]);
      equation 
        connect(PNP1.C, R1.p) annotation (points=[-120,55; -120,-40], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(PNP6.B, vi_n) annotation (points=[-90,6; -100,6; -100,30; -140,
              30], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(PNP6.E, PNP7.E) annotation (points=[-70,11; -70,20; -20,20; -20,
              11], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(PNP2.C, PNP7.E) annotation (points=[-46,55; -46,20; -20,20; -20,
              11], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(PNP7.B, vi_p) annotation (points=[0,6; 0,-10; -100,-10; -100,
              -30; -140,-30], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(C1.p, NPN10.B) annotation (points=[0,-20; 0,-50; 20,-50], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(PNP6.C, NPN11.C) annotation (points=[-70,1; -70,-65], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(NPN11.C, NPN11.B) annotation (points=[-70,-65; -70,-54; -46,-54;
              -46,-70; -50,-70], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(R1.n, NPN11.E) annotation (points=[-120,-60; -120,-90; -70,-90;
              -70,-75], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(NPN12.B, NPN11.B) annotation (points=[-40,-70; -50,-70], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(NPN10.E, NPN12.E) annotation (points=[40,-55; 40,-90; -20,-90;
              -20,-75], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(NPN11.E, NPN12.E) annotation (points=[-70,-75; -70,-90; -20,-90;
              -20,-75], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(NPN12.E, vee) annotation (points=[-20,-75; -20,-100], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(PNP7.C, NPN12.C) annotation (points=[-20,1; -20,-65], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(NPN12.C, NPN10.B) annotation (points=[-20,-65; -20,-50; 20,-50],
            style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(PNP9.C, NPN10.E) annotation (points=[80,-25; 80,-90; 40,-90; 40,
              -55], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(PNP1.E, PNP2.E) annotation (points=[-120,65; -120,80; -46,80;
              -46,65], style(color=3, rgbcolor={0,0,255}));
        connect(PNP2.E, vcc) annotation (points=[-46,65; -46,80; -20,80; -20,
              100], style(color=3, rgbcolor={0,0,255}));
        connect(NPN4.C, PNP3.E) annotation (points=[80,51; 80,80; 40,80; 40,65],
            style(color=3, rgbcolor={0,0,255}));
        connect(PNP2.E, PNP3.E) annotation (points=[-46,65; -46,80; 40,80; 40,
              65], style(color=3, rgbcolor={0,0,255}));
        connect(PNP3.C, NPN5.C) annotation (points=[40,55; 40,35], style(color=
                3, rgbcolor={0,0,255}));
        connect(NPN5.C, NPN4.B) annotation (points=[40,35; 40,46; 60,46], style(
              color=3, rgbcolor={0,0,255}));
        connect(NPN5.B, NPN5.C) annotation (points=[20,30; 20,46; 40,46; 40,35],
            style(color=3, rgbcolor={0,0,255}));
        connect(NPN5.E, NPN8.C) annotation (points=[40,25; 40,5], style(color=3,
              rgbcolor={0,0,255}));
        connect(NPN8.B, NPN8.C) annotation (points=[20,0; 20,16; 40,16; 40,5],
            style(color=3, rgbcolor={0,0,255}));
        connect(NPN4.E, PNP9.E) annotation (points=[80,41; 80,-15], style(color=
               3, rgbcolor={0,0,255}));
        connect(PNP9.E, vo) annotation (points=[80,-15; 80,0; 100,0], style(
              color=3, rgbcolor={0,0,255}));
        connect(NPN8.E, NPN10.C) annotation (points=[40,-5; 40,-45], style(
              color=3, rgbcolor={0,0,255}));
        connect(C1.n, NPN10.C) annotation (points=[20,-20; 40,-20; 40,-45],
            style(color=3, rgbcolor={0,0,255}));
        connect(PNP9.B, NPN10.C) annotation (points=[60,-20; 40,-20; 40,-45],
            style(color=3, rgbcolor={0,0,255}));
        connect(PNP1.B, PNP2.B) annotation (points=[-100,60; -66,60], style(
              color=3, rgbcolor={0,0,255}));
        connect(PNP1.B, PNP1.C) annotation (points=[-100,60; -90,60; -90,46;
              -120,46; -120,55], style(color=3, rgbcolor={0,0,255}));
        connect(PNP2.B, PNP3.B) annotation (points=[-66,60; 20,60], style(color=
               3, rgbcolor={0,0,255}));
      end OpAmp;
      
      model Inverter "Analog inverter circuit" 
        annotation (
          Icon(
            Line(points=[-60,60; -60,-60], style(
                thickness=2,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Line(points=[-60,60; 60,0], style(
                thickness=2,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Line(points=[-60,-60; 60,0], style(
                thickness=2,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Line(points=[-60,0; -100,0], style(
                pattern=0,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Line(points=[60,0; 100,0], style(
                pattern=0,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Text(
              extent=[-66,30; -12,-24],
              style(
                pattern=0,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1),
              string="-")),
          Diagram,
          Documentation(info="<html>
The analog inverter is built from a commercial high-gain operational amplifier. <p>

<hr> <p>

<b>Experimentation:</b> <p>

This model uses seconds as time units.  You should simulate the model during 0.0001 seconds.  Plot the input voltage and the output voltage of the inverter together in one plot. <p>

<hr> <p>

<b>Simulation Results:</b> <p>

<img src=\"../Images/BG_Ex6.gif\"> <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Cellier, F.E. (1991), <i>Continuous System Modeling</i>, Springer-Verlag, New York, pp. 216 ff.
</ol>
</html>
"),     experiment(StopTime=0.0001));
        Electrical.Analog.Basic.Resistor Rf(R=1e6) 
          annotation (extent=[20,60; 40,80]);
        Electrical.Analog.Basic.Resistor R1(R=1e6) 
          annotation (extent=[-40,0; -20,20]);
        Electrical.Analog.Basic.Ground Gnd1 annotation (extent=[-6,-26; 6,-16]);
        Electrical.Analog.Basic.Ground Gnd2 
          annotation (extent=[-66,-66; -54,-56]);
        Electrical.Analog.Basic.Ground Gnd3 annotation (extent=[34,14; 46,24]);
        Electrical.Analog.Basic.Ground Gnd4 annotation (extent=[14,-66; 26,-56]);
        Electrical.Analog.Basic.Ground Gnd5 annotation (extent=[54,-66; 66,-56]);
        Electrical.Analog.Sources.ConstantVoltage Vcc(V=15) 
          annotation (extent=[20,30; 40,50]);
        Electrical.Analog.Sources.ConstantVoltage Vee(V=-15) 
          annotation (extent=[10,-46; 30,-26], rotation=-90);
        Electrical.Analog.Sensors.VoltageSensor VO 
          annotation (extent=[70,-46; 50,-26], rotation=-90);
        Electrical.Analog.Sources.TrapezoidVoltage Vi(
          V=4,
          rising=1e-6,
          width=24e-6,
          falling=1e-6,
          period=50e-6,
          nperiod=2,
          offset=-2,
          startTime=5e-6) annotation (extent=[-70,-46; -50,-26], rotation=-90);
        BondLib.Examples.OperationalAmplifierCircuit.OpAmp OpAmp1 
          annotation (extent=[0,-16; 40,24]);
      equation 
        connect(Vcc.n, Gnd3.p) annotation (points=[40,40; 40,24], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(Vee.n, Gnd4.p) annotation (points=[20,-46; 20,-56], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(VO.n, Gnd5.p) annotation (points=[60,-46; 60,-56], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(Vi.n, Gnd2.p) annotation (points=[-60,-46; -60,-56], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(R1.p, Vi.p) annotation (points=[-40,10; -60,10; -60,-26], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(R1.n, OpAmp1.vi_n) annotation (points=[-20,10; 0,10], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(Vcc.p, OpAmp1.vcc) annotation (points=[20,40; 20,24], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(Rf.p, OpAmp1.vi_n) annotation (points=[20,70; 0,70; 0,10],
            style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(OpAmp1.vi_p, Gnd1.p) annotation (points=[0,-2; 0,-16], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(Vee.p, OpAmp1.vee) annotation (points=[20,-26; 20,-16], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(Rf.n, OpAmp1.vo) annotation (points=[40,70; 60,70; 60,4; 40,4],
            style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
        connect(VO.p, OpAmp1.vo) annotation (points=[60,-26; 60,4; 40,4], style(
            color=3,
            rgbcolor={0,0,255},
            pattern=0,
            fillColor=7,
            rgbfillColor={255,255,255},
            fillPattern=1));
      end Inverter;
    end OperationalAmplifierCircuit;
    
    model HydraulicControl "A hydraulic control system" 
      parameter Real ps=0.137e8 "Service pressure";
      parameter Real p0=1.0132e5 "Environment pressure";
      Modelica.Blocks.Sources.Constant ThSet annotation (extent=[-80, 0; -40,
            40]);
      Modelica.Blocks.Math.Feedback Feedback1 annotation (extent=[-20, 0; 20,
            40]);
      annotation (
        Diagram,
        Coordsys(extent=[-100, -100; 300, 100]),
        Icon(
          Rectangle(extent=[0, 100; 200, -100], style(
              color=0,
              thickness=2,
              fillColor=9)),
          Text(
            extent=[56, 46; 152, 18],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="A hydraulic"),
          Text(
            extent=[16, 32; 184, -14],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="position control circuit")),
        Documentation(info="<html>
This is a hydraulic position control circuit.  From the outside, the system is described as a simple block diagram.  Yet, three of the blocks have been modeled internally using bond graph technology.  The development of this control circuit has been described in: <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Cellier, F.E. and A. Nebot (2005), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/modelica2005_cellier.pdf\">The
     Modelica Bond Graph Library</a>,\" <i>Proc. 4<sup>th</sup> Modelica Conference</i>, Hamburg, Germany.
</ol> <p>

<hr> <p>

<b>Experimentation:</b> <p>

Simulate the bond graph during 0.3 second. <p>
 
<hr> <p>

<b>Simulation Results:</b> <p>

<img src=\"../Images/BG_Ex3.gif\"> 
</html>
"));
      Modelica.Blocks.Nonlinear.Limiter Limiter1 annotation (extent=[40, 0; 80,
              40]);
      BondLib.Hydraulic.Servo Servo1(
        ls=1e-12,
        bs=2,
        ms=0.01,
        ks=400,
        psis=0.005,
        rs=1.25e-5) annotation (extent=[100, 0; 140, 40]);
      BondLib.Hydraulic.Servovalve Servovalve1(
        k=0.248e-6,
        x0=0.05,
        ps=ps,
        p0=p0) annotation (extent=[160, 0; 200, 40]);
      BondLib.Hydraulic.Hydromotor Hydromotor1(
        ce=0.737e-12,
        ci=0.737e-13,
        c1=5.857e13,
        psi=0.575e-5,
        rhom=1.5,
        jm=0.08,
        ps=ps,
        p0=p0) annotation (extent=[160, -40; 200, 0]);
      Modelica.Blocks.Continuous.Integrator Integrator1 annotation (extent=[220,
              -40; 260, 0]);
    equation 
      connect(ThSet.y,Feedback1.u1)             annotation (points=[-38,20; -16,
            20],     style(color=3));
      connect(Feedback1.y,Limiter1.u)             annotation (points=[18,20; 36,
            20],     style(color=3));
      connect(Limiter1.y,Servo1.u)             annotation (points=[82,20; 96,20],
                 style(color=3));
      connect(Servo1.y,       Servovalve1.InPort1) annotation (points=[142,20;
            160.4,20],    style(color=3));
      connect(Servovalve1.BondCon1, Hydromotor1.BondCon1) annotation (points=[
            164,0; 164,-3.55271e-015],    style(color=8));
      connect(Servovalve1.BondCon2, Hydromotor1.BondCon2) annotation (points=[
            196,0; 196,-3.55271e-015],   style(color=8));
      connect(Hydromotor1.OutPort1,Integrator1.u)       annotation (points=[
            200.4,-20; 216,-20],
                              style(color=3));
      connect(Integrator1.y,Feedback1.u2)             annotation (points=[262,
            -20; 280,-20; 280,-80; 0,-80; 0,4],     style(color=3));
    end HydraulicControl;
    
    package SolarHouse "A passive solar heating model" 
      annotation (
        Coordsys(
          extent=[0, 0; 443, 453],
          grid=[2, 2],
          component=[20, 20]),
        Window(
          x=0.01,
          y=0.31,
          width=0.44,
          height=0.65,
          library=1,
          autolayout=1),
        Icon(
          Rectangle(extent=[-85.85, 100.65; 114.15, -99.35], style(
              color=0,
              thickness=2,
              fillColor=9)),
          Text(
            extent=[-45.85, 60.65; 74, 32],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="Thermal model of"),
          Text(
            extent=[-69.85, 12.65; 98.15, -33.35],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="with passive solar heating"),
          Text(
            extent=[-57.7, 43.3; 88, 12],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="an experimental house"),
          Text(
            extent=[-57.55, 23.95; 88.15, -7.35],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="located in Tucson, AZ")),
        Diagram(
          Rectangle(extent=[-95.7, 99.3; 104.3, -100.7], style(
              color=0,
              thickness=2,
              fillColor=9)),
          Text(
            extent=[-55.7, 59.3; 64.15, 30.65],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="Thermal model of"),
          Text(
            extent=[-79.7, 29.3; 88.3, -16.7],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="with passive solar heating"),
          Text(
            extent=[-67.55, 41.95; 78.15, 10.65],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="an experimental house"),
          Text(
            extent=[-69.4, 2.6; 76.3, -28.7],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="located in Tucson, AZ")),
        Documentation(info="<html>
This package contains a thermal building model of an experimental house located near the airport in Tucson, Arizona, with a passive solar heating system.  The house contains four rooms, one of which is a solarium that collects heat during the winter and releases it during the summer. <p>

The code is collected into individual models describing the walls, the windows, etc.  The main model to be simulated is the last model of the set, called <b>House</b>. <p>

The design of this model has been described in [1,2]. <p>

<hr> <p>

<b>Experimentation:</b> <p>

This model uses hours as time units.  If you wish to only experiment with this model, you can simulate it over 4 days by setting the final time to 96 hours.  However, if you wish to reproduce the results obtained by Markus Weiner in his MS Thesis, you need to simulate the model for a full year, i.e., during 8600 hours. <p>

Unfortunately, this simulation is fairly slow.  It takes roughly 20 minutes of real time on a modern PC.  The problem isn't primarily one of simulation.  It is a problem of producing too much I/O.  Dymola by default stores each and every variable.  Thus, if you wish to simulate over an extended period of time, you should turn off the automatic storage of all variables, and selectively store only those variables that you wish to look at.  This will speed up the simulation dramatically.  At least, you should turn off the storage of the auxiliary variables. <p>

However, there is also a table interpolation problem.  In order to optimize the modularity of the model, several tables were recomputed many times inside individual modules.  This is computationally wasteful, but reduces the external interconnections, thereby making the model more easily readable. <p>

Notice that the model uses its own table interpolation routines that were copied from the book by Michael Tiller [3].  I tried to replace this routine by the built-in table interpolation routines of the Modelica Standard Library, but failed, because I ran into a Dymola limitation on the number of allowed tables to be used. <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Weiner, M. (1992), <i>Bond Graph Model of a Passive Solar Heating System</i>, MS Thesis, Dept. of Electr. &amp;
     Comp. Engr., University of Arizona, Tucson, Arizona.
<li> Weiner, M., and F.E. Cellier (1993), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/weiner.pdf\">Modeling
     and Simulation of a Solar Energy System by Use of Bond Graphs</a>,\" <i>Proc. 1<sup>st</sup> SCS Intl. Conf. on Bond Graph
     Modeling</i>, San Diego, California, pp.301-306.
<li> Tiller, M.M. (2001), <i>Introduction to Physical Modeling with Modelica,</i> Kluwer Academic Publishers.
</ol>
</html>
"));
      function Piecewise "Two-dimensional table lookup" 
        input Real x "Independent variable";
        input Real x_grid[:] "Independent variable data points";
        input Real y_grid[:] "Dependent variable data points";
        output Real y "Interpolated result";
      protected 
        Integer n;
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(
            Rectangle(extent=[-44, 60; -8, 40], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, 40; -8, 20], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, 20; -8, -2], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, 0; -8, -22], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, -20; -8, -42], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, -40; -8, -60], style(color=0, fillColor=49)),
            Rectangle(extent=[-8, 60; 28, 40], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, 40; 28, 20], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, 20; 28, -2], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, 0; 28, -20], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, -20; 28, -40], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, -40; 28, -60], style(color=0, fillColor=7)),
            Text(extent=[-150, 150; 150, 110], string="%name")),
          Diagram(
            Rectangle(extent=[-44, 60; -8, 40], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, 40; -8, 20], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, 20; -8, -2], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, 0; -8, -22], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, -20; -8, -42], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, -40; -8, -60], style(color=0, fillColor=49)),
            Rectangle(extent=[-8, 60; 28, 40], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, 40; 28, 20], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, 20; 28, -2], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, 0; 28, -20], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, -20; 28, -40], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, -40; 28, -60], style(color=0, fillColor=7)),
            Text(extent=[-96, 94; 98, 70], string="Linear interpolation")),
          Documentation(info="<html>
This function contains an algorithm for interpolation in a two-dimensional lookup table.  The algorithm was taken from: <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Tiller, M.M. (2001), <i>Introduction to Physical Modeling with Modelica,</i> Kluwer Academic Publishers.
</ol>
</html>
"));
      algorithm 
        n := size(x_grid, 1);
        assert(size(x_grid, 1) == size(y_grid, 1), "Size mismatch");
        assert(x >= x_grid[1] and x <= x_grid[n], "Out of range");
        for i in 1:n - 1 loop
          if x >= x_grid[i] and x <= x_grid[i + 1] then
            y := y_grid[i] + (y_grid[i + 1] - y_grid[i])*((x - x_grid[i])/(
              x_grid[i + 1] - x_grid[i]));
          end if;
        end for;
      end Piecewise;
      
      block TableLookup "Two-dimensional table lookup" 
        extends Modelica.Blocks.Interfaces.SISO;
        parameter Real x_vals[:]={0} "Independent variable data points";
        parameter Real y_vals[:]={0} "Dependent variable data points";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Rectangle(extent=[-44, 60; -8, 40], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, 40; -8, 20], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, 20; -8, -2], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, 0; -8, -22], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, -20; -8, -42], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, -40; -8, -60], style(color=0, fillColor=49)),
            Rectangle(extent=[-8, 60; 28, 40], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, 40; 28, 20], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, 20; 28, -2], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, 0; 28, -20], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, -20; 28, -40], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, -40; 28, -60], style(color=0, fillColor=7)),
            Line(points=[-100, 0; -44, 0], style(color=9)),
            Line(points=[28, 0; 100, 0], style(color=9)),
            Text(
              extent=[-88, 20; -62, 2],
              string="u",
              style(color=9)),
            Text(
              extent=[52, 20; 78, 2],
              string="y",
              style(color=9))),
          Icon(
            Rectangle(extent=[-44, 60; -8, 40], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, 40; -8, 20], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, 20; -8, -2], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, 0; -8, -22], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, -20; -8, -42], style(color=0, fillColor=49)),
            Rectangle(extent=[-44, -40; -8, -60], style(color=0, fillColor=49)),
            Rectangle(extent=[-8, 60; 28, 40], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, 40; 28, 20], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, 20; 28, -2], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, 0; 28, -20], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, -20; 28, -40], style(color=0, fillColor=7)),
            Rectangle(extent=[-8, -40; 28, -60], style(color=0, fillColor=7))),
          Documentation(info="<html>
This block encapsulates the function for interpolation in a two-dimensional lookup table.
</html>
"));
      equation 
        y = Piecewise(x=u, x_grid=x_vals, y_grid=y_vals);
      end TableLookup;
      
      block DayHour "Conversion of fractional days to hours" 
        extends Modelica.Blocks.Interfaces.SISO;
        output Real day "day of the year";
        output Real hour "hour of the day";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Rectangle(extent=[-100, 100; 100, -100]),
            Text(extent=[-80, 60; 80, 20], string="Convert the"),
            Text(extent=[-80, 20; 80, -20], string="day of the year"),
            Text(extent=[-80, -20; 80, -60], string="to the hour of the day")),
          Icon(
            Text(extent=[-80, 72; 16, 32], string="Day of the year"),
            Rectangle(extent=[-84, 72; 20, 32]),
            Text(extent=[-22, -42; 86, -76], string="Hour of the day"),
            Rectangle(extent=[-22, -42; 86, -78]),
            Line(points=[-12, 12; 26, -26]),
            Line(points=[26, -14; 26, -26; 14, -26])),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This auxiliary block converts fractional days to hours of the day. <p>

The input variable is the simulation clock (in hours) divided by 24.  This is the day of the year, whereby the fraction indirectly contains the information about the hour of the day.  The fraction is extracted and converted back to hours.
</html>
"));
      equation 
        day = u;
        hour = 24*(day - floor(day));
        y = hour;
      end DayHour;
      
      block Temperature "Ambient temperature" 
        extends Modelica.Blocks.Interfaces.SISO;
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Line(points=[-140, 28; -94, 28], style(color=9)),
            Line(points=[-104, 34; -94, 28; -104, 22], style(color=9)),
            Text(
              extent=[-142, 40; -106, 32],
              string="Hour in the year",
              style(color=9)),
            Text(
              extent=[-52, 56; -16, 48],
              string="Day in the year",
              style(color=9)),
            Text(
              extent=[-6, 56; 30, 48],
              string="Hour of the day",
              style(color=9)),
            Text(
              extent=[54, 36; 90, 28],
              string="Daily variation",
              style(color=9)),
            Text(
              extent=[54, 28; 90, 20],
              string="of temperature",
              style(color=9)),
            Text(
              extent=[6, -32; 58, -40],
              string="Average temperature",
              style(color=9)),
            Text(
              extent=[6, -40; 38, -48],
              string="over the year",
              style(color=9))),
          Icon(
            Rectangle(extent=[-30, 76; 26, -78]),
            Rectangle(extent=[-6, 60; 2, -54]),
            Ellipse(extent=[-8, -52; 4, -64], style(fillColor=73)),
            Rectangle(extent=[-6, -10; 2, -58], style(fillColor=73)),
            Line(points=[-8, -44; -18, -44]),
            Line(points=[-8, -42; -12, -42]),
            Line(points=[-8, -40; -12, -40]),
            Line(points=[-8, -38; -12, -38]),
            Line(points=[-8, -36; -12, -36]),
            Line(points=[-8, 36; -18, 36]),
            Line(points=[-8, 38; -12, 38]),
            Line(points=[-8, 40; -12, 40]),
            Line(points=[-8, 42; -12, 42]),
            Line(points=[-8, 44; -12, 44]),
            Line(points=[-8, -34; -18, -34]),
            Line(points=[-8, -32; -12, -32]),
            Line(points=[-8, -30; -12, -30]),
            Line(points=[-8, -28; -12, -28]),
            Line(points=[-8, -26; -12, -26]),
            Line(points=[-8, -24; -18, -24]),
            Line(points=[-8, -22; -12, -22]),
            Line(points=[-8, -20; -12, -20]),
            Line(points=[-8, -18; -12, -18]),
            Line(points=[-8, -16; -12, -16]),
            Line(points=[-8, -14; -18, -14]),
            Line(points=[-8, -12; -12, -12]),
            Line(points=[-8, -10; -12, -10]),
            Line(points=[-8, -8; -12, -8]),
            Line(points=[-8, -6; -12, -6]),
            Line(points=[-8, -4; -18, -4]),
            Line(points=[-8, -2; -12, -2]),
            Line(points=[-8, 0; -12, 0]),
            Line(points=[-8, 2; -12, 2]),
            Line(points=[-8, 4; -12, 4]),
            Line(points=[-8, 6; -18, 6]),
            Line(points=[-8, 8; -12, 8]),
            Line(points=[-8, 10; -12, 10]),
            Line(points=[-8, 12; -12, 12]),
            Line(points=[-8, 14; -12, 14]),
            Line(points=[-8, 16; -18, 16]),
            Line(points=[-8, 18; -12, 18]),
            Line(points=[-8, 20; -12, 20]),
            Line(points=[-8, 22; -12, 22]),
            Line(points=[-8, 24; -12, 24]),
            Line(points=[-8, 26; -18, 26]),
            Line(points=[-8, 28; -12, 28]),
            Line(points=[-8, 30; -12, 30]),
            Line(points=[-8, 32; -12, 32]),
            Line(points=[-8, 34; -12, 34])),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This block computes the ambient temperature at the experimental house for any day of the year and any hour of the day.  Rather than operating on a huge data file with observed data for the location of Tucson for an entire year, the model contains two lookup tables. <p>

One table contains the average temperature for each day of the year measured in <sup>o</sup>K.  The table is small, as data values are stored only once per month (roughly).  Interpolation is used to interpolate between these storage data points. <p>

The other table contains the average temperature variation during one day.  Also this table is small, as data values are stored once per hour.  The temperature variation is stored as a multiplicative factor of the average temperature of the day. <p>

This model is good enough for our purposes.
</html>
"));
        Modelica.Blocks.Math.Gain K1(k=1/24)   annotation (extent=[-60, 20; -40,
                40]);
        DayHour DayHour1 annotation (extent=[-20, 20; 0, 40]);
        Modelica.Blocks.Math.Product P1 annotation (extent=[60, -10; 80, 10]);
        TableLookup AvgTemperature(x_vals={0,480,1224,1896,2640,3360,4104,4824,
              5568,6312,7032,7776,8496,8760}, y_vals={284,283.71,284.26,288.71,
              292.59,296.48,302.59,302.59,302.04,299.81,294.26,287.59,284.26,
              284.0}) annotation (extent=[-20, -40; 0, -20]);
        TableLookup TempVariation(x_vals=-1:33, y_vals={0.991,0.988,0.986,0.983,
               0.98,0.978,0.976,0.976,0.979,0.985,0.993,1.003,1.011,1.018,1.023,
               1.027,1.028,1.027,1.023,1.017,1.01,1.004,0.999,0.995,0.991,0.988,
               0.986,0.983,0.98,0.978,0.976,0.976,0.979,0.985,0.993}) 
          annotation (extent=[20, 20; 40, 40]);
      equation 
        connect(u,K1.u)            annotation (points=[-120,0; -80,0; -80,30;
              -62,30],    style(color=3));
        connect(P1.y,y)              annotation (points=[81,0; 110,0],   style(
              color=3));
        connect(K1.y,DayHour1.u)             annotation (points=[-39,30; -22,30],
                   style(color=3));
        connect(u,AvgTemperature.u)            annotation (points=[-120,0; -80,
              0; -80,-30; -22,-30],     style(color=3));
        connect(AvgTemperature.y,P1.u2)             annotation (points=[1,-30;
              50,-30; 50,-6; 58,-6],      style(color=3));
        connect(DayHour1.y,TempVariation.u)             annotation (points=[1,
              30; 18,30],  style(color=3));
        connect(TempVariation.y,P1.u1)             annotation (points=[41,30;
              50,30; 50,6; 58,6],    style(color=3));
      end Temperature;
      
      block Temperature2 "Ground temperature" 
        extends Modelica.Blocks.Interfaces.SISO;
        constant Real pi=Modelica.Constants.pi;
        output Real corr "Temperature correction factor";
        output Real AvgTemp "Average temperature";
        output Real AvgTemp2 "Average temperature corrected";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Text(
              extent=[-52, 56; -16, 48],
              string="Day in the year",
              style(color=9)),
            Text(
              extent=[-6, 56; 30, 48],
              string="Hour of the day",
              style(color=9)),
            Text(
              extent=[54, 36; 90, 28],
              string="Daily variation",
              style(color=9)),
            Text(
              extent=[54, 28; 90, 20],
              string="of temperature",
              style(color=9)),
            Text(
              extent=[-36, -32; 16, -40],
              string="Average temperature",
              style(color=9)),
            Text(
              extent=[-36, -40; -4, -48],
              string="over the year",
              style(color=9)),
            Polygon(points=[20, -20; 20, -40; 40, -30; 20, -20], style(color=53)),
            Text(
              extent=[20, -10; 40, -14],
              string="Temperature",
              style(color=53)),
            Text(
              extent=[20, -14; 40, -18],
              string="Correction",
              style(color=57)),
            Line(points=[-38, -30; 20, -30], style(color=57, fillColor=61)),
            Line(points=[40, -30; 50, -30; 50, -6; 56, -6], style(color=53))),
          Icon(
            Rectangle(extent=[-30, 76; 26, -78]),
            Rectangle(extent=[-6, 60; 2, -54]),
            Ellipse(extent=[-8, -52; 4, -64], style(fillColor=73)),
            Rectangle(extent=[-6, -10; 2, -58], style(fillColor=73)),
            Line(points=[-8, -44; -18, -44]),
            Line(points=[-8, -42; -12, -42]),
            Line(points=[-8, -40; -12, -40]),
            Line(points=[-8, -38; -12, -38]),
            Line(points=[-8, -36; -12, -36]),
            Line(points=[-8, 36; -18, 36]),
            Line(points=[-8, 38; -12, 38]),
            Line(points=[-8, 40; -12, 40]),
            Line(points=[-8, 42; -12, 42]),
            Line(points=[-8, 44; -12, 44]),
            Line(points=[-8, -34; -18, -34]),
            Line(points=[-8, -32; -12, -32]),
            Line(points=[-8, -30; -12, -30]),
            Line(points=[-8, -28; -12, -28]),
            Line(points=[-8, -26; -12, -26]),
            Line(points=[-8, -24; -18, -24]),
            Line(points=[-8, -22; -12, -22]),
            Line(points=[-8, -20; -12, -20]),
            Line(points=[-8, -18; -12, -18]),
            Line(points=[-8, -16; -12, -16]),
            Line(points=[-8, -14; -18, -14]),
            Line(points=[-8, -12; -12, -12]),
            Line(points=[-8, -10; -12, -10]),
            Line(points=[-8, -8; -12, -8]),
            Line(points=[-8, -6; -12, -6]),
            Line(points=[-8, -4; -18, -4]),
            Line(points=[-8, -2; -12, -2]),
            Line(points=[-8, 0; -12, 0]),
            Line(points=[-8, 2; -12, 2]),
            Line(points=[-8, 4; -12, 4]),
            Line(points=[-8, 6; -18, 6]),
            Line(points=[-8, 8; -12, 8]),
            Line(points=[-8, 10; -12, 10]),
            Line(points=[-8, 12; -12, 12]),
            Line(points=[-8, 14; -12, 14]),
            Line(points=[-8, 16; -18, 16]),
            Line(points=[-8, 18; -12, 18]),
            Line(points=[-8, 20; -12, 20]),
            Line(points=[-8, 22; -12, 22]),
            Line(points=[-8, 24; -12, 24]),
            Line(points=[-8, 26; -18, 26]),
            Line(points=[-8, 28; -12, 28]),
            Line(points=[-8, 30; -12, 30]),
            Line(points=[-8, 32; -12, 32]),
            Line(points=[-8, 34; -12, 34]),
            Text(extent=[-84, -116; 92, -154], string="corrected")),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This block computes the ground temperature at the experimental house for any day of the year and any hour of the day.  Rather than operating on a huge data file with observed data for the location of Tucson for an entire year, the model contains two lookup tables. <p>

One table contains the average air temperature for each day of the year measured in <sup>o</sup>K.  The table is small, as data values are stored only once per month (roughly).  Interpolation is used to interpolate between these storage data points. <p>

The other table contains the average temperature variation during one day.  Also this table is small, as data values are stored once per hour.  The temperature variation is stored as a multiplicative factor of the average temperature of the day. <p>

The average ground temperature is computed by a correction equation applied to the air temperature. <p>
</html>
"));
        Modelica.Blocks.Math.Gain K1(k=1/24)   annotation (extent=[-60, 20; -40,
                40]);
        DayHour DayHour1 annotation (extent=[-20, 20; 0, 40]);
        Modelica.Blocks.Math.Product P1 annotation (extent=[60, -10; 80, 10]);
        TableLookup AvgTemperature(x_vals={0,480,1224,1896,2640,3360,4104,4824,
              5568,6312,7032,7776,8496,8760}, y_vals={284,283.71,284.26,288.71,
              292.59,296.48,302.59,302.59,302.04,299.81,294.26,287.59,284.26,
              284.0}) annotation (extent=[-60, -40; -40, -20]);
        TableLookup TempVariation(x_vals=-1:33, y_vals={0.991,0.988,0.986,0.983,
               0.98,0.978,0.976,0.976,0.979,0.985,0.993,1.003,1.011,1.018,1.023,
               1.027,1.028,1.027,1.023,1.017,1.01,1.004,0.999,0.995,0.991,0.988,
               0.986,0.983,0.98,0.978,0.976,0.976,0.979,0.985,0.993}) 
          annotation (extent=[20, 20; 40, 40]);
      equation 
        connect(K1.y,DayHour1.u)             annotation (points=[-39,30; -22,30],
                   style(color=3));
        connect(u,K1.u)            annotation (points=[-120,0; -80,0; -80,30;
              -62,30],    style(color=3));
        connect(P1.y,y)              annotation (points=[81,0; 110,0],   style(
              color=3));
        connect(u,AvgTemperature.u)            annotation (points=[-120,0; -80,
              0; -80,-30; -62,-30],     style(color=3));
        connect(DayHour1.y,TempVariation.u)             annotation (points=[1,
              30; 18,30],  style(color=3));
        connect(TempVariation.y,P1.u1)             annotation (points=[41,30;
              50,30; 50,6; 58,6],    style(color=3));
        AvgTemp = AvgTemperature.y;
        corr = 1 + 0.004*sin(pi*time/60) + 0.0025*cos(pi*(time - 60)/120) +
          0.0002*sin(pi*(time - 30)/180);
        AvgTemp2 = corr*AvgTemp;
        P1.u2 = AvgTemp2;
      end Temperature2;
      
      block TFilter "Auxiliary block for air conditioning" 
        extends Modelica.Blocks.Interfaces.SISO;
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Rectangle(extent=[-100, 100; 100, -100]),
            Text(extent=[-80, 60; 80, 20], string="Temperature"),
            Text(extent=[-80, 20; 80, -20], string="Filter")),
          Icon(Text(extent=[-80, 20; 80, -20], string="Filter"), Text(extent=[-
                  80, 60; 80, 20], string="Temperature")),
          Documentation(info="<html>
This auxiliary block represents a \"temperature filter\" used inside the air conditioning unit for control purposes.
</html>
"));
      equation 
        y = 1 - 2/(1 + Modelica.Math.exp(-u));
      end TFilter;
      
      block AirConditioning "Air conditioning unit" 
        extends Modelica.Blocks.Interfaces.SISO;
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(
            Rectangle(extent=[-76, 38; 24, -58]),
            Line(points=[-76, 38; -20, 64]),
            Line(points=[24, 38; 80, 64]),
            Line(points=[24, -58; 80, -28]),
            Line(points=[-20, 64; 80, 64; 80, -28]),
            Rectangle(extent=[-70, 32; -28, -52]),
            Rectangle(extent=[-24, 32; 18, -52]),
            Rectangle(extent=[-68, 30; -30, 26]),
            Rectangle(extent=[-22, -46; 16, -50]),
            Rectangle(extent=[-68, 24; -30, 20]),
            Rectangle(extent=[-68, 18; -30, 14]),
            Rectangle(extent=[-68, 12; -30, 8]),
            Rectangle(extent=[-68, 4; -30, 0]),
            Rectangle(extent=[-68, -2; -30, -6]),
            Rectangle(extent=[-68, -8; -30, -12]),
            Rectangle(extent=[-68, -14; -30, -18]),
            Rectangle(extent=[-68, -22; -30, -26]),
            Rectangle(extent=[-68, -28; -30, -32]),
            Rectangle(extent=[-68, -34; -30, -38]),
            Rectangle(extent=[-68, -40; -30, -44]),
            Rectangle(extent=[-68, -46; -30, -50]),
            Rectangle(extent=[-22, 30; 16, 26]),
            Rectangle(extent=[-22, 24; 16, 20]),
            Rectangle(extent=[-22, 18; 16, 14]),
            Rectangle(extent=[-22, 12; 16, 8]),
            Rectangle(extent=[-22, 4; 16, 0]),
            Rectangle(extent=[-22, -2; 16, -6]),
            Rectangle(extent=[-22, -8; 16, -12]),
            Rectangle(extent=[-22, -14; 16, -18]),
            Rectangle(extent=[-22, -22; 16, -26]),
            Rectangle(extent=[-22, -28; 16, -32]),
            Rectangle(extent=[-22, -34; 16, -38]),
            Rectangle(extent=[-22, -40; 16, -44])),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
The air conditioning unit uses a control algorithm to determine the amount of active air conditioning to be applied to the living room.
</html>
"));
        Modelica.Blocks.Sources.Constant C1(k=300)   annotation (extent=[-80,
              20; -60, 40]);
        Modelica.Blocks.Sources.Constant C2(k=295)   annotation (extent=[-80, -
              30; -60, -10]);
        TFilter TF1 annotation (extent=[-20, 40; 0, 60]);
        TFilter TF2 annotation (extent=[-20, -10; 0, 10]);
        Modelica.Blocks.Nonlinear.Limiter L1(uMax=0, uMin=-10)     annotation (
            extent=[10, 40; 30, 60]);
        Modelica.Blocks.Nonlinear.Limiter L2(uMax=10, uMin=0)     annotation (
            extent=[10, -10; 30, 10]);
        Modelica.Blocks.Math.Add S1(k2=-1) annotation (extent=[-50, 40; -30, 60]);
        Modelica.Blocks.Math.Add S2(k2=-1) annotation (extent=[-50, -10; -30,
              10]);
        Modelica.Blocks.Math.Add A1 annotation (extent=[40, 14; 60, 34]);
        Modelica.Blocks.Math.Division Division1 annotation (extent=[40, -80; 60,
                -60]);
        Modelica.Blocks.Math.Gain G1(k=10000)   annotation (extent=[0, -60; 20,
                -40]);
      equation 
        connect(TF1.y,L1.u)             annotation (points=[1,50; 8,50],
            style(color=3));
        connect(TF2.y,L2.u)             annotation (points=[1,0; 8,0],   style(
              color=3));
        connect(S1.y,TF1.u)             annotation (points=[-29,50; -22,50],
            style(color=3));
        connect(C1.y,S1.u2)             annotation (points=[-59,30; -56,30; -56,
              44; -52,44],      style(color=3));
        connect(u,S1.u1)            annotation (points=[-120,0; -90,0; -90,56;
              -52,56],      style(color=3));
        connect(C2.y,S2.u2)             annotation (points=[-59,-20; -56,-20;
              -56,-6; -52,-6],     style(color=3));
        connect(u,S2.u1)            annotation (points=[-120,0; -56,0; -56,6;
              -52,6],    style(color=3));
        connect(S2.y,TF2.u)             annotation (points=[-29,0; -22,0],
            style(color=3));
        connect(L1.y,A1.u1)             annotation (points=[31,50; 34,50; 34,30;
              38,30],        style(color=3));
        connect(L2.y,A1.u2)             annotation (points=[31,0; 34,0; 34,18;
              38,18],      style(color=3));
        connect(A1.y,G1.u)             annotation (points=[61,24; 70,24; 70,-24;
              -10,-24; -10,-50; -2,-50],         style(color=3));
        connect(G1.y,Division1.u1)             annotation (points=[21,-50; 28,
              -50; 28,-64; 38,-64],     style(color=3));
        connect(u,Division1.u2)            annotation (points=[-120,0; -90,0;
              -90,-76; 38,-76],     style(color=3));
        connect(Division1.y,y)              annotation (points=[61,-70; 88,-70;
              88,0; 110,0],       style(color=3));
      end AirConditioning;
      
      block SolarPosition "Solar position in the sky" 
        extends Modelica.Blocks.Interfaces.SISO;
        constant Real pi=Modelica.Constants.pi;
        parameter Real lon=111 "Longitude in degrees";
        parameter Real lat=32 "Latitude in degrees";
        parameter Real lsm=105;
        parameter Real sfa "Orientation of surface in dgerees";
        parameter Real tilt "Tilt of surface in degrees";
        parameter Real latr=pi*lat/180 "Latitude in radians";
        parameter Real sfar=pi*sfa/180 "Orientation in radians";
        parameter Real tiltr=pi*tilt/180 "Tilt in radians";
        output Real h "Height";
        output Real dec "Declination";
        output Real inc1;
        output Real inc2;
        output Real inc3;
        output Real inc "Inclination";
        output Real alt "Altitude";
        output Real Time;
        output Real ETime;
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(
            Ellipse(extent=[-24, 24; 26, -26]),
            Polygon(points=[-66, 32; -18, 16; -36, 66; -6, 24; -6, 22; 2, 76; 8,
                    22; 44, 64; 20, 14; 70, 36; 26, 4; 78, -2; 26, -8; 70, -36;
                    18, -18; 38, -68; 8, -26; 2, -78; -6, -24; -38, -66; -18, -
                  20; -64, -38; -22, -8; -74, -2; -24, 2; -66, 32], style(color=
                   41, fillColor=49)),
            Text(extent=[92, 36; 132, 12], string="inc"),
            Text(extent=[90, -26; 130, -50], string="alt")),
          Diagram(
            Line(points=[-144, 28; -98, 28], style(color=9)),
            Line(points=[-108, 34; -98, 28; -108, 22], style(color=9)),
            Line(points=[118, 26; 128, 20; 118, 14], style(color=9)),
            Line(points=[82, 20; 128, 20], style(color=9)),
            Line(points=[118, -34; 128, -40; 118, -46], style(color=9)),
            Line(points=[82, -40; 128, -40], style(color=9)),
            Text(
              extent=[-144, 40; -104, 28],
              string="Time",
              style(color=9)),
            Text(
              extent=[78, 32; 118, 20],
              string="Inclination",
              style(color=9)),
            Text(
              extent=[78, -28; 118, -40],
              string="Altitude",
              style(color=9)),
            Rectangle(extent=[-4, 16; 80, -76], style(color=57)),
            Text(
              extent=[6, 6; 70, -12],
              string="Spherical",
              style(color=57)),
            Text(
              extent=[2, -12; 72, -28],
              string="Trigonometry",
              style(color=53)),
            Line(points=[-38, 0; -4, 0], style(color=57)),
            Line(points=[-82, 0; -82, -38; -4, -38], style(color=57)),
            Line(points=[80, 0; 100, 0], style(color=57)),
            Line(points=[80, -60; 100, -60], style(color=57)),
            Text(
              extent=[-40, 10; -6, 0],
              string="ETime",
              style(color=53))),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This block computes the postion of the sun in the sky using spherical trigonometry.
</html>
"));
        Modelica.Blocks.Interfaces.RealOutput OutPort1 
                                                    annotation (extent=[100, -
              70; 120, -50]);
        TableLookup ET1(x_vals={0,480,1224,1896,2640,3360,4104,4824,5568,6312,
              7032,7776,8496,8760}, y_vals={-6.4,-11.2,-13.9,-7.5,1.1,3.3,-1.4,
              -6.2,-2.4,7.5,15.4,13.8,1.6,-6.4}) annotation (extent=[-58, -10;
              -38, 10]);
      equation 
        connect(u,ET1.u)            annotation (points=[-120,0; -60,0],   style(
             color=3));
        Time = u;
        ETime = ET1.y;
        h = (pi/12)*(Time - 12 + ETime/60 + (lsm - lon)/15);
        dec = (pi/180)*23.45*sin(2*pi*(284 + Time/24)/365);
        inc1 = sin(dec)*sin(latr)*cos(tiltr) - sin(dec)*cos(latr)*sin(tiltr)*
          cos(sfar);
        inc2 = cos(dec)*cos(latr)*cos(tiltr)*cos(h) + cos(dec)*sin(latr)*sin(
          tiltr)*cos(sfar)*cos(h);
        inc3 = cos(dec)*sin(tiltr)*sin(sfar)*sin(h);
        inc = inc1 + inc2 + inc3;
        alt = cos(latr)*cos(dec)*cos(h) + sin(latr)*sin(dec);
        y = inc;
        OutPort1           = alt;
      end SolarPosition;
      
      block SolarRadiation "Solar radiation" 
        extends Modelica.Blocks.Interfaces.SISO;
        constant Real pi=Modelica.Constants.pi;
        parameter Real sc=1353;
        parameter Real tilt "Tilt of surface in degrees";
        parameter Real tiltr=pi*tilt/180 "Tilt in radians";
        parameter Real ro=0.33;
        parameter Real cr=1 "Direct light gain factor";
        parameter Real cf=1 "Diffuse light gain factor";
        parameter Real absor "Absorption coefficient";
        parameter Real area "Area of exposed surface";
        parameter Real OH;
        parameter Real W;
        output Real altL "Limited altitude value";
        output Real sou;
        output Real idn;
        output Real dir "Direct light";
        output Real dif "Diffuse light";
        output Real inc "Inclination";
        output Real alt "Altitude";
        output Real Time;
        output Real BTime;
        output Real CTime;
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Text(
              extent=[-144, -46; -108, -68],
              string="alt",
              style(color=49)),
            Text(
              extent=[-144, 10; -108, -12],
              string="inc",
              style(color=49)),
            Line(points=[90, 20; 126, 20], style(color=9)),
            Line(points=[116, 26; 126, 20; 116, 14], style(color=9)),
            Text(
              extent=[88, 32; 114, 20],
              string="Entropy",
              style(color=9)),
            Text(
              extent=[28, -12; 46, -16],
              string="Entropy",
              style(color=9)),
            Text(
              extent=[28, -16; 46, -20],
              string="Output",
              style(color=9)),
            Text(
              extent=[-2, 10; 16, 6],
              string="Heat",
              style(color=9)),
            Text(
              extent=[-2, 6; 16, 2],
              string="Output",
              style(color=9)),
            Text(
              extent=[-72, -96; -42, -100],
              string="Direct Light",
              style(color=9)),
            Text(
              extent=[-40, -96; -10, -100],
              string="Diffuse Light",
              style(color=9))),
          Icon(
            Ellipse(extent=[-24, 24; 26, -26]),
            Polygon(points=[-66, 32; -18, 16; -36, 66; -6, 24; -6, 22; 2, 76; 8,
                    22; 44, 64; 20, 14; 70, 36; 26, 4; 78, -2; 26, -8; 70, -36;
                    18, -18; 38, -68; 8, -26; 2, -78; -6, -24; -38, -66; -18, -
                  20; -64, -38; -22, -8; -74, -2; -24, 2; -66, 32], style(color=
                   41, fillColor=49)),
            Line(points=[16, -52; 22, -92], style(color=41, thickness=2)),
            Line(points=[44, -42; 78, -78], style(color=41, thickness=2)),
            Line(points=[62, -16; 92, -24], style(color=41, thickness=2)),
            Line(points=[60, -22; 90, -34], style(color=41, thickness=2)),
            Line(points=[48, -36; 88, -62], style(color=41, thickness=2)),
            Line(points=[38, -52; 64, -90], style(color=41, thickness=2)),
            Line(points=[22, -54; 36, -90], style(color=41, thickness=2)),
            Text(
              extent=[-126, -30; -100, -46],
              string="alt",
              style(color=9)),
            Text(
              extent=[-126, 30; -100, 14],
              string="inc",
              style(color=9)),
            Text(
              extent=[10, 96; 36, 80],
              string="Time",
              style(color=9)),
            Text(
              extent=[-42, -80; -12, -98],
              string="Temp",
              style(color=9)),
            Text(
              extent=[88, 32; 114, 20],
              string="Entropy",
              style(color=9)),
            Line(points=[116, 26; 126, 20; 116, 14], style(color=9)),
            Line(points=[126, 20; 86, 20], style(color=9))),
          Window(
            x=0.01,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This block computes the solar radiation available to any sun-exposed surface on the basis of the position of the sun in the sky and the relative angle at which the exposed surface faces the sun.  Also used are the color of the exposed surface (absorption coefficient). <p>

The model is fairly complex.  It calculates not only the direct radiation from the sun, but also the diffuse radiation received through the atmosphere.
</html>
"));
        Modelica.Blocks.Interfaces.RealInput InPort1 
                                                  annotation (extent=[-140, -80;
                -100, -40]);
        Modelica.Blocks.Interfaces.RealInput TimePort 
                                                   annotation (extent=[-10, 80;
                10, 100], rotation=-90);
        Modelica.Blocks.Interfaces.RealInput TempPort 
                                                   annotation (extent=[-10, -
              100; 10, -80], rotation=90);
        Modelica.Blocks.Nonlinear.Limiter L2(uMax=1E10, uMin=0)     annotation (
           extent=[70, -10; 90, 10]);
        Modelica.Blocks.Nonlinear.Limiter altLim(uMax=10, uMin=0.05) 
          annotation (extent=[-80, 60; -60, 80]);
        Modelica.Blocks.Nonlinear.Limiter Ldir(uMax=1E10, uMin=0) 
          annotation (extent=[-66, -90; -46, -70], rotation=90);
        Modelica.Blocks.Nonlinear.Limiter Ldif(uMax=1E10, uMin=0) 
          annotation (extent=[-36, -90; -16, -70], rotation=90);
        Modelica.Blocks.Math.Product P1 annotation (extent=[40, -10; 60, 10]);
        Modelica.Blocks.Math.Division D1 annotation (extent=[10, -20; 30, 0]);
        Modelica.Blocks.Math.Add A1 annotation (extent=[-50, -30; -30, -10],
            rotation=90);
        Modelica.Blocks.Math.Gain Absorption(k=absor)   annotation (extent=[-20,
                -10; 0, 10]);
        Modelica.Blocks.Math.Gain Gdif(k=cf)   annotation (extent=[-36, -60; -
              16, -40], rotation=90);
        Modelica.Blocks.Math.Gain Gdir(k=cr)   annotation (extent=[-66, -60; -
              46, -40], rotation=90);
        Modelica.Blocks.Math.Sign altSign annotation (extent=[-80, 20; -60, 40]);
        TableLookup BT1(x_vals={0,480,1224,1896,2640,3360,4104,4824,5568,6312,
              7032,7776,8496,8760}, y_vals={0.14,0.142,0.144,0.156,0.18,0.196,
              0.205,0.207,0.201,0.177,0.16,0.149,0.142,0.14}) annotation (
            extent=[40, 60; 60, 80]);
        TableLookup CT1(x_vals={0,480,1224,1896,2640,3360,4104,4824,5568,6312,
              7032,7776,8496,8760}, y_vals={0.057,0.058,0.06,0.071,0.097,0.121,
              0.134,0.136,0.122,0.092,0.073,0.063,0.057,0.057}) annotation (
            extent=[40, 30; 60, 50]);
      equation 
        connect(L2.y,y)              annotation (points=[91,0; 110,0],   style(
              color=3));
        connect(P1.y,L2.u)             annotation (points=[61,0; 68,0],   style(
             color=3));
        connect(D1.y,P1.u2)             annotation (points=[31,-10; 34,-10; 34,
              -6; 38,-6],      style(color=3));
        connect(TempPort,D1.u2)       annotation (points=[0,-90; 0,-16; 8,-16],
                   style(color=3));
        connect(Absorption.y,D1.u1)             annotation (points=[1,0; 4,0; 4,
              -4; 8,-4],       style(color=3));
        connect(A1.y,Absorption.u)             annotation (points=[-40,-9; -40,
              0; -22,0],    style(color=3));
        connect(Gdif.y,A1.u2)             annotation (points=[-26,-39; -34,-39;
              -34,-32],      style(color=3));
        connect(Gdir.y,A1.u1)             annotation (points=[-56,-39; -46,-39;
              -46,-32],      style(color=3));
        connect(Ldif.y,Gdif.u)             annotation (points=[-26,-69; -26,-62],
                   style(color=3));
        connect(Ldir.y,Gdir.u)             annotation (points=[-56,-69; -56,-62],
                   style(color=3));
        connect(altSign.y,P1.u1)             annotation (points=[-59,30; 30,30;
              30,6; 38,6],       style(color=3));
        connect(InPort1,altSign.u)       annotation (points=[-120,-60; -90,-60;
              -90,30; -82,30],       style(color=3));
        connect(InPort1,altLim.u)       annotation (points=[-120,-60; -90,-60;
              -90,70; -82,70],     style(color=3));
        connect(TimePort,BT1.u)       annotation (points=[0,90; 0,70; 38,70],
              style(color=3));
        connect(TimePort,CT1.u)       annotation (points=[0,90; 0,40; 38,40],
              style(color=3));
        Time =TimePort;
        BTime = BT1.y;
        CTime = CT1.y;
        altL = altLim.y;
        inc = u;
        alt =InPort1;
        sou = sc*(1 + 0.033*cos(2*pi*(Time/24)/365.));
        idn = sou/exp(BTime/altL);
        dir = idn*inc*(area - OH*W*(alt/sqrt(1 - alt*alt)));
        dif = idn*area*(CTime*(1 + cos(tiltr))/2 + (CTime + alt)*ro*(1 - cos(
          tiltr))/2);
        Ldir.u = dir;
        Ldif.u = dif;
      end SolarRadiation;
      
      block SolarGlass "Solar radiation through glass" 
        extends Modelica.Blocks.Interfaces.SISO;
        constant Real pi=Modelica.Constants.pi;
        parameter Real sc;
        parameter Real tilt "Tilt of surface in degrees";
        parameter Real tiltr=pi*tilt/180 "Tilt in radians";
        parameter Real ro=0.33;
        parameter Real cr=1 "Direct light gain factor";
        parameter Real cf=1 "Diffuse light gain factor";
        parameter Real hi=8.3;
        parameter Real ho=22.7;
        parameter Real area "Area of exposed surface";
        parameter Real OH;
        parameter Real W;
        output Real altL "Limited altitude value";
        output Real idn;
        output Real dir "Direct light";
        output Real dif "Diffuse light";
        output Real inc "Inclination";
        output Real alt "Altitude";
        output Real Time;
        output Real ATime;
        output Real BTime;
        output Real CTime;
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[1, 1],
            component=[10, 10]),
          Icon(
            Rectangle(extent=[-100, -100; 100, 100], style(color=3, fillColor=7)),
            Ellipse(extent=[-24, 24; 26, -26]),
            Polygon(points=[-66, 32; -18, 16; -36, 66; -6, 24; -6, 22; 2, 76; 8,
                    22; 44, 64; 20, 14; 70, 36; 26, 4; 78, -2; 26, -8; 70, -36;
                    18, -18; 38, -68; 8, -26; 2, -78; -6, -24; -38, -66; -18, -
                  20; -64, -38; -22, -8; -74, -2; -24, 2; -66, 32], style(color=
                   41, fillColor=49)),
            Line(points=[16, -52; 22, -92], style(color=41, thickness=2)),
            Line(points=[44, -42; 78, -78], style(color=41, thickness=2)),
            Line(points=[62, -16; 92, -24], style(color=41, thickness=2)),
            Line(points=[60, -22; 90, -34], style(color=41, thickness=2)),
            Line(points=[48, -36; 88, -62], style(color=41, thickness=2)),
            Line(points=[38, -52; 64, -90], style(color=41, thickness=2)),
            Line(points=[22, -54; 36, -90], style(color=41, thickness=2)),
            Text(
              extent=[-126, -30; -100, -46],
              string="alt",
              style(color=9)),
            Text(
              extent=[-126, 30; -100, 14],
              string="inc",
              style(color=9)),
            Text(
              extent=[10, 96; 36, 80],
              string="Time",
              style(color=9)),
            Text(
              extent=[88, 32; 114, 20],
              string="Entropy",
              style(color=9)),
            Line(points=[116, 26; 126, 20; 116, 14], style(color=9)),
            Line(points=[126, 20; 86, 20], style(color=9)),
            Text(
              extent=[-42, -80; -12, -98],
              string="Temp",
              style(color=9)),
            Line(points=[38, 2; 38, 8; 96, -2; 96, -100], style(color=57,
                  thickness=2)),
            Line(points=[38, -6; 38, -16], style(color=53, thickness=2)),
            Line(points=[38, -26; 38, -88; 96, -100], style(color=53, thickness=
                   2))),
          Diagram(
            Text(
              extent=[-125, 26; -100, 11],
              string="inc",
              style(color=9)),
            Text(
              extent=[-123, -38; -98, -53],
              string="alt",
              style(color=9)),
            Text(
              extent=[-88, -1; -80, -4],
              string="direct",
              style(color=9)),
            Text(
              extent=[-88, -4; -80, -7],
              string="light",
              style(color=9)),
            Text(
              extent=[44, -6; 55, -9],
              string="diffuse",
              style(color=9)),
            Text(
              extent=[45, -10; 53, -13],
              string="light",
              style(color=9))),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This block computes the solar radiation available to any sun-exposed glass surface on the basis of the position of the sun in the sky and the relative angle at which the exposed surface faces the sun.  Glass windows require a special model, because some of the incoming radiation is directly transmitted through the glass. <p>

The model is fairly complex.  It calculates not only the direct radiation from the sun, but also the diffuse radiation received through the atmosphere.
</html>
"));
        Modelica.Blocks.Interfaces.RealInput InPort1 
                                                  annotation (extent=[-140, -80;
                -100, -40], layer="icon");
        Modelica.Blocks.Interfaces.RealInput TempPort 
                                                   annotation (extent=[-10, -
              100; 10, -80], rotation=90);
        Modelica.Blocks.Interfaces.RealInput TimePort 
                                                   annotation (extent=[-10, 80;
                10, 100], rotation=-90);
        DirectGlassTransmission DirectGlassTransmission1 annotation (extent=[-
              80, 20; -60, 40]);
        DirectGlassAbsorption DirectGlassAbsorption1 annotation (extent=[-80, -
              60; -60, -40]);
        Modelica.Blocks.Nonlinear.Limiter Ldir(uMax=1E10, uMin=0) 
          annotation (extent=[-75, -10; -65, 0]);
        Modelica.Blocks.Math.Gain Gdir(k=cr)   annotation (extent=[-60, -10; -
              50, 0]);
        Modelica.Blocks.Math.Product P1 annotation (extent=[-40, 25; -30, 35]);
        Modelica.Blocks.Math.Product P2 annotation (extent=[-40, -55; -30, -45]);
        Modelica.Blocks.Math.Add A1 annotation (extent=[-20, 22; -10, 32]);
        Modelica.Blocks.Math.Add A2 annotation (extent=[-20, -52; -10, -42]);
        Modelica.Blocks.Math.Product P3 annotation (extent=[-10, 0; -20, 10]);
        Modelica.Blocks.Math.Product P4 annotation (extent=[-10, -30; -20, -20]);
        DiffuseGlassTransmission DiffuseGlassTransmission1 annotation (extent=[
              20, -2; 0, 18]);
        DiffuseGlassAbsorption DiffuseGlassAbsorption1 annotation (extent=[20,
              -38; 0, -18]);
        Modelica.Blocks.Math.Gain Gdif(k=2*cf)   annotation (extent=[40, -15;
              30, -5]);
        Modelica.Blocks.Math.Gain G1(k=hi/(hi + ho))   annotation (extent=[26,
              -54; 40, -40]);
        Modelica.Blocks.Math.Add A3 annotation (extent=[51, -49; 61, -39]);
        Modelica.Blocks.Math.Division Division1 annotation (extent=[5, -75; 15,
                -65]);
        Modelica.Blocks.Math.Gain G2(k=sc)   annotation (extent=[-15, -75; -5,
              -65]);
        Modelica.Blocks.Nonlinear.Limiter L1(uMax=1E10, uMin=0)     annotation (
           extent=[25, -75; 35, -65]);
        Modelica.Blocks.Math.Product P5 annotation (extent=[45, -78; 55, -68]);
        Modelica.Blocks.Math.Sign altSig annotation (extent=[-70, -95; -60, -85]);
        Modelica.Blocks.Nonlinear.Limiter L2(uMax=1E10, uMin=0)     annotation (
           extent=[65, -78; 75, -68]);
        Modelica.Blocks.Nonlinear.Limiter altLim(uMax=10, uMin=0.05) 
          annotation (extent=[-70, -75; -60, -65]);
        TableLookup BT1(x_vals={0,480,1224,1896,2640,3360,4104,4824,5568,6312,
              7032,7776,8496,8760}, y_vals={0.14,0.142,0.144,0.156,0.18,0.196,
              0.205,0.207,0.201,0.177,0.16,0.149,0.142,0.14}) annotation (
            extent=[30, 55; 45, 70]);
        TableLookup CT1(x_vals={0,480,1224,1896,2640,3360,4104,4824,5568,6312,
              7032,7776,8496,8760}, y_vals={0.057,0.058,0.06,0.071,0.097,0.121,
              0.134,0.136,0.122,0.092,0.073,0.063,0.057,0.057}) annotation (
            extent=[30, 33; 45, 48]);
        TableLookup AT1(x_vals={0,480,1224,1896,2640,3360,4104,4824,5568,6312,
              7032,7776,8496,8760}, y_vals={1232,1230,1214,1185,1135,1103,1088,
              1085,1107,1151,1192,1220,1233,1232}) annotation (extent=[30, 80;
              45, 95]);
      equation 
        connect(u,DirectGlassTransmission1.u)            annotation (points=[
              -120,0; -90,0; -90,30; -82,30],    style(color=3));
        connect(u,DirectGlassAbsorption1.u)            annotation (points=[-120,
              0; -90,0; -90,-50; -82,-50],      style(color=3));
        connect(Ldir.y,Gdir.u)             annotation (points=[-64.5,-5; -61,-5],
                   style(color=3));
        connect(DirectGlassTransmission1.y,P1.u1)             annotation (
            points=[-59,30; -50,30; -50,33; -41,33],     style(color=3));
        connect(Gdir.y,P1.u2)             annotation (points=[-49.5,-5; -45,-5;
              -45,27; -41,27],     style(color=3));
        connect(DirectGlassAbsorption1.y,P2.u2)             annotation (points=[
              -59,-50; -50,-50; -50,-53; -41,-53],      style(color=3));
        connect(Gdir.y,P2.u1)             annotation (points=[-49.5,-5; -45,-5;
              -45,-47; -41,-47],     style(color=3));
        connect(P1.y,A1.u1)             annotation (points=[-29.5,30; -21,30],
            style(color=3));
        connect(P2.y,A2.u2)             annotation (points=[-29.5,-50; -21,-50],
              style(color=3));
        connect(P3.y,A1.u2)             annotation (points=[-20.5,5; -25,5; -25,
              24; -21,24],    style(color=3));
        connect(P4.y,A2.u1)             annotation (points=[-20.5,-25; -25,-25;
              -25,-44; -21,-44],     style(color=3));
        connect(DiffuseGlassTransmission1.y,P3.u1)             annotation (
            points=[-1,8; -9,8],   style(color=3));
        connect(DiffuseGlassAbsorption1.y,P4.u2)             annotation (points=[-1,
              -28; -9,-28],      style(color=3));
        connect(Gdif.y,P3.u2)             annotation (points=[29.5,-10; -6,-10;
              -6,2; -9,2],     style(color=3));
        connect(Gdif.y,P4.u1)             annotation (points=[29.5,-10; -6,-10;
              -6,-22; -9,-22],     style(color=3));
        connect(A2.y,G1.u)             annotation (points=[-9.5,-47; 24.6,-47],
              style(color=3));
        connect(G1.y,A3.u2)             annotation (points=[40.7,-47; 50,-47],
            style(color=3));
        connect(A1.y,A3.u1)             annotation (points=[-9.5,27; 56,27; 56,
              -26; 44,-26; 44,-41; 50,-41],      style(color=3));
        connect(TempPort,Division1.u2)       annotation (points=[0,-90; 0,-73;
              4,-73],    style(color=3));
        connect(G2.y,Division1.u1)             annotation (points=[-4.5,-70; 0,
              -70; 0,-67; 4,-67],   style(color=3));
        connect(A3.y,G2.u)             annotation (points=[61.5,-44; 65,-44; 65,
              -60; -20,-60; -20,-70; -16,-70],      style(color=3));
        connect(Division1.y,L1.u)             annotation (points=[15.5,-70; 24,
              -70], style(color=3));
        connect(L1.y,P5.u1)             annotation (points=[35.5,-70; 44,-70],
            style(color=3));
        connect(P5.y,L2.u)             annotation (points=[55.5,-73; 64,-73],
            style(color=3));
        connect(L2.y,y)              annotation (points=[75.5,-73; 90,-73; 90,0;
              110,0],     style(color=3));
        connect(InPort1,altSig.u)       annotation (points=[-120,-60; -90,-60;
              -90,-90; -71,-90],     style(color=3));
        connect(altSig.y,P5.u2)             annotation (points=[-59.5,-90; 40,
              -90; 40,-76; 44,-76],  style(color=3));
        connect(InPort1,altLim.u)       annotation (points=[-120,-60; -90,-60;
              -90,-70; -71,-70],     style(color=3));
        connect(TimePort,BT1.u)       annotation (points=[0,90; 0,62.5; 28.5,
              62.5],
              style(color=3));
        connect(TimePort,CT1.u)       annotation (points=[0,90; 0,63; 15,63; 15,
              40.5; 28.5,40.5],  style(color=3));
        connect(TimePort,AT1.u)       annotation (points=[0,90; 0,63; 15,63; 15,
              87.5; 28.5,87.5],  style(color=3));
        Time =TimePort;
        ATime = AT1.y;
        BTime = BT1.y;
        CTime = CT1.y;
        altL = altLim.y;
        inc = u;
        alt =InPort1;
        idn = ATime/exp(BTime/altL);
        dir = idn*inc*(area - OH*W*(alt/sqrt(1 - alt*alt)));
        dif = idn*area*(CTime*(1 + cos(tiltr))/2 + (CTime + alt)*ro*(1 - cos(
          tiltr))/2);
        Ldir.u = dir;
        Gdif.u = dif;
      end SolarGlass;
      
      block DirectGlassAbsorption 
        "Absorption coefficient of glass for direct solar radiation" 
        extends Modelica.Blocks.Interfaces.SISO;
        output Real inc "Inclination";
        output Real absor "Absorption";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Text(
              extent=[-140, 8; -114, -10],
              string="inc",
              style(color=49)),
            Text(extent=[-60, 78; 60, 38], string="Absorption of"),
            Text(extent=[-80, 38; 82, -2], string="direct solar radiation"),
            Text(extent=[-60, -2; 60, -42], string="for DSA glass")),
          Icon(
            Text(extent=[-60, 0; 60, -40], string="for DSA glass"),
            Text(extent=[-80, 40; 82, 0], string="direct solar radiation"),
            Text(extent=[-60, 80; 60, 40], string="Absorption of"),
            Text(
              extent=[-140, 8; -114, -10],
              string="inc",
              style(color=49))),
          Documentation(info="<html>
This auxiliary block computes the absorption coefficient for glass with respect to direct solar radiation.
</html>
"));
      equation 
        inc = u;
        absor = 0.01154 + 0.77674*inc - 3.94657*inc*inc + 8.57881*inc^3 -
          8.38135*inc^4 + 3.01188*inc^5;
        y = absor;
      end DirectGlassAbsorption;
      
      block DiffuseGlassAbsorption 
        "Absorption coefficient of glass for diffuse solar radiation" 
        extends Modelica.Blocks.Interfaces.SO;
        output Real absor "Absorption";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Text(extent=[-60, 80; 60, 40], string="Absorption of"),
            Text(extent=[-80, 40; 82, 0], string="diffuse solar radiation"),
            Text(extent=[-60, 0; 60, -40], string="for DSA glass")),
          Icon(
            Text(extent=[-60, 80; 60, 40], string="Absorption of"),
            Text(extent=[-80, 40; 82, 0], string="diffuse solar radiation"),
            Text(extent=[-60, 0; 60, -40], string="for DSA glass")),
          Documentation(info="<html>
This auxiliary block computes the absorption coefficient for glass with respect to diffuse solar radiation.
</html>
"));
      equation 
        absor = 0.01154/2 + 0.77674/3 - 3.94657/4 + 8.57881/5 - 8.38135/6 +
          3.01188/7;
        y = absor;
      end DiffuseGlassAbsorption;
      
      block DirectGlassTransmission 
        "Transmission coefficient of glass for direct solar radiation" 
        extends Modelica.Blocks.Interfaces.SISO;
        output Real inc "Inclination";
        output Real trans "Transmission";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Text(extent=[-60, 78; 60, 38], string="Transmission of"),
            Text(extent=[-80, 38; 82, -2], string="direct solar radiation"),
            Text(extent=[-60, -2; 60, -42], string="for DSA glass"),
            Text(
              extent=[-140, 8; -114, -10],
              string="inc",
              style(color=49))),
          Icon(
            Text(extent=[-60, 78; 60, 38], string="Transmission of"),
            Text(extent=[-80, 38; 82, -2], string="direct solar radiation"),
            Text(extent=[-60, -2; 60, -42], string="for DSA glass"),
            Text(
              extent=[-140, 8; -114, -10],
              string="inc",
              style(color=49))),
          Documentation(info="<html>
This auxiliary block computes the transmission coefficient for glass with respect to direct solar radiation.
</html>
"));
      equation 
        inc = u;
        trans = -0.00885 + 2.71235*inc - 0.62062*inc*inc - 7.07329*inc^3 +
          9.75995*inc^4 - 3.89922*inc^5;
        y = trans;
      end DirectGlassTransmission;
      
      block DiffuseGlassTransmission 
        "Transmission coefficient of glass for diffuse solar radiation" 
        extends Modelica.Blocks.Interfaces.SO;
        output Real trans "Transmission";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Text(extent=[-60, 78; 60, 38], string="Transmission of"),
            Text(extent=[-80, 38; 82, -2], string="diffuse solar radiation"),
            Text(extent=[-60, -2; 60, -42], string="for DSA glass")),
          Icon(
            Text(extent=[-60, 78; 60, 38], string="Transmission of"),
            Text(extent=[-80, 38; 82, -2], string="diffuse solar radiation"),
            Text(extent=[-60, -2; 60, -42], string="for DSA glass")),
          Documentation(info="<html>
This auxiliary block computes the transmission coefficient for glass with respect to diffuse solar radiation.
</html>
"));
      equation 
        trans = -0.00885/2 + 2.71235/3 - 0.62062/4 - 7.07329/5 + 9.75995/6 -
          3.89922/7;
        y = trans;
      end DiffuseGlassTransmission;
      
      model C1D "Heat conduction through wall" 
        extends BondLib.Interfaces.TwoPort;
        parameter Real theta "Thermal Resistance";
        parameter Real gamma "Thermal Capacity";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-78, 52; 78, -54],
              string="C1D",
              style(color=0, pattern=0)), Text(extent=[-70, 90; 70, 50], string=
                 "%name")),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
The heat conduction model used here is the directed (why not) heat exchanger model of the bond graph library with an additional heat capacity built in at the output node.  In this way, walls can be subdivided into layers, possibly consisting of different material, with heat conduction models cascaded without a need for attaching heat capacitors externally, except at the very first node. <p>

Heat capacitors were attached only at one side, because otherwise, higher index models result when such models get cascaded.  Although Modelica is perfectly capable of reducing the perturbation index on its own, this would only have slowed down the compilation of the model unnecessarily.
</html>
"));
        BondLib.Bonds.fBond B1 annotation (extent=[-60, -10; -40, 10]);
        BondLib.Bonds.fBond B3 annotation (extent=[-20, 30; 0, 50]);
        BondLib.Bonds.eBond B2 annotation (extent=[0, -10; 20, 10]);
        BondLib.Bonds.eBond B4 annotation (extent=[20, 30; 40, 50]);
        BondLib.Bonds.eBond B5 annotation (extent=[40, -30; 60, -10], rotation=
              -90);
        BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-40, 10; -20, -10]);
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[-80, -10; -60, 10]);
        BondLib.Junctions.J0p4 J0p4_1 annotation (extent=[40, -10; 60, 10]);
        BondLib.Thermal.RSth RSth1(theta=theta) annotation (extent=[0, 30; 20,
              50]);
        BondLib.Thermal.Cth Cth1(gamma=gamma, e(start=288)) annotation (extent=
              [40, -50; 60, -30], rotation=-90);
      equation 
        connect(BondCon1, J0p2_1.BondCon1) annotation (points=[-100,0; -80,0],
              style(color=8));
        connect(J0p2_1.BondCon2, B1.eBondCon1) annotation (points=[-60, 0; -60,
                0], style(color=8));
        connect(B1.fBondCon1, J1p3_1.BondCon1) annotation (points=[-40, 0; -40,
                0], style(color=8));
        connect(J1p3_1.BondCon3, B3.eBondCon1) annotation (points=[-30, 10; -30,
                40; -20, 40], style(color=8));
        connect(B3.fBondCon1, RSth1.BondCon1) annotation (points=[0, 40; 0, 40],
              style(color=8));
        connect(RSth1.BondCon2, B4.fBondCon1) annotation (points=[20, 40; 20,
              40], style(color=8));
        connect(B4.eBondCon1, J0p4_1.BondCon4) annotation (points=[40, 40; 50,
              40; 50, 10], style(color=8));
        connect(J1p3_1.BondCon2, B2.fBondCon1) annotation (points=[-20, 0; 0, 0],
                 style(color=8));
        connect(B2.eBondCon1, J0p4_1.BondCon1) annotation (points=[20, 0; 40, 0],
                 style(color=8));
        connect(J0p4_1.BondCon3, B5.fBondCon1) annotation (points=[50, -10; 50,
                -10], style(color=8));
        connect(B5.eBondCon1, Cth1.BondCon1) annotation (points=[50, -30; 50, -
              30], style(color=8));
        connect(J0p4_1.BondCon2, BondCon2) annotation (points=[60,0; 100,0],
            style(color=8));
      end C1D;
      
      model C1V "Heat convection in boundary layer" 
        extends BondLib.Interfaces.TwoPort;
        parameter Real theta "Thermal Resistance";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-78, 52; 78, -54],
              string="C1V",
              style(color=0, pattern=0)), Text(extent=[-70, 90; 70, 50], string=
                 "%name")),
          Window(
            x=0.03,
            y=0.02,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This model is the regular directed heat exchanger model, <b>HEr</b>, of the bond graph library.  However, we have duplicated the model here under a different name, in order to be able to provide meaningful documentation for its use. <p>

In thermal building models, it is customary to assume that there is a special convection layer in the air neighboring each wall.  Our model follows this tradition, and offers convection in the boundary layer of air next to each wall.
</html>
"));
        BondLib.Bonds.fBond B1 annotation (extent=[-60, -10; -40, 10]);
        BondLib.Bonds.fBond B3 annotation (extent=[-20, 30; 0, 50]);
        BondLib.Bonds.eBond B2 annotation (extent=[0, -10; 20, 10]);
        BondLib.Bonds.eBond B4 annotation (extent=[20, 30; 40, 50]);
        BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-40, 10; -20, -10]);
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[-80, -10; -60, 10]);
        BondLib.Thermal.RSth RSth1(theta=theta) annotation (extent=[0, 30; 20,
              50]);
        BondLib.Junctions.J0p3 J0p3_1 annotation (extent=[40, 10; 60, -10]);
      equation 
        connect(J0p2_1.BondCon2, B1.eBondCon1) annotation (points=[-60, 0; -60,
                0], style(color=8));
        connect(B1.fBondCon1, J1p3_1.BondCon1) annotation (points=[-40, 0; -40,
                0], style(color=8));
        connect(J1p3_1.BondCon3, B3.eBondCon1) annotation (points=[-30, 10; -30,
                40; -20, 40], style(color=8));
        connect(B3.fBondCon1, RSth1.BondCon1) annotation (points=[0, 40; 0, 40],
              style(color=8));
        connect(RSth1.BondCon2, B4.fBondCon1) annotation (points=[20, 40; 20,
              40], style(color=8));
        connect(J1p3_1.BondCon2, B2.fBondCon1) annotation (points=[-20, 0; 0, 0],
                 style(color=8));
        connect(BondCon1, J0p2_1.BondCon1) annotation (points=[-100,0; -80,0],
              style(color=8));
        connect(B4.eBondCon1, J0p3_1.BondCon3) annotation (points=[40, 40; 50,
              40; 50, 10], style(color=8));
        connect(B2.eBondCon1, J0p3_1.BondCon1) annotation (points=[20, 0; 40, 0],
                 style(color=8));
        connect(J0p3_1.BondCon2, BondCon2) annotation (points=[60,0; 100,0],
            style(color=8));
      end C1V;
      
      model ExWall "Exterior wall" 
        extends BondLib.Interfaces.ActiveOnePort;
        parameter Real lv1=22.7 
          "Specific thermal conductance of convection outside";
        parameter Real dxv1=1 "Width of convective layer outside";
        parameter Real area "Area of external wall";
        parameter Real thv1=dxv1/(lv1*area) 
          "Thermal resistance of convection outside";
        parameter Real ld=1.7 "Specific thermal conductance of dry wall";
        parameter Real dxd=0.14 "Thickness of conduction layer";
        parameter Real theta=dxd/(ld*area) 
          "Thermal resistance of dry wall layer";
        parameter Real lv2=8.3 
          "Specific thermal conductance of convection inside";
        parameter Real dxv2=1 "Width of convective layer inside";
        parameter Real thv2=dxv2/(lv2*area) 
          "Thermal resistance of convection inside";
        parameter Real c=840 "Specific heat capacity of dry wall";
        parameter Real dens=1762 "Density of external wall";
        parameter Real thk=0.41 "Thickness of external wall";
        parameter Real m=area*thk*dens/4 "Mass of external wall segment";
        parameter Real gamma=c*m/3600 "Heat capacity of external wall segment";
        parameter Real sfa "Orientation of wall";
        parameter Real tilt=90 "Tilt of wall";
        parameter Real OH;
        parameter Real W;
        parameter Real absor=0.5 "Absorption coefficient of wall";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Window(
            x=0.02,
            y=0.01,
            width=0.44,
            height=0.65),
          Icon(Text(
              extent=[-74, 68; 86, -66],
              string="ExWall",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Diagram,
          Documentation(info="<html>
The exterior wall model consists of a boundary convection layer on the outside, three conduction layers inside the wall, and another boundary convection layer on the inside. <p>

The model computes its own solar position, which is computationally wasteful, but reduces the number of connections on the higher level models.  It then computes the radiation through the wall.  Since the wall also radiates to the outside, the radiation model, which computes the balance radiation, requires information of the temperature of the outside of the wall (the 0-junction between the outside convection layer, <b>C1V</b>, and the first conduction layer, <b>C1D</b>.  This temperature is sensed using an effort detector, <b>De</b>. <p>

The solar radiation model computes the entropy flow to the wall from both direct and diffuse radiation.  This enters the model through a modulated flow source, which is attached to the 0-junction representing the outside of the wall. <p>

The ambient air temperature is also computed inside the model, which is again computationally wasteful.  The ambient air temperature is connected by means of a modulated effort source to the outside of the air convection layer.  Since the ambient air temperature is simply an observed quantity, rather than a physically computed quantity, no heat capacity is added to that node.
</html>
"));
        Temperature Temperature1 annotation (extent=[-50, 30; -30, 50]);
        SolarPosition SolarPosition1(sfa=sfa, tilt=tilt) annotation (extent=[-
              50, 60; -30, 80]);
        SolarRadiation SolarRadiation1(
          tilt=tilt,
          absor=absor,
          area=area,
          OH=OH,
          W=W) annotation (extent=[-20, 60; 0, 80]);
        C1D C1D1(theta=theta, gamma=gamma) annotation (extent=[40, -10; 60, 10]);
        C1D C1D3(theta=theta, gamma=gamma) annotation (extent=[10, -90; -10, -
              70]);
        C1D C1D2(theta=theta, gamma=gamma) annotation (extent=[70, -70; 90, -50],
                 rotation=-90);
        C1V C1V1(theta=thv1) annotation (extent=[-40, -10; -20, 10]);
        C1V C1V2(theta=thv2) annotation (extent=[-70, -90; -90, -70]);
        Modelica.Blocks.Sources.Clock Clock1 annotation (extent=[-80, 60; -60,
              80]);
        BondLib.Sources.mSe mSe1 annotation (extent=[0, 30; -20, 50]);
        BondLib.Sources.mSf mSf1 annotation (extent=[30, 60; 10, 80]);
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[-80, -10; -60, 10]);
        BondLib.Bonds.fBond B2 annotation (extent=[-60, -10; -40, 10]);
        BondLib.Bonds.fBond B1 annotation (extent=[0, 30; 20, 50]);
        BondLib.Bonds.eBond B3 annotation (extent=[-20, -10; 0, 10]);
        BondLib.Bonds.eBond B4 annotation (extent=[30, 60; 50, 80]);
        BondLib.Bonds.eBond B5 annotation (extent=[0, -30; 20, -10], rotation=-
              90);
        BondLib.Thermal.Cth Cth1(gamma=gamma, e(start=288)) annotation (extent=
              [0, -50; 20, -30], rotation=-90);
        BondLib.Bonds.fBond B6 annotation (extent=[20, -10; 40, 10]);
        BondLib.Bonds.fBond B7 annotation (extent=[60, -10; 80, 10]);
        BondLib.Junctions.J0p2 J0p2_2 annotation (extent=[70, -30; 90, -10],
            rotation=90);
        BondLib.Bonds.fBond B8 annotation (extent=[70, -50; 90, -30], rotation=
              270);
        BondLib.Bonds.fBond B9 annotation (extent=[50, -90; 70, -70], rotation=
              180);
        BondLib.Junctions.J0p2 J0p2_3 annotation (extent=[30, -90; 50, -70]);
        BondLib.Bonds.fBond B10 annotation (extent=[10, -90; 30, -70], rotation=
             180);
        BondLib.Junctions.J0p2 J0p2_4 annotation (extent=[-50, -90; -30, -70]);
        BondLib.Bonds.fBond B12 annotation (extent=[-70, -90; -50, -70],
            rotation=180);
        BondLib.Bonds.eBond B13 annotation (extent=[-110, -70; -90, -50],
            rotation=90);
        BondLib.Junctions.J0p2 J0p2_5 annotation (extent=[-110, -50; -90, -30],
              rotation=90);
        BondLib.Junctions.J0p5 J0p5_1 annotation (extent=[0, 10; 20, -10]);
        BondLib.Sensors.De De1 annotation (extent=[20, 44; 0, 64]);
        BondLib.Bonds.fBond B14 annotation (extent=[20, 44; 40, 64], rotation=
              180);
        BondLib.Bonds.fBond B11 annotation (extent=[-30, -90; -10, -70],
            rotation=180);
      equation 
        connect(Clock1.y,SolarPosition1.u)             annotation (points=[-59,
              70; -52,70],    style(color=3));
        connect(SolarPosition1.y,SolarRadiation1.u)             annotation (
            points=[-29,70; -22,70],   style(color=3));
        connect(SolarPosition1.OutPort1, SolarRadiation1.InPort1) annotation (
            points=[-29,64; -22,64],   style(color=3));
        connect(SolarRadiation1.y,       mSf1.InPort1) annotation (points=[1,70;
              11,70],      style(color=3));
        connect(Temperature1.y,       mSe1.InPort1) annotation (points=[-29,40;
              -19,40],    style(color=3));
        connect(J0p2_1.BondCon2, B2.eBondCon1) annotation (points=[-60, 0; -60,
                0], style(color=8));
        connect(mSe1.BondCon1, B1.eBondCon1) annotation (points=[0, 40; 0, 40],
              style(color=8));
        connect(B1.fBondCon1, J0p2_1.BondCon1) annotation (points=[20, 40; 26,
              40; 26, 22; -86, 22; -86, 0; -80, 0], style(color=8));
        connect(B2.fBondCon1, C1V1.BondCon1) annotation (points=[-40, 0; -40, 0],
                 style(color=8));
        connect(C1V1.BondCon2, B3.fBondCon1) annotation (points=[-20, 0; -20, 0],
                 style(color=8));
        connect(mSf1.BondCon1, B4.fBondCon1) annotation (points=[30, 70; 30, 70],
                 style(color=8));
        connect(B5.eBondCon1, Cth1.BondCon1) annotation (points=[10, -30; 10, -
              30], style(color=8));
        connect(B6.fBondCon1, C1D1.BondCon1) annotation (points=[40, 0; 40, 0],
              style(color=8));
        connect(C1D1.BondCon2, B7.eBondCon1) annotation (points=[60, 0; 60, 0],
              style(color=8));
        connect(B7.fBondCon1, J0p2_2.BondCon2) annotation (points=[80, 0; 80, -
              10], style(color=8));
        connect(B9.fBondCon1, J0p2_3.BondCon2) annotation (points=[50, -80; 50,
                -80], style(color=8));
        connect(J0p2_3.BondCon1, B10.eBondCon1) annotation (points=[30, -80; 30,
                -80], style(color=8));
        connect(B10.fBondCon1, C1D3.BondCon1) annotation (points=[10, -80; 10,
              -80], style(color=8));
        connect(J0p2_4.BondCon1, B12.eBondCon1) annotation (points=[-50, -80; -
              50, -80], style(color=8));
        connect(B12.fBondCon1, C1V2.BondCon1) annotation (points=[-70, -80; -70,
                -80], style(color=8));
        connect(Clock1.y,Temperature1.u)             annotation (points=[-59,70;
              -56,70; -56,40; -52,40],        style(color=3));
        connect(Clock1.y,       SolarRadiation1.TimePort) annotation (points=[
              -59,70; -56,70; -56,90; -10,90; -10,79],     style(color=3));
        connect(C1V2.BondCon2, B13.fBondCon1) annotation (points=[-90, -80; -
              100, -80; -100, -70], style(color=8));
        connect(B13.eBondCon1, J0p2_5.BondCon1) annotation (points=[-100, -50;
              -100, -50], style(color=8));
        connect(J0p2_5.BondCon2, BondCon1) annotation (points=[-100,-30; -100,0],
                     style(color=8));
        connect(B3.eBondCon1, J0p5_1.BondCon1) annotation (points=[0, 0; 0, 0],
              style(color=8));
        connect(J0p5_1.BondCon2, B6.eBondCon1) annotation (points=[20, 0; 20, 0],
                 style(color=8));
        connect(J0p5_1.BondCon5, B5.fBondCon1) annotation (points=[10, -10; 10,
                -10], style(color=8));
        connect(B14.fBondCon1, De1.BondCon1) annotation (points=[20, 54; 20, 54],
                 style(color=8));
        connect(J0p5_1.BondCon3, B14.eBondCon1) annotation (points=[6, 10; 6,
              18; 46, 18; 46, 54; 40, 54], style(color=8));
        connect(B4.eBondCon1, J0p5_1.BondCon4) annotation (points=[50, 70; 60,
              70; 60, 14; 14, 14; 14, 10], style(color=8));
        connect(De1.OutPort1, SolarRadiation1.TempPort) annotation (points=[-1,
              54; -10,54; -10,61],     style(color=3));
        connect(J0p2_2.BondCon1, B8.eBondCon1) annotation (points=[80, -30; 80,
                -30], style(color=8));
        connect(B8.fBondCon1, C1D2.BondCon1) annotation (points=[80, -50; 80, -
              50], style(color=8));
        connect(C1D2.BondCon2, B9.eBondCon1) annotation (points=[80, -70; 80, -
              80; 70, -80], style(color=8));
        connect(C1D3.BondCon2, B11.eBondCon1) annotation (points=[-10, -80; -10,
                -80], style(color=8));
        connect(B11.fBondCon1, J0p2_4.BondCon2) annotation (points=[-30, -80; -
              30, -80], style(color=8));
      end ExWall;
      
      model IntWall "Interior wall" 
        extends BondLib.Interfaces.TwoPort;
        
        parameter Real lv=8.3 "Specific thermal conductance of convection";
        parameter Real dxv=1 "Width of convective layer";
        parameter Real area "Area of internal wall";
        parameter Real thv=dxv/(lv*area) "Thermal resistance of convection";
        parameter Real ld=1.7 "Specific thermal conductance of dry wall";
        parameter Real dxd=0.1 "Thickness of conduction layer";
        parameter Real theta=dxd/(ld*area) 
          "Thermal resistance of dry wall layer";
        parameter Real c=840 "Specific heat capacity of dry wall";
        parameter Real dens=1762 "Density of internal wall";
        parameter Real thk=0.3 "Thickness of internal wall";
        parameter Real m=area*thk*dens/4 "Mass of internal wall segment";
        parameter Real gamma=c*m/3600 "Heat capacity of internal wall segment";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-74, 68; 86, -66],
              string="IntWall",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Diagram(
            Line(points=[0, 0; 0, 0], style(color=8)),
            Line(points=[10, -10; 10, -10], style(color=8)),
            Line(points=[20, 0; 20, 0], style(color=8))),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
Interior walls have the same structure as exterior walls, i.e., a boundary convection layer on one side, followed by three conduction layers inside the wall, followed by another boundary convection layer on the other side. <p>

However, there is no solar radiation to be taken into account for interior walls.  Thus, the inerior wall model is considerably simpler than the exterior wall model.
</html>
"));
        C1D C1D1(theta=theta, gamma=gamma) annotation (extent=[40, -10; 60, 10]);
        C1D C1D3(theta=theta, gamma=gamma) annotation (extent=[-10, -70; -30, -
              50]);
        C1D C1D2(theta=theta, gamma=gamma) annotation (extent=[70, -70; 50, -50]);
        C1V C1V1(theta=thv) annotation (extent=[-40, -10; -20, 10]);
        C1V C1V2(theta=thv) annotation (extent=[-50, -90; -30, -70]);
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[-80, -10; -60, 10]);
        BondLib.Bonds.fBond B1 annotation (extent=[-60, -10; -40, 10]);
        BondLib.Bonds.eBond B2 annotation (extent=[-20, -10; 0, 10]);
        BondLib.Bonds.eBond B3 annotation (extent=[0, -30; 20, -10], rotation=-
              90);
        BondLib.Thermal.Cth Cth1(gamma=gamma, e(start=288)) annotation (extent=
              [0, -50; 20, -30], rotation=-90);
        BondLib.Bonds.fBond B4 annotation (extent=[20, -10; 40, 10]);
        BondLib.Bonds.fBond B5 annotation (extent=[60, -10; 80, 10]);
        BondLib.Junctions.J0p2 J0p2_2 annotation (extent=[70, -30; 90, -10],
            rotation=90);
        BondLib.Bonds.fBond B6 annotation (extent=[70, -50; 90, -30], rotation=
              270);
        BondLib.Bonds.fBond B7 annotation (extent=[30, -70; 50, -50], rotation=
              180);
        BondLib.Junctions.J0p2 J0p2_3 annotation (extent=[10, -70; 30, -50]);
        BondLib.Bonds.fBond B8 annotation (extent=[-10, -70; 10, -50], rotation=
             180);
        BondLib.Junctions.J0p2 J0p2_4 annotation (extent=[-70, -70; -50, -50]);
        BondLib.Bonds.fBond B9 annotation (extent=[-50, -70; -30, -50],
            rotation=180);
        BondLib.Junctions.J0p3 J0p3_1 annotation (extent=[0, -10; 20, 10]);
        BondLib.Bonds.eBond B10 annotation (extent=[-70, -90; -50, -70]);
        BondLib.Junctions.J0p2 J0p2_5 annotation (extent=[-10, -90; 10, -70]);
        BondLib.Bonds.eBond B11 annotation (extent=[-30, -90; -10, -70]);
      equation 
        connect(J0p2_1.BondCon2, B1.eBondCon1) annotation (points=[-60, 0; -60,
                0], style(color=8));
        connect(B1.fBondCon1, C1V1.BondCon1) annotation (points=[-40, 0; -40, 0],
                 style(color=8));
        connect(C1V1.BondCon2, B2.fBondCon1) annotation (points=[-20, 0; -20, 0],
                 style(color=8));
        connect(B3.eBondCon1, Cth1.BondCon1) annotation (points=[10, -30; 10, -
              30], style(color=8));
        connect(B4.fBondCon1, C1D1.BondCon1) annotation (points=[40, 0; 40, 0],
              style(color=8));
        connect(C1D1.BondCon2, B5.eBondCon1) annotation (points=[60, 0; 60, 0],
              style(color=8));
        connect(B5.fBondCon1, J0p2_2.BondCon2) annotation (points=[80, 0; 80, -
              10], style(color=8));
        connect(B2.eBondCon1, J0p3_1.BondCon1) annotation (points=[0, 0; 0, 0],
              style(color=8));
        connect(J0p3_1.BondCon3, B3.fBondCon1) annotation (points=[10, -10; 10,
                -10], style(color=8));
        connect(J0p3_1.BondCon2, B4.eBondCon1) annotation (points=[20, 0; 20, 0],
                 style(color=8));
        connect(BondCon1, J0p2_1.BondCon1) annotation (points=[-100,0; -80,0],
              style(color=8));
        connect(J0p2_2.BondCon1, B6.eBondCon1) annotation (points=[80, -30; 80,
                -30], style(color=8));
        connect(B6.fBondCon1, C1D2.BondCon1) annotation (points=[80, -50; 80, -
              60; 70, -60], style(color=8));
        connect(C1D2.BondCon2, B7.eBondCon1) annotation (points=[50, -60; 50, -
              60], style(color=8));
        connect(B7.fBondCon1, J0p2_3.BondCon2) annotation (points=[30, -60; 30,
                -60], style(color=8));
        connect(J0p2_3.BondCon1, B8.eBondCon1) annotation (points=[10, -60; 10,
                -60], style(color=8));
        connect(B8.fBondCon1, C1D3.BondCon1) annotation (points=[-10, -60; -10,
                -60], style(color=8));
        connect(C1D3.BondCon2, B9.eBondCon1) annotation (points=[-30, -60; -30,
                -60], style(color=8));
        connect(B9.fBondCon1, J0p2_4.BondCon2) annotation (points=[-50, -60; -
              50, -60], style(color=8));
        connect(J0p2_4.BondCon1, B10.fBondCon1) annotation (points=[-70, -60; -
              80, -60; -80, -80; -70, -80], style(color=8));
        connect(B10.eBondCon1, C1V2.BondCon1) annotation (points=[-50, -80; -50,
                -80], style(color=8));
        connect(C1V2.BondCon2, B11.fBondCon1) annotation (points=[-30, -80; -30,
                -80], style(color=8));
        connect(B11.eBondCon1, J0p2_5.BondCon1) annotation (points=[-10, -80; -
              10, -80], style(color=8));
        connect(J0p2_5.BondCon2, BondCon2) annotation (points=[10,-80; 100,-80;
              100,0],       style(color=8));
      end IntWall;
      
      model Roof "Roof" 
        extends BondLib.Interfaces.ActiveOnePort;
        parameter Real lv1=22.7 
          "Specific thermal conductance of convection outside";
        parameter Real dxv1=1 "Width of convective layer outside";
        parameter Real area "Area of roof";
        parameter Real thv1=dxv1/(lv1*area) 
          "Thermal resistance of convection outside";
        parameter Real ld1=45.3 
          "Specific thermal conductance of outmost roof layer";
        parameter Real dxd1=0.038 "Thickness of outmost roof layer";
        parameter Real theta1=dxd1/(ld1*area) 
          "Thermal resistance of outmost layer";
        parameter Real ld2=0.0385 
          "Specific thermal conductance of center roof layer";
        parameter Real dxd2=0.2 "Thickness of center roof layer";
        parameter Real theta2=dxd2/(ld2*area) 
          "Thermal resistance of center layer";
        parameter Real ld3=0.1143 
          "Specific thermal conductance of inner roof layer";
        parameter Real dxd3=0.016 "Thickness of inner roof layer";
        parameter Real theta3=dxd3/(ld3*area) 
          "Thermal resistance of inner layer";
        parameter Real lv2=7.4 
          "Specific thermal conductance of convection inside";
        parameter Real dxv2=1 "Width of convective layer inside";
        parameter Real thv2=dxv2/(lv2*area) 
          "Thermal resistance of convection inside";
        parameter Real c1=500 "Specific heat capacity of outmost roof layer";
        parameter Real dens1=7850 "Density of outmost roof layer";
        parameter Real m1=area*ld1*dens1 "Mass of outmost roof layer";
        parameter Real gamma1=c1*m1/3600 "Heat capacity of outmost roof layer";
        parameter Real c2=657 "Specific heat capacity of outmost roof layer";
        parameter Real dens2=19.2 "Density of outmost roof layer";
        parameter Real m2=0.5*area*ld2*dens2 "Mass of outmost roof layer";
        parameter Real gamma2=c2*m2/3600 "Heat capacity of outmost roof layer";
        parameter Real c3=1214 "Specific heat capacity of outmost roof layer";
        parameter Real dens3=544 "Density of outmost roof layer";
        parameter Real m3=area*ld3*dens3 "Mass of outmost roof layer";
        parameter Real gamma3=c3*m3/3600 "Heat capacity of outmost roof layer";
        parameter Real sfa=180 "Orientation of wall";
        parameter Real tilt=7 "Tilt of wall";
        parameter Real OH;
        parameter Real W;
        parameter Real absor=0.2 "Absorption coefficient of wall";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-74, 68; 86, -66],
              string="Roof",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Diagram,
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
It would not have been necessary to create a separate roof model, as this model is exactly the same physical model as the exterior wall model (only with different physical parameter values), yet cut and paste is cheap, and since the readability of the higher level models seemed improved by offering a separate roof model, such a model was created.
</html>
"));
        Temperature Temperature1 annotation (extent=[-50, 30; -30, 50]);
        SolarPosition SolarPosition1(sfa=sfa, tilt=tilt) annotation (extent=[-
              50, 60; -30, 80]);
        SolarRadiation SolarRadiation1(
          tilt=tilt,
          absor=absor,
          area=area,
          OH=OH,
          W=W) annotation (extent=[-20, 60; 0, 80]);
        C1D C1D1(theta=theta1, gamma=gamma2) annotation (extent=[40, -10; 60,
              10]);
        C1V C1V1(theta=thv1) annotation (extent=[-40, -10; -20, 10]);
        Modelica.Blocks.Sources.Clock Clock1 annotation (extent=[-80, 60; -60,
              80]);
        BondLib.Sources.mSe mSe1 annotation (extent=[0, 30; -20, 50]);
        BondLib.Sources.mSf mSf1 annotation (extent=[30, 60; 10, 80]);
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[-80, -10; -60, 10]);
        BondLib.Bonds.fBond B2 annotation (extent=[-60, -10; -40, 10]);
        BondLib.Bonds.fBond B1 annotation (extent=[0, 30; 20, 50]);
        BondLib.Bonds.eBond B3 annotation (extent=[-20, -10; 0, 10]);
        BondLib.Bonds.eBond B4 annotation (extent=[30, 60; 50, 80]);
        BondLib.Bonds.eBond B5 annotation (extent=[0, -30; 20, -10], rotation=-
              90);
        BondLib.Thermal.Cth Cth1(gamma=gamma1, e(start=288)) annotation (extent=
             [0, -50; 20, -30], rotation=-90);
        BondLib.Bonds.fBond B6 annotation (extent=[20, -10; 40, 10]);
        BondLib.Bonds.fBond B7 annotation (extent=[60, -10; 80, 10]);
        BondLib.Junctions.J0p5 J0p5_1 annotation (extent=[0, 10; 20, -10]);
        BondLib.Sensors.De De1 annotation (extent=[20, 44; 0, 64]);
        BondLib.Bonds.fBond B14 annotation (extent=[20, 44; 40, 64], rotation=
              180);
        C1D C1D3(theta=theta3, gamma=gamma3) annotation (extent=[10, -90; -10,
              -70]);
        C1D C1D2(theta=theta2, gamma=gamma2) annotation (extent=[70, -70; 90, -
              50], rotation=-90);
        C1V C1V2(theta=thv2) annotation (extent=[-70, -90; -90, -70]);
        BondLib.Bonds.fBond B9 annotation (extent=[50, -90; 70, -70], rotation=
              180);
        BondLib.Junctions.J0p2 J0p2_3 annotation (extent=[30, -90; 50, -70]);
        BondLib.Bonds.fBond B10 annotation (extent=[10, -90; 30, -70], rotation=
             180);
        BondLib.Junctions.J0p2 J0p2_4 annotation (extent=[-50, -90; -30, -70]);
        BondLib.Bonds.fBond B12 annotation (extent=[-70, -90; -50, -70],
            rotation=180);
        BondLib.Bonds.eBond B13 annotation (extent=[-110, -70; -90, -50],
            rotation=90);
        BondLib.Bonds.fBond B11 annotation (extent=[-30, -90; -10, -70],
            rotation=180);
        BondLib.Junctions.J0p2 J0p2_5 annotation (extent=[-110, -50; -90, -30],
              rotation=90);
        BondLib.Bonds.fBond B8 annotation (extent=[70, -50; 90, -30], rotation=
              270);
        BondLib.Junctions.J0p2 J0p2_2 annotation (extent=[70, -30; 90, -10],
            rotation=90);
      equation 
        connect(Clock1.y,SolarPosition1.u)             annotation (points=[-59,
              70; -52,70],    style(color=3));
        connect(SolarPosition1.y,SolarRadiation1.u)             annotation (
            points=[-29,70; -22,70],   style(color=3));
        connect(SolarPosition1.OutPort1, SolarRadiation1.InPort1) annotation (
            points=[-29,64; -22,64],   style(color=3));
        connect(SolarRadiation1.y,       mSf1.InPort1) annotation (points=[1,70;
              11,70],      style(color=3));
        connect(Temperature1.y,       mSe1.InPort1) annotation (points=[-29,40;
              -19,40],    style(color=3));
        connect(J0p2_1.BondCon2, B2.eBondCon1) annotation (points=[-60, 0; -60,
                0], style(color=8));
        connect(mSe1.BondCon1, B1.eBondCon1) annotation (points=[0, 40; 0, 40],
              style(color=8));
        connect(B1.fBondCon1, J0p2_1.BondCon1) annotation (points=[20, 40; 26,
              40; 26, 22; -86, 22; -86, 0; -80, 0], style(color=8));
        connect(B2.fBondCon1, C1V1.BondCon1) annotation (points=[-40, 0; -40, 0],
                 style(color=8));
        connect(C1V1.BondCon2, B3.fBondCon1) annotation (points=[-20, 0; -20, 0],
                 style(color=8));
        connect(mSf1.BondCon1, B4.fBondCon1) annotation (points=[30, 70; 30, 70],
                 style(color=8));
        connect(B5.eBondCon1, Cth1.BondCon1) annotation (points=[10, -30; 10, -
              30], style(color=8));
        connect(B6.fBondCon1, C1D1.BondCon1) annotation (points=[40, 0; 40, 0],
              style(color=8));
        connect(C1D1.BondCon2, B7.eBondCon1) annotation (points=[60, 0; 60, 0],
              style(color=8));
        connect(Clock1.y,Temperature1.u)             annotation (points=[-59,70;
              -56,70; -56,40; -52,40],        style(color=3));
        connect(Clock1.y,       SolarRadiation1.TimePort) annotation (points=[
              -59,70; -56,70; -56,90; -10,90; -10,79],     style(color=3));
        connect(B3.eBondCon1, J0p5_1.BondCon1) annotation (points=[0, 0; 0, 0],
              style(color=8));
        connect(J0p5_1.BondCon5, B5.fBondCon1) annotation (points=[10, -10; 10,
                -10], style(color=8));
        connect(J0p5_1.BondCon2, B6.eBondCon1) annotation (points=[20, 0; 20, 0],
                 style(color=8));
        connect(B14.fBondCon1, De1.BondCon1) annotation (points=[20, 54; 20, 54],
                 style(color=8));
        connect(De1.OutPort1, SolarRadiation1.TempPort) annotation (points=[-1,
              54; -10,54; -10,61],     style(color=3));
        connect(J0p5_1.BondCon3, B14.eBondCon1) annotation (points=[6, 10; 6,
              18; 46, 18; 46, 54; 40, 54], style(color=8));
        connect(B4.eBondCon1, J0p5_1.BondCon4) annotation (points=[50, 70; 60,
              70; 60, 14; 14, 14; 14, 10], style(color=8));
        connect(B9.fBondCon1, J0p2_3.BondCon2) annotation (points=[50, -80; 50,
                -80], style(color=8));
        connect(J0p2_3.BondCon1, B10.eBondCon1) annotation (points=[30, -80; 30,
                -80], style(color=8));
        connect(B10.fBondCon1, C1D3.BondCon1) annotation (points=[10, -80; 10,
              -80], style(color=8));
        connect(J0p2_4.BondCon1, B12.eBondCon1) annotation (points=[-50, -80; -
              50, -80], style(color=8));
        connect(B12.fBondCon1, C1V2.BondCon1) annotation (points=[-70, -80; -70,
                -80], style(color=8));
        connect(C1V2.BondCon2, B13.fBondCon1) annotation (points=[-90, -80; -
              100, -80; -100, -70], style(color=8));
        connect(C1D2.BondCon2, B9.eBondCon1) annotation (points=[80, -70; 80, -
              80; 70, -80], style(color=8));
        connect(C1D3.BondCon2, B11.eBondCon1) annotation (points=[-10, -80; -10,
                -80], style(color=8));
        connect(B11.fBondCon1, J0p2_4.BondCon2) annotation (points=[-30, -80; -
              30, -80], style(color=8));
        connect(B13.eBondCon1, J0p2_5.BondCon1) annotation (points=[-100, -50;
              -100, -50], style(color=8));
        connect(J0p2_5.BondCon2, BondCon1) annotation (points=[-100,-30; -100,0],
                     style(color=8));
        connect(B8.fBondCon1, C1D2.BondCon1) annotation (points=[80, -50; 80, -
              50], style(color=8));
        connect(J0p2_2.BondCon1, B8.eBondCon1) annotation (points=[80, -30; 80,
                -30], style(color=8));
        connect(B7.fBondCon1, J0p2_2.BondCon2) annotation (points=[80, 0; 80, -
              10], style(color=8));
      end Roof;
      
      model Window "Window" 
        extends BondLib.Interfaces.ActiveOnePort;
        parameter Real lv=3.4 
          "Specific thermal conductance of convection outside";
        parameter Real dxv=1 "Width of convective layer outside";
        parameter Real area "Area of window";
        parameter Real thv=dxv/(lv*area) 
          "Thermal resistance of convection outside";
        parameter Real tilt=90 "Tilt of window";
        parameter Real OH;
        parameter Real W;
        parameter Real sc=0.85;
        parameter Real sfa "Orientation of window";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-74, 68; 86, -66],
              string="Window",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Diagram,
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
The window model has an outside convection layer, but no conduction layers, as the glass is considered thin and homogeneous.  It would have been possible (and probably meaningful!), to provide an inside convection layer as well, but the student didn't do so.  Thus, the glass doesn't have its own temperature.  The 0-junction on the inside of the convection layer simply represents the temperature of the room behind the window. <p>

The solar input is similar to the solar input used in the exterior wall model, except that the general <i>solar radiation</i> model was replaced here by the <i>solar radiation through glass</i> model.
</html>
"));
        Temperature Temperature1 annotation (extent=[-50, 30; -30, 50]);
        SolarPosition SolarPosition1(sfa=sfa, tilt=tilt) annotation (extent=[-
              50, 60; -30, 80]);
        C1V C1V1(theta=thv) annotation (extent=[-40, -10; -20, 10]);
        Modelica.Blocks.Sources.Clock Clock1 annotation (extent=[-80, 60; -60,
              80]);
        BondLib.Sources.mSe mSe1 annotation (extent=[0, 30; -20, 50]);
        BondLib.Sources.mSf mSf1 annotation (extent=[30, 60; 10, 80]);
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[-80, -10; -60, 10]);
        BondLib.Bonds.fBond B2 annotation (extent=[-60, -10; -40, 10]);
        BondLib.Bonds.fBond B1 annotation (extent=[0, 30; 20, 50]);
        BondLib.Bonds.eBond B3 annotation (extent=[-20, -10; 0, 10]);
        BondLib.Bonds.eBond B4 annotation (extent=[30, 60; 50, 80]);
        SolarGlass SolarGlass1(
          sc=sc,
          tilt=tilt,
          area=area,
          OH=OH,
          W=W) annotation (extent=[-20, 60; 0, 80]);
        BondLib.Sensors.De De1 annotation (extent=[20, 44; 0, 64]);
        BondLib.Bonds.fBond B5 annotation (extent=[20, 44; 40, 64], rotation=
              180);
        BondLib.Junctions.J0p4 J0p4_1 annotation (extent=[0, -10; 20, 10]);
      equation 
        connect(Clock1.y,SolarPosition1.u)             annotation (points=[-59,
              70; -52,70],    style(color=3));
        connect(Temperature1.y,       mSe1.InPort1) annotation (points=[-29,40;
              -19,40],    style(color=3));
        connect(J0p2_1.BondCon2, B2.eBondCon1) annotation (points=[-60, 0; -60,
                0], style(color=8));
        connect(mSe1.BondCon1, B1.eBondCon1) annotation (points=[0, 40; 0, 40],
              style(color=8));
        connect(B1.fBondCon1, J0p2_1.BondCon1) annotation (points=[20, 40; 26,
              40; 26, 20; -86, 20; -86, 0; -80, 0], style(color=8));
        connect(B2.fBondCon1, C1V1.BondCon1) annotation (points=[-40, 0; -40, 0],
                 style(color=8));
        connect(C1V1.BondCon2, B3.fBondCon1) annotation (points=[-20, 0; -20, 0],
                 style(color=8));
        connect(mSf1.BondCon1, B4.fBondCon1) annotation (points=[30, 70; 30, 70],
                 style(color=8));
        connect(SolarPosition1.y,SolarGlass1.u)             annotation (points=[
              -29,70; -22,70],    style(color=3));
        connect(SolarPosition1.OutPort1, SolarGlass1.InPort1) annotation (
            points=[-29,64; -22,64],   style(color=3));
        connect(SolarGlass1.y,       mSf1.InPort1) annotation (points=[1,70; 11,
              70],     style(color=3));
        connect(Clock1.y,Temperature1.u)             annotation (points=[-59,70;
              -56,70; -56,40; -52,40],        style(color=3));
        connect(Clock1.y,       SolarGlass1.TimePort) annotation (points=[-59,
              70; -56,70; -56,90; -10,90; -10,79],     style(color=3));
        connect(B5.fBondCon1, De1.BondCon1) annotation (points=[20, 54; 20, 54],
              style(color=8));
        connect(De1.OutPort1, SolarGlass1.TempPort) annotation (points=[-1,54;
              -10,54; -10,61],     style(color=3));
        connect(B3.eBondCon1, J0p4_1.BondCon1) annotation (points=[0, 0; 0, 0],
              style(color=8));
        connect(J0p4_1.BondCon4, B5.eBondCon1) annotation (points=[10, 10; 10,
              16; 46, 16; 46, 54; 40, 54], style(color=8));
        connect(B4.eBondCon1, J0p4_1.BondCon2) annotation (points=[50, 70; 60,
              70; 60, 0; 20, 0], style(color=8));
        connect(J0p4_1.BondCon3, BondCon1) annotation (points=[10,-10; 10,-20;
              -100,-20; -100,0],      style(color=8));
      end Window;
      
      model Door "Door" 
        extends BondLib.Interfaces.TwoPort;
        parameter Real lv=0.189 
          "Specific thermal conductance of convection outside";
        parameter Real dxv=1 "Width of convective layer outside";
        parameter Real area "Area of door";
        parameter Real thv=dxv/(lv*area) 
          "Thermal resistance of convection outside";
        parameter Real sfa "Orientation of door";
        parameter Real tilt=90 "Tilt of door";
        parameter Real OH;
        parameter Real W;
        parameter Real absor=0.2 "Absorption coefficient of door";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Line(points=[10, -10; 10, -10], style(color=8)),
            Line(points=[60, 0; 60, 0], style(color=8)),
            Line(points=[40, 0; 40, 0], style(color=8)),
            Line(points=[20, 0; 20, 0], style(color=8)),
            Line(points=[0, 0; 0, 0], style(color=8)),
            Line(points=[0, 40; 0, 40], style(color=8))),
          Icon(Text(
              extent=[-78, 66; 82, -68],
              string="Door",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
The doors are similar to windows, in that they are thin and homogeneous.  Thus the model contains an outside convection layer, no conduction layers, and (unfortunately) no inside convection layer either.  This is the same error that the student made in modeling the windows. <p>

Yet, here the situation is worse.  The student should have distinguished between interior doors and exterior doors, whereby solar radiation only affects exterior doors.  The student didn't do that.  He allowed for solar radiation on all doors, also the interior ones.  This is evidently a bad blunder.  Yet, when the student wrote his thesis in 1992, Dymola didn't offer a graphical front-end yet.  Dymola was strictly an alphanumerical language, with a language definition similar to that of Modelica today.  All of the pictures drawn for the thesis were simply hand-drawn illustrations.  They had nothing to do with the program itself ... and thus, I never noticed the error.  I only noticed it, when I painstakingly converted the code developed by the student to the current version of Dymola with Modelica, now using of course the graphical interface, which is when the blunder surfaced. <p>

The student actually should have noticed that something is wrong here ... and he probably even did.  He recognized that the interior doors need to connect to the neighboring room, whereas the exterior doors need to connect to the ambient temperature, and thus, he attached the ambient temperature externally to the door model at the next higher level (again, kind of ugly), but still forgot to disable the radiation from the interior doors.
</html>

"));
        SolarPosition SolarPosition1(sfa=sfa, tilt=tilt) annotation (extent=[-
              50, 60; -30, 80]);
        C1V C1V1(theta=thv) annotation (extent=[0, -10; 20, 10]);
        Modelica.Blocks.Sources.Clock Clock1 annotation (extent=[-80, 60; -60,
              80]);
        BondLib.Sources.mSf mSf1 annotation (extent=[30, 60; 10, 80]);
        BondLib.Bonds.fBond B1 annotation (extent=[-20, -10; 0, 10]);
        BondLib.Bonds.eBond B2 annotation (extent=[20, -10; 40, 10]);
        BondLib.Bonds.eBond B3 annotation (extent=[30, 60; 50, 80]);
        BondLib.Junctions.J0p3 J0p3_1 annotation (extent=[40, 10; 60, -10]);
        SolarRadiation SolarRadiation1(
          tilt=tilt,
          absor=absor,
          area=area,
          OH=OH,
          W=W) annotation (extent=[-20, 60; 0, 80]);
        BondLib.Junctions.J0p3 J0p3_2 annotation (extent=[-40, 10; -20, -10]);
        BondLib.Bonds.fBond B4 annotation (extent=[-40, 10; -20, 30], rotation=
              90);
        BondLib.Sensors.De De1 annotation (extent=[-26, 30; -6, 50], rotation=0);
      equation 
        connect(Clock1.y,SolarPosition1.u)             annotation (points=[-59,
              70; -52,70],    style(color=3));
        connect(B1.fBondCon1, C1V1.BondCon1) annotation (points=[0, 0; 0, 0],
            style(color=8));
        connect(C1V1.BondCon2, B2.fBondCon1) annotation (points=[20, 0; 20, 0],
              style(color=8));
        connect(mSf1.BondCon1, B3.fBondCon1) annotation (points=[30, 70; 30, 70],
                 style(color=8));
        connect(B2.eBondCon1, J0p3_1.BondCon1) annotation (points=[40, 0; 40, 0],
                 style(color=8));
        connect(SolarPosition1.y,SolarRadiation1.u)             annotation (
            points=[-29,70; -22,70],   style(color=3));
        connect(SolarPosition1.OutPort1, SolarRadiation1.InPort1) annotation (
            points=[-29,64; -22,64],   style(color=3));
        connect(SolarRadiation1.y,       mSf1.InPort1) annotation (points=[1,70;
              11,70],      style(color=3));
        connect(J0p3_1.BondCon2, BondCon2) annotation (points=[60,0; 100,0],
            style(color=8));
        connect(Clock1.y,       SolarRadiation1.TimePort) annotation (points=[
              -59,70; -56,70; -56,92; -10,92; -10,79],     style(color=3));
        connect(B3.eBondCon1, J0p3_1.BondCon3) annotation (points=[50, 70; 50,
              10], style(color=8));
        connect(J0p3_2.BondCon2, B1.eBondCon1) annotation (points=[-20, 0; -20,
                0], style(color=8));
        connect(J0p3_2.BondCon1, BondCon1) annotation (points=[-40,0; -100,0],
              style(color=8));
        connect(J0p3_2.BondCon3, B4.eBondCon1) annotation (points=[-30, 10; -30,
                10], style(color=8));
        connect(De1.OutPort1, SolarRadiation1.TempPort) annotation (points=[-5,
              40; 0,40; 0,50; -10,50; -10,61],       style(color=3));
        connect(B4.fBondCon1, De1.BondCon1) annotation (points=[-30, 30; -30,
              40; -26, 40], style(color=8));
      end Door;
      
      model Slab "Slab below the experimental house" 
        extends BondLib.Interfaces.TwoPort;
        parameter Real ld=5.11 "Specific thermal conductance of slab";
        parameter Real dxd=1 "Thickness of slab for conduction";
        parameter Real thk=0.2 "Thickness of slab";
        parameter Real perim "Area of floor for conduction";
        parameter Real aread=perim*thk "Effective area of floor for conduction";
        parameter Real theta=dxd/(ld*aread) "Thermal resistance of slab";
        parameter Real lv=7.4 "Specific thermal conductance of convection";
        parameter Real dxv=1 "Width of convective layer";
        parameter Real area "Area of floor for convection";
        parameter Real thv=dxv/(lv*area) "Thermal resistance of convection";
        parameter Real c=835 "Specific heat capacity of slab";
        parameter Real dens=2083 "Density of slab";
        parameter Real m=area*thk*dens "Mass of slab";
        parameter Real gamma=c*m/3600 "Heat capacity of slab";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Line(points=[0, 0; 0, 0], style(color=8)),
            Line(points=[10, -10; 10, -10], style(color=8)),
            Line(points=[20, 0; 20, 0], style(color=8)),
            Line(points=[10, -10; 10, -10], style(color=8)),
            Line(points=[0, 0; 0, 0], style(color=8)),
            Line(points=[20, 0; 20, 0], style(color=8))),
          Icon(Text(
              extent=[-74, 68; 86, -66],
              string="Slab",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Documentation(info="<html>
In Tucson, houses are built on sand.  The house is not thermally insulated from the ground, thus, the thermal building model ought to take into account the exchange of heat between the house and the slab underneath it. <p>

The slab is modeled with a single conduction layer connecting the temperature of the slab to the temperature of the floor.  Above the floor, there is a boundary convection layer.
</html>
"));
        C1D C1D1(theta=theta, gamma=gamma) annotation (extent=[-50, -10; -30,
              10]);
        C1V C1V1(theta=thv) annotation (extent=[30, -10; 50, 10]);
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[-90, -10; -70, 10]);
        BondLib.Bonds.fBond B1 annotation (extent=[-70, -10; -50, 10]);
        BondLib.Bonds.eBond B4 annotation (extent=[50, -10; 70, 10]);
        BondLib.Bonds.fBond B3 annotation (extent=[10, -10; 30, 10]);
        BondLib.Bonds.fBond B2 annotation (extent=[-30, -10; -10, 10]);
        BondLib.Junctions.J0p2 J0p2_2 annotation (extent=[-10, -10; 10, 10]);
        BondLib.Junctions.J0p2 J0p2_3 annotation (extent=[70, -10; 90, 10]);
      equation 
        connect(J0p2_1.BondCon2, B1.eBondCon1) annotation (points=[-70, 0; -70,
                0], style(color=8));
        connect(J0p2_2.BondCon2, B3.eBondCon1) annotation (points=[10, 0; 10, 0],
                 style(color=8));
        connect(B1.fBondCon1, C1D1.BondCon1) annotation (points=[-50, 0; -50, 0],
                 style(color=8));
        connect(B3.fBondCon1, C1V1.BondCon1) annotation (points=[30, 0; 30, 0],
              style(color=8));
        connect(BondCon1, J0p2_1.BondCon1) annotation (points=[-100,0; -90,0],
              style(color=8));
        connect(J0p2_3.BondCon2, BondCon2) annotation (points=[90,0; 100,0],
            style(color=8));
        connect(C1D1.BondCon2, B2.eBondCon1) annotation (points=[-30, 0; -30, 0],
                 style(color=8));
        connect(B2.fBondCon1, J0p2_2.BondCon1) annotation (points=[-10, 0; -10,
                0], style(color=8));
        connect(C1V1.BondCon2, B4.fBondCon1) annotation (points=[50, 0; 50, 0],
              style(color=8));
        connect(B4.eBondCon1, J0p2_3.BondCon1) annotation (points=[70, 0; 70, 0],
                 style(color=8));
      end Slab;
      
      model LivingRoom "Living room" 
        parameter Real c=1000 "Specific heat capacity of living room";
        parameter Real m=265 "Mass of living room";
        parameter Real gamma=c*m/3600 "Heat capacity of living room";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[1, 1],
            component=[10, 10]),
          Diagram(
            Line(points=[-90, 90; -90, -40; 90, -40; 90, 20; -30, 20; -30, 90;
                  -90, 90], style(color=41, thickness=2)),
            Line(points=[-29, 90; 90, 90; 90, 20], style(color=57, thickness=2)),
            Line(points=[30, 90; 30, 20], style(color=53, thickness=2)),
            Line(points=[10, -40; 10, -80; 90, -80; 90, -41], style(color=53,
                  thickness=2)),
            Rectangle(extent=[60, -38; 80, -42], style(color=41)),
            Rectangle(extent=[-30, -38; -10, -42], style(color=41)),
            Rectangle(extent=[-70, -38; -50, -42], style(color=41)),
            Rectangle(extent=[-84, 92; -64, 88], style(color=41)),
            Polygon(points=[-56, 90; -41, 75; -41, 90; -56, 90], style(color=41)),
            Polygon(points=[20, 20; 20, 40; 5, 20; 20, 20], style(color=41)),
            Polygon(points=[40, 20; 40, 40; 56, 20; 40, 20], style(color=41)),
            Polygon(points=[19, -40; 19, -20; 34, -40; 19, -40], style(color=41)),
            Rectangle(extent=[-10, 92; 10, 88], style(color=53)),
            Rectangle(extent=[50, 92; 70, 88], style(color=53)),
            Rectangle(extent=[10, -78; 30, -82], style(color=53)),
            Rectangle(extent=[30, -78; 50, -82], style(color=53)),
            Rectangle(extent=[50, -78; 70, -82], style(color=53)),
            Rectangle(extent=[70, -78; 90, -82], style(color=53)),
            Polygon(points=[10, -50; -10, -50; 10, -65; 10, -50], style(color=
                    53)),
            Text(
              extent=[-19, 69; 17, 54],
              string="Bedroom 2",
              style(color=53)),
            Text(
              extent=[41, 70; 76, 54],
              string="Bedroom 1",
              style(color=53)),
            Text(
              extent=[33, -58; 64, -70],
              string="Sunspace",
              style(color=53)),
            Line(points=[50, -44; 50, -44], style(color=8)),
            Line(points=[41, -64; 41, -64], style(color=8)),
            Line(points=[70, -61; 70, -60], style(color=8))),
          Icon(
            Line(points=[-90, 90; -90, -40; 90, -40; 90, 20; -30, 20; -30, 90;
                  -90, 90], style(color=9, thickness=2)),
            Line(points=[-29, 90; 90, 90; 90, 20], style(color=57, thickness=2)),
            Line(points=[30, 90; 30, 20], style(color=53, thickness=2)),
            Line(points=[10, -40; 10, -80; 90, -80; 90, -41], style(color=53,
                  thickness=2)),
            Rectangle(extent=[60, -38; 80, -42], style(color=9)),
            Rectangle(extent=[-30, -38; -10, -42], style(color=9)),
            Rectangle(extent=[-70, -38; -50, -42], style(color=9)),
            Rectangle(extent=[-84, 92; -64, 88], style(color=9)),
            Polygon(points=[-55, 90; -40, 75; -40, 90; -55, 90], style(color=9)),
            Polygon(points=[20, 20; 20, 40; 5, 20; 20, 20], style(color=9)),
            Polygon(points=[40, 20; 40, 40; 56, 20; 40, 20], style(color=9)),
            Polygon(points=[20, -40; 20, -20; 35, -40; 20, -40], style(color=9)),
            Rectangle(extent=[-10, 92; 10, 88], style(color=53)),
            Rectangle(extent=[50, 92; 70, 88], style(color=53)),
            Rectangle(extent=[10, -78; 30, -82], style(color=53)),
            Rectangle(extent=[30, -78; 50, -82], style(color=53)),
            Rectangle(extent=[50, -78; 70, -82], style(color=53)),
            Rectangle(extent=[70, -78; 90, -82], style(color=53)),
            Polygon(points=[10, -50; -10, -50; 10, -65; 10, -50], style(color=
                    53)),
            Text(
              extent=[-19, 69; 17, 54],
              string="Bedroom 2",
              style(color=53)),
            Text(
              extent=[41, 70; 76, 54],
              string="Bedroom 1",
              style(color=53)),
            Text(
              extent=[35, -54; 66, -66],
              string="Sunspace",
              style(color=53)),
            Text(
              extent=[-66, 3; 59, -17],
              string="Living Room",
              style(color=9))),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
We are now ready to assemble the house from its components.  At this point, the modeling task has become quite simple. <p>

The living room is assumed to be hmogeneous with respect to its temperature.  Thus, there is a single 0-junction with a heat capacity attached representing the air of the living room.  SInce the living room interacts with lots of modeling elements, there are many connections to the single 0-junction.  Thus, the 0-junction was split into 5 individual 0-junctions connected by bonds. <p>

The living room has four exterior walls facing North, West, South, and East.  It has three interior walls connecting it with the other three rooms. <p>

The living room has three exterior windows facing North and South.  It has three interior doors connecting it with the other three rooms.  There is also an interior window to the solarium.  Since interior windows use the same model as interior doors, the student chose to represent that window using the door model. There is also an exterior door, to which the ambient temperature was connected externally, which is ugly, because inconsistent in its programming style. <p>

Here is, where the student goofed once again.  The student needed a model of the ground temperature to connect to the slab.  Since he already had a \"temperature\" model, he also connected that to the exterior door.  Thus, the outside of the door is at the slab temperature, rather than at the ambient temperature.  Again, I didn't notice this error, when reading the thesis, because it is exceedingly difficult to extract this kind of information from an alphanumerical model.  The human eye is good at interpreting two- and even three-dimentsional topology, which gets lost when the model is mapped to the one-dimensional flow of an alphanumerical model. <p>

Other than that, there is the roof, the slab, and the air conditioning unit, and that's it. <p>

Of course, the devil is in the detail.  Each of these models contains a substantial number of parameters that need to be set, and getting the correct parameter values together for such a complex model is no easy task.
</html>
"));
        Window NWin(
          area=1.5,
          OH=0,
          W=0,
          sfa=180) annotation (extent=[-85, 68; -66, 88], rotation=90);
        ExWall NWall(
          area=6.6,
          sfa=180,
          OH=0.3,
          W=12) annotation (extent=[-70, 68; -50, 88], rotation=90);
        Door NDoor(
          lv=3.57,
          area=2.17,
          sfa=180,
          OH=0,
          W=0,
          absor=0.6) annotation (extent=[-54, 68; -34, 88], rotation=270);
        ExWall WWall(
          area=20.7,
          sfa=90,
          OH=0.3,
          W=8) annotation (extent=[-80, 20; -100, 40]);
        BondLib.Bonds.eBond NB1 annotation (extent=[-85, 48; -65, 68], rotation=
             -90);
        BondLib.Bonds.eBond NB2 annotation (extent=[-70, 48; -50, 68], rotation=
             -90);
        BondLib.Bonds.eBond NB3 annotation (extent=[-55, 48; -35, 68], rotation=
             -90);
        BondLib.Bonds.eBond WB1 annotation (extent=[-79, 22; -64, 37]);
        BondLib.Junctions.J0p5 J0p5_1 annotation (extent=[-63, 40; -43, 20]);
        Window SWin1(
          area=2.23,
          OH=0,
          W=0,
          sfa=0) annotation (extent=[-70, -62; -50, -42], rotation=-90);
        Window SWin2(
          area=2.23,
          OH=0,
          W=0,
          sfa=0) annotation (extent=[-29, -62; -9, -42], rotation=-90);
        ExWall SWall(
          area=15.7,
          sfa=0,
          OH=0.3,
          W=12) annotation (extent=[-50, -62; -30, -42], rotation=-90);
        BondLib.Bonds.eBond SB1 annotation (extent=[-70, -42; -50, -22],
            rotation=90);
        BondLib.Bonds.eBond SB2 annotation (extent=[-50, -42; -30, -22],
            rotation=90);
        BondLib.Bonds.eBond SB3 annotation (extent=[-30, -42; -10, -22],
            rotation=90);
        BondLib.Bonds.eBond CB1 annotation (extent=[-62, 5; -47, 20], rotation=
              -90);
        BondLib.Junctions.J0p6 J0p6_1 annotation (extent=[-13, -10; 7, 10]);
        BondLib.Bonds.eBond CB2 annotation (extent=[-29, -7; -14, 8]);
        BondLib.Bonds.eBond CB3 annotation (extent=[7, -7; 22, 8], rotation=180);
        BondLib.Junctions.J0p5 J0p5_3 annotation (extent=[22, 10; 42, -10]);
        BondLib.Bonds.eBond CB4 annotation (extent=[42, -7; 57, 8], rotation=
              180);
        BondLib.Junctions.J0p6 J0p6_2 annotation (extent=[57, -10; 77, 10]);
        Door SsWin(
          lv=3.4,
          area=1.1,
          sfa=0,
          OH=3.1,
          W=5.4,
          absor=0) annotation (extent=[60, -60; 80, -40], rotation=-90);
        Door SsDoor(
          lv=3.57,
          area=2.17,
          sfa=0,
          OH=0,
          W=0,
          absor=0) annotation (extent=[15, -60; 35, -40], rotation=-90);
        IntWall SsWall(
          area=12.9,
          dxd=0.14,
          thk=0.41) annotation (extent=[42, -35; 57, -19], rotation=-90);
        BondLib.Bonds.fBond SB4 annotation (extent=[52, -15; 62, -5], rotation=
              180);
        BondLib.Bonds.eBond SB5 annotation (extent=[40, -55; 60, -35], rotation=
             -90);
        BondLib.Bonds.fBond NB4 annotation (extent=[2, 20; 17, 34], rotation=90);
        BondLib.Bonds.fBond NB5 annotation (extent=[17, 20; 32, 34], rotation=
              90);
        Temperature2 Temperature2_1 annotation (extent=[-84, 95; -74, 105]);
        Modelica.Blocks.Sources.Clock Clock1 annotation (extent=[-100, 95; -90,
                105]);
        BondLib.Sources.mSe mSe1 annotation (extent=[-54, 94; -68, 107]);
        BondLib.Bonds.fBond NB6 annotation (extent=[-54, 95; -44, 105]);
        BondLib.Junctions.J0p4 J0p4_1 annotation (extent=[44, -65; 55, -55]);
        BondLib.Bonds.fBond SB6 annotation (extent=[17, -40; 32, -25], rotation=
             -90);
        BondLib.Bonds.fBond SB7 annotation (extent=[63, -40; 78, -25], rotation=
             -90);
        BondLib.Bonds.eBond SB8 annotation (extent=[31, -66; 44, -53]);
        BondLib.Bonds.eBond SB9 annotation (extent=[55, -67; 68, -54], rotation=
             180);
        BondLib.Interfaces.BondCon BondCon1 annotation (extent=[45, -77; 55, -
              67]);
        IntWall WallL2(area=15.2) annotation (extent=[15, 34; 35, 54], rotation=
             90);
        Door DoorL2(
          lv=3.57,
          area=2.17,
          sfa=180,
          OH=0,
          W=0,
          absor=0) annotation (extent=[-1, 34; 19, 54], rotation=90);
        BondLib.Bonds.eBond NB7 annotation (extent=[3, 55; 16, 68], rotation=90);
        BondLib.Bonds.eBond NB8 annotation (extent=[19, 55; 32, 68], rotation=
              90);
        BondLib.Junctions.J0p3 J0p3_1 annotation (extent=[9, 75; 25, 62]);
        BondLib.Interfaces.BondCon BondCon2 annotation (extent=[12, 78; 22, 88]);
        BondLib.Bonds.fBond NB9 annotation (extent=[42, 20; 57, 34], rotation=
              90);
        BondLib.Bonds.fBond NB10 annotation (extent=[63, 20; 78, 34], rotation=
              90);
        Door DoorL1(
          lv=3.57,
          area=2.17,
          sfa=180,
          OH=0,
          W=0,
          absor=0) annotation (extent=[40, 34; 60, 54], rotation=90);
        IntWall WallL1(area=6.6) annotation (extent=[60, 34; 80, 54], rotation=
              90);
        BondLib.Bonds.eBond NB11 annotation (extent=[43, 55; 56, 68], rotation=
              90);
        BondLib.Bonds.eBond NB12 annotation (extent=[64, 55; 77, 68], rotation=
              90);
        BondLib.Junctions.J0p3 J0p3_2 annotation (extent=[52, 75; 68, 62]);
        BondLib.Interfaces.BondCon BondCon3 annotation (extent=[55, 78; 65, 88]);
        BondLib.Bonds.eBond EB1 annotation (extent=[77, -6; 92, 9], rotation=
              180);
        ExWall EWall(
          area=11.3,
          sfa=270,
          OH=0.3,
          W=8) annotation (extent=[92, -10; 112, 10]);
        BondLib.Bonds.eBond AB1 annotation (extent=[-30, 16; -16, 30], rotation=
             -90);
        BondLib.Bonds.eBond RB1 annotation (extent=[-14, 16; 0, 30], rotation=-
              90);
        Roof Roof1(
          area=72.5,
          OH=0,
          W=0) annotation (extent=[-17, 30; 3, 50], rotation=90);
        BondLib.Sources.mSf mSf1 annotation (extent=[-30, 30; -15, 45],
            rotation=90);
        AirConditioning AirConditioning1 annotation (extent=[-28, 50; -18, 60],
              rotation=-90);
        BondLib.Bonds.eBond CCB1 annotation (extent=[-14, -29; 0, -15],
            rotation=-90);
        BondLib.Thermal.Cth Cth1(gamma=gamma, e(start=288)) annotation (extent=
              [-14, -45; 1, -30], rotation=-90);
        Slab Slab1(perim=23.7, area=72.5) annotation (extent=[-4, -80; 15, -60],
              rotation=90);
        BondLib.Sources.mSe mSe2 annotation (extent=[-20, -86; -34, -73]);
        BondLib.Bonds.fBond SLB1 annotation (extent=[-19, -87; -6, -75]);
        BondLib.Bonds.eBond SLB2 annotation (extent=[-4, -60; 16, -40],
            rotation=90);
        BondLib.Junctions.J0p6 J0p6_3 annotation (extent=[-50, -10; -30, 10]);
        BondLib.Sensors.De De1 annotation (extent=[-28, 67; -18, 77], rotation=
              -90);
        BondLib.Bonds.fBond AB2 annotation (extent=[-31, 77; -16, 92], rotation=
             -90);
      equation 
        connect(NWin.BondCon1, NB1.fBondCon1) annotation (points=[-75.5,68; -75,
              68],   style(color=8));
        connect(NWall.BondCon1, NB2.fBondCon1) annotation (points=[-60, 68; -60,
                68], style(color=8));
        connect(WWall.BondCon1, WB1.fBondCon1) annotation (points=[-80,30;
              -79.5,30; -79.5,29.5; -79,29.5],
                     style(color=8));
        connect(WB1.eBondCon1, J0p5_1.BondCon1) annotation (points=[-64,29.5;
              -64,29.75; -64,30; -63,30],
                       style(color=8));
        connect(NB1.eBondCon1, J0p5_1.BondCon3) annotation (points=[-75,48; -75,
              40; -57,40],      style(color=8));
        connect(NB2.eBondCon1, J0p5_1.BondCon4) annotation (points=[-60,48; -49,
              48; -49,40],      style(color=8));
        connect(NB3.eBondCon1, J0p5_1.BondCon2) annotation (points=[-45,48; -45,
              40; -40,40; -40,30; -43,30],        style(color=8));
        connect(SWin1.BondCon1, SB1.fBondCon1) annotation (points=[-60, -42; -
              60, -42], style(color=8));
        connect(SWall.BondCon1, SB2.fBondCon1) annotation (points=[-40, -42; -
              40, -42], style(color=8));
        connect(SWin2.BondCon1, SB3.fBondCon1) annotation (points=[-19,-42; -20,
              -42],     style(color=8));
        connect(J0p5_1.BondCon5, CB1.fBondCon1) annotation (points=[-53,20;
              -53.5,20; -54.5,20; -54.5,20],
                       style(color=8));
        connect(CB2.eBondCon1, J0p6_1.BondCon1) annotation (points=[-14,0.5;
              -13.5,0.5; -13.5,0; -13,0],
                    style(color=8));
        connect(CB3.eBondCon1, J0p6_1.BondCon2) annotation (points=[7,0.5; 7,0],
              style(color=8));
        connect(J0p5_3.BondCon1, CB3.fBondCon1) annotation (points=[22,0; 22,
              0.5],
                  style(color=8));
        connect(CB4.eBondCon1, J0p5_3.BondCon2) annotation (points=[42,0.5; 
              42.25,0.5; 42.25,-0.5; 42.5,-0.5; 42.5,0; 42,0],
                  style(color=8));
        connect(J0p6_2.BondCon1, CB4.fBondCon1) annotation (points=[57,0; 57,
              0.5],
                  style(color=8));
        connect(J0p5_3.BondCon3, NB4.eBondCon1) annotation (points=[28, 10; 28,
                15; 9.5, 15; 9.5, 20], style(color=8));
        connect(Clock1.y,Temperature2_1.u)             annotation (points=[-
              89.5, 100; -85, 100], style(color=3));
        connect(Temperature2_1.y,       mSe1.InPort1) annotation (points=[-73.5,
              100; -70.4,100; -70.4,100.5; -67.3,100.5],
                                style(color=3));
        connect(mSe1.BondCon1, NB6.eBondCon1) annotation (points=[-54,100.5;
              -54,100],
                      style(color=8));
        connect(NDoor.BondCon2, NB3.fBondCon1) annotation (points=[-44,68; -45,
              68],   style(color=8));
        connect(NB6.fBondCon1, NDoor.BondCon1) annotation (points=[-44,100; -40,
              100; -40,95; -44,95; -44,88],        style(color=8));
        connect(J0p5_3.BondCon4, NB5.eBondCon1) annotation (points=[36,10; 36,
              18; 24.5,18; 24.5,20], style(color=8));
        connect(SsWall.BondCon2, SB5.fBondCon1) annotation (points=[49.5,-35;
              50,-35],style(color=8));
        connect(SB6.fBondCon1, SsDoor.BondCon1) annotation (points=[24.5,-40;
              25,-40],style(color=8));
        connect(SB7.fBondCon1, SsWin.BondCon1) annotation (points=[70.5,-40; 70,
              -40],   style(color=8));
        connect(J0p6_2.BondCon4, SB7.eBondCon1) annotation (points=[71,-10; 71,
              -17.5; 71,-25; 70.5,-25],
                      style(color=8));
        connect(SB5.eBondCon1, J0p4_1.BondCon4) annotation (points=[50,-55;
              49.5,-55],
                      style(color=8));
        connect(SB8.eBondCon1, J0p4_1.BondCon1) annotation (points=[44,-59.5;
              44,-60],style(color=8));
        connect(SsDoor.BondCon2, SB8.fBondCon1) annotation (points=[25,-60; 28,
              -60; 28,-59.5; 31,-59.5],
                      style(color=8));
        connect(SB9.eBondCon1, J0p4_1.BondCon2) annotation (points=[55,-60.5;
              55,-60],style(color=8));
        connect(SsWin.BondCon2, SB9.fBondCon1) annotation (points=[70,-60; 69,
              -60; 69,-60.5; 68,-60.5],
                      style(color=8));
        connect(J0p4_1.BondCon3, BondCon1) annotation (points=[49.5,-65; 49.5,
              -68; 50,-68; 50,-72],
                 style(color=8));
        connect(NB5.fBondCon1, WallL2.BondCon1) annotation (points=[24.5,34; 25,
              34],   style(color=8));
        connect(NB4.fBondCon1, DoorL2.BondCon1) annotation (points=[9.5,34; 9,
              34], style(color=8));
        connect(DoorL2.BondCon2, NB7.fBondCon1) annotation (points=[9,54; 9,
              54.5; 9,55; 9.5,55],
                   style(color=8));
        connect(WallL2.BondCon2, NB8.fBondCon1) annotation (points=[25,54; 25,
              54.5; 25,55; 25.5,55],
                     style(color=8));
        connect(NB7.eBondCon1, J0p3_1.BondCon1) annotation (points=[9.5,68; 9.5,
              68.25; 9,68.25; 9,68.5],
                     style(color=8));
        connect(NB8.eBondCon1, J0p3_1.BondCon2) annotation (points=[25.5,68;
              25.5,68.25; 25,68.25; 25,68.5],
                       style(color=8));
        connect(J0p3_1.BondCon3, BondCon2) annotation (points=[17,75; 17,83],
              style(color=8));
        connect(J0p6_2.BondCon5, NB9.eBondCon1) annotation (points=[63,10; 63,
              16; 49.5,16; 49.5,20], style(color=8));
        connect(J0p6_2.BondCon6, NB10.eBondCon1) annotation (points=[71,10; 71,
              15; 71,20; 70.5,20],
                     style(color=8));
        connect(NB9.fBondCon1, DoorL1.BondCon1) annotation (points=[49.5,34; 50,
              34],   style(color=8));
        connect(NB10.fBondCon1, WallL1.BondCon1) annotation (points=[70.5,34;
              70,34],style(color=8));
        connect(DoorL1.BondCon2, NB11.fBondCon1) annotation (points=[50,54; 50,
              54.5; 50,55; 49.5,55],
                     style(color=8));
        connect(WallL1.BondCon2, NB12.fBondCon1) annotation (points=[70,54; 70,
              54.5; 70,55; 70.5,55],
                     style(color=8));
        connect(NB11.eBondCon1, J0p3_2.BondCon1) annotation (points=[49.5,68;
              50.75,68; 50.75,68.5; 52,68.5],
                     style(color=8));
        connect(NB12.eBondCon1, J0p3_2.BondCon2) annotation (points=[70.5,68;
              69.25,68; 69.25,68.5; 68,68.5],
                     style(color=8));
        connect(J0p3_2.BondCon3, BondCon3) annotation (points=[60,75; 60,83],
              style(color=8));
        connect(EB1.eBondCon1, J0p6_2.BondCon2) annotation (points=[77,1.5; 77,
              0], style(color=8));
        connect(EWall.BondCon1, EB1.fBondCon1) annotation (points=[92,0; 92,1.5],
                    style(color=8));
        connect(RB1.eBondCon1, J0p6_1.BondCon6) annotation (points=[-7,16; -7,
              13; 1,13; 1,10],     style(color=8));
        connect(AB1.eBondCon1, J0p6_1.BondCon5) annotation (points=[-23, 16; -
              23, 10; -7, 10], style(color=8));
        connect(Roof1.BondCon1, RB1.fBondCon1) annotation (points=[-7,30; -7,30],
                   style(color=8));
        connect(mSf1.BondCon1, AB1.fBondCon1) annotation (points=[-22.5,30; -23,
              30],   style(color=8));
        connect(AirConditioning1.y,       mSf1.InPort1) annotation (points=[-23,
              49.5; -23,44.25; -22.5,44.25],
                              style(color=3));
        connect(J0p6_1.BondCon3, CCB1.fBondCon1) annotation (points=[-7,-10; -7,
              -12.5; -7,-15; -7,-15],
                       style(color=8));
        connect(CCB1.eBondCon1, Cth1.BondCon1) annotation (points=[-7,-29; -7,
              -29.5; -6.5,-29.5; -6.5,-30],     style(color=8));
        connect(mSe2.BondCon1, SLB1.eBondCon1) annotation (points=[-20,-79.5;
              -19.5,-79.5; -19.5,-81; -19,-81], style(color=8));
        connect(SLB1.fBondCon1, Slab1.BondCon1) annotation (points=[-6,-81; 5.5,
              -81; 5.5,-80],  style(color=8));
        connect(Temperature2_1.y,       mSe2.InPort1) annotation (points=[-73.5,
              100; -70,100; -70,110; -105,110; -105,-79.5; -33.3,-79.5],style(
              color=3));
        connect(Slab1.BondCon2, SLB2.fBondCon1) annotation (points=[5.5,-60; 
              5.5,-60; 6,-60; 6,-60],
                    style(color=8));
        connect(SLB2.eBondCon1, J0p6_1.BondCon4) annotation (points=[6,-40; 6,
              -25; 1,-25; 1,-10],     style(color=8));
        connect(CB1.eBondCon1, J0p6_3.BondCon5) annotation (points=[-54.5,5;
              -54.5,2; -49,2; -49,10; -44,10],style(color=8));
        connect(J0p6_3.BondCon2, CB2.fBondCon1) annotation (points=[-30,0;
              -29.5,0; -29.5,0.5; -29,0.5],
                    style(color=8));
        connect(SB1.eBondCon1, J0p6_3.BondCon1) annotation (points=[-60, -22; -
              60, 0; -50, 0], style(color=8));
        connect(SB2.eBondCon1, J0p6_3.BondCon3) annotation (points=[-40, -22; -
              40, -16; -44, -16; -44, -10], style(color=8));
        connect(SB3.eBondCon1, J0p6_3.BondCon4) annotation (points=[-20,-22;
              -20,-10; -36,-10],  style(color=8));
        connect(De1.OutPort1,AirConditioning1.u)       annotation (points=[-23,
              66.5; -23,61],  style(color=3));
        connect(AB2.fBondCon1, De1.BondCon1) annotation (points=[-23.5,77; -23,
              77], style(color=8));
        connect(J0p6_3.BondCon6, AB2.eBondCon1) annotation (points=[-36,10; -36,
              95; -23.5,95; -23.5,92],   style(color=8));
        connect(SB4.eBondCon1, J0p6_2.BondCon3) annotation (points=[62, -10; 63,
                -10], style(color=8));
        connect(SB4.fBondCon1, SsWall.BondCon1) annotation (points=[52,-10;
              49.5,-10; 49.5,-19],
                               style(color=8));
        connect(J0p5_3.BondCon5, SB6.eBondCon1) annotation (points=[32,-10; 32,
              -16; 24.5,-16; 24.5,-25], style(color=8));
      end LivingRoom;
      
      model BedRoom1 "Bed room #1" 
        parameter Real c=1000 "Specific heat capacity of living room";
        parameter Real m=54 "Mass of living room";
        parameter Real gamma=c*m/3600 "Heat capacity of living room";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[1, 1],
            component=[10, 10]),
          Icon(
            Line(points=[-90, 90; -90, -40; 90, -40; 90, 20; -30, 20; -30, 90;
                  -90, 90], style(color=53, thickness=2)),
            Line(points=[-29, 90; 90, 90; 90, 20], style(color=57, thickness=2)),
            Line(points=[30, 90; 30, 20], style(color=53, thickness=2)),
            Line(points=[10, -40; 10, -80; 90, -80; 90, -41], style(color=53,
                  thickness=2)),
            Rectangle(extent=[60, -38; 80, -42], style(color=53)),
            Rectangle(extent=[-30, -38; -10, -42], style(color=53)),
            Rectangle(extent=[-70, -38; -50, -42], style(color=53)),
            Rectangle(extent=[-84, 92; -64, 88], style(color=53)),
            Polygon(points=[-55, 90; -40, 75; -40, 90; -55, 90], style(color=53)),
            Polygon(points=[20, 20; 20, 40; 5, 20; 20, 20], style(color=53)),
            Polygon(points=[40, 20; 40, 40; 56, 20; 40, 20], style(color=9)),
            Polygon(points=[20, -40; 20, -20; 35, -40; 20, -40], style(color=53)),
            Rectangle(extent=[-10, 92; 10, 88], style(color=53)),
            Rectangle(extent=[50, 92; 70, 88], style(color=9)),
            Rectangle(extent=[10, -78; 30, -82], style(color=53)),
            Rectangle(extent=[30, -78; 50, -82], style(color=53)),
            Rectangle(extent=[50, -78; 70, -82], style(color=53)),
            Rectangle(extent=[70, -78; 90, -82], style(color=53)),
            Polygon(points=[10, -50; -10, -50; 10, -65; 10, -50], style(color=
                    53)),
            Text(
              extent=[-19, 69; 17, 54],
              string="Bedroom 2",
              style(color=53)),
            Text(
              extent=[34, 74; 86, 40],
              string="Bedroom 1",
              style(color=9)),
            Text(
              extent=[35, -54; 66, -66],
              string="Sunspace",
              style(color=53)),
            Text(
              extent=[-36, 0; 44, -10],
              string="Living Room",
              style(color=53)),
            Rectangle(extent=[30, 90; 90, 20], style(color=9, thickness=2))),
          Diagram(
            Line(points=[-90, 90; -90, -40; 90, -40; 90, 20; -30, 20; -30, 90;
                  -90, 90], style(color=53, thickness=2)),
            Line(points=[-29, 90; 90, 90; 90, 20], style(color=57, thickness=2)),
            Line(points=[30, 90; 30, 20], style(color=53, thickness=2)),
            Line(points=[10, -40; 10, -80; 90, -80; 90, -41], style(color=53,
                  thickness=2)),
            Rectangle(extent=[60, -38; 80, -42], style(color=53)),
            Rectangle(extent=[-30, -38; -10, -42], style(color=53)),
            Rectangle(extent=[-70, -38; -50, -42], style(color=53)),
            Rectangle(extent=[-84, 92; -64, 88], style(color=53)),
            Polygon(points=[-55, 90; -40, 75; -40, 90; -55, 90], style(color=53)),
            Polygon(points=[20, 20; 20, 40; 5, 20; 20, 20], style(color=53)),
            Polygon(points=[40, 20; 40, 40; 56, 20; 40, 20], style(color=41)),
            Polygon(points=[20, -40; 20, -20; 35, -40; 20, -40], style(color=53)),
            Rectangle(extent=[-10, 92; 10, 88], style(color=53)),
            Rectangle(extent=[50, 92; 70, 88], style(color=41)),
            Rectangle(extent=[10, -78; 30, -82], style(color=53)),
            Rectangle(extent=[30, -78; 50, -82], style(color=53)),
            Rectangle(extent=[50, -78; 70, -82], style(color=53)),
            Rectangle(extent=[70, -78; 90, -82], style(color=53)),
            Polygon(points=[10, -50; -10, -50; 10, -65; 10, -50], style(color=
                    53)),
            Text(
              extent=[-19, 69; 17, 54],
              string="Bedroom 2",
              style(color=53)),
            Text(
              extent=[34, 72; 86, 38],
              string="Bedroom 1",
              style(color=41)),
            Text(
              extent=[35, -54; 66, -66],
              string="Sunspace",
              style(color=53)),
            Text(
              extent=[-36, -7; 44, -17],
              string="Living Room",
              style(color=53)),
            Rectangle(extent=[30, 90; 90, 20], style(color=41, thickness=2)),
            Line(points=[56, 29; 56, 29], style(color=8))),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This model uses the same technology as the more complex <i>living room</i>.  Please, read the documeentation of the living room model.
</html>
"));
        BondLib.Junctions.J0p5 J0p5_1 annotation (extent=[50, 30; 70, 50]);
        BondLib.Junctions.J0p5 J0p5_2 annotation (extent=[50, 84; 70, 64]);
        BondLib.Bonds.eBond CB1 annotation (extent=[53, 50; 67, 64], rotation=-
              90);
        BondLib.Bonds.eBond EB1 annotation (extent=[71, 33; 86, 48], rotation=
              180);
        ExWall EWall(
          area=9.4,
          sfa=270,
          OH=0.3,
          W=8) annotation (extent=[86, 30; 106, 50]);
        BondLib.Bonds.eBond NB1 annotation (extent=[49, 84; 63, 99], rotation=-
              90);
        BondLib.Bonds.eBond NB2 annotation (extent=[70, 84; 84, 99], rotation=-
              90);
        Window NWin(
          area=1.5,
          OH=0,
          W=0,
          sfa=180) annotation (extent=[47, 89; 28, 109]);
        ExWall NWall(
          area=9,
          sfa=180,
          OH=0.3,
          W=12) annotation (extent=[87, 89; 107, 109]);
        BondLib.Bonds.eBond RB1 annotation (extent=[70, 67; 84, 81], rotation=-
              180);
        Roof Roof1(
          area=15,
          OH=0,
          W=0) annotation (extent=[84, 64; 104, 84]);
        BondLib.Bonds.fBond WB1 annotation (extent=[35, 67; 50, 81], rotation=
              180);
        IntWall Wall12(area=6.6) annotation (extent=[35, 64; 15, 84]);
        BondLib.Bonds.eBond WB2 annotation (extent=[2, 68; 15, 81], rotation=
              180);
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[-13, 67; 2, 82]);
        BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-30, 70; -20,
              80]);
        BondLib.Bonds.eBond CCB1 annotation (extent=[73, 6; 87, 20], rotation=-
              90);
        BondLib.Thermal.Cth Cth1(gamma=gamma, e(start=288)) annotation (extent=
              [72, -9; 87, 6], rotation=-90);
        BondLib.Bonds.eBond CB2 annotation (extent=[48, 5; 63, 20], rotation=90);
        BondLib.Interfaces.BondCon BondCon2 annotation (extent=[51, -20; 61, -
              10]);
        BondLib.Bonds.eBond SLB2 annotation (extent=[10, 15; 30, 35], rotation=
              90);
        Slab Slab1(perim=7.9, area=15) annotation (extent=[10, -5; 30, 15],
            rotation=90);
        BondLib.Bonds.fBond SLB1 annotation (extent=[-2, -11; 11, 1]);
        BondLib.Sources.mSe mSe1 annotation (extent=[-3, -15; -22, 5]);
        Temperature2 Temperature2_1 annotation (extent=[-50, -16; -30, 4]);
        Modelica.Blocks.Sources.Clock Clock1 annotation (extent=[-80, -16; -60,
                4]);
      equation 
        connect(CB1.eBondCon1, J0p5_1.BondCon5) annotation (points=[60, 50; 60,
                50], style(color=8));
        connect(J0p5_2.BondCon5, CB1.fBondCon1) annotation (points=[60, 64; 60,
                64], style(color=8));
        connect(EB1.eBondCon1, J0p5_1.BondCon2) annotation (points=[71,40.5; 71,
              40.25; 71,40; 70,40],
                     style(color=8));
        connect(EWall.BondCon1, EB1.fBondCon1) annotation (points=[86,40; 86,
              40.5],
                   style(color=8));
        connect(NB1.eBondCon1, J0p5_2.BondCon3) annotation (points=[56, 84; 56,
                84], style(color=8));
        connect(NB2.eBondCon1, J0p5_2.BondCon4) annotation (points=[77, 84; 64,
                84], style(color=8));
        connect(NWall.BondCon1, NB2.fBondCon1) annotation (points=[87, 99; 77,
              99], style(color=8));
        connect(RB1.eBondCon1, J0p5_2.BondCon2) annotation (points=[70,74; 70,
              74],   style(color=8));
        connect(Roof1.BondCon1, RB1.fBondCon1) annotation (points=[84, 74; 84,
              74], style(color=8));
        connect(NWin.BondCon1, NB1.fBondCon1) annotation (points=[47, 99; 56,
              99], style(color=8));
        connect(J0p5_2.BondCon1, WB1.eBondCon1) annotation (points=[50, 74; 50,
                74], style(color=8));
        connect(WB1.fBondCon1, Wall12.BondCon1) annotation (points=[35, 74; 35,
                74], style(color=8));
        connect(Wall12.BondCon2, WB2.fBondCon1) annotation (points=[15,74; 15,
              74.5], style(color=8));
        connect(WB2.eBondCon1, J0p2_1.BondCon2) annotation (points=[2,74.5; 2,
              74.5], style(color=8));
        connect(J0p2_1.BondCon1, BondCon1) annotation (points=[-13,74.5; -19,
              74.5; -19,75; -25,75],
                 style(color=8));
        connect(J0p5_1.BondCon4, CCB1.fBondCon1) annotation (points=[64, 30; 80,
                30; 80, 20], style(color=8));
        connect(CCB1.eBondCon1, Cth1.BondCon1) annotation (points=[80,6; 79.75,
              6; 79.75,6; 79.5,6],
                 style(color=8));
        connect(CB2.eBondCon1, J0p5_1.BondCon3) annotation (points=[55.5,20;
              55.5,25; 56,25; 56,30],
                     style(color=8));
        connect(CB2.fBondCon1, BondCon2) annotation (points=[55.5,5; 55.5,-6.5;
              56,-6.5; 56,-15],
            style(color=8));
        connect(SLB2.eBondCon1, J0p5_1.BondCon1) annotation (points=[20, 35; 20,
                40; 50, 40], style(color=8));
        connect(Slab1.BondCon2, SLB2.fBondCon1) annotation (points=[20, 15; 20,
                15], style(color=8));
        connect(SLB1.fBondCon1, Slab1.BondCon1) annotation (points=[11, -5; 20,
                -5], style(color=8));
        connect(mSe1.BondCon1, SLB1.eBondCon1) annotation (points=[-3, -5; -2,
              -5], style(color=8));
        connect(Temperature2_1.y,       mSe1.InPort1) annotation (points=[-29,
              -6; -25.025,-6; -25.025,-5; -21.05,-5],
                            style(color=3));
        connect(Clock1.y,Temperature2_1.u)             annotation (points=[-59,
              -6; -52,-6],    style(color=3));
      end BedRoom1;
      
      model BedRoom2 "Bed room #2" 
        parameter Real c=1000 "Specific heat capacity of living room";
        parameter Real m=54 "Mass of living room";
        parameter Real gamma=c*m/3600 "Heat capacity of living room";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[1, 1],
            component=[10, 10]),
          Icon(
            Line(points=[-90, 90; -90, -40; 90, -40; 90, 20; -30, 20; -30, 90;
                  -90, 90], style(color=53, thickness=2)),
            Line(points=[-29, 90; 90, 90; 90, 20], style(color=57, thickness=2)),
            Line(points=[30, 90; 30, 20], style(color=53, thickness=2)),
            Line(points=[10, -40; 10, -80; 90, -80; 90, -41], style(color=53,
                  thickness=2)),
            Rectangle(extent=[60, -38; 80, -42], style(color=53)),
            Rectangle(extent=[-30, -38; -10, -42], style(color=53)),
            Rectangle(extent=[-70, -38; -50, -42], style(color=53)),
            Rectangle(extent=[-84, 92; -64, 88], style(color=53)),
            Polygon(points=[-55, 90; -40, 75; -40, 90; -55, 90], style(color=53)),
            Polygon(points=[20, 20; 20, 40; 5, 20; 20, 20], style(color=9)),
            Polygon(points=[40, 20; 40, 40; 56, 20; 40, 20], style(color=53)),
            Polygon(points=[20, -40; 20, -20; 35, -40; 20, -40], style(color=53)),
            Rectangle(extent=[-10, 92; 10, 88], style(color=9)),
            Rectangle(extent=[50, 92; 70, 88], style(color=53)),
            Rectangle(extent=[10, -78; 30, -82], style(color=53)),
            Rectangle(extent=[30, -78; 50, -82], style(color=53)),
            Rectangle(extent=[50, -78; 70, -82], style(color=53)),
            Rectangle(extent=[70, -78; 90, -82], style(color=53)),
            Polygon(points=[10, -50; -10, -50; 10, -65; 10, -50], style(color=
                    53)),
            Text(
              extent=[41, 69; 77, 54],
              string="Bedroom 1",
              style(color=53)),
            Text(
              extent=[-26, 76; 26, 42],
              string="Bedroom 2",
              style(color=9)),
            Text(
              extent=[35, -54; 66, -66],
              string="Sunspace",
              style(color=53)),
            Text(
              extent=[-36, 0; 44, -10],
              string="Living Room",
              style(color=53)),
            Rectangle(extent=[-30, 90; 30, 20], style(color=9, thickness=2))),
          Diagram(
            Line(points=[-90, 90; -90, -40; 90, -40; 90, 20; -30, 20; -30, 90;
                  -90, 90], style(color=53, thickness=2)),
            Line(points=[-29, 90; 90, 90; 90, 20], style(color=57, thickness=2)),
            Line(points=[30, 90; 30, 20], style(color=53, thickness=2)),
            Line(points=[10, -40; 10, -80; 90, -80; 90, -41], style(color=53,
                  thickness=2)),
            Rectangle(extent=[60, -38; 80, -42], style(color=53)),
            Rectangle(extent=[-30, -38; -10, -42], style(color=53)),
            Rectangle(extent=[-70, -38; -50, -42], style(color=53)),
            Rectangle(extent=[-84, 92; -64, 88], style(color=53)),
            Polygon(points=[-55, 90; -40, 75; -40, 90; -55, 90], style(color=53)),
            Polygon(points=[20, 20; 20, 40; 5, 20; 20, 20], style(color=41)),
            Polygon(points=[40, 20; 40, 40; 56, 20; 40, 20], style(color=53)),
            Polygon(points=[20, -40; 20, -20; 35, -40; 20, -40], style(color=53)),
            Rectangle(extent=[-10, 92; 10, 88], style(color=41)),
            Rectangle(extent=[50, 92; 70, 88], style(color=53)),
            Rectangle(extent=[10, -78; 30, -82], style(color=53)),
            Rectangle(extent=[30, -78; 50, -82], style(color=53)),
            Rectangle(extent=[50, -78; 70, -82], style(color=53)),
            Rectangle(extent=[70, -78; 90, -82], style(color=53)),
            Polygon(points=[10, -50; -10, -50; 10, -65; 10, -50], style(color=
                    53)),
            Text(
              extent=[41, 69; 77, 54],
              string="Bedroom 1",
              style(color=53)),
            Text(
              extent=[-26, 76; 26, 42],
              string="Bedroom 2",
              style(color=41)),
            Text(
              extent=[35, -54; 66, -66],
              string="Sunspace",
              style(color=53)),
            Text(
              extent=[-27, -1; 53, -11],
              string="Living Room",
              style(color=53)),
            Rectangle(extent=[-30, 90; 30, 20], style(color=41, thickness=2)),
            Polygon(points=[20, 20; 20, 40; 5, 20; 20, 20], style(color=53))),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This model uses the same technology as the more complex <i>living room</i>.  Please, read the documeentation of the living room model.
</html>
"));
        BondLib.Junctions.J0p5 J0p5_2 annotation (extent=[-10, 84; 10, 64]);
        BondLib.Bonds.eBond CB1 annotation (extent=[-7, 50; 7, 64], rotation=-
              90);
        BondLib.Junctions.J0p4 J0p4_1 annotation (extent=[-10, 30; 10, 50]);
        BondLib.Bonds.eBond NB1 annotation (extent=[-11, 84; 3, 99], rotation=-
              90);
        BondLib.Bonds.eBond NB2 annotation (extent=[13, 84; 27, 99], rotation=-
              90);
        ExWall NWall(
          area=9,
          sfa=180,
          OH=0.3,
          W=12) annotation (extent=[30, 89; 50, 109]);
        Window NWin(
          area=1.5,
          OH=0,
          W=0,
          sfa=180) annotation (extent=[-14, 89; -33, 109]);
        BondLib.Bonds.eBond RB1 annotation (extent=[-24, 67; -10, 81]);
        Roof Roof1(
          area=15,
          OH=0,
          W=0) annotation (extent=[-24, 64; -44, 84]);
        BondLib.Bonds.eBond CCB1 annotation (extent=[13, 16; 27, 30], rotation=
              -90);
        BondLib.Thermal.Cth Cth1(gamma=gamma, e(start=288)) annotation (extent=
              [13, 1; 28, 16], rotation=-90);
        BondLib.Bonds.eBond CB2 annotation (extent=[-8, 3; 7, 18], rotation=90);
        BondLib.Interfaces.BondCon BondCon1 annotation (extent=[-5, -20; 5, -10]);
        BondLib.Bonds.eBond SLB2 annotation (extent=[-30, 10; -10, 30],
            rotation=90);
        Slab Slab1(perim=4.2, area=15) annotation (extent=[-30, -10; -10, 10],
            rotation=90);
        BondLib.Bonds.fBond SLB1 annotation (extent=[-34, -16; -21, -4]);
        BondLib.Sources.mSe mSe1 annotation (extent=[-34, -20; -53, 0]);
        Temperature2 Temperature2_1 annotation (extent=[-80, 0; -60, 20],
            rotation=-90);
        Modelica.Blocks.Sources.Clock Clock1 annotation (extent=[-80, 30; -60,
              50], rotation=-90);
        BondLib.Bonds.eBond CB3 annotation (extent=[22, 66; 37, 81], rotation=
              180);
        BondLib.Interfaces.BondCon BondCon2 annotation (extent=[50, 68; 60, 78]);
      equation 
        connect(J0p5_2.BondCon5, CB1.fBondCon1) annotation (points=[0,64; 
              4.59566e-016,64],
                   style(color=8));
        connect(CB1.eBondCon1, J0p4_1.BondCon4) annotation (points=[
              1.31679e-015,50; 0,50],
                   style(color=8));
        connect(NB1.eBondCon1, J0p5_2.BondCon3) annotation (points=[-4,84; -4,
              84],   style(color=8));
        connect(NB2.eBondCon1, J0p5_2.BondCon4) annotation (points=[20, 84; 4,
              84], style(color=8));
        connect(NWall.BondCon1, NB2.fBondCon1) annotation (points=[30, 99; 20,
              99], style(color=8));
        connect(NWin.BondCon1, NB1.fBondCon1) annotation (points=[-14,99; -4,99],
                   style(color=8));
        connect(RB1.eBondCon1, J0p5_2.BondCon1) annotation (points=[-10, 74; -
              10, 74], style(color=8));
        connect(Roof1.BondCon1, RB1.fBondCon1) annotation (points=[-24, 74; -24,
                74], style(color=8));
        connect(J0p4_1.BondCon2, CCB1.fBondCon1) annotation (points=[10, 40; 20,
                40; 20, 30], style(color=8));
        connect(CCB1.eBondCon1, Cth1.BondCon1) annotation (points=[20,16; 20.5,
              16], style(color=8));
        connect(CB2.eBondCon1, J0p4_1.BondCon3) annotation (points=[-0.5,18; 
              -0.5,24; 0,24; 0,30],
                   style(color=8));
        connect(CB2.fBondCon1, BondCon1) annotation (points=[-0.5,3; -0.5,-8; 0,
              -8; 0,-15],
            style(color=8));
        connect(SLB2.eBondCon1, J0p4_1.BondCon1) annotation (points=[-20, 30; -
              20, 40; -10, 40], style(color=8));
        connect(Slab1.BondCon2, SLB2.fBondCon1) annotation (points=[-20, 10; -
              20, 10], style(color=8));
        connect(SLB1.fBondCon1, Slab1.BondCon1) annotation (points=[-21, -10; -
              20, -10], style(color=8));
        connect(mSe1.BondCon1, SLB1.eBondCon1) annotation (points=[-34, -10; -
              34, -10], style(color=8));
        connect(Temperature2_1.y,       mSe1.InPort1) annotation (points=[-70,
              -1; -70,-10; -52.05,-10],style(color=3));
        connect(Clock1.y,Temperature2_1.u)             annotation (points=[-70,
              29; -70,22],    style(color=3));
        connect(CB3.eBondCon1, J0p5_2.BondCon2) annotation (points=[22,73.5; 16,
              73.5; 16,74; 10,74],
                     style(color=8));
        connect(CB3.fBondCon1, BondCon2) annotation (points=[37,73.5; 42.25,
              73.5; 42.25,72.5; 47.5,72.5; 47.5,73; 55,73],
            style(color=8));
      end BedRoom2;
      
      model SunSpace "Solarium" 
        parameter Real c=1000 "Specific heat capacity of living room";
        parameter Real m=48.6 "Mass of living room";
        parameter Real gamma=c*m/3600 "Heat capacity of living room";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[1, 1],
            component=[10, 10]),
          Icon(
            Line(points=[-90, 90; -90, -40; 90, -40; 90, 20; -30, 20; -30, 90;
                  -90, 90], style(color=53, thickness=2)),
            Line(points=[-29, 90; 90, 90; 90, 20], style(color=57, thickness=2)),
            Line(points=[30, 90; 30, 20], style(color=53, thickness=2)),
            Line(points=[10, -40; 10, -80; 90, -80; 90, -41], style(color=53,
                  thickness=2)),
            Rectangle(extent=[60, -38; 80, -42], style(color=9)),
            Rectangle(extent=[-30, -38; -10, -42], style(color=53)),
            Rectangle(extent=[-70, -38; -50, -42], style(color=53)),
            Rectangle(extent=[-84, 92; -64, 88], style(color=53)),
            Polygon(points=[-55, 90; -40, 75; -40, 90; -55, 90], style(color=53)),
            Polygon(points=[20, 20; 20, 40; 5, 20; 20, 20], style(color=53)),
            Polygon(points=[40, 20; 40, 40; 56, 20; 40, 20], style(color=53)),
            Polygon(points=[20, -40; 20, -20; 35, -40; 20, -40], style(color=9)),
            Rectangle(extent=[-10, 92; 10, 88], style(color=53)),
            Rectangle(extent=[50, 92; 70, 88], style(color=53)),
            Rectangle(extent=[10, -78; 30, -82], style(color=9)),
            Rectangle(extent=[30, -78; 50, -82], style(color=9)),
            Rectangle(extent=[50, -78; 70, -82], style(color=9)),
            Rectangle(extent=[70, -78; 90, -82], style(color=9)),
            Polygon(points=[10, -50; -10, -50; 10, -65; 10, -50], style(color=9)),
            Text(
              extent=[-19, 69; 17, 54],
              string="Bedroom 2",
              style(color=53)),
            Text(
              extent=[24, -50; 76, -70],
              string="Sunspace",
              style(color=9)),
            Text(
              extent=[-36, 0; 44, -10],
              string="Living Room",
              style(color=53)),
            Text(
              extent=[41, 69; 77, 54],
              string="Bedroom 1",
              style(color=53)),
            Rectangle(extent=[10, -40; 90, -80], style(color=9, thickness=2))),
          Diagram(
            Rectangle(extent=[30, 2; 70, -2], style(color=41)),
            Polygon(points=[-60, 0; -60, 40; -30, 0; -60, 0], style(color=41)),
            Rectangle(extent=[-70, -78; -30, -82], style(color=41)),
            Polygon(points=[-70, -20; -110, -20; -70, -48; -70, -20], style(
                  color=41)),
            Text(
              extent=[-6, -22; 26, -40],
              string="Sunspace",
              style(color=41)),
            Rectangle(extent=[-70, 0; 90, -80], style(color=41, thickness=2)),
            Rectangle(extent=[-30, -78; 10, -82], style(color=41)),
            Rectangle(extent=[10, -78; 50, -82], style(color=41)),
            Rectangle(extent=[50, -78; 90, -82], style(color=41)),
            Line(points=[90, 0; 90, 100], style(color=53, thickness=2)),
            Line(points=[-70, 0; -100, 0], style(color=53, thickness=2)),
            Text(
              extent=[-86, 74; 14, 60],
              string="Living Room",
              style(color=53))),
          Documentation(info="<html>
This model uses the same technology as the more complex <i>living room</i>.  Please, read the documeentation of the living room model.
</html>
"));
        BondLib.Junctions.J0p6 J0p6_1 annotation (extent=[20, -55; 50, -25]);
        BondLib.Junctions.J0p6 J0p6_2 annotation (extent=[-30, -55; 0, -25]);
        BondLib.Bonds.eBond CB1 annotation (extent=[0, -50; 20, -30]);
        BondLib.Bonds.eBond EB1 annotation (extent=[50, -50; 70, -30], rotation=
             180);
        Window EWin(
          lv=4.9,
          area=6.2,
          OH=0,
          W=0,
          sfa=270) annotation (extent=[70, -50; 89, -30]);
        BondLib.Bonds.eBond EB2 annotation (extent=[41, -30; 61, -10], rotation=
             180);
        Door EWall(
          lv=5.11,
          area=3,
          sfa=270,
          OH=0,
          W=0) annotation (extent=[81, -30; 61, -10]);
        BondLib.Bonds.fBond EB3 annotation (extent=[81, -30; 101, -10],
            rotation=180);
        BondLib.Sources.mSe mSe1 annotation (extent=[111, -10; 91, 10],
            rotation=90);
        BondLib.Bonds.eBond CB2 annotation (extent=[19, -17; 39, 3], rotation=
              270);
        BondLib.Interfaces.BondCon BondCon1 annotation (extent=[24, 8; 34, 18]);
        BondLib.Bonds.eBond WB1 annotation (extent=[-50, -50; -30, -30]);
        Window WWin(
          lv=4.9,
          area=6.2,
          OH=0,
          W=0,
          sfa=90) annotation (extent=[-50, -50; -69, -30]);
        BondLib.Bonds.eBond WB2 annotation (extent=[-41, -30; -21, -10]);
        Door WWall(
          lv=5.11,
          area=3,
          sfa=90,
          OH=0,
          W=0) annotation (extent=[-61, -30; -41, -10]);
        BondLib.Bonds.fBond WB3 annotation (extent=[-81, -30; -61, -10]);
        BondLib.Sources.mSe mSe2 annotation (extent=[-91, -10; -71, 10],
            rotation=90);
        BondLib.Bonds.eBond RB1 annotation (extent=[-19, -15; 1, 5], rotation=
              270);
        Door SsRoof(
          lv=0.23,
          area=17.2,
          sfa=0,
          tilt=15,
          OH=0,
          W=0,
          absor=0.3) annotation (extent=[-19, 5; 1, 25], rotation=-90);
        BondLib.Bonds.fBond RB2 annotation (extent=[-19, 25; 1, 45], rotation=-
              90);
        BondLib.Sources.mSe mSe3 annotation (extent=[-20, 35; -40, 55]);
        BondLib.Bonds.eBond CCB1 annotation (extent=[19, -75; 39, -55],
            rotation=-90);
        BondLib.Thermal.Cth Cth1(gamma=gamma, e(start=288)) annotation (extent=
              [19, -95; 39, -75], rotation=-90);
        BondLib.Bonds.eBond SB1 annotation (extent=[-19, -75; 1, -55], rotation=
             90);
        Window SWin(
          lv=4.9,
          area=10.3,
          OH=0,
          W=0,
          sfa=0) annotation (extent=[-19, -95; 1, -75], rotation=-90);
        BondLib.Bonds.eBond SB2 annotation (extent=[-40, -75; -20, -55],
            rotation=90);
        Door SWall(
          lv=5.11,
          area=1,
          sfa=0,
          OH=0,
          W=0) annotation (extent=[-40, -95; -20, -75], rotation=90);
        BondLib.Bonds.fBond SB3 annotation (extent=[-60, -105; -40, -85]);
        BondLib.Sources.mSe mSe4 annotation (extent=[-60, -105; -80, -85]);
        BondLib.Bonds.eBond SLB2 annotation (extent=[40, -75; 60, -55],
            rotation=90);
        Slab Slab1(
          thk=0.1,
          perim=11.7,
          area=17.2,
          c=880,
          dens=2300) annotation (extent=[40, -95; 60, -75], rotation=90);
        BondLib.Bonds.fBond SLB1 annotation (extent=[60, -105; 80, -85],
            rotation=180);
        BondLib.Sources.mSe mSe5 annotation (extent=[80, -105; 100, -85]);
        Temperature2 Temperature2_1 annotation (extent=[-70, 80; -50, 100]);
        Modelica.Blocks.Sources.Clock Clock1 annotation (extent=[-100, 80; -80,
                100]);
      equation 
        connect(J0p6_2.BondCon2, CB1.fBondCon1) annotation (points=[0, -40; 0,
              -40], style(color=8));
        connect(CB1.eBondCon1, J0p6_1.BondCon1) annotation (points=[20, -40; 20,
                -40], style(color=8));
        connect(EB1.eBondCon1, J0p6_1.BondCon2) annotation (points=[50, -40; 50,
                -40], style(color=8));
        connect(EWin.BondCon1, EB1.fBondCon1) annotation (points=[70, -40; 70,
              -40], style(color=8));
        connect(EB2.eBondCon1, J0p6_1.BondCon6) annotation (points=[41, -20; 41,
                -25], style(color=8));
        connect(EWall.BondCon2, EB2.fBondCon1) annotation (points=[61, -20; 61,
                -20], style(color=8));
        connect(EB3.fBondCon1, EWall.BondCon1) annotation (points=[81, -20; 81,
                -20], style(color=8));
        connect(mSe1.BondCon1, EB3.eBondCon1) annotation (points=[101, -10; 101,
                -20], style(color=8));
        connect(CB2.eBondCon1, J0p6_1.BondCon5) annotation (points=[29,-17; 29,
              -21; 29,-21; 29,-25],
                      style(color=8));
        connect(WB1.eBondCon1, J0p6_2.BondCon1) annotation (points=[-30, -40; -
              30, -40], style(color=8));
        connect(WWin.BondCon1, WB1.fBondCon1) annotation (points=[-50, -40; -50,
                -40], style(color=8));
        connect(J0p6_2.BondCon5, WB2.eBondCon1) annotation (points=[-21,-25;
              -21,-20], style(color=8));
        connect(WWall.BondCon2, WB2.fBondCon1) annotation (points=[-41, -20; -
              41, -20], style(color=8));
        connect(WB3.fBondCon1, WWall.BondCon1) annotation (points=[-61, -20; -
              61, -20], style(color=8));
        connect(RB1.eBondCon1, J0p6_2.BondCon6) annotation (points=[-9,-15; -9,
              -20.5; -9,-25; -9,-25],
                      style(color=8));
        connect(SsRoof.BondCon2, RB1.fBondCon1) annotation (points=[-9,5; -9,5],
                  style(color=8));
        connect(RB2.fBondCon1, SsRoof.BondCon1) annotation (points=[-9, 25; -9,
                25], style(color=8));
        connect(mSe3.BondCon1, RB2.eBondCon1) annotation (points=[-20,45; -9,45],
                     style(color=8));
        connect(mSe2.BondCon1, WB3.eBondCon1) annotation (points=[-81, -10; -81,
                -20], style(color=8));
        connect(SB1.eBondCon1, J0p6_2.BondCon4) annotation (points=[-9, -55; -9,
                -55], style(color=8));
        connect(J0p6_1.BondCon3, CCB1.fBondCon1) annotation (points=[29, -55;
              29, -55], style(color=8));
        connect(CCB1.eBondCon1, Cth1.BondCon1) annotation (points=[29, -75; 29,
                -75], style(color=8));
        connect(SWin.BondCon1, SB1.fBondCon1) annotation (points=[-9, -75; -9,
              -75], style(color=8));
        connect(SB2.eBondCon1, J0p6_2.BondCon3) annotation (points=[-30,-55;
              -21,-55], style(color=8));
        connect(SWall.BondCon2, SB2.fBondCon1) annotation (points=[-30,-75; -30,
              -75],     style(color=8));
        connect(SB3.fBondCon1, SWall.BondCon1) annotation (points=[-40, -95; -
              30, -95], style(color=8));
        connect(mSe4.BondCon1, SB3.eBondCon1) annotation (points=[-60, -95; -60,
                -95], style(color=8));
        connect(SLB2.eBondCon1, J0p6_1.BondCon4) annotation (points=[50,-55; 41,
              -55],     style(color=8));
        connect(Slab1.BondCon2, SLB2.fBondCon1) annotation (points=[50, -75; 50,
                -75], style(color=8));
        connect(SLB1.fBondCon1, Slab1.BondCon1) annotation (points=[60, -95; 50,
                -95], style(color=8));
        connect(mSe5.BondCon1, SLB1.eBondCon1) annotation (points=[80, -95; 80,
                -95], style(color=8));
        connect(Clock1.y,Temperature2_1.u)             annotation (points=[-79,
              90; -72,90],    style(color=3));
        connect(Temperature2_1.y,       mSe1.InPort1) annotation (points=[-49,
              90; 101,90; 101,9],   style(color=3));
        connect(Temperature2_1.y,       mSe5.InPort1) annotation (points=[-49,
              90; 113,90; 113,-95; 99,-95],     style(color=3));
        connect(Temperature2_1.y,       mSe3.InPort1) annotation (points=[-49,
              90; -30, 90; -30, 107; -105, 107; -105, 45; -39, 45], style(color=
               3));
        connect(Temperature2_1.y,       mSe2.InPort1) annotation (points=[-49,
              90; -30,90; -30,107; -105,107; -105,26; -81,26; -81,9],
            style(color=3));
        connect(Temperature2_1.y,       mSe4.InPort1) annotation (points=[-49,
              90; -30,90; -30,107; -105,107; -105,-95; -79,-95],      style(
              color=3));
        connect(CB2.fBondCon1, BondCon1) annotation (points=[29,3; 29,6.25; 28,
              6.25; 28,9.5; 29,9.5; 29,13],
            style(color=8));
      end SunSpace;
      
      model House "Experimental house" 
        constant Modelica.SIunits.Temperature T0 = Modelica.Constants.T_zero 
          "Conversion between Centigrade and Kelvin";
        output Modelica.SIunits.CelsiusTemperature T_lr 
          "Temperature of living room";
        output Modelica.SIunits.CelsiusTemperature T_br1 
          "Temperature of bedroom 1";
        output Modelica.SIunits.CelsiusTemperature T_br2 
          "Temperature of bedroom 2";
        output Modelica.SIunits.CelsiusTemperature T_sol 
          "Temperature of solarium";
        output Modelica.SIunits.CelsiusTemperature T_amb "Ambient temperature";
        output Modelica.SIunits.CelsiusTemperature T_ew1 
          "Temperature at outer surface of eastern wall";
        output Modelica.SIunits.CelsiusTemperature T_ew2 
          "Outer internal temperature of eastern wall";
        output Modelica.SIunits.CelsiusTemperature T_ew3 
          "Inner internal temperature of eastern wall";
        output Modelica.SIunits.CelsiusTemperature T_ew4 
          "Temperature at inner surface of eastern wall";
        output Modelica.SIunits.HeatFlowRate Q_lr "Heat flow into living room";
        output Modelica.SIunits.HeatFlowRate Q_br1 "Heat flow into bedroom 1";
        output Modelica.SIunits.HeatFlowRate Q_br2 "Heat flow into bedroom 2";
        output Modelica.SIunits.HeatFlowRate Q_sol "Heat flow into solarium";
        output Modelica.SIunits.HeatFlowRate Q_ac 
          "Cooling flow from air conditioning";
        output Modelica.SIunits.HeatFlowRate Q_nwin 
          "Radiation heat flow through North exposed window";
        output Modelica.SIunits.HeatFlowRate Q_ewall 
          "Radiation heat flow into living room through East exposed wall";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(
            Rectangle(extent=[-82, 88; 86, 82], style(color=9)),
            Rectangle(extent=[-74, 82; 78, 74], style(color=9)),
            Rectangle(extent=[-74, 74; 78, 38], style(color=9)),
            Rectangle(extent=[-50, 68; -30, 50], style(color=9)),
            Line(points=[-40, 68; -40, 50], style(color=9)),
            Rectangle(extent=[-52, 68; -28, 66], style(color=0, fillColor=9)),
            Rectangle(extent=[-8, 68; 12, 50], style(color=9)),
            Line(points=[2, 68; 2, 50], style(color=9)),
            Rectangle(extent=[-10, 68; 14, 66], style(color=0, fillColor=9)),
            Rectangle(extent=[52, 68; 72, 50], style(color=9)),
            Line(points=[62, 68; 62, 50], style(color=9)),
            Rectangle(extent=[46, 68; 30, 38], style(color=9)),
            Rectangle(extent=[28, 68; 74, 66], style(color=9, fillColor=9)),
            Rectangle(extent=[28, 40; 48, 38], style(color=9, fillColor=9)),
            Ellipse(extent=[42, 54; 44, 52], style(color=9)),
            Line(points=[-86, 38; 90, 38], style(color=9)),
            Text(
              extent=[-90, 38; -2, 30],
              string="North Elevation",
              style(color=9)),
            Rectangle(extent=[-38, -20; 78, 10], style(color=9)),
            Line(points=[78, 10; 78, 18; -38, 12], style(color=9)),
            Line(points=[-38, -20; -38, 12], style(color=9)),
            Line(points=[78, 18; -46, 12; -46, 18; 78, 26; 78, 18], style(color=
                   9)),
            Line(points=[-38, 10; -76, 2; -76, -2; -38, 6], style(color=9)),
            Rectangle(extent=[-74, -2; -38, -20], style(color=9)),
            Rectangle(extent=[-72, -20; -40, -2], style(color=9)),
            Rectangle(extent=[-60, -20; -50, -2], style(color=9)),
            Rectangle(extent=[-62, -20; -52, -2], style(color=9)),
            Line(points=[-40, -2; -40, 6], style(color=9)),
            Line(points=[-42, -2; -42, 6], style(color=9)),
            Line(points=[-44, -2; -44, 4], style(color=9)),
            Line(points=[-46, -2; -46, 4], style(color=9)),
            Line(points=[-48, -2; -48, 4], style(color=9)),
            Line(points=[-50, -2; -50, 4], style(color=9)),
            Line(points=[-52, -2; -52, 4], style(color=9)),
            Line(points=[-54, -2; -54, 2], style(color=9)),
            Line(points=[-56, -2; -56, 2], style(color=9)),
            Line(points=[-58, -2; -58, 2], style(color=9)),
            Line(points=[-60, -4; -60, 2], style(color=9)),
            Line(points=[-62, -4; -62, 0], style(color=9)),
            Line(points=[-64, -2; -64, 0], style(color=9)),
            Line(points=[-66, -2; -66, 0], style(color=9)),
            Line(points=[-68, -2; -68, 0], style(color=9)),
            Text(
              extent=[4, -20; 92, -28],
              string="East Elevation",
              style(color=9)),
            Line(points=[-86, -20; 88, -20], style(color=9)),
            Rectangle(extent=[-80, -40; 84, -46], style(color=9)),
            Rectangle(extent=[-80, -46; 84, -54], style(color=9)),
            Rectangle(extent=[-72, -54; 76, -90], style(color=9)),
            Rectangle(extent=[-72, -90; 76, -56], style(color=9)),
            Rectangle(extent=[-62, -64; -34, -82], style(color=9)),
            Line(points=[-48, -64; -48, -82], style(color=9)),
            Rectangle(extent=[-64, -62; -32, -64], style(color=9, fillColor=9)),
            Rectangle(extent=[-24, -64; 4, -82], style(color=9)),
            Line(points=[-10, -64; -10, -82], style(color=9)),
            Rectangle(extent=[-26, -62; 6, -64], style(color=9, fillColor=9)),
            Rectangle(extent=[10, -56; 82, -64], style(color=9, fillColor=7)),
            Rectangle(extent=[10, -64; 82, -66], style(color=9, fillColor=7)),
            Rectangle(extent=[10, -66; 82, -68], style(color=9, fillColor=7)),
            Rectangle(extent=[14, -68; 76, -90], style(color=9)),
            Rectangle(extent=[16, -68; 74, -90], style(color=9)),
            Rectangle(extent=[20, -68; 34, -90], style(color=9)),
            Ellipse(extent=[30, -76; 32, -80], style(color=9)),
            Rectangle(extent=[36, -68; 50, -90], style(color=9)),
            Rectangle(extent=[52, -68; 72, -90], style(color=9)),
            Rectangle(extent=[52, -78; 64, -68], style(color=9)),
            Line(points=[56, -78; 56, -68], style(color=9)),
            Line(points=[-86, -90; 88, -90], style(color=9)),
            Text(
              extent=[-88, -90; 0, -98],
              string="South Elevation",
              style(color=9)),
            Rectangle(extent=[12, -90; 78, -92], style(color=9, fillColor=9))),
          Window(
            x=0.55,
            y=0.19,
            width=0.44,
            height=0.65),
          experiment(StopTime=8600),
          experimentSetupOutput(
            doublePrecision=true,
            states=false,
            derivatives=false,
            inputs=false,
            auxiliaries=false),
          Documentation(info="<html>
This is the top-level model of the experimental house.  This is the program that needs to be compiled and simulated. <p>
 
The iconic representation shows schematics of the North, East, and South elevations of the house. <p>

The diagram representation is interesting too.  Here, we overlaid four different models, the models of the four rooms onto the same space on the screen.  The four models have transparent backgrounds, thus they are visible to the top layer, except in places, where different models have lines at the same locations.  The living room model is the top layer.  Therefore, the walls of the living room are grey, whereas those of the other rooms are green (they actually come from the living room model). <p>

The actual \"model\" here consists of the four connections in the colors red, lilac, yellow, and blue. <p>

<font size=6 color=red><b>Enjoy!</b></font>
</html>
"));
        BedRoom1 BedRoom1_1 annotation (extent=[-100, -100; 100, 100]);
        BedRoom2 BedRoom2_1 annotation (extent=[-100, -100; 100, 100]);
        SunSpace SunSpace1 annotation (extent=[-100, -100; 100, 100]);
        LivingRoom LivingRoom1 annotation (extent=[-100, -100; 100, 100]);
      equation 
        T_lr = LivingRoom1.Cth1.e + T0;
        T_br1 = BedRoom1_1.Cth1.e + T0;
        T_br2 = BedRoom2_1.Cth1.e + T0;
        T_sol = SunSpace1.Cth1.e + T0;
        T_amb = LivingRoom1.NWin.Temperature1.y + T0;
        T_ew1 = LivingRoom1.EWall.Cth1.e + T0;
        T_ew2 = LivingRoom1.EWall.C1D1.Cth1.e + T0;
        T_ew3 = LivingRoom1.EWall.C1D2.Cth1.e + T0;
        T_ew4 = LivingRoom1.EWall.C1D3.Cth1.e + T0;
        Q_lr = LivingRoom1.Cth1.e * LivingRoom1.Cth1.f;
        Q_br1 = BedRoom1_1.Cth1.e * BedRoom1_1.Cth1.f;
        Q_br2 = BedRoom2_1.Cth1.e * BedRoom2_1.Cth1.f;
        Q_sol = SunSpace1.Cth1.e * SunSpace1.Cth1.f;
        Q_ac = LivingRoom1.Cth1.e * LivingRoom1.AirConditioning1.y;
        Q_nwin = LivingRoom1.Cth1.e * LivingRoom1.NWin.SolarGlass1.y;
        Q_ewall = LivingRoom1.EWall.Cth1.e * LivingRoom1.EWall.SolarRadiation1.y;
        connect(BedRoom2_1.BondCon2, BedRoom1_1.BondCon1) annotation (points=[55,
              73; 34.25,73; 34.25,74; 13.5,74; 13.5,75; -25,75],
                                style(color=41, thickness=4));
        connect(LivingRoom1.BondCon3, BedRoom1_1.BondCon2) annotation (points=[60,
              83; 60,34; 60,-15; 56,-15],
                                style(color=77, thickness=4));
        connect(BedRoom2_1.BondCon1, LivingRoom1.BondCon2) annotation (points=[0,
              -15; 0,-17; 14,84; 17,83],       style(color=81, thickness=4));
        connect(LivingRoom1.BondCon1, SunSpace1.BondCon1) annotation (points=[50,
              -72; 50,13; 29,13],       style(color=49, thickness=4));
      end House;
    end SolarHouse;
    
    package Biosphere "Biosphere 2" 
      annotation (
        Coordsys(
          extent=[0, 0; 433, 436],
          grid=[2, 2],
          component=[20, 20]),
        Diagram(
          Rectangle(extent=[-100.4, 100.9; 99.6, -99.1], style(
              color=0,
              thickness=2,
              fillColor=9)),
          Text(
            extent=[-60.4, 60.9; 59.45, 32.25],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="Thermal model of"),
          Text(
            extent=[-74.4, 10.9; 77.65, -34.2],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="without air conditioning"),
          Text(
            extent=[-40.25, 41.55; 41.65, 11.8],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="Biosphere 2"),
          Text(
            extent=[-72.1, 24.2; 73.6, -7.1],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="located in Tucson, AZ")),
        Icon(
          Rectangle(extent=[-100.05, 99.1; 99.95, -100.9], style(
              color=0,
              thickness=2,
              fillColor=9)),
          Text(
            extent=[-60.05, 59.1; 59.8, 30.45],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="Thermal model of"),
          Text(
            extent=[-74.05, 9.1; 78, -36],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="without air conditioning"),
          Text(
            extent=[-39.9, 39.75; 42, 10],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="Biosphere 2"),
          Text(
            extent=[-71.75, 22.4; 73.95, -8.9],
            style(
              color=0,
              thickness=2,
              fillColor=9,
              fillPattern=1),
            string="located in Tucson, AZ")),
        Documentation(info="<html>
This package contains a model of the thermal budget without air conditioning of Biosphere 2, an experimental research facility located 35 miles (50 km) north of Tucson, Arizona.  The structure is modeled in its original use, as a <i>materially closed, but energetically open system</i>.  Biosphere 2 is a glass building on 3 acres (12,000 m<sup>2</sup>).  It contains a number of different biomes: <p>

<ol>
<li> Amazonas rain forest biome,
<li> upper and lower Savannah biomes,
<li> salt-water lake biome,
<li> mangrove marsh biome,
<li> Southwestern desert biome, and
<li> agricultural biome.
</ol> <p>

<img src=\"../Images/BG_Ex4.jpg\"> <p>

<img src=\"../Images/BG_Ex5.jpg\"> <p>

Eight people lived in this structure for two years, growing their own food and regenerating their own air.  The purpose of the exercise was to test the feasibility of space colonies with current technology.

The design of this model has been described in: <p>

<hr> <p>

<b>References:</b> <p>

<ol>
<li> Nebot, A., F.E. Cellier, and F. Mugica (1999), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/ecoeng_bio2.pdf\">Simulation
     of Heat and Humidity Budget of Biosphere 2 without its Air Conditioning</a>,\" <i>Ecological Engineering</i>,
     <b>13</b>, pp. 333-356.
<li> Cellier, F.E. and A. Nebot (2005), \"<a href=\"http://www.inf.ethz.ch/~fcellier/Publikationen/modelica2005_cellier.pdf\">The
     Modelica Bond Graph Library</a>,\" <i>Proc. 4<sup>th</sup> Modelica Conference</i>, Hamburg, Germany.
</ol> <p>

<hr> <p>

The model makes use of five large data tables containing observations of: <p>

<ol>
<li> temperature,
<li> humidity,
<li> cloud cover,
<li> solar radiation. and
<li> wind velocity
</ol> <p>

stored hourly for an entire year for the location of Oracle, AZ, i.e., the location of the Biospere 2 project. <p>

These data items are stored on an external binary file (Bio_tables.mat) rather than in memory.  This is essential, as Dymola isn't geared to dealing with large data tables in memory.  Dymola essentially converts all matrices to sets of individual scalar variables in the process of compilation.  This is necessary, as the most flexible automatic causality assignment depends on this feature.  Yet, this is highly inefficient, when dealing with large data tables containing many thousands of data points.  We must hide these tables from Dymola, and can do so by placing them in external data files.

<hr> <p>

<b>Experimentation:</b> <p>

This model uses hours as time units.  If you wish to only experiment with this model, you can simulate it over 4 days by setting the final time to 96 hours.  However, if you wish to reproduce the results published in the 1999 paper [1], you need to simulate the model for a full year, i.e., during 8600 hours.  You should set the communication interval to 1 hour.  It may also make sense to limit the output storage to the explicitly defined output variable.  Both compilation and simulation of this complex model are amazingly fast (in the order of a few seconds).
</html>
"),     uses(Modelica(version="2.1"), BondLib(version="1")),
        version="2",
        conversion(from(version="", script="ConvertFromBiosphere_.mos"), from(
              version="1", script="ConvertFromBiosphere_1.mos")));
      block AmbientTemp "Ambient temperature" 
        extends Modelica.Blocks.Interfaces.SISO;
        constant Real m=0.556 
          "Multiplicative factor for conversion of temperature from Fahrenheit to Centigrade";
        constant Real a=-17.78 
          "Additive factor for conversion of temperature from Fahrenheit to Centigrade";
        constant Modelica.SIunits.Temperature T0 = -Modelica.Constants.T_zero 
          "Conversion between Centigrade and Kelvin";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(
            Rectangle(extent=[-30, 76; 26, -78]),
            Rectangle(extent=[-6, 60; 2, -54]),
            Ellipse(extent=[-8, -52; 4, -64], style(fillColor=73)),
            Rectangle(extent=[-6, -10; 2, -58], style(fillColor=73)),
            Line(points=[-8, -44; -18, -44]),
            Line(points=[-8, -42; -12, -42]),
            Line(points=[-8, -40; -12, -40]),
            Line(points=[-8, -38; -12, -38]),
            Line(points=[-8, -36; -12, -36]),
            Line(points=[-8, 36; -18, 36]),
            Line(points=[-8, 38; -12, 38]),
            Line(points=[-8, 40; -12, 40]),
            Line(points=[-8, 42; -12, 42]),
            Line(points=[-8, 44; -12, 44]),
            Line(points=[-8, -34; -18, -34]),
            Line(points=[-8, -32; -12, -32]),
            Line(points=[-8, -30; -12, -30]),
            Line(points=[-8, -28; -12, -28]),
            Line(points=[-8, -26; -12, -26]),
            Line(points=[-8, -24; -18, -24]),
            Line(points=[-8, -22; -12, -22]),
            Line(points=[-8, -20; -12, -20]),
            Line(points=[-8, -18; -12, -18]),
            Line(points=[-8, -16; -12, -16]),
            Line(points=[-8, -14; -18, -14]),
            Line(points=[-8, -12; -12, -12]),
            Line(points=[-8, -10; -12, -10]),
            Line(points=[-8, -8; -12, -8]),
            Line(points=[-8, -6; -12, -6]),
            Line(points=[-8, -4; -18, -4]),
            Line(points=[-8, -2; -12, -2]),
            Line(points=[-8, 0; -12, 0]),
            Line(points=[-8, 2; -12, 2]),
            Line(points=[-8, 4; -12, 4]),
            Line(points=[-8, 6; -18, 6]),
            Line(points=[-8, 8; -12, 8]),
            Line(points=[-8, 10; -12, 10]),
            Line(points=[-8, 12; -12, 12]),
            Line(points=[-8, 14; -12, 14]),
            Line(points=[-8, 16; -18, 16]),
            Line(points=[-8, 18; -12, 18]),
            Line(points=[-8, 20; -12, 20]),
            Line(points=[-8, 22; -12, 22]),
            Line(points=[-8, 24; -12, 24]),
            Line(points=[-8, 26; -18, 26]),
            Line(points=[-8, 28; -12, 28]),
            Line(points=[-8, 30; -12, 30]),
            Line(points=[-8, 32; -12, 32]),
            Line(points=[-8, 34; -12, 34])),
          Diagram(
            Text(
              extent=[4, -18; 84, -24],
              string="Temperature in Centigrade",
              style(color=0)),
            Text(
              extent=[70, -62; 102, -68],
              string="Temperature",
              style(color=0)),
            Text(
              extent=[70, -68; 102, -74],
              string="in Kelvin",
              style(color=0)),
            Text(
              extent=[-120,-16; -88,-22],
              string="Temperature",
              style(color=0)),
            Text(
              extent=[-120,-22; -88,-28],
              style(color=0),
              string="in Fahrenheit")),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This block computes the ambient temperature as a function of time for the location of Oracle, Arizona, i.e., for the location of Biosphere 2.  The model operates on a huge table containing temperature values of an entire year stored hourly in <sup>o</sup>F.  The model then converts the interpolated temperature value to <sup>o</sup>C, and finally to <sup>o</sup>K, which are the unit needed by the model. <p>

The model reads the data from an external file.  This is essential, as Dymola isn't geared to dealing with large data tables in memory.  Dymola essentially converts all matrices to sets of individual scalar variables in the process of compilation.  This is necessary, as the most flexible automatic causality assignment depends on this feature.  Yet, this is highly inefficient, when dealing with large data tables containing many thousands of data points.  We must hide these tables from Dymola, and can do so by placing them in external data files.
</html>
"));
      public 
        Modelica.Blocks.Math.Gain CelsiusConversion(k=m)    annotation (extent=[-30,
                -20; 10, 20]);
        Modelica.Blocks.Math.Add Add1 annotation (extent=[30, -8; 70, 32]);
        Modelica.Blocks.Sources.Constant Offset(k=a)   annotation (extent=[-30, 40;
                10, 80]);
        Modelica.Blocks.Math.Add Add2 annotation (extent=[30, -80; 70, -40]);
        Modelica.Blocks.Sources.Constant KelvinConversion(k=T0) 
                                                            annotation (extent=[-40,
                -92; 0, -52]);
        Modelica.Blocks.Tables.CombiTable1Ds TempTable(
          tableOnFile=true,
          tableName="temp_table",
          fileName="Bio_tables.mat") 
                                 annotation (extent=[-88,-20; -48,20]);
      equation 
        connect(CelsiusConversion.y, Add1.u2)             annotation (points=[12,0;
              26,0],    style(color=3));
        connect(Offset.y,Add1.u1)             annotation (points=[12,60; 18,60; 18,
              24; 26,24],      style(color=3));
        connect(Add1.y,Add2.u1)             annotation (points=[72,12; 80,12; 80,
              -26; 10,-26; 10,-48; 26,-48],      style(color=3));
        connect(KelvinConversion.y, Add2.u2)      annotation (points=[2,-72; 26,-72],
                   style(color=3));
        connect(Add2.y,y)              annotation (points=[72,-60; 90,-60; 90,0;
              110,0],    style(color=3));
        connect(TempTable.u, u) 
          annotation (points=[-92,0; -120,0], style(color=74, rgbcolor={0,0,127}));
        connect(TempTable.y[1], CelsiusConversion.u) 
          annotation (points=[-46,0; -34,0], style(color=74, rgbcolor={0,0,127}));
      end AmbientTemp;
      
      block NightSkyTemp "Apparent night sky temperature" 
        extends Modelica.Blocks.Interfaces.SISO;
        constant Real m=0.556 
          "Multiplicative factor for conversion of temperature from Fahrenheit to Centigrade";
        constant Real a=-17.78 
          "Additive factor for conversion of temperature from Fahrenheit to Centigrade";
        constant Modelica.SIunits.Temperature T0 = -Modelica.Constants.T_zero 
          "Conversion between Centigrade and Kelvin";
        output Real tdp "Night sky temperature table";
        output Real ccf "Clouding table";
        output Real eps1;
        output Real eps2;
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(
            Rectangle(extent=[-30, 76; 26, -78]),
            Rectangle(extent=[-6, 60; 2, -54]),
            Ellipse(extent=[-8, -52; 4, -64], style(fillColor=73)),
            Rectangle(extent=[-6, -10; 2, -58], style(fillColor=73)),
            Line(points=[-8, -44; -18, -44]),
            Line(points=[-8, -42; -12, -42]),
            Line(points=[-8, -40; -12, -40]),
            Line(points=[-8, -38; -12, -38]),
            Line(points=[-8, -36; -12, -36]),
            Line(points=[-8, 36; -18, 36]),
            Line(points=[-8, 38; -12, 38]),
            Line(points=[-8, 40; -12, 40]),
            Line(points=[-8, 42; -12, 42]),
            Line(points=[-8, 44; -12, 44]),
            Line(points=[-8, -34; -18, -34]),
            Line(points=[-8, -32; -12, -32]),
            Line(points=[-8, -30; -12, -30]),
            Line(points=[-8, -28; -12, -28]),
            Line(points=[-8, -26; -12, -26]),
            Line(points=[-8, -24; -18, -24]),
            Line(points=[-8, -22; -12, -22]),
            Line(points=[-8, -20; -12, -20]),
            Line(points=[-8, -18; -12, -18]),
            Line(points=[-8, -16; -12, -16]),
            Line(points=[-8, -14; -18, -14]),
            Line(points=[-8, -12; -12, -12]),
            Line(points=[-8, -10; -12, -10]),
            Line(points=[-8, -8; -12, -8]),
            Line(points=[-8, -6; -12, -6]),
            Line(points=[-8, -4; -18, -4]),
            Line(points=[-8, -2; -12, -2]),
            Line(points=[-8, 0; -12, 0]),
            Line(points=[-8, 2; -12, 2]),
            Line(points=[-8, 4; -12, 4]),
            Line(points=[-8, 6; -18, 6]),
            Line(points=[-8, 8; -12, 8]),
            Line(points=[-8, 10; -12, 10]),
            Line(points=[-8, 12; -12, 12]),
            Line(points=[-8, 14; -12, 14]),
            Line(points=[-8, 16; -18, 16]),
            Line(points=[-8, 18; -12, 18]),
            Line(points=[-8, 20; -12, 20]),
            Line(points=[-8, 22; -12, 22]),
            Line(points=[-8, 24; -12, 24]),
            Line(points=[-8, 26; -18, 26]),
            Line(points=[-8, 28; -12, 28]),
            Line(points=[-8, 30; -12, 30]),
            Line(points=[-8, 32; -12, 32]),
            Line(points=[-8, 34; -12, 34])),
          Diagram(
            Rectangle(extent=[-30,-36; 20,-86],   style(color=61)),
            Line(points=[-58,-60; -30,-60],   style(color=61)),
            Line(points=[2,4; 10,4; 10,-36],  style(color=61)),
            Line(points=[20,-60; 28,-60; 28,0; 36,0],     style(color=57)),
            Text(
              extent=[-20,-46; 8,-54],
              string="Night Sky",
              style(color=57)),
            Text(
              extent=[-24,-56; 14,-64],
              string="Temperature",
              style(color=57)),
            Text(
              extent=[-24,-66; 14,-74],
              string="Computation",
              style(color=57))),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
The model also requires the apparent temperature of the night sky to compute the radiation of the structure to the sky during the night.  The night sky temperature depends on the ambient temperature, the humidity, and the cloud cover.  All three are retrieved from huge data tables stored on an external binary file.
</html>
"));
      public 
        Modelica.Blocks.Math.Gain CelsiusConversion2(k=m)   annotation (extent=[-50,
                -10; -30, 10]);
        Modelica.Blocks.Math.Gain CelsiusConversion1(k=m)    annotation (extent=[-
              50, 50; -30, 70]);
        Modelica.Blocks.Sources.Constant Offset(k=a)   annotation (extent=[-50, 20;
                -30, 40]);
        Modelica.Blocks.Math.Add Add1 annotation (extent=[-20, 44; 0, 64]);
        Modelica.Blocks.Math.Add Add2 annotation (extent=[-20, -6; 0, 14]);
        Modelica.Blocks.Math.Add Add3 annotation (extent=[70, -10; 90, 10]);
        Modelica.Blocks.Sources.Constant KelvinConversion(k=T0) 
                                                            annotation (extent=[40,
                -40; 60, -20]);
        Modelica.Blocks.Math.Product Product1 annotation (extent=[40, -4; 60, 16]);
        Modelica.Blocks.Tables.CombiTable1Ds TempTable(
          tableOnFile=true,
          tableName="temp_table",
          fileName="Bio_tables.mat") 
                                 annotation (extent=[-80,50; -60,70]);
        Modelica.Blocks.Tables.CombiTable1Ds WetTable(
          tableOnFile=true,
          tableName="wet_table",
          fileName="Bio_tables.mat") 
                                annotation (extent=[-80,-10; -60,10]);
        Modelica.Blocks.Tables.CombiTable1Ds CloudTable(
          tableOnFile=true,
          tableName="cloud_table",
          fileName="Bio_tables.mat") 
                                  annotation (extent=[-80,-70; -60,-50]);
      equation 
        connect(CelsiusConversion1.y, Add1.u1)             annotation (points=[-29,
              60; -22,60],    style(color=3));
        connect(Offset.y,Add1.u2)             annotation (points=[-29,30; -26,30;
              -26,48; -22,48],     style(color=3));
        connect(CelsiusConversion2.y,Add2.u2)             annotation (points=[-29,0;
              -25.5,0; -25.5,-2; -22,-2],
                          style(color=3));
        connect(Offset.y,Add2.u1)             annotation (points=[-29,30; -26,30;
              -26,10; -22,10],     style(color=3));
        connect(Product1.y,Add3.u1)             annotation (points=[61,6; 68,6],
            style(color=3));
        connect(Add1.y,Product1.u1)             annotation (points=[1,54; 20,54; 20,
              12; 38,12],      style(color=3));
        connect(KelvinConversion.y, Add3.u2)      annotation (points=[61,-30; 64,
              -30; 64,-6; 68,-6],   style(color=3));
        connect(Add3.y,y)              annotation (points=[91,0; 110,0],   style(
              color=3));
        tdp = Add2.y;
        ccf = CloudTable.y[1];
        eps1 = 0.8 + 0.00366*tdp;
        eps2 = eps1 + (1 - eps1)*ccf;
        Product1.u2 = eps2^(1/4);
        connect(TempTable.y[1], CelsiusConversion1.u)  annotation (points=[-59,60;
              -52,60], style(color=74, rgbcolor={0,0,127}));
        connect(u, TempTable.u) annotation (points=[-120,0; -90,0; -90,60; -82,60],
            style(color=74, rgbcolor={0,0,127}));
        connect(WetTable.u, u) 
          annotation (points=[-82,0; -120,0], style(color=74, rgbcolor={0,0,127}));
        connect(WetTable.y[1],CelsiusConversion2. u) 
          annotation (points=[-59,0; -52,0], style(color=74, rgbcolor={0,0,127}));
        connect(CloudTable.u, u) annotation (points=[-82,-60; -90,-60; -90,0; -120,
              0], style(color=74, rgbcolor={0,0,127}));
      end NightSkyTemp;
      
      model SolarInput "Solar radiation" 
        extends Modelica.Blocks.Interfaces.SISO;
        constant Real m=11.247 
          "Multiplicative factor for conversion of radiation from a Fahrenheit to a Kelvin based system";
        constant Real a=0 
          "Additive factor for conversion of radiation from a Fahrenheit to a Kelvin based system";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(
            Ellipse(extent=[-24, 24; 26, -26]),
            Polygon(points=[-66, 32; -18, 16; -36, 66; -6, 24; -6, 22; 2, 76; 8, 22;
                    44, 64; 20, 14; 70, 36; 26, 4; 78, -2; 26, -8; 70, -36; 18, -18;
                    38, -68; 8, -26; 2, -78; -6, -24; -38, -66; -18, -20; -64, -38;
                    -22, -8; -74, -2; -24, 2; -66, 32], style(color=41, fillColor=
                    49)),
            Line(points=[16, -52; 22, -92], style(color=41, thickness=2)),
            Line(points=[44, -42; 78, -78], style(color=41, thickness=2)),
            Line(points=[62, -16; 92, -24], style(color=41, thickness=2)),
            Line(points=[60, -22; 90, -34], style(color=41, thickness=2)),
            Line(points=[48, -36; 88, -62], style(color=41, thickness=2)),
            Line(points=[38, -52; 64, -90], style(color=41, thickness=2)),
            Line(points=[22, -54; 36, -90], style(color=41, thickness=2))),
          Documentation(info="<html>
The model also requires the total solar input available to the Biosphere 2 structure.  Rather than using spherical trigonometry to compute the available radiation, also this information is simply pulled out of a huge table, where data have been stored for an entire year.
</html>
"),       Diagram);
      public 
        Modelica.Blocks.Math.Gain KelvinConversion(k=m)     annotation (extent=[-30,
                -20; 10, 20]);
        Modelica.Blocks.Math.Add Add1 annotation (extent=[30, -8; 70, 32]);
        Modelica.Blocks.Sources.Constant Offset(k=a)   annotation (extent=[-30, 40;
                10, 80]);
        Modelica.Blocks.Tables.CombiTable1Ds RadiationTable(
          tableOnFile=true,
          tableName="rad_table",
          fileName="Bio_tables.mat") 
                                annotation (extent=[-86,-20; -46,20]);
      equation 
        connect(KelvinConversion.y, Add1.u2)              annotation (points=[12,0;
              26,0],    style(color=3));
        connect(Offset.y,Add1.u1)             annotation (points=[12,60; 18,60; 18,
              24; 26,24],      style(color=3));
        connect(Add1.y,y)              annotation (points=[72,12; 80,12; 80,0; 110,
              0],      style(color=3));
        connect(RadiationTable.y[1], KelvinConversion.u) 
          annotation (points=[-44,0; -34,0], style(color=74, rgbcolor={0,0,127}));
        connect(RadiationTable.u, u) 
          annotation (points=[-90,0; -120,0], style(color=74, rgbcolor={0,0,127}));
      end SolarInput;
      
      model WindVelocity "Wind velocity" 
        extends Modelica.Blocks.Interfaces.SISO;
        constant Real m=1600 
          "Multiplicative factor for converting from miles per hour to meters per hour";
        constant Real a=0 
          "Additive factor for converting from miles per hour to meters per hour";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(
            Rectangle(extent=[-100, -54; 100, -100], style(color=9, fillColor=53)),
            Polygon(points=[-24, -68; -14, -44; -10, -30; -10, -20; -2, -20; -2, -
                  30; 2, -44; 12, -70; -24, -70; -24, -68], style(color=9,
                  fillColor=46)),
            Polygon(points=[-20, -20; -22, 6; -20, 32; -10, 52; 6, 74; 30, 90; 24,
                  62; 16, 36; 14, 2; 8, -20; -20, -20], style(color=9, fillColor=62)),
            Line(points=[-76, 64; -14, 64], style(thickness=2)),
            Line(points=[-56, 56; -34, 56], style(thickness=2)),
            Line(points=[-68, 48; -22, 48], style(thickness=2))),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
The model also requires the wind velocity to compute the convection of the boundary layer of air surrounding the dome of the Biosphere 2 structure.  Also this information has been stored for an entire year, and is simply pulled out of a huge data table.
</html>
"),       Diagram);
      public 
        Modelica.Blocks.Math.Gain SI_Conversion(k=m)        annotation (extent=[-30,
              -32; 10,8]);
        Modelica.Blocks.Math.Add Add1 annotation (extent=[30,-20; 70,20]);
        Modelica.Blocks.Sources.Constant Offset(k=a)   annotation (extent=[-30, 40;
                10, 80]);
        Modelica.Blocks.Tables.CombiTable1Ds VelocityTable(
          tableOnFile=true,
          tableName="vel_table",
          fileName="Bio_tables.mat") 
                                annotation (extent=[-86,-32; -46,8]);
      equation 
        connect(Offset.y,Add1.u1)             annotation (points=[12,60; 18,60; 18,
              12; 26,12],      style(color=3));
        connect(Add1.y,y)              annotation (points=[72,0; 110,0],
                       style(color=3));
        connect(SI_Conversion.y, Add1.u2)                 annotation (points=[12,
              -12; 26,-12],
                        style(color=3));
        connect(VelocityTable.y[1], SI_Conversion.u)      annotation (points=[-44,
              -12; -34,-12], style(color=74, rgbcolor={0,0,127}));
        connect(VelocityTable.u, u) annotation (points=[-90,-12; -96,-12; -96,0;
              -120,0], style(color=74, rgbcolor={0,0,127}));
      end WindVelocity;
      
      block Glass 
        "Absorption, transmission, reflection of solar input at glass panels" 
        extends Modelica.Blocks.Interfaces.BlockIcon;
        parameter Real alph "Percentage of absorbed power";
        parameter Real tau "Percentage of transmitted power";
        parameter Real refl=1 - alph - tau "Percentage of reflected power";
        output Real Pin "Power input";
        output Real Pabs "Absorbed power";
        output Real Prefl "Reflected power";
        output Real Ptrans "Transmitted power";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(
            Line(points=[-46, -52; -46, 24], style(color=57, thickness=2)),
            Line(points=[-46, 24; 32, 56], style(color=57, thickness=2)),
            Line(points=[-46, -52; 32, -20], style(color=61, thickness=2)),
            Line(points=[32, -20; 32, 56], style(color=57, thickness=2)),
            Line(points=[-8, 76; -22, 42], style(color=41, thickness=2)),
            Line(points=[-4, 72; -10, 46], style(color=41, thickness=2)),
            Line(points=[2, 76; 2, 52], style(color=41, thickness=2)),
            Line(points=[0, -34; 0, -100], style(color=41, thickness=2)),
            Line(points=[32, 0; 100, 0], style(color=41, thickness=2)),
            Line(points=[-46, 0; -100, 0], style(color=41, thickness=2)),
            Text(
              extent=[4, -54; 46, -70],
              string="Transmission",
              style(color=41)),
            Text(
              extent=[48, 14; 84, 0],
              string="Absorption",
              style(color=41)),
            Text(
              extent=[-88, 14; -54, 0],
              string="Reflection",
              style(color=41))),
          Diagram(
            Line(points=[32, -20; 32, 56], style(color=57, thickness=2)),
            Line(points=[-46, -52; 32, -20], style(color=61, thickness=2)),
            Line(points=[-46, -52; -46, 24], style(color=57, thickness=2)),
            Line(points=[-46, 24; 32, 56], style(color=57, thickness=2)),
            Line(points=[-8, 76; -22, 42], style(color=41, thickness=2)),
            Line(points=[-4, 72; -10, 46], style(color=41, thickness=2)),
            Line(points=[2, 76; 2, 52], style(color=41, thickness=2)),
            Text(
              extent=[48, 14; 84, 0],
              string="Absorption",
              style(color=41)),
            Line(points=[32, 0; 100, 0], style(color=41, thickness=2)),
            Text(
              extent=[4, -54; 46, -70],
              string="Transmission",
              style(color=41)),
            Line(points=[0, -34; 0, -100], style(color=41, thickness=2)),
            Text(
              extent=[-88, 14; -54, 0],
              string="Reflection",
              style(color=41)),
            Line(points=[-46, 0; -100, 0], style(color=41, thickness=2))),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This model computes in a global fashion, how much of the solar input gets absorbed by the glass panes, how much gets transmitted through, and how much gets reflected. <p>

Since the glass panes have many different orientations, a physical model would be rather computation intensive.  Thus, the model goes another route.  It estimaes the three quantities globally and on average.
</html>
"));
        Modelica.Blocks.Interfaces.RealInput InPort1 
                                                  annotation (extent=[-10, 80; 10,
              100], rotation=-90);
        Modelica.Blocks.Interfaces.RealOutput OutPort2 
                                                    annotation (extent=[-100, -10;
              -120, 10]);
        Modelica.Blocks.Interfaces.RealOutput OutPort3 
                                                    annotation (extent=[10, -120; -
              10, -100], rotation=-90);
        Modelica.Blocks.Interfaces.RealOutput OutPort1 
                                                    annotation (extent=[100, -10;
              120, 10]);
      equation 
        Pin =InPort1;
        Pabs = alph*Pin;
        Ptrans = tau*Pin;
        Prefl = refl*Pin;
        OutPort1           = Pabs;
        OutPort2           = Prefl;
        OutPort3           = Ptrans;
      end Glass;
      
      block Absorption "Distribution of solar input" 
        extends Modelica.Blocks.Interfaces.BlockIcon;
        parameter Real apix "Percentage of Biosphere covered by pond";
        parameter Real avix "Percetage of Biosphere covered by vegetation";
        parameter Real laix "Efficiency factor of vegetation";
        parameter Real refl "Percentage of power reflected at pond";
        parameter Real vkx;
        parameter Real rhos;
        output Real Pin "Power input";
        output Real Ppond "Power absorbed by pond";
        output Real Pveg "Power absorbed by vegetation";
        output Real Psoil "Power absorbed by soil";
        output Real Prefl "Reflected power";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Line(points=[-46, 78; -60, 44], style(color=41, thickness=2)),
            Line(points=[-42, 74; -48, 48], style(color=41, thickness=2)),
            Line(points=[-36, 78; -36, 54], style(color=41, thickness=2)),
            Line(points=[-30, 84; -26, 62], style(color=41, thickness=2)),
            Line(points=[-60, 36; -60, 0; -100, 0], style(color=41, thickness=2)),
            Line(points=[-48, 36; -48, -40; 0, -40; 0, -100], style(color=41,
                  thickness=2)),
            Line(points=[-36, 36; -36, 0; 100, 0], style(color=45, thickness=2)),
            Line(points=[-26, 36; -26, 20; 40, 20; 40, 100], style(color=41,
                  thickness=2)),
            Text(
              extent=[-96, 12; -70, 2],
              string="Soil",
              style(color=41)),
            Text(
              extent=[4, -66; 40, -78],
              string="Vegetation",
              style(color=45)),
            Text(
              extent=[58, 12; 84, 2],
              string="Pond",
              style(color=41)),
            Text(
              extent=[42, 76; 78, 64],
              string="Reflected",
              style(color=45))),
          Icon(
            Line(points=[-46, 78; -60, 44], style(color=41, thickness=2)),
            Line(points=[-42, 74; -48, 48], style(color=41, thickness=2)),
            Line(points=[-36, 78; -36, 54], style(color=41, thickness=2)),
            Line(points=[-30, 84; -26, 62], style(color=41, thickness=2)),
            Line(points=[-60, 36; -60, 0; -100, 0], style(color=41, thickness=2)),
            Line(points=[-48, 36; -48, -40; 0, -40; 0, -100], style(color=41,
                  thickness=2)),
            Line(points=[-36, 36; -36, 0; 100, 0], style(color=45, thickness=2)),
            Line(points=[-26, 36; -26, 20; 40, 20; 40, 100], style(color=41,
                  thickness=2)),
            Text(
              extent=[-96, 12; -70, 2],
              string="Soil",
              style(color=41)),
            Text(
              extent=[4, -66; 40, -78],
              string="Vegetation",
              style(color=45)),
            Text(
              extent=[58, 12; 84, 2],
              string="Pond",
              style(color=41)),
            Text(
              extent=[42, 76; 78, 64],
              string="Reflected",
              style(color=45))),
          Documentation(info="<html>
This model computes, how much of the transmitted solar input gets absorbed by the soil, by the vegetation, and by the pond, and how much gets reflected back out.
</html>
"));
        Modelica.Blocks.Interfaces.RealOutput OutPort2 
                                                    annotation (extent=[-100, -10;
              -120, 10]);
        Modelica.Blocks.Interfaces.RealOutput OutPort1 
                                                    annotation (extent=[100, -10;
              120, 10]);
        Modelica.Blocks.Interfaces.RealOutput OutPort3 
                                                    annotation (extent=[10, -120; -
              10, -100], rotation=-90);
        Modelica.Blocks.Interfaces.RealInput InPort1 
                                                  annotation (extent=[-50, 80; -30,
                100], rotation=-90);
        Modelica.Blocks.Interfaces.RealOutput OutPort4 
                                                    annotation (extent=[50, 120; 30,
                100], rotation=-90);
      equation 
        Pin =InPort1;
        Ppond = apix*(1 - refl)*Pin;
        Pveg = avix*(1 - exp(-vkx*laix))*Pin;
        Psoil = (1 - rhos)*(avix*exp(-vkx*laix) + (1 - avix - apix))*Pin;
        Prefl = Pin - Ppond - Pveg - Psoil;
        OutPort1           = Ppond;
        OutPort2           = Psoil;
        OutPort3           = Pveg;
        OutPort4           = Prefl;
      end Absorption;
      
      model CV "Convection" 
        extends BondLib.Interfaces.TwoPort;
        parameter Real G0=1 "Thermal Conductance";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-66, 80; 64, -80],
              string="CV",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Documentation(info="<html>
The convection model is the regular directed heat exchanger model, <b>HEr</b>, of the bond graph library.  However, we have duplicated the model here under a different name, in order to be able to provide meaningful documentation for its use. <p>

Convection, in general, requires a much more complex model, because mass and entropy get moved around together.  However, in the current implementation of the model, we ignored the air conditioning.  Thus air doesn't get moved around, except for the purpose of potential equilibration.  In that case, a much simplified version of the model, namely that of a simple heat exchanger can be used.
</html>
"));
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[-50, -10; -30, 10]);
        BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-10, 10; 10, -10]);
        BondLib.Bonds.fBond B1 annotation (extent=[-30, -10; -10, 10]);
        BondLib.Bonds.eBond B2 annotation (extent=[10, -10; 30, 10]);
        BondLib.Junctions.J0p3 J0p3_2 annotation (extent=[30, 10; 50, -10]);
        BondLib.Bonds.eBond B4 annotation (extent=[30, 10; 50, 30], rotation=-90);
        BondLib.Bonds.fBond B3 annotation (extent=[-10, 10; 10, 30], rotation=90);
        BondLib.Thermal.GSth GSth1(G0=G0) annotation (extent=[10, 30; 30, 50]);
      equation 
        connect(B1.fBondCon1, J1p3_1.BondCon1) annotation (points=[-10, 0; -10, 0],
              style(color=8));
        connect(J0p2_1.BondCon2, B1.eBondCon1) annotation (points=[-30, 0; -30, 0],
              style(color=8));
        connect(J1p3_1.BondCon2, B2.fBondCon1) annotation (points=[10, 0; 10, 0],
            style(color=8));
        connect(B2.eBondCon1, J0p3_2.BondCon1) annotation (points=[30, 0; 30, 0],
            style(color=8));
        connect(B4.eBondCon1, J0p3_2.BondCon3) annotation (points=[40, 10; 40, 10],
              style(color=8));
        connect(J1p3_1.BondCon3, B3.eBondCon1) annotation (points=[0,10; 
              -6.12303e-016,10],
            style(color=8));
        connect(BondCon1, J0p2_1.BondCon1) annotation (points=[-100,0; -50,0],
            style(color=8));
        connect(J0p3_2.BondCon2, BondCon2) annotation (points=[50,0; 100,0],  style(
             color=8));
        connect(B3.fBondCon1, GSth1.BondCon1) annotation (points=[6.12303e-016,
              30; 6.12303e-016,40; 10,40],
                     style(color=8));
        connect(GSth1.BondCon2, B4.fBondCon1) annotation (points=[30, 40; 40, 40;
              40, 30], style(color=8));
      end CV;
      
      model CD "Heat conduction in the soil" 
        extends BondLib.Interfaces.TwoPort;
        parameter Real ag "Ground area of Biosphere";
        parameter Real apix "Percentage of Biosphere covered by pond";
        parameter Real lambda "Specific thermal conductance of ground";
        parameter Real G0=ag*(1 - apix)*lambda 
          "Thermal conductance of ground layer";
        parameter Real gamma0 "Specific thermal capacity of ground";
        parameter Real gamma=ag*(1 - apix)*gamma0 
          "Thermal capacity of ground layer";
        parameter Real T0 "Initial temperature";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-66, 80; 64, -80],
              string="CD",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
The heat conduction model used here is the directed heat exchanger model of the bond graph library with an additional heat capacity built in at the output node.  In this way, the soil can be subdivided into layers, with heat conduction models being cascaded without a need for attaching heat capacitors externally, except at the very first node. <p>

Heat capacitors were attached only at one side, because otherwise, higher index models result when such models get cascaded.  Although Modelica is perfectly capable of reducing the perturbation index on its own, this would only have slowed down the compilation of the model unnecessarily.
</html>
"));
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[-50, -10; -30, 10]);
        BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-10, 10; 10, -10]);
        BondLib.Bonds.fBond B1 annotation (extent=[-30, -10; -10, 10]);
        BondLib.Bonds.eBond B2 annotation (extent=[10, -10; 30, 10]);
        BondLib.Bonds.eBond B4 annotation (extent=[30, 10; 50, 30], rotation=-90);
        BondLib.Bonds.fBond B3 annotation (extent=[-10, 10; 10, 30], rotation=90);
        BondLib.Thermal.GSth GSth1(G0=G0) annotation (extent=[10, 30; 30, 50]);
        BondLib.Junctions.J0p4 J0p4_1 annotation (extent=[30, -10; 50, 10]);
        BondLib.Bonds.eBond B5 annotation (extent=[30, -30; 50, -10], rotation=-90);
        BondLib.Thermal.Cth Cth1(gamma=gamma, e(start=T0)) annotation (extent=[30,
              -50; 50, -30], rotation=-90);
      equation 
        connect(B1.fBondCon1, J1p3_1.BondCon1) annotation (points=[-10, 0; -10, 0],
              style(color=8));
        connect(J0p2_1.BondCon2, B1.eBondCon1) annotation (points=[-30, 0; -30, 0],
              style(color=8));
        connect(J1p3_1.BondCon2, B2.fBondCon1) annotation (points=[10, 0; 10, 0],
            style(color=8));
        connect(J1p3_1.BondCon3, B3.eBondCon1) annotation (points=[0,10; 
              -6.12303e-016,10],
            style(color=8));
        connect(B3.fBondCon1, GSth1.BondCon1) annotation (points=[6.12303e-016,
              30; 6.12303e-016,40; 10,40],
                     style(color=8));
        connect(GSth1.BondCon2, B4.fBondCon1) annotation (points=[30, 40; 40, 40;
              40, 30], style(color=8));
        connect(B4.eBondCon1, J0p4_1.BondCon4) annotation (points=[40, 10; 40, 10],
              style(color=8));
        connect(B2.eBondCon1, J0p4_1.BondCon1) annotation (points=[30, 0; 30, 0],
            style(color=8));
        connect(BondCon1, J0p2_1.BondCon1) annotation (points=[-100,0; -50,0],
            style(color=8));
        connect(J0p4_1.BondCon2, BondCon2) annotation (points=[50,0; 100,0],  style(
             color=8));
        connect(J0p4_1.BondCon3, B5.fBondCon1) annotation (points=[40, -10; 40, -10],
                 style(color=8));
        connect(B5.eBondCon1, Cth1.BondCon1) annotation (points=[40, -30; 40, -30],
              style(color=8));
      end CD;
      
      model CVext "External boundary layer convection" 
        extends BondLib.Interfaces.TwoPort;
        parameter Real ac "Cover area of Biosphere";
        parameter Real hai "Constant convection factor";
        parameter Real hai2 "Wind velocity dependent convection factor";
        parameter Real ucx=1;
        parameter Real ucp=72;
        parameter Real R2=1/(ucx*ucp) "Specific resistance due to conduction";
        Real uao "Wind velocity";
        Real R1 "Specific resistance due to convection";
        Real G0 "Thermal Conductance";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Rectangle(extent=[-26, -54; 6, -86], style(color=57)),
            Line(points=[-38, -70; -26, -70], style(color=57)),
            Line(points=[6, -70; 20, -70; 20, -50], style(color=57)),
            Text(
              extent=[-22, -58; 4, -68],
              string="Computation of",
              style(color=57)),
            Text(
              extent=[-22, -66; 4, -76],
              string="convection",
              style(color=57)),
            Text(
              extent=[-22, -74; 4, -84],
              string="due to wind",
              style(color=57))),
          Icon(Text(
              extent=[-66, 80; 64, -80],
              string="CVext",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
The external boundary layer convection requires a slightly more complex model than the internal convection, since air circulation around the dome removes hot air from the surface, thereby seemingly enhancing the convecting area. <p>

The model is essentially the same model as used for internal convection, but the conductance of convection is here not a constant, but rather a function of the wind velocity. <p>

The wind velocity is retrieved from a large lookup table.
</html>
"));
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[-50, -10; -30, 10]);
        BondLib.Junctions.J1p3 J1p3_1 annotation (extent=[-10, -10; 10, 10]);
        BondLib.Bonds.fBond B1 annotation (extent=[-30, -10; -10, 10]);
        BondLib.Bonds.eBond B2 annotation (extent=[10, -10; 30, 10]);
        BondLib.Junctions.J0p3 J0p3_2 annotation (extent=[30, -10; 50, 10]);
        BondLib.Bonds.eBond B4 annotation (extent=[30, -30; 50, -10], rotation=90);
        BondLib.Bonds.fBond B3 annotation (extent=[-10, -30; 10, -10], rotation=270);
        BondLib.Thermal.mGSth mGSth1 annotation (extent=[10, -50; 30, -30]);
        WindVelocity WindVelocity1 annotation (extent=[-60, -80; -40, -60]);
        Modelica.Blocks.Sources.Clock Clock1 annotation (extent=[-100,-80; -80,-60]);
      equation 
        connect(B1.fBondCon1, J1p3_1.BondCon1) annotation (points=[-10, 0; -10, 0],
              style(color=8));
        connect(J0p2_1.BondCon2, B1.eBondCon1) annotation (points=[-30, 0; -30, 0],
              style(color=8));
        connect(J1p3_1.BondCon2, B2.fBondCon1) annotation (points=[10, 0; 10, 0],
            style(color=8));
        connect(B2.eBondCon1, J0p3_2.BondCon1) annotation (points=[30, 0; 30, 0],
            style(color=8));
        connect(J1p3_1.BondCon3, B3.eBondCon1) annotation (points=[0,-10; 
              1.83691e-015,-10],
              style(color=8));
        connect(B4.eBondCon1, J0p3_2.BondCon3) annotation (points=[40, -10; 40, -10],
                 style(color=8));
        connect(BondCon1, J0p2_1.BondCon1) annotation (points=[-100,0; -50,0],
            style(color=8));
        connect(J0p3_2.BondCon2, BondCon2) annotation (points=[50,0; 100,0],  style(
             color=8));
        connect(B3.fBondCon1, mGSth1.BondCon1) annotation (points=[
              -1.83691e-015,-30; -1.83691e-015,-40; 10,-40],
                        style(color=8));
        connect(mGSth1.BondCon2, B4.fBondCon1) annotation (points=[30, -40; 40, -40;
                40, -30], style(color=8));
        uao = WindVelocity1.y;
        R1 = 1/(hai + hai2*uao);
        G0 = ac/(R1 + R2);
        mGSth1.InPort1           = G0;
        connect(Clock1.y, WindVelocity1.u) annotation (points=[-79,-70; -62,-70],
            style(color=74, rgbcolor={0,0,127}));
      end CVext;
      
      model mGSev "Evaporation" 
        extends BondLib.Interfaces.ModTwoPort;
        parameter Real pao;
        Real G "Bondgraphic evaporation conductance";
        Real svp "Saturation vapor pressure";
        Real hum "Relative humidity";
        Real P "Power flow into evaporation";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(Text(
              extent=[-78, 70; 76, -70],
              string="mGSev",
              style(color=0))),
          Icon(Text(
              extent=[-78, 70; 76, -70],
              string="mGSev",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
Evaporation is modeled in this program using Teten's law, an experimental equation that avoids the need of using steam tables. <p>

In the process of evaporation, <i>sensible heat</i> gets converted to <i>latent heat</i>. <p>

Water vapor is at a higher energy level than liquid water.  In order to evaporate, the activation energy must be overcome that is needed to provide the water molecules with the additional energy.  This energy is taken out of the thermal domain. <p>

In our model, humidity is used as an effort variable.  It gets multiplied with a quantity that corresponds to the power converted in the process. <p>

The humidity generated in the process of evaporation is proportional to the difference between the current humidity and the humidity at saturation vapor pressure, i.e., the humidity at the dew point.
</html>
"));
      equation 
        G = s;
        svp = 0.61078*exp(17.269*(e1 - 273.15)/(e1 - 35.85));
        hum = 0.62198/((pao/svp) - 1);
        P = G*(hum - e2);
        e1*f1 = P;
        e2*f2 = P;
      end mGSev;
      
      model mGSco "Condensation" 
        extends BondLib.Interfaces.ModTwoPort;
        parameter Real pao;
        Real G "Bondgraphic condensation conductance";
        Real svp "Saturation vapor pressure";
        Real hum "Relative humidity";
        Real P "Power flow into condensation";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(Text(
              extent=[-78, 70; 76, -70],
              string="mGSco",
              style(color=0))),
          Icon(Text(
              extent=[-78, 70; 76, -70],
              string="mGSco",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Documentation(info="<html>
Condensation is the reverse process of evaporation.  It is also modeled here using Teten's law, an experimental equation that avoids the need of using steam tables. <p>

In the process of condensation, <i>latent heat</i> gets converted to <i>sensible heat</i>. <p>

Liquid water is at a lower energy level than water vapor.  In the process of condensation, the surplus energy is given back to the thermal domain, i.e., gets converted to entropy. <p>

In our model, humidity is used as an effort variable.  It gets multiplied with a quantity that corresponds to the power converted in the process. <p>

The humidity comsumed in the process of condensation is proportional to the difference between the current humidity and the humidity at saturation vapor pressure, i.e., the humidity at the dew point. <p>

No condensation takes place, until the humidty reaches the dew point.  Once it passes this point, water vapor is being liquified, such that the relative humidity remains at exactly 100%. <p>

Condensation takes place in our model both at the glass panes of the dome, and also in the bulk of the air.  The dome isn't tall enough to produce rain, but it most certainly can produce very dense fog.
</html>
"));
      equation 
        G = s;
        svp = 0.61078*exp(17.269*(e2 - 273.15)/(e2 - 35.85));
        hum = 0.62198/((pao/svp) - 1);
        P = G*(e1 - hum);
        e1*f1 = P;
        e2*f2 = P;
      end mGSco;
      
      model CWpond "Evaporation of the pond" 
        extends BondLib.Interfaces.TwoPort;
        parameter Real ag "Ground area of Biosphere";
        parameter Real hai "Constant convection factor";
        parameter Real apix "Percentage of Biosphere covered by pond";
        parameter Real lambda "Evaporation constant";
        parameter Real pao;
        Real ca;
        Real G0 "Specific conductance due to evaporation";
        Real G "Conductance of evaporation";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-66, 80; 64, -80],
              string="CWpond",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Diagram(
            Rectangle(extent=[-46, -44; -14, -76], style(color=57)),
            Line(points=[-14, -60; 0, -60; 0, -20], style(color=57)),
            Text(
              extent=[-42, -48; -16, -58],
              string="Computation of",
              style(color=57)),
            Text(
              extent=[-42, -56; -16, -66],
              string="convection due",
              style(color=57)),
            Text(
              extent=[-42, -64; -16, -74],
              string="to evaporation",
              style(color=57))),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This model computes the evaporation of the pond.  It uses the generic evaporation model together with an internal modulation computing the conductance of evaporation.
</html>
"));
        mGSev mGSev1(pao=pao) annotation (extent=[-20, -20; 20, 20]);
      equation 
        connect(BondCon1, mGSev1.BondCon1) annotation (points=[-100,0; -20,0],
            style(color=8));
        connect(mGSev1.BondCon2, BondCon2) annotation (points=[20,0; 100,0],  style(
             color=8));
        ca = 1.005 + 1.859*e2;
        G0 = hai/ca;
        G = ag*apix*lambda*G0;
        mGSev1.InPort1           = G;
      end CWpond;
      
      model CWsoil "Evaporation of the soil" 
        extends BondLib.Interfaces.TwoPort;
        parameter Real ag "Ground area of Biosphere";
        parameter Real hai "Constant convection factor";
        parameter Real apix "Percentage of Biosphere covered by pond";
        parameter Real lambda "Evaporation constant";
        parameter Real rg=0.0278 
          "Specific evaporation of soil due to conduction";
        parameter Real pao;
        Real ca;
        Real R0 "Specific resistance of evaporation of soil due to convection";
        Real G0 "Specific conductance due to evaporation";
        Real G "Conductance of evaporation";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-66, 80; 64, -80],
              string="CWsoil",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Diagram(
            Rectangle(extent=[-46, -44; -14, -76], style(color=57)),
            Line(points=[-14, -60; 0, -60; 0, -20], style(color=57)),
            Text(
              extent=[-42, -48; -16, -58],
              string="Computation of",
              style(color=57)),
            Text(
              extent=[-42, -56; -16, -66],
              string="convection due",
              style(color=57)),
            Text(
              extent=[-42, -64; -16, -74],
              string="to evaporation",
              style(color=57))),
          Documentation(info="<html>
This model computes the evaporation of the soil.  It uses the generic evaporation model together with an internal modulation computing the conductance of evaporation.
</html>
"));
        mGSev mGSev1(pao=pao) annotation (extent=[-20, -20; 20, 20]);
      equation 
        connect(BondCon1, mGSev1.BondCon1) annotation (points=[-100,0; -20,0],
            style(color=8));
        connect(mGSev1.BondCon2, BondCon2) annotation (points=[20,0; 100,0],  style(
             color=8));
        ca = 1.005 + 1.859*e2;
        R0 = ca/hai;
        G0 = 1/(R0 + rg);
        G = ag*(1 - apix)*lambda*G0;
        mGSev1.InPort1           = G;
      end CWsoil;
      
      model CWveg "Evaporation of the vegetation" 
        extends BondLib.Interfaces.TwoPort;
        parameter Real ag "Ground area of Biosphere";
        parameter Real hai "Constant convection factor";
        parameter Real avix "Percetage of Biosphere covered by vegetation";
        parameter Real laix "Efficiency factor of vegetation";
        parameter Real lambda "Evaporation constant";
        parameter Real rg=0.0278 
          "Specific evaporation of vegetation due to conduction";
        parameter Real b1=20.3 "Radiation evaporation constant";
        parameter Real b2=61.2 "Radiation evaporation constant";
        parameter Real taux=1;
        parameter Real taup=0.6;
        parameter Real pao;
        Real ca;
        Real so "Solar input";
        Real R0 
          "Specific resistance of evaporation of vegetation due to convection";
        Real R1 
          "Specific resistance of evaporation of vegetation due to radiation";
        Real G0 "Specific conductance due to evaporation";
        Real G "Conductance of evaporation";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-66, 80; 64, -80],
              string="CWveg",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Diagram(
            Rectangle(extent=[-16, -44; 16, -76], style(color=57)),
            Text(
              extent=[-12, -48; 14, -58],
              string="Computation of",
              style(color=57)),
            Text(
              extent=[-12, -56; 14, -66],
              string="convection due",
              style(color=57)),
            Text(
              extent=[-12, -64; 14, -74],
              string="to evaporation",
              style(color=57)),
            Line(points=[-28, -60; -16, -60], style(color=61)),
            Line(points=[0, -44; 0, -20], style(color=57))),
          Documentation(info="<html>
This model computes the evaporation of the vegetation.  It uses the generic evaporation model together with an internal modulation computing the conductance of evaporation.
</html>
"));
        mGSev mGSev1(pao=pao) annotation (extent=[-20, -20; 20, 20]);
        SolarInput SolarInput1 annotation (extent=[-50, -70; -30, -50]);
        Modelica.Blocks.Sources.Clock Clock1 annotation (extent=[-90,-70; -70,-50]);
      equation 
        connect(BondCon1, mGSev1.BondCon1) annotation (points=[-100,0; -20,0],
            style(color=8));
        connect(mGSev1.BondCon2, BondCon2) annotation (points=[20,0; 100,0],  style(
             color=8));
        ca = 1.005 + 1.859*e2;
        R0 = ca/hai;
        so = SolarInput1.y;
        R1 = b1/(b2 + (so*taux*taup));
        G0 = 1/(R0 + R1 + rg);
        G = ag*avix*laix*lambda*G0;
        mGSev1.InPort1           = G;
        connect(Clock1.y, SolarInput1.u) annotation (points=[-69,-60; -52,-60],
            style(color=74, rgbcolor={0,0,127}));
      end CWveg;
      
      model CWcov "Condensation at the dome" 
        extends BondLib.Interfaces.TwoPort;
        parameter Real ac "Cover area of Biosphere";
        parameter Real hai "Constant convection factor";
        parameter Real lambda "Condensation constant";
        parameter Real pao;
        Real ca;
        Real flgc;
        Real G0 "Specific conductance of condensation on cover";
        Real G "Conductance of condensation";
        Real svp "Saturation vapor pressure";
        Real hum "Relative humidity";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-66, 80; 64, -80],
              string="CWcov",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Diagram(
            Rectangle(extent=[-46, -44; -14, -76], style(color=57)),
            Line(points=[-14, -60; 0, -60; 0, -20], style(color=57)),
            Text(
              extent=[-42, -48; -16, -58],
              string="Computation of",
              style(color=57)),
            Text(
              extent=[-42, -56; -16, -66],
              string="convection due",
              style(color=57)),
            Text(
              extent=[-42, -64; -16, -74],
              string="to condensation",
              style(color=57))),
          Documentation(info="<html>
This model computes the condensation at the dome.  It uses the generic condensation model together with an internal modulation computing the conductance of condensation. <p>

An if statement is used to check whether the current humidity is above that of the dew point.  If this is not the case, no condensation takes place.
</html>
"));
        mGSco mGSco1(pao=pao) annotation (extent=[-20, -20; 20, 20]);
      equation 
        connect(BondCon1, mGSco1.BondCon1) annotation (points=[-100,0; -20,0],
            style(color=8));
        connect(mGSco1.BondCon2, BondCon2) annotation (points=[20,0; 100,0],  style(
             color=8));
        ca = 1.005 + 1.859*e2;
        G0 = hai/ca;
        svp = 0.61078*exp(17.269*(e2 - 273.15)/(e2 - 35.85));
        hum = 0.62198/((pao/svp) - 1);
        flgc = if hum < e1 then 0 else 1;
        G = ac*G0*lambda*flgc;
        mGSco1.InPort1           = G;
      end CWcov;
      
      model CWbulk "Condensation in the bulk" 
        extends BondLib.Interfaces.TwoPort;
        parameter Real vai "Air volume of Biosphere";
        parameter Real hai "Constant convection factor";
        parameter Real lambda "Condensation constant";
        parameter Real pao;
        Real ca;
        Real flgc;
        Real G0 "Specific conductance of condensation on cover";
        Real G "Conductance of condensation";
        Real svp "Saturation vapor pressure";
        Real hum "Relative humidity";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-66, 80; 64, -80],
              string="CWbulk",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Diagram(
            Rectangle(extent=[-46, -44; -14, -76], style(color=57)),
            Line(points=[-14, -60; 0, -60; 0, -20], style(color=57)),
            Text(
              extent=[-42, -48; -16, -58],
              string="Computation of",
              style(color=57)),
            Text(
              extent=[-42, -56; -16, -66],
              string="convection due",
              style(color=57)),
            Text(
              extent=[-42, -64; -16, -74],
              string="to condensation",
              style(color=57))),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This model computes the condensation in the bulk of the air.  It uses the generic condensation model together with an internal modulation computing the conductance of condensation. <p>

An if statement is used to check whether the current humidity is above that of the dew point.  If this is not the case, no condensation takes place.
</html>
"));
        mGSco mGSco1(pao=pao) annotation (extent=[-20, -20; 20, 20]);
      equation 
        connect(BondCon1, mGSco1.BondCon1) annotation (points=[-100,0; -20,0],
            style(color=8));
        connect(mGSco1.BondCon2, BondCon2) annotation (points=[20,0; 100,0],  style(
             color=8));
        ca = 1.005 + 1.859*e2;
        G0 = hai/ca;
        svp = 0.61078*exp(17.269*(e2 - 273.15)/(e2 - 35.85));
        hum = 0.62198/((pao/svp) - 1);
        flgc = if hum > e1 then 0 else 1;
        G = vai*G0*lambda*flgc;
        mGSco1.InPort1           = G;
      end CWbulk;
      
      model Cmoist "Capacity of moisture" 
        extends BondLib.Interfaces.ModPassiveOnePort;
        parameter Real pao;
        parameter Real vai "Air volume of biosphere";
        Real Tair "Air temperature inside Biosphere";
        Real da;
        Real C "Capacity of moisture";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(Text(
              extent=[-76, 54; 66, -56],
              string="Cmoist",
              style(color=0))),
          Icon(Text(
              extent=[-76, 54; 66, -56],
              string="Cmoist",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Documentation(info="<html>
This model computes the capacity of the moisture, i.e., represents the capacitor attached to the 0-junction representing the humidity.
</html>
"));
      equation 
        Tair = s;
        da = pao/(0.287*Tair);
        C = (da*vai)/e;
        C*der(e) = f;
      end Cmoist;
      
      model Soil "Soil" 
        extends BondLib.Interfaces.PassiveOnePort;
        parameter Real ag "Ground area of Biosphere";
        parameter Real apix "Percentage of Biosphere covered by pond";
        parameter Real lambda1=90 
          "Specific thermal conductance of first ground layer";
        parameter Real gamma1=200 
          "Specific thermal capacity of first ground layer";
        parameter Real lambda2=45 
          "Specific thermal conductance of second ground layer";
        parameter Real gamma2=300 
          "Specific thermal capacity of second ground layer";
        parameter Real lambda3=22.5 
          "Specific thermal conductance of third ground layer";
        parameter Real gamma3=600 
          "Specific thermal capacity of third ground layer";
        parameter Real T01=285 "Initial temperature of first ground layer";
        parameter Real T02=286 "Initial temperature of second ground layer";
        parameter Real T03=288 "Initial temperature of third ground layer";
        annotation (
          Coordsys(
            extent=[-100, -100; 100, 100],
            grid=[2, 2],
            component=[20, 20]),
          Icon(Text(
              extent=[-74, 56; 70, -62],
              string="Soil",
              style(color=0)), Text(extent=[-70, 90; 70, 50], string="%name")),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          Diagram(Line(points=[-60, 0; -60, 0], style(color=8))),
          Documentation(info="<html>
This model calculates the heat conduction in the soil.  The soil is modeled as having three layers.  The bottom of the soil is assumed to be thermally insulated.  Therefore, the model uses three <b>CD</b> elements followed by a flow source of zero flow.
</html>
"));
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[-60, -10; -40, 10]);
        CD CD1(
          ag=ag,
          apix=apix,
          lambda=lambda1,
          gamma0=gamma1,
          T0=T01) annotation (extent=[-20, -10; 0, 10]);
        BondLib.Bonds.fBond B2 annotation (extent=[-40, -10; -20, 10]);
        BondLib.Bonds.fBond B3 annotation (extent=[0, -10; 20, 10]);
        BondLib.Junctions.J0p2 J0p2_2 annotation (extent=[20, -10; 40, 10]);
        BondLib.Bonds.fBond B4 annotation (extent=[40, -10; 60, 10]);
        CD CD2(
          ag=ag,
          apix=apix,
          lambda=lambda2,
          gamma0=gamma2,
          T0=T02) annotation (extent=[60, -10; 80, 10]);
        BondLib.Bonds.fBond B5 annotation (extent=[60, -50; 80, -30], rotation=180);
        BondLib.Junctions.J0p2 J0p2_3 annotation (extent=[40, -50; 60, -30]);
        BondLib.Bonds.fBond B6 annotation (extent=[20, -50; 40, -30], rotation=180);
        CD CD3(
          ag=ag,
          apix=apix,
          lambda=lambda2,
          gamma0=gamma2,
          T0=T03) annotation (extent=[20, -50; 0, -30]);
        BondLib.Bonds.fBond B7 annotation (extent=[-20, -50; 0, -30], rotation=180);
        BondLib.Sources.Sf Sf1(f0=0) annotation (extent=[-60, -50; -80, -30]);
        BondLib.Junctions.J0p2 J0p2_4 annotation (extent=[-40, -50; -20, -30]);
        BondLib.Bonds.fBond B8 annotation (extent=[-60, -50; -40, -30], rotation=
              180);
      equation 
        connect(J0p2_1.BondCon2, B2.eBondCon1) annotation (points=[-40, 0; -40, 0],
              style(color=8));
        connect(B2.fBondCon1, CD1.BondCon1) annotation (points=[-20, 0; -20, 0],
            style(color=8));
        connect(CD1.BondCon2, B3.eBondCon1) annotation (points=[0, 0; 0, 0], style(
              color=8));
        connect(B3.fBondCon1, J0p2_2.BondCon1) annotation (points=[20, 0; 20, 0],
            style(color=8));
        connect(J0p2_2.BondCon2, B4.eBondCon1) annotation (points=[40, 0; 40, 0],
            style(color=8));
        connect(B4.fBondCon1, CD2.BondCon1) annotation (points=[60, 0; 60, 0],
            style(color=8));
        connect(CD2.BondCon2, B5.eBondCon1) annotation (points=[80, 0; 90, 0; 90, -
              40; 80, -40], style(color=8));
        connect(B5.fBondCon1, J0p2_3.BondCon2) annotation (points=[60, -40; 60, -40],
                 style(color=8));
        connect(J0p2_3.BondCon1, B6.eBondCon1) annotation (points=[40, -40; 40, -40],
                 style(color=8));
        connect(B6.fBondCon1, CD3.BondCon1) annotation (points=[20, -40; 20, -40],
            style(color=8));
        connect(CD3.BondCon2, B7.eBondCon1) annotation (points=[0, -40; 0, -40],
            style(color=8));
        connect(B7.fBondCon1, J0p2_4.BondCon2) annotation (points=[-20, -40; -20, -
              40], style(color=8));
        connect(J0p2_4.BondCon1, B8.eBondCon1) annotation (points=[-40, -40; -40, -
              40], style(color=8));
        connect(B8.fBondCon1, Sf1.BondCon1) annotation (points=[-60, -40; -60, -40],
              style(color=8));
        connect(BondCon1, J0p2_1.BondCon1) annotation (points=[-100,0; -60,0],
            style(color=8));
      end Soil;
      
      model Biosphere "Biosphere 2 main model" 
        constant Modelica.SIunits.Temperature T0 = Modelica.Constants.T_zero 
          "Conversion between Centigrade and Kelvin";
        constant Real sigma=20.4109E-8 "Specific radiation constant";
        constant Real lambda=2501 "Condensation/evaporation constant";
        parameter Real ag=2369 "Ground area of Biosphere";
        parameter Real ac=4771 "Cover area of Biosphere";
        parameter Real pao=87.848;
        parameter Real alph=0.2 "Percentage of absorbed power";
        parameter Real tau=0.6 "Percentage of transmitted power";
        parameter Real avix=0.4 "Percetage of Biosphere covered by vegetation";
        parameter Real apix=0.4 "Percentage of Biosphere covered by pond";
        parameter Real laix=2 "Efficiency factor of vegetation";
        parameter Real vkx=0.6;
        parameter Real rhos=0.13;
        parameter Real vai=35000 "Air volume of Biosphere";
        parameter Real refl=0.05 "Percentage of power reflected at pond";
        parameter Real hai=39.6 "Constant convection factor";
        parameter Real hai2=0.0034 "Wind velocity dependent convection factor";
        parameter Real Ct=2842 "Thermal Capacity of air";
        parameter Real hpd=2;
        parameter Real Cp=4.19*1000*ag*apix*hpd "Thermal Capacity of pond";
        parameter Real fcsky=0.67 "Radiation to sky";
        parameter Real epsc=1 "Radiation to sky correction";
        output Modelica.SIunits.CelsiusTemperature Tdome 
          "Temperature of the dome in degrees Centigrade";
        output Modelica.SIunits.CelsiusTemperature Tlake 
          "Temperature of the lake in degrees Centigrade";
        output Modelica.SIunits.CelsiusTemperature Tveg 
          "Temperature of the vegetation in degrees Centigrade";
        output Modelica.SIunits.CelsiusTemperature Tsoil 
          "Temperature of the top layer of the soil in degrees Centigrade";
        output Modelica.SIunits.CelsiusTemperature Tgr1 
          "Temperature of the topmost layer inside the soil in degrees Centigrade";
        output Modelica.SIunits.CelsiusTemperature Tgr2 
          "Temperature of the middle layer inside the soil in degrees Centigrade";
        output Modelica.SIunits.CelsiusTemperature Tgr3 
          "Temperature of the lowermost layer inside the soil in degrees Centigrade";
        output Modelica.SIunits.CelsiusTemperature Tair 
          "Temperature of the air in degrees Centigrade";
        output Real Hair "Humidity of the air [kg_water/kg_air]";
        output Real Hsat 
          "Saturation vapor pressure of the air [kg_water/kg_air]";
        output Real Hrel "Relative humidity of the air [%]";
        annotation (
          Coordsys(
            extent=[-200, -150; 200, 150],
            grid=[2, 2],
            component=[20, 20]),
          Diagram(
            Polygon(points=[-190, -140; 190, -140; 190, 20; 80, 80; -80, 80; -190,
                  20; -190, -140], style(color=81, thickness=2)),
            Polygon(points=[2, -64; 2, -48; -2, -48; -2, -64; 2, -64], style(
                  pattern=0, fillColor=42)),
            Polygon(points=[-8, -48; 8, -48; 0, -18; -8, -48], style(pattern=0,
                  fillColor=58)),
            Polygon(points=[-18, -64; -18, -48; -22, -48; -22, -64; -18, -64],
                style(pattern=0, fillColor=42)),
            Polygon(points=[-28, -48; -12, -48; -20, -18; -28, -48], style(pattern=
                    0, fillColor=58)),
            Line(points=[-190, -64; 40, -64; 80, -104; 190, -104], style(color=81,
                  thickness=2)),
            Line(points=[48, -72; 190, -72], style(color=81, thickness=2)),
            Line(points=[-80, -60; -80, -60], style(color=8)),
            Line(points=[40, -10; 40, -10], style(color=8)),
            Line(points=[-80, 20; -80, 20], style(color=8)),
            Line(points=[-102, 22; -102, 62; 176, 62; 176, 20; 168, 20], style(
                  color=57)),
            Line(points=[150, 20; 150, 20], style(color=8))),
          Icon(
            Text(extent=[-162,134; 158,94],    string="%name"), Bitmap(extent=[-202,
                  60; 202,-140], name="Images/BG_Ex4.jpg")),
          Window(
            x=0.45,
            y=0.01,
            width=0.44,
            height=0.65),
          experiment(StopTime=8600, Interval=1),
          experimentSetupOutput(
            doublePrecision=true,
            states=false,
            derivatives=false,
            inputs=false,
            auxiliaries=false),
          Documentation(info="<html>
This is the top-level model of the Biosphere 2 model.  This is the program that needs to be compiled and simulated. <p>
 
The iconic representation represents Biosphere 2, modeled as a single biome, i.e., we assume that the entire air inside Biosphere 2 is at the same temperature.  This is certainly not realistic, but doesn't truly matter, as long as the air conditioning is left out of the model. <p>

We are now ready to assemble the Biosphere 2 model from its components.  At this point, the modeling task has become quite simple. <p>

Each of the five modeling elements: <p>

<ol>
<li>the inside air,
<li>the dome,
<li>the pond,
<li>the vegetation, and
<li>the top layer of the soil
</ol> <p>

is represented by a 0-junction with a heat capacity attached to it that calculates the temperature of that modeling element.  The dome 0-junction was split into two 0-junctions connected by a bond due to the large number of connections to it. <p>

A sixth 0-junction is used to represent the moisture of the air.  It has its own special moisture capacitor element attached to it. <p>

The six modeling elements are connected among each other by convection, radiation, condensation, and evaporation as appropriate. <p>

Each modeling element has furthermore a modulated power source attached to it, which represents the solar input to that modeling element.  Rather than modeling the distribution of solar energy in any detail, the model uses a fairly global approach to railroad the available solar input to the five modeling elements. <p>


At the top of the model, we have the usual computation of ambient temperature (for external convection), night sky temperature (for radiation), solar radiation, and that's it. <p>

Of course, the devil is in the detail.  Each of these models contains a substantial number of parameters that need to be set, and getting the correct parameter values together for such a complex model is no easy task. <p>

<font size=6 color=red><b>Enjoy!</b></font>
</html>
"));
        BondLib.Junctions.J0p6 J0p6_1 annotation (extent=[-140, -70; -120, -50]);
        BondLib.Junctions.J0p6 J0p6_2 annotation (extent=[-30, 70; -10, 90]);
        BondLib.Junctions.J0p6 J0p6_3 annotation (extent=[10, 70; 30, 90]);
        BondLib.Junctions.J0p5 J0p5_3 annotation (extent=[120, -58; 140, -78]);
        BondLib.Junctions.J0p5 J0p5_4 annotation (extent=[-20, 0; 0, -20]);
        BondLib.Junctions.J0p2 J0p2_1 annotation (extent=[90, 120; 110, 140]);
        BondLib.Junctions.J0p2 J0p2_2 annotation (extent=[-110, 120; -90, 140]);
        BondLib.Bonds.fBond B1 annotation (extent=[-10, 70; 10, 90], rotation=180);
        BondLib.Bonds.fBond B2 annotation (extent=[-130, 120; -110, 140]);
        BondLib.Sources.mSe mSe1 annotation (extent=[-130, 120; -150, 140]);
        NightSkyTemp NightSkyTemp1 annotation (extent=[-180, 120; -160, 140]);
        BondLib.Bonds.fBond B3 annotation (extent=[-90, 120; -70, 140]);
        BondLib.Thermal.RA RA1(A=ac*fcsky*epsc, sigma=sigma) annotation (extent=[-
              70, 120; -50, 140]);
        BondLib.Bonds.eBond B4 annotation (extent=[-50, 120; -30, 140]);
        AmbientTemp AmbientTemp1 annotation (extent=[180, 120; 160, 140]);
        BondLib.Sources.mSe mSe2 annotation (extent=[130, 120; 150, 140]);
        BondLib.Bonds.fBond B5 annotation (extent=[110, 120; 130, 140], rotation=
              180);
        BondLib.Bonds.fBond B6 annotation (extent=[70, 120; 90, 140], rotation=180);
        CVext CVext1(
          ac=ac,
          hai=hai,
          hai2=hai2) annotation (extent=[70, 120; 50, 140]);
        BondLib.Bonds.eBond B7 annotation (extent=[30, 120; 50, 140], rotation=180);
        BondLib.Bonds.eBond B8 annotation (extent=[40, 80; 60, 100]);
        BondLib.Thermal.Cth Cth1(gamma=Ct, e(start=276)) annotation (extent=[60, 80;
                80, 100]);
        BondLib.Bonds.eBond B9 annotation (extent=[-50, 80; -30, 100]);
        BondLib.Sources.mSP mSP1 annotation (extent=[-50, 80; -70, 100]);
        Glass Glass1(alph=alph, tau=tau) annotation (extent=[-110, 80; -90, 100]);
        SolarInput SolarInput1 annotation (extent=[-180, 80; -160, 100]);
        Modelica.Blocks.Math.Gain Gain1(k=ag)   annotation (extent=[-148, 80; -128,
                100]);
        Absorption Absorption1(
          apix=apix,
          avix=avix,
          laix=laix,
          refl=refl,
          vkx=vkx,
          rhos=rhos) annotation (extent=[-180, -20; -160, 0]);
        BondLib.Bonds.eBond B10 annotation (extent=[-50, 60; -30, 80]);
        BondLib.Sources.mSP mSP2 annotation (extent=[-50, 58; -70, 78]);
        Glass Glass2(alph=alph, tau=tau) annotation (extent=[-150, 10; -130, 30]);
        BondLib.Bonds.eBond B11 annotation (extent=[-160, -70; -140, -50]);
        BondLib.Sources.mSP mSP3 annotation (extent=[-160, -70; -180, -50]);
        BondLib.Bonds.eBond B12 annotation (extent=[-40, -20; -20, 0]);
        BondLib.Sources.mSP mSP4 annotation (extent=[-40, -20; -60, 0]);
        BondLib.Bonds.eBond B13 annotation (extent=[100, -78; 120, -58]);
        BondLib.Sources.mSP mSP5 annotation (extent=[100, -78; 80, -58]);
        BondLib.Bonds.eBond B14 annotation (extent=[120, -100; 140, -80], rotation=
              -90);
        BondLib.Thermal.Cth Cth2(gamma=Cp, e(start=288)) annotation (extent=[120, -
              120; 140, -100], rotation=-90);
        BondLib.Bonds.eBond B15 annotation (extent=[-150, -100; -130, -80],
            rotation=-90);
        BondLib.Thermal.Cth Cth3(gamma=Ct, e(start=285)) annotation (extent=[-150,
              -120; -130, -100], rotation=-90);
        BondLib.Bonds.fBond B16 annotation (extent=[-130, -100; -110, -80],
            rotation=-90);
        Soil Soil1(ag=ag, apix=apix) annotation (extent=[-130, -120; -110, -100],
            rotation=-90);
        BondLib.Bonds.eBond B17 annotation (extent=[-20, -80; 0, -60], rotation=-90);
        BondLib.Thermal.Cth Cth4(gamma=Ct, e(start=280)) annotation (extent=[-20, -
              100; 0, -80], rotation=-90);
        BondLib.Bonds.eBond B18 annotation (extent=[-120, -70; -100, -50], rotation=
             180);
        BondLib.Thermal.RA RA2(A=ag*(1 - avix - apix), sigma=sigma) annotation (
            extent=[-80, -70; -100, -50]);
        BondLib.Bonds.eBond B20 annotation (extent=[0, -20; 20, 0], rotation=180);
        BondLib.Thermal.RA RA3(A=ag*avix, sigma=sigma) annotation (extent=[40, -20;
                20, 0]);
        BondLib.Bonds.eBond B22 annotation (extent=[140, -78; 160, -58], rotation=
              180);
        BondLib.Thermal.RA RA4(A=ag*apix, sigma=sigma) annotation (extent=[180, -78;
                160, -58]);
        BondLib.Bonds.fBond B19 annotation (extent=[-80, -70; -60, -50], rotation=
              180);
        BondLib.Bonds.fBond B21 annotation (extent=[40, -20; 60, 0], rotation=180);
        BondLib.Bonds.fBond B23 annotation (extent=[170, -52; 190, -32], rotation=-
              90);
        CV CV1(G0=ag*(1 - apix)*hai) annotation (extent=[-100, -10; -120, 10]);
        BondLib.Bonds.fBond B24 annotation (extent=[-100, -10; -80, 10], rotation=
              180);
        BondLib.Bonds.eBond B25 annotation (extent=[-140, -10; -120, 10], rotation=
              180);
        BondLib.Bonds.eBond B26 annotation (extent=[-100, 10; -80, 30], rotation=
              180);
        BondLib.Thermal.Cth Cth5(gamma=Ct, e(start=280)) annotation (extent=[-120,
              10; -100, 30], rotation=180);
        BondLib.Bonds.fBond B27 annotation (extent=[-70, 40; -50, 60]);
        CV CV2(G0=ac*hai) annotation (extent=[-50, 40; -30, 60]);
        BondLib.Bonds.eBond B28 annotation (extent=[-30, 40; -10, 60]);
        BondLib.Bonds.fBond B29 annotation (extent=[-60, 20; -40, 40]);
        CV CV3(G0=ag*avix*laix*2*hai) annotation (extent=[-40, 20; -20, 40]);
        BondLib.Bonds.eBond B30 annotation (extent=[-20, 20; 0, 40]);
        BondLib.Bonds.fBond B31 annotation (extent=[-60, 0; -40, 20]);
        CV CV4(G0=ag*apix*hai) annotation (extent=[-40, 0; -20, 20]);
        BondLib.Bonds.eBond B32 annotation (extent=[-20, 0; 0, 20]);
        BondLib.Junctions.J0p6 J0p6_4 annotation (extent=[-80, 10; -60, 30]);
        BondLib.Junctions.J0p6 J0p6_5 annotation (extent=[110, 10; 130, 30]);
        BondLib.Bonds.eBond B33 annotation (extent=[130, 10; 150, 30]);
        BondLib.Bonds.fBond B34 annotation (extent=[80, 40; 100, 60], rotation=180);
        CWcov CWcov1(
          ac=ac,
          hai=hai,
          lambda=lambda,
          pao=pao) annotation (extent=[80, 40; 60, 60]);
        BondLib.Bonds.eBond B35 annotation (extent=[40, 40; 60, 60], rotation=180);
        BondLib.Bonds.eBond B36 annotation (extent=[80, 20; 100, 40]);
        CWveg CWveg1(
          ag=ag,
          hai=hai,
          avix=avix,
          laix=laix,
          lambda=lambda,
          pao=pao) annotation (extent=[60, 20; 80, 40]);
        BondLib.Bonds.fBond B37 annotation (extent=[40, 20; 60, 40]);
        BondLib.Bonds.eBond B38 annotation (extent=[80, 0; 100, 20]);
        CWpond CWpond1(
          ag=ag,
          hai=hai,
          apix=apix,
          lambda=lambda,
          pao=pao) annotation (extent=[60, 0; 80, 20]);
        BondLib.Bonds.fBond B39 annotation (extent=[40, 0; 60, 20]);
        BondLib.Bonds.eBond B40 annotation (extent=[80, -40; 100, -20]);
        CWsoil CWsoil1(
          ag=ag,
          hai=hai,
          apix=apix,
          lambda=lambda,
          pao=pao) annotation (extent=[60, -40; 80, -20]);
        BondLib.Bonds.fBond B41 annotation (extent=[40, -40; 60, -20]);
        CWbulk CWbulk1(
          vai=vai,
          hai=hai,
          lambda=lambda,
          pao=pao) annotation (extent=[0, -130; -20, -110]);
        BondLib.Bonds.fBond B42 annotation (extent=[0, -130; 20, -110], rotation=
              180);
        BondLib.Bonds.eBond B43 annotation (extent=[-40, -130; -20, -110], rotation=
             180);
        Cmoist Cmoist1(
          pao=pao,
          vai=vai,
          e(start=0.015)) annotation (extent=[150, 10; 170, 30]);
        Modelica.Blocks.Sources.Clock Clock1 annotation (extent=[160,80; 180,100]);
        Modelica.Blocks.Nonlinear.Limiter Lim1(uMin=0) 
          annotation (extent=[-182,-132; -170,-120]);
      equation 
        connect(J0p6_3.BondCon1, B1.eBondCon1) annotation (points=[10, 80; 10, 80],
              style(color=8));
        connect(B1.fBondCon1, J0p6_2.BondCon2) annotation (points=[-10, 80; -10, 80],
                 style(color=8));
        connect(B2.fBondCon1, J0p2_2.BondCon1) annotation (points=[-110, 130; -110,
                130], style(color=8));
        connect(mSe1.BondCon1, B2.eBondCon1) annotation (points=[-130, 130; -130,
              130], style(color=8));
        connect(NightSkyTemp1.y,       mSe1.InPort1) annotation (points=[-159,130;
              -149,130],    style(color=3));
        connect(J0p2_2.BondCon2, B3.eBondCon1) annotation (points=[-90, 130; -90,
              130], style(color=8));
        connect(B3.fBondCon1, RA1.BondCon1) annotation (points=[-70, 130; -70, 130],
              style(color=8));
        connect(RA1.BondCon2, B4.fBondCon1) annotation (points=[-50, 130; -50, 130],
              style(color=8));
        connect(AmbientTemp1.y,       mSe2.InPort1) annotation (points=[159,130;
              149,130],  style(color=3));
        connect(mSe2.BondCon1, B5.eBondCon1) annotation (points=[130, 130; 130, 130],
                 style(color=8));
        connect(B5.fBondCon1, J0p2_1.BondCon2) annotation (points=[110, 130; 110,
              130], style(color=8));
        connect(J0p2_1.BondCon1, B6.eBondCon1) annotation (points=[90, 130; 90, 130],
                 style(color=8));
        connect(B6.fBondCon1, CVext1.BondCon1) annotation (points=[70, 130; 70, 130],
                 style(color=8));
        connect(CVext1.BondCon2, B7.fBondCon1) annotation (points=[50, 130; 50, 130],
                 style(color=8));
        connect(B4.eBondCon1, J0p6_2.BondCon6) annotation (points=[-30, 130; -16,
              130; -16, 90], style(color=8));
        connect(B7.eBondCon1, J0p6_3.BondCon5) annotation (points=[30, 130; 16, 130;
                16, 90], style(color=8));
        connect(J0p6_3.BondCon6, B8.fBondCon1) annotation (points=[24, 90; 40, 90],
              style(color=8));
        connect(B8.eBondCon1, Cth1.BondCon1) annotation (points=[60, 90; 60, 90],
            style(color=8));
        connect(B9.eBondCon1, J0p6_2.BondCon5) annotation (points=[-30, 90; -24, 90],
                 style(color=8));
        connect(mSP1.BondCon1, B9.fBondCon1) annotation (points=[-50, 90; -50, 90],
              style(color=8));
        connect(Glass1.OutPort1, mSP1.InPort1) annotation (points=[-89,90; -69,90],
                 style(color=3));
        connect(SolarInput1.y,Gain1.u)             annotation (points=[-159,90;
              -150,90], style(color=3));
        connect(Gain1.y,       Glass1.InPort1) annotation (points=[-127,90; -120,90;
              -120,110; -100,110; -100,99],         style(color=3));
        connect(Glass1.OutPort3, Absorption1.InPort1) annotation (points=[-100,79;
              -100,72; -174,72; -174,-1],     style(color=3));
        connect(mSP2.BondCon1, B10.fBondCon1) annotation (points=[-50, 68; -50, 70],
              style(color=8));
        connect(Absorption1.OutPort4, Glass2.InPort1) annotation (points=[-166,1;
              -166,40; -140,40; -140,29],    style(color=3));
        connect(B11.eBondCon1, J0p6_1.BondCon1) annotation (points=[-140, -60; -140,
                -60], style(color=8));
        connect(mSP3.BondCon1, B11.fBondCon1) annotation (points=[-160, -60; -160,
              -60], style(color=8));
        connect(Absorption1.OutPort2, mSP3.InPort1) annotation (points=[-181,-10;
              -186,-10; -186,-60; -179,-60],    style(color=3));
        connect(B12.eBondCon1, J0p5_4.BondCon1) annotation (points=[-20, -10; -20,
              -10], style(color=8));
        connect(mSP4.BondCon1, B12.fBondCon1) annotation (points=[-40, -10; -40, -
              10], style(color=8));
        connect(Absorption1.OutPort3, mSP4.InPort1) annotation (points=[-170,-21;
              -170,-26; -70,-26; -70,-10; -59,-10],     style(color=3));
        connect(B13.eBondCon1, J0p5_3.BondCon1) annotation (points=[120, -68; 120,
              -68], style(color=8));
        connect(mSP5.BondCon1, B13.fBondCon1) annotation (points=[100, -68; 100, -
              68], style(color=8));
        connect(Absorption1.OutPort1, mSP5.InPort1) annotation (points=[-159,-10;
              -100,-10; -100,-50; 68,-50; 68,-68; 81,-68],      style(color=3));
        connect(J0p5_3.BondCon5, B14.fBondCon1) annotation (points=[130, -78; 130,
              -80], style(color=8));
        connect(B14.eBondCon1, Cth2.BondCon1) annotation (points=[130, -100; 130, -
              100], style(color=8));
        connect(B15.eBondCon1, Cth3.BondCon1) annotation (points=[-140, -100; -140,
                -100], style(color=8));
        connect(J0p6_1.BondCon3, B15.fBondCon1) annotation (points=[-134, -70; -140,
                -70; -140, -80], style(color=8));
        connect(J0p6_1.BondCon4, B16.eBondCon1) annotation (points=[-126, -70; -120,
                -70; -120, -80], style(color=8));
        connect(B16.fBondCon1, Soil1.BondCon1) annotation (points=[-120, -100; -120,
                -100], style(color=8));
        connect(J0p5_4.BondCon5, B17.fBondCon1) annotation (points=[-10, -20; -10,
              -60], style(color=8));
        connect(B17.eBondCon1, Cth4.BondCon1) annotation (points=[-10, -80; -10, -
              80], style(color=8));
        connect(B18.eBondCon1, J0p6_1.BondCon2) annotation (points=[-120, -60; -120,
                -60], style(color=8));
        connect(RA2.BondCon2, B18.fBondCon1) annotation (points=[-100, -60; -100, -
              60], style(color=8));
        connect(B20.eBondCon1, J0p5_4.BondCon2) annotation (points=[0,-10; 0,
              -10],
              style(color=8));
        connect(RA3.BondCon2, B20.fBondCon1) annotation (points=[20,-10; 20,-10],
              style(color=8));
        connect(B10.eBondCon1, J0p6_2.BondCon1) annotation (points=[-30, 70; -30,
              80], style(color=8));
        connect(B22.eBondCon1, J0p5_3.BondCon2) annotation (points=[140, -68; 140,
              -68], style(color=8));
        connect(RA4.BondCon2, B22.fBondCon1) annotation (points=[160, -68; 160, -68],
                 style(color=8));
        connect(B19.fBondCon1, RA2.BondCon1) annotation (points=[-80, -60; -80, -60],
                 style(color=8));
        connect(J0p6_2.BondCon3, B19.eBondCon1) annotation (points=[-24, 70; -24,
              60; -36, 60; -36, -60; -60, -60], style(color=8));
        connect(B21.fBondCon1, RA3.BondCon1) annotation (points=[40,-10; 40,-10],
              style(color=8));
        connect(J0p6_3.BondCon4, B21.eBondCon1) annotation (points=[24,70; 24,
              60; 88,60; 88,-10; 60,-10],  style(color=8));
        connect(B23.fBondCon1, RA4.BondCon1) annotation (points=[180, -52; 180, -68],
                 style(color=8));
        connect(B23.eBondCon1, J0p6_3.BondCon2) annotation (points=[180, -32; 180,
              70; 30, 70; 30, 80], style(color=8));
        connect(B24.fBondCon1, CV1.BondCon1) annotation (points=[-100,
              1.22461e-015; -100,0],
              style(color=8));
        connect(CV1.BondCon2, B25.fBondCon1) annotation (points=[-120,0; -120,
              -1.22461e-015],
              style(color=8));
        connect(B25.eBondCon1, J0p6_1.BondCon5) annotation (points=[-140,
              1.22461e-015; -148,1.22461e-015; -148,-34; -134,-34; -134,-50],
                                                   style(color=8));
        connect(B26.eBondCon1, Cth5.BondCon1) annotation (points=[-100, 20; -100,
              20], style(color=8));
        connect(B27.fBondCon1, CV2.BondCon1) annotation (points=[-50, 50; -50, 50],
              style(color=8));
        connect(CV2.BondCon2, B28.fBondCon1) annotation (points=[-30, 50; -30, 50],
              style(color=8));
        connect(B28.eBondCon1, J0p6_2.BondCon4) annotation (points=[-10, 50; -4, 50;
                -4, 60; -16, 60; -16, 70], style(color=8));
        connect(B29.fBondCon1, CV3.BondCon1) annotation (points=[-40, 30; -40, 30],
              style(color=8));
        connect(CV3.BondCon2, B30.fBondCon1) annotation (points=[-20, 30; -20, 30],
              style(color=8));
        connect(B30.eBondCon1, J0p5_4.BondCon3) annotation (points=[0, 30; 8, 30; 8,
                4; -14, 4; -14, 0], style(color=8));
        connect(B31.fBondCon1, CV4.BondCon1) annotation (points=[-40, 10; -40, 10],
              style(color=8));
        connect(CV4.BondCon2, B32.fBondCon1) annotation (points=[-20, 10; -20, 10],
              style(color=8));
        connect(B32.eBondCon1, J0p5_3.BondCon3) annotation (points=[0, 10; 26, 10;
              26, -44; 126, -44; 126, -58], style(color=8));
        connect(J0p6_4.BondCon1, B26.fBondCon1) annotation (points=[-80, 20; -80,
              20], style(color=8));
        connect(J0p6_4.BondCon3, B24.eBondCon1) annotation (points=[-74,10; -74,
              -1.22461e-015; -80,-1.22461e-015],
                         style(color=8));
        connect(J0p6_4.BondCon4, B31.eBondCon1) annotation (points=[-66, 10; -60,
              10], style(color=8));
        connect(J0p6_4.BondCon2, B29.eBondCon1) annotation (points=[-60, 20; -60,
              30], style(color=8));
        connect(J0p6_4.BondCon6, B27.eBondCon1) annotation (points=[-66, 30; -66,
              40; -74, 40; -74, 50; -70, 50], style(color=8));
        connect(J0p6_5.BondCon2, B33.fBondCon1) annotation (points=[130, 20; 130,
              20], style(color=8));
        connect(J0p6_5.BondCon6, B34.eBondCon1) annotation (points=[124, 30; 124,
              50; 100, 50], style(color=8));
        connect(B34.fBondCon1, CWcov1.BondCon1) annotation (points=[80, 50; 80, 50],
              style(color=8));
        connect(CWcov1.BondCon2, B35.fBondCon1) annotation (points=[60, 50; 60, 50],
              style(color=8));
        connect(B35.eBondCon1, J0p6_3.BondCon3) annotation (points=[40, 50; 16, 50;
                16, 70], style(color=8));
        connect(B36.eBondCon1, J0p6_5.BondCon5) annotation (points=[100, 30; 116,
              30], style(color=8));
        connect(CWveg1.BondCon2, B36.fBondCon1) annotation (points=[80, 30; 80, 30],
              style(color=8));
        connect(B37.fBondCon1, CWveg1.BondCon1) annotation (points=[60, 30; 60, 30],
              style(color=8));
        connect(J0p5_4.BondCon4, B37.eBondCon1) annotation (points=[-6, 0; 14, 0;
              14, 30; 40, 30], style(color=8));
        connect(B38.eBondCon1, J0p6_5.BondCon1) annotation (points=[100, 10; 106,
              10; 106, 20; 110, 20], style(color=8));
        connect(CWpond1.BondCon2, B38.fBondCon1) annotation (points=[80, 10; 80, 10],
                 style(color=8));
        connect(B39.fBondCon1, CWpond1.BondCon1) annotation (points=[60, 10; 60, 10],
                 style(color=8));
        connect(J0p5_3.BondCon4, B39.eBondCon1) annotation (points=[134, -58; 134,
              -36; 34, -36; 34, 10; 40, 10], style(color=8));
        connect(B40.eBondCon1, J0p6_5.BondCon3) annotation (points=[100, -30; 116,
              -30; 116, 10], style(color=8));
        connect(CWsoil1.BondCon2, B40.fBondCon1) annotation (points=[80, -30; 80, -
              30], style(color=8));
        connect(B41.fBondCon1, CWsoil1.BondCon1) annotation (points=[60, -30; 60, -
              30], style(color=8));
        connect(J0p6_1.BondCon6, B41.eBondCon1) annotation (points=[-126, -50; -126,
                -34; 18, -34; 18, -30; 40, -30], style(color=8));
        connect(B42.fBondCon1, CWbulk1.BondCon1) annotation (points=[0, -120; 0, -
              120], style(color=8));
        connect(J0p6_5.BondCon4, B42.eBondCon1) annotation (points=[124, 10; 124, -
              30; 150, -30; 150, -128; 60, -128; 60, -120; 20, -120], style(color=8));
        connect(CWbulk1.BondCon2, B43.fBondCon1) annotation (points=[-20, -120; -20,
                -120], style(color=8));
        connect(B43.eBondCon1, J0p6_4.BondCon5) annotation (points=[-40, -120; -92,
                -120; -92, 34; -74, 34; -74, 30], style(color=8));
        connect(B33.eBondCon1, Cmoist1.BondCon1) annotation (points=[150, 20; 150,
              20], style(color=8));
        connect(Glass2.OutPort1, mSP2.InPort1) annotation (points=[-129,20; -124,20;
              -124,68; -69,68],       style(color=3));
        Cmoist1.InPort1           = Cth5.e;
        Tdome = Cth1.e + T0;
        Tlake = Cth2.e + T0;
        Tveg = Cth4.e + T0;
        Tsoil = Cth3.e + T0;
        Tgr1 = Soil1.CD1.Cth1.e + T0;
        Tgr2 = Soil1.CD2.Cth1.e + T0;
        Tgr3 = Soil1.CD3.Cth1.e + T0;
        Tair = Cth5.e + T0;
        Hair = Cmoist1.e;
        Hsat = CWbulk1.hum;
        Lim1.u = Hair/Hsat;
        Hrel = 100*Lim1.y;
        connect(Clock1.y, AmbientTemp1.u) annotation (points=[181,90; 190,90; 190,
              130; 182,130], style(color=74, rgbcolor={0,0,127}));
        connect(Clock1.y, NightSkyTemp1.u) annotation (points=[181,90; 190,90; 190,
              114; -190,114; -190,130; -182,130], style(color=74, rgbcolor={0,0,127}));
        connect(SolarInput1.u, NightSkyTemp1.u) annotation (points=[-182,90; -190,
              90; -190,130; -182,130], style(color=74, rgbcolor={0,0,127}));
      end Biosphere;
    end Biosphere;
  end Examples;
end BondLib;
